<?php return array(
    'root' => array(
        'name' => 'nextcloud/contacts',
        'pretty_version' => 'v5.5.2',
        'version' => '5.5.2.0',
        'reference' => '409468742edde8889e3a9ecd2b8a65fe63887b41',
        'type' => 'library',
        'install_path' => __DIR__ . '/../../',
        'aliases' => array(),
        'dev' => false,
    ),
    'versions' => array(
        'nextcloud/contacts' => array(
            'pretty_version' => 'v5.5.2',
            'version' => '5.5.2.0',
            'reference' => '409468742edde8889e3a9ecd2b8a65fe63887b41',
            'type' => 'library',
            'install_path' => __DIR__ . '/../../',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
    ),
);
