OC.L10N.register(
    "contacts",
    {
    "Details" : "விவரங்கள்",
    "Contacts" : "தொடர்புகள்",
    "Download" : "பதிவிறக்குக",
    "Rename" : "பெயர்மாற்றம்",
    "Delete" : "நீக்குக",
    "can edit" : "தொகுக்க முடியும்",
    "First name" : "முதல் பெயர்",
    "Last name" : "கடைசிப் பெயர்",
    "Password protection" : "Password protection",
    "Save" : "சேமிக்க ",
    "Description" : "விவரிப்பு",
    "Cancel" : "இரத்து செய்க",
    "Name" : "பெயர்",
    "Title" : "தலைப்பு",
    "Pending" : "நிலுவையிலுள்ள",
    "Close" : "மூடுக",
    "Import" : "இறக்குமதி",
    "User" : "User",
    "Group" : "Group",
    "Email" : "மின்னஞ்சல்",
    "Admin" : "நிர்வாகம்",
    "Owner" : "Owner",
    "Users" : "பயனாளர்",
    "Additional names" : "மேலதிக பெயர்கள்",
    "Nickname" : "பட்டப்பெயர்",
    "Notes" : "குறிப்புகள்",
    "Location" : "இடம்",
    "Home" : "அகம்",
    "Work" : "வேலை",
    "Other" : "மற்றவை",
    "Address" : "முகவரி",
    "City" : "நகரம்",
    "Postal code" : "தபால் குறியீடு",
    "Country" : "நாடு",
    "Birthday" : "பிறந்த நாள்",
    "Phone" : "தொலைப்பேசி",
    "Mobile" : "இடமாற்றக்கூடிய",
    "Fax" : "தொலை நகல்",
    "Pager" : "தொலை அழைப்பான்",
    "Voice" : "குரல்",
    "None" : "ஒன்றுமில்லை",
    "Unknown" : "தெரியாத"
},
"nplurals=2; plural=(n != 1);");
