OC.L10N.register(
    "contacts",
    {
    "Details" : "Detalii",
    "All contacts" : "Toate contactele",
    "Contacts" : "Contacte",
    "Loading contacts …" : "Se încarcă contactele ...",
    "Loading …" : "Se încarcă…",
    "Delete circle" : "Șterge cerc",
    "Send email" : "Trimite email-ul",
    "Circles" : "Cercuri",
    "Create a new circle" : "Crează un cerc nou",
    "Download" : "Descărcare",
    "Rename" : "Redenumește",
    "Delete" : "Șterge",
    "Copied" : "Copiat",
    "Copy link" : "Copiază linkul",
    "Share with users or groups" : "Partajează cu utilizatori sau grupuri",
    "No users or groups" : "Nu sunt utilizatori sau grupuri",
    "can edit" : "poate edita",
    "First name" : "Prenume",
    "Last name" : "Nume",
    "Display name" : "Nume afișat",
    "Password protection" : "Protecție parolă ",
    "Save" : "Salvează",
    "Description" : "Descriere",
    "Cancel" : "Anulează",
    "Invalid image" : "Imagine invalidă",
    "Name" : "Nume",
    "Title" : "Titlu",
    "Company" : "Companie",
    "Address book" : "Listă de contacte",
    "Search contacts …" : "Caută contacte ...",
    "No results" : "Niciun rezultat",
    "Personal circle" : "Cerc personal",
    "Pending" : "În așteptare",
    "Select option" : "Selectatți opțiunea",
    "New contact" : "Contact nou ",
    "Close" : "Închide",
    "Import" : "Importă",
    "Not grouped" : "Negrupate",
    "Recently contacted" : "Contactat recent",
    "Circle" : "Cerc",
    "User" : "Utilizator",
    "Group" : "Grup",
    "Email" : "Email",
    "Contact" : "Contact",
    "Member" : "Membru",
    "Moderator" : "Moderator",
    "Admin" : "Admin",
    "Owner" : "Proprietar",
    "Visibility" : "Vizibil",
    "Users" : "Utilizatori",
    "Detailed name" : "Nume detaliat",
    "Additional names" : "Nume adiționale",
    "Prefix" : "Prefix",
    "Suffix" : "Sufix",
    "Nickname" : "Pseudonim",
    "Notes" : "Notă",
    "Website" : "Website",
    "Location" : "Locație",
    "Federated Cloud ID" : "Federated Cloud ID",
    "Home" : "Acasă",
    "Work" : "Serviciu",
    "Other" : "Altele",
    "Address" : "Adresă",
    "Post office box" : "Oficiul poștal",
    "City" : "Oraș",
    "State or province" : "Județ sau provincie",
    "Postal code" : "Codul poștal",
    "Country" : "Țară",
    "Birthday" : "Zi de naștere",
    "Anniversary" : "Aniversare",
    "Date of death" : "Data decesului",
    "Instant messaging" : "Mesagerie instantă",
    "Phone" : "Telefon",
    "Mobile" : "Mobil",
    "Work mobile" : "Telefon serviciu",
    "Fax" : "Fax",
    "Fax home" : "Fax - acasă",
    "Fax work" : "Fax - serviciu",
    "Pager" : "Pager",
    "Voice" : "Voce",
    "Car" : "Mașina",
    "Work pager" : "Pager de serviciu",
    "Manager" : "Director",
    "Social network" : "Rețea socială",
    "Spouse" : "Soție",
    "Child" : "Copil",
    "Mother" : "Mamă",
    "Father" : "Tată",
    "Parent" : "Părinte",
    "Brother" : "Frate",
    "Sister" : "Soră",
    "Relative" : "Rudă",
    "Friend" : "Prieten",
    "Colleague" : "Coleg",
    "Assistant" : "Asistent",
    "Gender" : "Sex",
    "Female" : "Femeie",
    "Male" : "Bărbat",
    "None" : "Niciuna",
    "Unknown" : "Necunoscut"
},
"nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));");
