OC.L10N.register(
    "contacts",
    {
    "Details" : "Jikme-jiklikler",
    "Download" : "12",
    "Rename" : "Adyny üýtgetmek",
    "Delete" : "Pozmak",
    "Copy link" : "Link-y nusgalaň",
    "Save" : "Saklamak",
    "Cancel" : "ýatyrmak",
    "Name" : "Ady",
    "No results" : " Netije ýok",
    "Pending" : "Garaşylýar",
    "Close" : "Ýap",
    "User" : "Ulanyjy",
    "Website" : "Website",
    "Home" : "Baş sahypa",
    "Address" : "Salgysy",
    "None" : "Hiç",
    "Unknown" : "Näbelli"
},
"nplurals=2; plural=(n != 1);");
