OC.L10N.register(
    "contacts",
    {
    "Details" : "Detil",
    "All contacts" : "Semua kontak",
    "Contacts" : "Kontak",
    "A contacts app for Nextcloud" : "Sebuah aplikasi kontak untuk Nextcloud",
    "Send email" : "Kirim surel",
    "Download" : "Unduh",
    "Rename" : "Ubah nama",
    "Delete" : "Hapus",
    "Copy link" : "Salin tautan",
    "Share with users or groups" : "Bagi dengan pengguna atau grup",
    "No users or groups" : "Tidak ada pengguna atau grup",
    "can edit" : "dapat menyunting",
    "First name" : "Nama depan",
    "Last name" : "Nama belakang",
    "Display name" : "Nama tampilan",
    "Last modified" : "Terakhir diubah",
    "Password protection" : "Password protection",
    "Save" : "Simpan",
    "Description" : "Deskrisi",
    "Cancel" : "Membatalkan",
    "Invalid image" : "Gambar tidak sah",
    "Name" : "Nama",
    "Title" : "Judul",
    "Search contacts …" : "Cari kontak ...",
    "No results" : "Tidak ada hasil",
    "Pending" : "Tunggu",
    "New contact" : "Kontak baru",
    "Close" : "Tutup",
    "Import" : "Impor",
    "Not grouped" : "Tidak dikelompokkan",
    "User" : "Pengguna",
    "Group" : "Grup",
    "Email" : "Surel",
    "Admin" : "Admin",
    "Owner" : "Owner",
    "Users" : "Pengguna",
    "Detailed name" : "Nama lengkap",
    "Additional names" : "Nama tambahan",
    "Prefix" : "Prefix",
    "Suffix" : "Suffix",
    "Nickname" : "Nama panggilan",
    "Notes" : "Catatan",
    "Website" : "Situs Web",
    "Location" : "Lokasi",
    "Federated Cloud ID" : "Federated Cloud ID",
    "Home" : "Depan",
    "Work" : "Kantor",
    "Other" : "Lainnya",
    "Address" : "Alamat",
    "Post office box" : "PO BOX",
    "City" : "Kota",
    "State or province" : "Provinsi",
    "Postal code" : "Kode pos",
    "Country" : "Negara",
    "Birthday" : "Tanggal lahir",
    "Anniversary" : "Ulang tahun",
    "Date of death" : "Tanggal kematian",
    "Instant messaging" : "Pesan Instan",
    "Phone" : "Telpon",
    "Mobile" : "Ponsel",
    "Fax" : "Fax",
    "Fax home" : "Fax rumah",
    "Fax work" : "Fax kerja",
    "Pager" : "Pager",
    "Voice" : "Suara",
    "Social network" : "Media sosial",
    "None" : "Tidak ada",
    "Unknown" : "Tidak diketahui"
},
"nplurals=1; plural=0;");
