OC.L10N.register(
    "contacts",
    {
    "Details" : "פרטים",
    "All contacts" : "כל אנשי הקשר",
    "Contacts" : "אנשי קשר",
    "A contacts app for Nextcloud" : "יישומון אנשי קשר ל־Nextcloud",
    "The Nextcloud contacts app is a user interface for Nextcloud's CardDAV server. Easily sync contacts from various devices with your Nextcloud and edit them online.\n\n* 🚀 **Integration with other Nextcloud apps!** Currently Mail and Calendar – more to come.\n* 🎉 **Never forget a birthday!** You can sync birthdays and other recurring events with your Nextcloud Calendar.\n* 👥 **Sharing of Adressbooks!** You want to share your contacts with your friends or coworkers? No problem!\n* 🙈 **We’re not reinventing the wheel!** Based on the great and open SabreDAV library." : "יישומון אנשי הקשר של Nextcloud הוא מנשק משתמש לשרת ה־CardDAV של Nextcloud. ניתן לסנכרן אנשי קשר ממגוון מכשירים אל Nextcloud ולערוך אותם באופן מקוון.\n\n* 🚀 **שילוב ביישומונים אחרים של Nextcloud!** כרגע דוא״ל ולוח שנה – יהיו נוספים בקרוב.\n* 🎉 **לא שוכחים עוד ימי הולדת!** ניתן לסנכרן ימי הולדת ואירועים מחזוריים נוספים עם לוח השנה שלך ב־Nextcloud.\n* 👥 **שיתוף ספרי כתובות!** חשוב לך לשתף את אנשי הקשר שלך עם חבריך או חבריך לעבודה? אין שום בעיה!\n* 🙈 **אנחנו לא ממציאים את הגלגל מחדש!** על בסיס ספריית SabreDAV הפתוחה והנהדרת.",
    "Copy to full name" : "העתקת שם מלא",
    "Omit year" : "השמטת שנה",
    "Allow updating avatars from social media" : "לאפשר לעדכן תמונה ייצוגית מרשתות חברתיות",
    "Loading contacts …" : "אנשי הקשר נטענים…",
    "There are no contacts yet" : "אין עדיין אנשי קשר",
    "Create contact" : "צור איש קשר",
    "There are no contacts in this group" : "אין אנשי קשר בקבוצה זו",
    "Create contacts" : "צור אנשי קשר",
    "Add contacts" : "הוספת אנשי קשר",
    "Loading …" : "בטעינה",
    "Delete circle" : "מחיקת מעגל",
    "General settings" : "הגדרות כלליות",
    "Update avatars from social media" : "עדכן אווטרים מהמדיה החברתית",
    "(refreshed once per week)" : "(רענן פעם בשבוע)",
    "Send email" : "שליחת דואר אלקטרוני",
    "Circles" : "מעגלים",
    "Create a new circle" : "יצירת מעגל חדש",
    "This group already exists" : "קבוצה זו כבר קיימת",
    "Download" : "הורדה",
    "Rename" : "שנה שם",
    "Delete" : "מחק",
    "Copied" : "הועתק",
    "Copy link" : "העתק קישור",
    "Toggling of address book was not successful" : "החלפת המצב של ספר הכתובות לא הצליחה",
    "This will delete the address book and every contacts within it" : "פעולה זו תמחק את ספר הכתובות על כל אנשי הקשר שבו",
    "Deletion of address book was not successful." : "המחיקה של ספר הכתובות לא הצליחה.",
    "Renaming of address book was not successful." : "שינוי השם של ספר הכתובות לא הצליח.",
    "_Shared with {num} entity_::_Shared with {num} entities_" : ["משותף עם ישות אחת","משותף עם {num} ישויות","משותף עם {num} ישויות","משותף עם {num} ישויות"],
    "Share with users or groups" : "שיתוף עם משתמשים או קבוצות",
    "No users or groups" : "אין משתמשים או קבוצות",
    "can edit" : "יש הרשאת עריכה",
    "Unable to delete the share" : "לא ניתן למחוק את השיתוף",
    "Unable to change permissions" : "לא ניתן לשנות את ההרשאות",
    "Import contacts" : "ייבוא אנשי קשר",
    "Select local file" : "בחירת קובץ מקומי",
    "Import from files" : "ייבוא מקבצים",
    "Importing is disabled because there are no address books available" : "הייבוא מושבת כיוון שאין לך ספרי כתובות זמינים",
    "Choose a vCard file to import" : "נא לבחור קובץ vCard לייבוא",
    "An error occurred, unable to create the address book" : "אירעה שגיאה--לא הצליחה ליצור את פנקס הכתובות",
    "First name" : "שם פרטי",
    "Last name" : "שם משפחה",
    "Phonetic first name" : "שם פרטי פונטי",
    "Phonetic last name" : "שם משפחה פונטי",
    "Display name" : "שם התצוגה",
    "Last modified" : "שינוי אחרון",
    "Sort by {sorting}" : "מיון לפי {sorting}",
    "Password protection" : "הגנה בססמה",
    "Save" : "שמירה",
    "Description" : "תיאור",
    "Cancel" : "ביטול",
    "Upload a new picture" : "העלאת תמונה חדשה",
    "Choose from Files" : "בחר מתוך קבצים",
    "Get from " : "להוריד מתוך",
    "Download picture" : "הורדת תמונה",
    "Delete picture" : "מחיקת תמונה",
    "Invalid image" : "תמונה לא חוקית",
    "Pick an avatar" : "נא לבחור תמונה מייצגת",
    "Error while processing the picture." : "שגיאה בעת עיבוד התמונה.",
    "Avatar downloaded from social network" : "תמונה ייצוגית שהתקבלה מרשת חברתית",
    "Avatar already up to date" : "התמונה הייצוגית כבר עדכנית",
    "Avatar download failed" : "הורדת התמונה הייצוגית נכשלה",
    "No contact selected" : "לא נבחר איש קשר",
    "Select a contact on the list to begin" : "נא לבחור איש קשר מהרשימה כדי להתחיל",
    "Name" : "שם",
    "Title" : "תפקיד",
    "Company" : "חברה",
    "This contact was broken and received a fix. Please review the content and click here to save it." : "איש קשר זה נפגם וקיבל תיקון. נא לסקור את התוכן וללחוץ כדי לשמור אותו.",
    "Clone contact" : "שכפול איש קשר",
    "Generate QR Code" : "יצירת קוד QR",
    "Pick an address book" : "נא לבחור ספר כתובות",
    "Select address book" : "בחירת ספר כתובות",
    "This contact is in read-only mode. You do not have permission to edit this contact." : "איש קשר זה הוא במצב קריאה בלבד. אין לך הרשאה לערוך את איש הקשר הזה.",
    "The contact you were trying to edit has changed. Please manually refresh the contact. Any further edits will be discarded." : "איש הקשר שניסית לערוך כבר נערך. נא לרענן את איש הקשר ידנית. כל העריכות הבאות לא תחולנה.",
    "Address book" : "ספר כתובות",
    "Syntax error. Cannot open the contact." : "שגיאת תחביר. לא ניתן לפתוח את איש הקשר.",
    "Unable to retrieve the contact from the server, please check your network connection." : "לא ניתן לקבל את איש הקשר מהשרת, נא לבדוק את החיבור שלך לרשת.",
    "An error occurred while trying to move the contact" : "אירעה שגיאה בניסיון להעברת איש הקשר",
    "An error occurred while trying to copy the contact" : "אירעה שגיאה בעת הניסיון להעתקת איש הקשר",
    "Search contacts …" : "חיפוש אנשי קשר…",
    "Remove {type}" : "הסר את {type}",
    "Search {types}" : "חפש {types}",
    "No results" : "אין תוצאות",
    "Add to group" : "הוסף לקבוצה",
    "Add {type}" : "הוסף {type}",
    "Personal circle" : "מעגל אישי",
    "Pending" : "בהמתנה",
    "Chart" : "תרשים",
    "Select type" : "בחירת סוג",
    "Select Date" : "בחירת תאריך",
    "Add contact in group" : "הוספת איש קשר בקבוצה",
    "Select option" : "בחירת אפשרות",
    "New contact" : "איש קשר חדש",
    "Unable to create the contact." : "לא ניתן ליצור את איש הקשר.",
    "Contact not found" : "איש הקשר לא נמצא",
    "Close" : "סגירה",
    "_{success} contact added to {name}_::_{success} contacts added to {name}_" : ["{success} איש קשר נוסף ל- {name}","{success} אנשי קשר נוספו ל- {name}","{success} אנשי קשר נוספו ל- {name}","{success} אנשי קשר נוספו ל- {name}"],
    "_Adding {success} contact to {name}_::_Adding {success} contacts to {name}_" : ["הוספת {success} איש קשר ל- {name}","הוספת {success} איש קשר ל- {name}","הוספת {success} איש קשר ל- {name}","הוספת {success} אנשי קשר ל- {name}"],
    "_{count} error_::_{count} errors_" : ["{count} שגיאה","{count} שגיאה","{count} שגיאה","{count} שגיאות"],
    "_Importing %n contact into {addressbook}_::_Importing %n contacts into {addressbook}_" : ["איש קשר מיובא לתוך {addressbook}","%n אנשי קשר מיובאים לתוך {addressbook}","%n אנשי קשר מיובאים לתוך {addressbook}","%n אנשי קשר מיובאים לתוך {addressbook}"],
    "_Done importing %n contact into {addressbook}_::_Done importing %n contacts into {addressbook}_" : ["הסתיים ייבוא של איש קשר לתוך {addressbook}","הסתיים ייבוא של %n אנשי קשר לתוך {addressbook}","הסתיים ייבוא של %n אנשי קשר לתוך {addressbook}","הסתיים ייבוא של %n אנשי קשר לתוך {addressbook}"],
    "Import" : "ייבוא",
    "Not grouped" : "לא מקובץ",
    "Recently contacted" : "נוצר קשר לאחרונה",
    "Circle" : "מעגל",
    "User" : "משתמש",
    "Group" : "קבוצה",
    "Email" : "דואר אלקטרוני",
    "Contact" : "איש/אשת קשר",
    "Member" : "חבר",
    "Moderator" : "פיקוח",
    "Admin" : "מנהל",
    "Owner" : "בעלות",
    "Users" : "משתמשים",
    "Detailed name" : "פרטי שם",
    "Additional names" : "שמות נוספים",
    "Prefix" : "תואר",
    "Suffix" : "סיומת",
    "Nickname" : "כינוי",
    "Notes" : "הערות",
    "Website" : "אתר אינטרנט",
    "Location" : "מיקום",
    "Federated Cloud ID" : "מספר זיהוי ענן מאוגד",
    "Home" : "בית",
    "Work" : "עבודה",
    "Other" : "אחר",
    "Address" : "כתובת",
    "Post office box" : "תיבת דואר",
    "Extended address" : "כתובת מורחבת",
    "City" : "עיר",
    "State or province" : "מדינה או מחוז",
    "Postal code" : "מיקוד",
    "Country" : "מדינה",
    "Birthday" : "יום הולדת",
    "Anniversary" : "יום השנה",
    "Date of death" : "תאריך פטירה",
    "Instant messaging" : "מסרים מיידיים",
    "Phone" : "טלפון",
    "Mobile" : "נייד",
    "Work mobile" : "סלולרי מהעבודה",
    "Home mobile" : "סלולרי פרטי",
    "Fax" : "פקס",
    "Fax home" : "פקס בבית",
    "Fax work" : "פקס בעבודה",
    "Pager" : "זימונית",
    "Voice" : "קולי",
    "Car" : "רכב",
    "Work pager" : "זימונית מהעבודה",
    "Manager" : "מנהל/ת",
    "Social network" : "רשת חברתית",
    "Relationship to you" : "מערכת יחסים אליך",
    "Spouse" : "בן/בת זוג",
    "Child" : "בן/בת",
    "Mother" : "אימא",
    "Father" : "אבא",
    "Parent" : "הורה",
    "Brother" : "אח",
    "Sister" : "אחות",
    "Relative" : "קרוב/ת משפחה",
    "Friend" : "חבר/ה",
    "Colleague" : "חבר/ה לעבודה",
    "Assistant" : "עוזר/ת",
    "Related contacts" : "אנשי קשר קשורים",
    "Agent" : "סוכן/נת",
    "Emergency" : "חירום",
    "Co-worker" : "חבר/ה לעבודה",
    "Gender" : "מגדר",
    "Female" : "נקבה",
    "Male" : "זכר",
    "None" : "אין",
    "Unknown" : "לא ידוע",
    "Spoken languages" : "שפות מדוברות",
    "_{failed} contact failed to be read_::_{failed} contacts failed to be read_" : ["הקריאה של איש קשר אחד נכשלה","הקריאה של {failed} אנשי קשר נכשלה","הקריאה של {failed} אנשי קשר נכשלה","הקריאה של {failed} אנשי קשר נכשלה"],
    "Unable to delete contact" : "לא ניתן למחוק איש קשר"
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: (n % 10 == 0 && n % 1 == 0 && n > 10) ? 2 : 3;");
