OC.L10N.register(
    "contacts",
    {
    "Send email" : "ಇ-ಅಂಚೆಯನ್ನು  ಕಳುಹಿಸಿ",
    "Download" : "ಪ್ರತಿಯನ್ನು ಸ್ಥಳೀಯವಾಗಿ ಉಳಿಸಿಕೊಳ್ಳಿ",
    "Rename" : "﻿ಮರುಹೆಸರಿಸು",
    "Delete" : "﻿ಅಳಿಸಿ",
    "can edit" : "﻿ಸಂಪಾದಿಸಬಹುದು",
    "Password protection" : "Password protection",
    "Save" : "﻿ಉಳಿಸಿ",
    "Cancel" : "﻿ರದ್ದು",
    "Invalid image" : "ಅಸಾಮರ್ಥ್ಯ ಚಿತ್ರ",
    "Name" : "﻿ಹೆಸರು",
    "Title" : "ಶೀರ್ಷಿಕೆ",
    "Pending" : "﻿ಬಾಕಿ ಇದೆ",
    "Close" : "ಮುಚ್ಚು",
    "Import" : "ಆಮದು",
    "User" : "User",
    "Group" : "﻿ಗುಂಪು",
    "Email" : "﻿ಇ-ಅಂಚೆ",
    "Admin" : "﻿ನಿರ್ವಹಕ",
    "Owner" : "Owner",
    "Users" : "﻿ಬಳಕೆದಾರರು",
    "Notes" : "Notes",
    "Home" : "﻿ಮುಖಪುಟ",
    "Other" : "﻿ಇತರೆ",
    "Address" : "ವಿಳಾಸ",
    "None" : "﻿ಯಾವುದೂ ಇಲ್ಲ"
},
"nplurals=2; plural=(n > 1);");
