<?php

// autoload_static.php @generated by Composer

namespace Composer\Autoload;

class ComposerStaticInitContacts
{
    public static $prefixLengthsPsr4 = array (
        'O' => 
        array (
            'OCA\\Contacts\\' => 13,
        ),
    );

    public static $prefixDirsPsr4 = array (
        'OCA\\Contacts\\' => 
        array (
            0 => __DIR__ . '/../..' . '/lib',
        ),
    );

    public static $classMap = array (
        'Composer\\InstalledVersions' => __DIR__ . '/..' . '/composer/InstalledVersions.php',
        'OCA\\Contacts\\AppInfo\\Application' => __DIR__ . '/../..' . '/lib/AppInfo/Application.php',
        'OCA\\Contacts\\ContactsMenu\\Providers\\DetailsProvider' => __DIR__ . '/../..' . '/lib/ContactsMenu/Providers/DetailsProvider.php',
        'OCA\\Contacts\\Controller\\ContactsController' => __DIR__ . '/../..' . '/lib/Controller/ContactsController.php',
        'OCA\\Contacts\\Controller\\PageController' => __DIR__ . '/../..' . '/lib/Controller/PageController.php',
        'OCA\\Contacts\\Controller\\SocialApiController' => __DIR__ . '/../..' . '/lib/Controller/SocialApiController.php',
        'OCA\\Contacts\\Cron\\SocialUpdate' => __DIR__ . '/../..' . '/lib/Cron/SocialUpdate.php',
        'OCA\\Contacts\\Cron\\SocialUpdateRegistration' => __DIR__ . '/../..' . '/lib/Cron/SocialUpdateRegistration.php',
        'OCA\\Contacts\\Dav\\PatchPlugin' => __DIR__ . '/../..' . '/lib/Dav/PatchPlugin.php',
        'OCA\\Contacts\\Listener\\LoadContactsFilesActions' => __DIR__ . '/../..' . '/lib/Listener/LoadContactsFilesActions.php',
        'OCA\\Contacts\\Service\\ImageResizer' => __DIR__ . '/../..' . '/lib/Service/ImageResizer.php',
        'OCA\\Contacts\\Service\\SocialApiService' => __DIR__ . '/../..' . '/lib/Service/SocialApiService.php',
        'OCA\\Contacts\\Service\\Social\\CompositeSocialProvider' => __DIR__ . '/../..' . '/lib/Service/Social/CompositeSocialProvider.php',
        'OCA\\Contacts\\Service\\Social\\DiasporaProvider' => __DIR__ . '/../..' . '/lib/Service/Social/DiasporaProvider.php',
        'OCA\\Contacts\\Service\\Social\\FacebookProvider' => __DIR__ . '/../..' . '/lib/Service/Social/FacebookProvider.php',
        'OCA\\Contacts\\Service\\Social\\GravatarProvider' => __DIR__ . '/../..' . '/lib/Service/Social/GravatarProvider.php',
        'OCA\\Contacts\\Service\\Social\\ISocialProvider' => __DIR__ . '/../..' . '/lib/Service/Social/ISocialProvider.php',
        'OCA\\Contacts\\Service\\Social\\InstagramProvider' => __DIR__ . '/../..' . '/lib/Service/Social/InstagramProvider.php',
        'OCA\\Contacts\\Service\\Social\\MastodonProvider' => __DIR__ . '/../..' . '/lib/Service/Social/MastodonProvider.php',
        'OCA\\Contacts\\Service\\Social\\TelegramProvider' => __DIR__ . '/../..' . '/lib/Service/Social/TelegramProvider.php',
        'OCA\\Contacts\\Service\\Social\\TumblrProvider' => __DIR__ . '/../..' . '/lib/Service/Social/TumblrProvider.php',
        'OCA\\Contacts\\Service\\Social\\XingProvider' => __DIR__ . '/../..' . '/lib/Service/Social/XingProvider.php',
        'OCA\\Contacts\\Settings\\AdminSettings' => __DIR__ . '/../..' . '/lib/Settings/AdminSettings.php',
    );

    public static function getInitializer(ClassLoader $loader)
    {
        return \Closure::bind(function () use ($loader) {
            $loader->prefixLengthsPsr4 = ComposerStaticInitContacts::$prefixLengthsPsr4;
            $loader->prefixDirsPsr4 = ComposerStaticInitContacts::$prefixDirsPsr4;
            $loader->classMap = ComposerStaticInitContacts::$classMap;

        }, null, ClassLoader::class);
    }
}
