OC.L10N.register(
    "contacts",
    {
    "Details" : "Detallar",
    "Contacts" : "Əlaqələr",
    "Send email" : "Email yolla",
    "Download" : "Yüklə",
    "Rename" : "Adı dəyiş",
    "Delete" : "Sil",
    "Copy link" : "linki nüsxələ",
    "can edit" : "dəyişmək olar",
    "Password protection" : "Password protection",
    "Save" : "Saxla",
    "Description" : "Açıqlanma",
    "Cancel" : "Dayandır",
    "Invalid image" : "Yalnış şəkil",
    "Name" : "Ad",
    "Title" : "Başlıq",
    "Pending" : "Gözləmə",
    "Close" : "Bağla",
    "Import" : "Əlavə et",
    "Not grouped" : "Qruplaşdırılmayıb",
    "User" : "User",
    "Group" : "Qrup",
    "Email" : "Email",
    "Admin" : "İnzibatçı",
    "Owner" : "Owner",
    "Users" : "İstifadəçilər",
    "Notes" : "Qeydlər",
    "Location" : "Yerləşdiyiniz ünvan",
    "Home" : "Ev",
    "Work" : "İş",
    "Other" : "Digər",
    "Address" : "Ünvan",
    "Birthday" : "Ad günü",
    "None" : "Heç bir"
},
"nplurals=2; plural=(n != 1);");
