OC.L10N.register(
    "contacts",
    {
    "Details" : "Детаљи",
    "All contacts" : "Сви контакти",
    "Contacts" : "Контакти",
    "A contacts app for Nextcloud" : "Контакти за Некстклауд",
    "The Nextcloud contacts app is a user interface for Nextcloud's CardDAV server. Easily sync contacts from various devices with your Nextcloud and edit them online.\n\n* 🚀 **Integration with other Nextcloud apps!** Currently Mail and Calendar – more to come.\n* 🎉 **Never forget a birthday!** You can sync birthdays and other recurring events with your Nextcloud Calendar.\n* 👥 **Sharing of Adressbooks!** You want to share your contacts with your friends or coworkers? No problem!\n* 🙈 **We’re not reinventing the wheel!** Based on the great and open SabreDAV library." : "Апликација Контакти за Некстклауд је корисничко сучеље за Некстклаудов КардДАВ сервер. Лако синхронизујте контакте са различитих уређаја са Некстклаудом и уређујте их преко мреже.\n\n* 🚀 **Интеграција са осталим Некстклауд апликацијама!** Тренутно са Е-Поштом и Календаром – планирано је још.\n* 🎉 **Да никад не заборавите рођендан!** Можете синхронизовати рођендане и друге догађаје који се понављају са Некстклауд Календаром.\n* 👥 **Дељење адресара!** Желите да поделите своје контакте са пријатељима или колегама? Нема проблема!\n* 🙈 **Не измишљамо топлу воду!** Базирано на сјајној и отвореној СејбрДАВ (SabreDAV) библиотеци.",
    "Copy to full name" : "Копирај у пуно име",
    "Omit year" : "без године",
    "Allow updating avatars from social media" : "Дозволи ажурирање аватара са друштвених медија",
    "Please select a circle" : "Молимо вас да изаберете круг",
    "Loading circle …" : "Круг се учитава ...",
    "Your request to join this circle is pending approval" : "Ваш захтев за приступ кругу чека на одобрење",
    "You are not a member of {circle}" : "Нисте члан круга {circle}",
    "There was an error fetching the member list" : "Дошло је до грешке приликом добављања листе чланова",
    "Loading contacts …" : "Учитавам контакте …",
    "There are no contacts yet" : "Још увек нема контаката",
    "Create contact" : "Направи контакт",
    "There are no contacts in this group" : "Нема контаката у овој групи",
    "Create contacts" : "Направи контакте",
    "Add contacts" : "Додај контакте",
    "Loading …" : "Учитавање…",
    "Add member" : "Додај члана",
    "Leave circle" : "Напусти круг",
    "Delete circle" : "Обриши круг",
    "Contacts settings" : "Подешавања контакта",
    "General settings" : "Опште поставке",
    "Update avatars from social media" : "Ажурирај аватар са друштвених медија",
    "(refreshed once per week)" : "(освежава се једном недељно)",
    "Address books" : "Адресари",
    "Export" : "Извоз",
    "Send email" : "Пошаљи е-пошту",
    "Send email as BCC" : "Пошаљи и-мејл као BCC",
    "Contact groups" : "Групе контаката",
    "Create a new contact group" : "Креирај нову групу контаката",
    "Contact group name" : "Назив групе контаката",
    "Circles" : "Кругови",
    "Create a new circle" : "Направи нови круг",
    "Show all groups" : "Прикажи две групе",
    "Collapse groups" : "Сажми групе",
    "Show all circles" : "Прикажи све кругове",
    "Collapse circles" : "Сажми кругове",
    "This group already exists" : "Група већ постоји",
    "This circle already exists" : "Овај круг већ постоји",
    "An error happened during the creation of the circle" : "Дошло је до грешке приликом креирања круга",
    "{addressbookname} (Disabled)" : "{addressbookname} (Искључен)",
    "Download" : "Преузми",
    "Show" : "Прикажи",
    "Rename" : "Преименуј",
    "Delete" : "Обриши",
    "Copied" : "Копирано",
    "Cannot copy" : "Не може да се копира",
    "Copy link" : "Копирај везу",
    "Toggling of address book was not successful" : "Укључивање/искључивање адресара није било успешно",
    "This will delete the address book and every contacts within it" : "Ово ће обрисати адресар и све контакте из њега",
    "Delete {addressbook}?" : "Да обришем {addressbook}?",
    "Deletion of address book was not successful." : "Брисање адресара није успело.",
    "Renaming of address book was not successful." : "Преименовање адресара није успело.",
    "_%n contact_::_%n contacts_" : ["%n контакт","%n контакта","%n контакта"],
    "_%n group_::_%n groups_" : ["%n група","%n групе","%n група"],
    "_Shared with {num} entity_::_Shared with {num} entities_" : ["Дељено са {num} ентитетом","Дељено са {num} ентитета","Дељено са {num} ентитета"],
    "Share with users or groups" : "Дели са корисницима или групама",
    "Share with users" : "Подели са корисницима",
    "No users or groups" : "Нема корисника или група",
    "can edit" : "може да уређује",
    "Unable to delete the share" : "Не могу да обришем дељење",
    "Unable to change permissions" : "Не могу да променим права приступа",
    "Import contacts" : "Увези контакте",
    "Import into the {addressbookName} address book" : "Увоз у адресар {addressbookName}",
    "Select local file" : "Одабери локални фајл",
    "Import from files" : "Увези из фајлова",
    "Importing is disabled because there are no address books available" : "Увоз је искључен пошто нема доступних адресара",
    "Choose a vCard file to import" : "Изаберите „vCard“ фајл за увоз",
    "Add new address book" : "Додај нови адресар",
    "An error occurred, unable to create the address book" : "Дошло је до грешке, не могу да направим адресар",
    "First name" : "Име",
    "Last name" : "Презиме",
    "Phonetic first name" : "Име онако како се изговара",
    "Phonetic last name" : "Презиме онако како се изговара",
    "Display name" : "Име за приказ",
    "Last modified" : "Последња измена",
    "Sort by {sorting}" : "Сортирање: {sorting}",
    "Manages" : "Управља",
    "Oversees" : "Надгледа",
    "An error happened during the config change" : "Дошло је до грешке током измене конфигурације",
    "Password protection" : "Заштита лозинком",
    "Enforce password protection on files shared to this circle" : "Форсирај да се фајлови подељени са овим кругом заштите лозинком ",
    "Use a unique password for all shares to this circle" : "Користи јединствену лозинку за сва дељења са овим кругом",
    "Unique password …" : "Јединствена лозинка ...",
    "Save" : "Сачувај",
    "Change unique password" : "Промени јединствену лозинку",
    "Failed to save password. Please try again later." : "Није успело чување лозинке. Молимо вас да касније покушате поново.",
    "Circle name" : "Назив круга",
    "Circle owned by {owner}" : "Власник круга је {owner}",
    "Request to join" : "Захтев за приступ",
    "Description" : "Опис",
    "There is no description for this circle" : "Нема описа овог круга",
    "Enter a description for the circle" : "Унесите опис овог круга",
    "An error happened during description sync" : "Дошло је до грешке приликом синхронизације описа",
    "An error happened during name sync" : "Дошло је до грешке приликом синхронизације назива",
    "Add more info" : "Додај још информација",
    "More fields" : "Још поља",
    "Crop contact photo" : "Опсеци фото контакта",
    "Cancel" : "Одустани",
    "Upload a new picture" : "Отпреми нову слику",
    "Choose from Files" : "Изаберите из Фајлова",
    "Get from " : "Узми са",
    "Download picture" : "Преузми слику",
    "Delete picture" : "Обриши слику",
    "Please select a valid format" : "Молимо вас да изаберете исправни формат",
    "Invalid image" : "Неисправна слика",
    "Error cropping picture" : "Грешка приликом опсецања слике",
    "Pick an avatar" : "Одабери аватар",
    "Error while processing the picture." : "Грешка приликом обраде слике.",
    "Avatar downloaded from social network" : "Аватар преузет са друштвене мреже",
    "Avatar already up to date" : "Аватар већ ажуран",
    "Avatar download failed" : "Преузимање аватара није успело",
    "No contact selected" : "Није одабран контакт",
    "Select a contact on the list to begin" : "Одаберите контакт са списка да почнете",
    "Name" : "Име",
    "Title" : "Звање",
    "Company" : "Компанија",
    "This contact was broken and received a fix. Please review the content and click here to save it." : "Контакт је био неисправан и поправљен је. Прегледајте садржај и кликните овде да га сачувате.",
    "Edit" : "Уреди",
    "Clone contact" : "Клонирај контакт",
    "Generate QR Code" : "Генериши КуеР код",
    "Contact vCard as QR code" : "vCard контакта као QR кôд",
    "Pick an address book" : "Изабери адресар",
    "Select address book" : "Одаберите адресар",
    "Go to talk conversation" : "Иди на talk разговор",
    "View profile" : "Погледај профил",
    "Media shares with you" : "Медији подељени са вама",
    "Talk conversations with you" : "Talk разговори са вама",
    "Calendar events with you" : "Догађаји календара са вама",
    "Deck cards with you" : "Шпилови картица са вама",
    "No shared items with this contact" : "Нема ставки подељених са овим контактом",
    "This contact is in read-only mode. You do not have permission to edit this contact." : "Контакт је у режиму само за читање. Немате дозволе да га уређујете.",
    "The contact you were trying to edit has changed. Please manually refresh the contact. Any further edits will be discarded." : "Контакт који уређујете је промењен. Освежите га ручно. Свака даља измена биће одбачена.",
    "Address book" : "Адресар",
    "Add contact to Birthday Calendar" : "Додај контакт у календар Рођендани",
    "Exclude contact from Birthday Calendar" : "Изузми контакт из календара Рођендани",
    "{title} at {organization}" : "{title} у {organization}",
    "Syntax error. Cannot open the contact." : "Синтаксна грешка. Не могу да отворим контакт.",
    "The contact does not exist on the server anymore." : "Контакт више не постоји на серверу.",
    "Unable to retrieve the contact from the server, please check your network connection." : "Грешка приликом дохватања контакта са сервера, проверите интернет везу.",
    "An error occurred while trying to move the contact" : "Грешка приликом покушаја померања контакта",
    "An error occurred while trying to copy the contact" : "Грешка приликом покушаја копирања контакта",
    "Unable to update contact" : "Контакт не може да се ажурира",
    "Search contacts …" : "Претражи контакте ...",
    "Add to {group}" : "Додај у {group}",
    "Remove {type}" : "Уклони {type}",
    "Search {types}" : "Претражи {types}",
    "Search for people to add" : "Претражите особе које желите да додате",
    "No results" : "Нема резултата",
    "Add to group" : "Додај у групу",
    "Add {type}" : "Додај {type}",
    "New circle name" : "Назив новог круга",
    "Personal circle" : "Лични круг",
    "This circle will only be visible to you. Other members will not be able to see or use it." : "Овај круг ће бити видљив само вама. Остали чланови га неће видети и неће моћи да га користе.",
    "Local circle" : "Локални круг",
    "This circle will not be shared with the other instances of the global scale" : "Овај круг се неће делити са осталим инстанцама на глобалном нивоу",
    "Create circle" : "Креирај круг",
    "Loading members list …" : "Учитавање листе чланова ...",
    "The list of members is only visible to members of this circle" : "Листа чланова могу да виде само чланови овог круга",
    "You currently have no access to the member list" : "Тренутно немате приступ листи чланова",
    "Add members" : "Додај чланове",
    "Show circle details" : "Прикажи детаље круга",
    "Add to {circle}" : "Додај у {circle}",
    "Unable to get the recommendations list" : "Није могла да се добави листа препорука",
    "Unable to get the results" : "Нису могли да се добаве резултати",
    "Some members could not be added" : "Неки чланови нису могли да се додају",
    "There was an issue adding members to the circle" : "Дошло је до проблема приликом додавања чланова у круг",
    "Accept membership request" : "Прихвати захтев за чланство",
    "Reject membership request" : "Одбиј захтев за чланство",
    "Manage level" : "Управљање нивоом",
    "Remove member" : "Уклони члана",
    "Pending" : "На чекању",
    "Promote as sole owner" : "Унапреди као јединог власника",
    "Promote to {level}" : "Унапреди у {level}",
    "Demote to {level}" : "Врати на {level}",
    "Could not delete the member {displayName}" : "Члан {displayName} не може да се обрише",
    "Could not change the member level to {level}" : "Ниво члана није могао да се промени у {level}",
    "Could not accept membership request" : "Захтев за чланство није могао да се прихвати",
    "Chart" : "График",
    "Select chart …" : "Изаберите график ...",
    "Select type" : "Одаберите тип",
    "Select Date" : "Одаберите датум",
    "Add contact in group" : "Додај контакт у групу",
    "none" : "ништа",
    "Select option" : "Изаберите опцију",
    "Add property of this type" : "Додај особину овог типа",
    "New contact" : "Нови контакт",
    "Unable to create the contact." : "Не могу да направим контакт.",
    "Contact not found" : "Контакт није нађен",
    "Group {group} not found" : "Група {group} не може да се пронађе",
    "Close" : "Затвори",
    "_{success} contact added to {name}_::_{success} contacts added to {name}_" : ["{success} контакт додат у {name}","{success} контакта додата у {name}","{success} контаката додато у {name}"],
    "_Adding {success} contact to {name}_::_Adding {success} contacts to {name}_" : ["Додајем {success} контакт у {name}","Додајем {success} контакта у {name}","Додајем {success} контаката у {name}"],
    "_{count} error_::_{count} errors_" : ["{count} грешка","{count} грешке","{count} грешака"],
    "_Importing %n contact into {addressbook}_::_Importing %n contacts into {addressbook}_" : ["Увозим %n контакт у {addressbook}","Увозим %n контакта у {addressbook}","Увозим %n контаката у {addressbook}"],
    "_Done importing %n contact into {addressbook}_::_Done importing %n contacts into {addressbook}_" : ["Завршен увоз %n контакта у {addressbook}","Завршен увоз %n контакта у {addressbook}","Завршен увоз %n контаката у {addressbook}"],
    "Import" : "Увоз",
    "Could not copy" : "Не може да се копира",
    "Join circle" : "Приступи кругу",
    "You are about to leave {circle}.\nAre you sure?" : "Напустићете {circle}.\nДа ли сте сигурни?",
    "Please confirm circle leave" : "Молимо вас да потврдите напуштање круга",
    "Could not leave the circle {displayName}" : "Круг {displayName} не може да се напусти",
    "Unable to join the circle" : "Не може да се приступи кругу",
    "You are about to delete {circle}.\nAre you sure?" : "Обрисаћете {circle}.\nДа ли сте сигурни?",
    "Please confirm circle deletion" : "Молимо вас да потврдите брисање круга",
    "Unable to delete the circle" : "Круг не може да се обрише",
    "Link copied to the clipboard" : "Линк је копиран у клипборд",
    "Could not copy link to the clipboard." : "Линк није могао да се копира у клипборд.",
    "Not grouped" : "Негруписани",
    "Recently contacted" : "Недавно контактирани",
    "Organization chart" : "Организациони график",
    "Circles are groups of people that you can create yourself and with whom you can share data. They can be made up of other accounts or groups of accounts of the Nextcloud instance, but also of contacts from your address book or even external people by simply entering their e-mail addresses." : "Кругови су групе људи које сами можете да креирате и са којима можете да делите своје податке. Они могу да се састоје од осталих налога или група налога на Nextcloud инстанци, али такође и од контаката из вашег адресара или чак од спољних људи простим уносом њихових и-мејл адреса.",
    "Circle" : "Круг",
    "User" : "Корисник",
    "Group" : "Група",
    "Email" : "Е-пошта",
    "Contact" : "Контакт",
    "Member" : "Члан",
    "Moderator" : "Модератор",
    "Admin" : "Администратор",
    "Owner" : "Власник",
    "Invites" : "Позивнице",
    "Anyone can request membership" : "Било ко може да захтева чланство",
    "Members need to accept invitation" : "Чланови морају да прихвате позивницу",
    "Memberships must be confirmed/accepted by a Moderator (requires Open)" : "Чланство мора да потврди/прихвати Модератор (захтева се Отворено)",
    "Members can also invite" : "Чланови такође могу да позивају",
    "Visibility" : "Видљивост",
    "Visible to everyone" : "Видљиво свима",
    "Circle membership" : "Чланство круга",
    "Prevent circle from being a member of another circle" : "Спречи да круг буде члан другог круга",
    "Users" : "Корисници",
    "Email addresses" : "И-мејл адресе",
    "Detailed name" : "Пуно име",
    "Additional names" : "Додатна имена",
    "Prefix" : "Префикс",
    "Suffix" : "Суфикс",
    "Nickname" : "Надимак",
    "Notes" : "Белешке",
    "Website" : "Вебсајт",
    "Location" : "Локација",
    "Federated Cloud ID" : "ИД Здруженог облака",
    "Home" : "Кућа",
    "Work" : "Посао",
    "Other" : "Остало",
    "Address" : "Адреса",
    "Post office box" : "Поштански фах",
    "Extended address" : "Додатак адреси",
    "City" : "Место",
    "State or province" : "Област",
    "Postal code" : "Поштански број",
    "Country" : "Држава",
    "Birthday" : "Рођендан",
    "Anniversary" : "Годишњица",
    "Date of death" : "Датум смрти",
    "Instant messaging" : "Брзе поруке",
    "Phone" : "Телефон",
    "Mobile" : "Мобилни",
    "Work mobile" : "Пословни мобилни",
    "Home mobile" : "Лични мобилни",
    "Fax" : "Факс",
    "Fax home" : "Факс кућа",
    "Fax work" : "Факс посао",
    "Pager" : "Пејџер",
    "Voice" : "Гласовна пошта",
    "Car" : "Кола",
    "Work pager" : "Пословни пејџер",
    "Manager" : "Менаџер",
    "Social network" : "Друштвена мрежа",
    "Relationship to you" : "Веза са Вама",
    "Spouse" : "Супружник",
    "Child" : "Дете",
    "Mother" : "Мајка",
    "Father" : "Отац",
    "Parent" : "Родитељ",
    "Brother" : "Брат",
    "Sister" : "Сестра",
    "Relative" : "Родбина",
    "Friend" : "Пријатељ",
    "Colleague" : "Колега",
    "Assistant" : "Асистент",
    "Related contacts" : "Слични контакти",
    "Agent" : "Агент",
    "Emergency" : "Хитни број",
    "Co-worker" : "Сарадник",
    "Gender" : "Пол",
    "Female" : "Женски",
    "Male" : "Мушки",
    "None" : "Ништа",
    "Unknown" : "Непознато",
    "Time zone" : "Временска зона",
    "Spoken languages" : "Знање језика",
    "_{failed} contact failed to be read_::_{failed} contacts failed to be read_" : ["Не могу да прочитам {failed} контакт","Не могу да прочитам {failed} контакта","Не могу да прочитам {failed} контаката"],
    "An error has occurred in circle(s). Check the console for more details." : "Дошло је до грешке у кругу/круговима. Погледајте конзолу за више детаља.",
    "Unable to create circle {circleName}" : "Не може да се креира круг {circleName}",
    "Unable to delete circle {circleId}" : "Не може да се обрише круг {circleId}",
    "Unable to delete contact" : "Не могу да обришем контакт"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
