OC.L10N.register(
    "contacts",
    {
    "Details" : "Detalles",
    "All contacts" : "Todos os contactos",
    "Contacts" : "Contactos",
    "A contacts app for Nextcloud" : "Unha aplicación de contactos para Nextcloud",
    "The Nextcloud contacts app is a user interface for Nextcloud's CardDAV server. Easily sync contacts from various devices with your Nextcloud and edit them online.\n\n* 🚀 **Integration with other Nextcloud apps!** Currently Mail and Calendar – more to come.\n* 🎉 **Never forget a birthday!** You can sync birthdays and other recurring events with your Nextcloud Calendar.\n* 👥 **Sharing of Adressbooks!** You want to share your contacts with your friends or coworkers? No problem!\n* 🙈 **We’re not reinventing the wheel!** Based on the great and open SabreDAV library." : "O Contactos de Nextcloud é unha interface de usuario para o servidor CalDAV de Nextcloud. Sincronice doadamente os contactos en varios dispositivos co seu Nextcloud e edíteos en liña.\n\n* 🚀 **Integración con outras aplicacións de Nextcloud!** Actualmente Correo e Calendario – outras por chegar.\n* 🎉 **Non esqueza nunca un aniversario!** Pode sincronizar aniversarios e outros eventos recorrentes co seu Calendario de Nextcloud.\n* 👥 **Compartir as axendas!** Quere compartir os seus contactos cos seus amigos e compañeiros de traballo? Non hai problema!\n* 🙈 **Non reinventamos a roda!** Baseada na grande e aberta biblioteca SabreDAV.",
    "Copy to full name" : "Copiar a nome completo",
    "Omit year" : "Omitir o ano",
    "Allow updating avatars from social media" : "Permitir actualizar avatares dende os medios sociais",
    "Please select a circle" : "Seleccione un círculo",
    "Loading circle …" : "Cargando o círculo…",
    "Your request to join this circle is pending approval" : "A súa solicitude para unirse a este círculo está pendente de aprobación",
    "You are not a member of {circle}" : "Vde. non é membro de {circle}",
    "There was an error fetching the member list" : "Produciuse un erro ao recuperar a lista de membros",
    "Loading contacts …" : "Cargando contactos…",
    "There are no contacts yet" : "Aínda non hai contactos",
    "Create contact" : "Crear contacto.",
    "There are no contacts in this group" : "Non hai contactos neste grupo",
    "Create contacts" : "Crear contactos",
    "Add contacts" : "Engadir contactos",
    "Loading …" : "Cargando…",
    "Add member" : "Engadir membro",
    "Leave circle" : "Abandonar o círculo",
    "Delete circle" : "Eliminar círculo",
    "Contacts settings" : "Axustes de Contactos",
    "General settings" : "Axustes xerais",
    "Update avatars from social media" : "Actualizar avatares dende as redes sociais",
    "(refreshed once per week)" : "(actualizado unha vez por semana)",
    "Address books" : "Cadernos de enderezos",
    "Export" : "Exportar",
    "Send email" : "Enviar o correo",
    "Send email as BCC" : "Enviar un correo-e como Cca",
    "Contact groups" : "Grupos de contacto",
    "Create a new contact group" : "Crear un novo grupo de contactos",
    "Contact group name" : "Nome do grupo de contacto",
    "Circles" : "Círculos",
    "Create a new circle" : "Crear un novo círculo",
    "Show all groups" : "Amosar todos os grupos",
    "Collapse groups" : "Contraer grupos",
    "Show all circles" : "Amosar todos os círculos",
    "Collapse circles" : "Contraer círculos",
    "This group already exists" : "Xa existe este grupo",
    "This circle already exists" : "Este círculo xa existe",
    "An error happened during the creation of the circle" : "Produciuse un erro durante a creación do círculo",
    "{addressbookname} (Disabled)" : "{addressbookname} (Desactivdo)",
    "Download" : "Descargar",
    "Show" : "Amosar",
    "Rename" : "Renomear",
    "Delete" : "Eliminar",
    "Copied" : "Copiado",
    "Cannot copy" : "Non se pode copiar",
    "Copy link" : "Copiar a ligazón",
    "Toggling of address book was not successful" : "Non foi posíbel facer o cambio do caderno de enderezos.",
    "This will delete the address book and every contacts within it" : "Isto eliminará o caderno de enderezos e todos os contactos dentro del",
    "Delete {addressbook}?" : "Quere eliminar {addressbook}?",
    "Deletion of address book was not successful." : "Non foi posíbel eliminar o caderno de enderezos.",
    "Renaming of address book was not successful." : "Non foi posíbel renomear o caderno de enderezos.",
    "_%n contact_::_%n contacts_" : ["%n contacto","%n contactos"],
    "_%n group_::_%n groups_" : ["%n grupo","%n grupos"],
    "_Shared with {num} entity_::_Shared with {num} entities_" : ["Compartido con {num} entidade","Compartido con {num} entidades"],
    "Share with users or groups" : "Compartir con usuarios ou grupos",
    "Share with users" : "Compartir cos usuarios",
    "No users or groups" : "Non hai usuarios nin grupos",
    "can edit" : "pode editar",
    "Unable to delete the share" : "Non é posíbel eliminar a compartición",
    "Unable to change permissions" : "Non é posíbel cambiar os permisos",
    "Import contacts" : "Importar contactos",
    "Import into the {addressbookName} address book" : "Importar ao caderno de enderezos {addressbookName}",
    "Select local file" : "Seleccionar ficheiro local",
    "Import from files" : "Importar dende ficheiros",
    "Importing is disabled because there are no address books available" : "A importación está desactivado porque non hai cadernos de enderezos dispoñíbeis",
    "Choose a vCard file to import" : "Escolla un ficheiro vCard para importalo",
    "Add new address book" : "Engadir novo caderno de enderezos",
    "An error occurred, unable to create the address book" : "Produciuse un erro: non é posíbel crear o caderno de enderezos",
    "First name" : "Nome",
    "Last name" : "Apelidos",
    "Phonetic first name" : "Nome fonético",
    "Phonetic last name" : "Apelido fonético",
    "Display name" : "Nome para amosar",
    "Last modified" : "Última modificación",
    "Sort by {sorting}" : "Ordenar por {sorting}",
    "Manages" : "Xestiona",
    "Oversees" : "Supervisa",
    "An error happened during the config change" : "Produciuse un erro durante o cambio de configuración",
    "Password protection" : "Protección por contrasinal",
    "Enforce password protection on files shared to this circle" : "Impor a protección por contrasinal nos ficheiros compartidos con este círculo",
    "Use a unique password for all shares to this circle" : "Usar un contrasinal único para todas as accións compartidas neste círculo",
    "Unique password …" : "Contrasinal único …",
    "Save" : "Gardar",
    "Change unique password" : "Cambiar o contrasinal único",
    "Failed to save password. Please try again later." : "Produciuse un fallo ao gardar o contrasinal. Ténteo de novo máis tarde.",
    "Circle name" : "Nome do círculo",
    "Circle owned by {owner}" : "Círculo propiedade de {owner}",
    "Request to join" : "Solicitude para unirse",
    "Description" : "Descrición",
    "There is no description for this circle" : "Non hai ningunha descrición para este círculo",
    "Enter a description for the circle" : "Introduza unha descrición para o círculo",
    "An error happened during description sync" : "Produciuse un erro durante a sincronización da descrición",
    "An error happened during name sync" : "Produciuse un erro durante a sincronización do nome",
    "Add more info" : "Engadir máis información",
    "More fields" : "Máis campos",
    "Crop contact photo" : "Recortar a foto do contacto",
    "Cancel" : "Cancelar",
    "Upload a new picture" : "Enviar unha nova imaxe",
    "Choose from Files" : "Escoller dende Ficheiros",
    "Get from " : "Obter de",
    "Download picture" : "Descargar a imaxe",
    "Delete picture" : "Eliminar a imaxe",
    "Please select a valid format" : "Seleccione un formato válido",
    "Invalid image" : "Imaxe incorrecta",
    "Error cropping picture" : "Produciuse un erro ao recortar a imaxe",
    "Pick an avatar" : "Escolla un avatar",
    "Error while processing the picture." : "Produciuse un erro ao procesar a imaxe.",
    "Avatar downloaded from social network" : "Avatar descargado das redes sociais",
    "Avatar already up to date" : "O avatar xa está actualizado",
    "Avatar download failed" : "Produciuse un fallo ao descargar o avatar",
    "No contact selected" : "Non hai ningún contacto seleccionado",
    "Select a contact on the list to begin" : "Para comezar, seleccione un contacto da lista",
    "Name" : "Nome",
    "Title" : "Título",
    "Company" : "Empresa",
    "This contact was broken and received a fix. Please review the content and click here to save it." : "Este contacto rachou e recibiu unha solución. Revise o contido e prema aquí para gardalo.",
    "Edit" : "Editar",
    "Clone contact" : "Clonar o contacto",
    "Generate QR Code" : "Xerar código QR",
    "Contact vCard as QR code" : "Contacto con vCard como código QR",
    "Pick an address book" : "Escolla un caderno de enderezos",
    "Select address book" : "Seleccionar caderno de enderezos",
    "Go to talk conversation" : "Ir á conversa en Talk",
    "View profile" : "Ver o perfil",
    "Media shares with you" : "Medios compartidos con Vde.",
    "Talk conversations with you" : "Conversas de Talk con Vde.",
    "Calendar events with you" : "Eventos de calendario con Vde.",
    "Deck cards with you" : "Tarxetas da Gabeta con Vde.",
    "No shared items with this contact" : "Non hai elementos compartidos con este contacto",
    "This contact is in read-only mode. You do not have permission to edit this contact." : "Este contacto está en modo de só lectura. Non ten permiso para editar este contacto.",
    "The contact you were trying to edit has changed. Please manually refresh the contact. Any further edits will be discarded." : "O contacto que estaba tentando editar cambiou, Actualice o contacto manualmente. Calquera outra edición será desbotada.",
    "Address book" : "Caderno de enderezos",
    "Add contact to Birthday Calendar" : "Engadir contacto ao calendario de aniversarios",
    "Exclude contact from Birthday Calendar" : "Excluír contacto do calendario de aniversarios",
    "{title} at {organization}" : "{title} en {organization}",
    "Syntax error. Cannot open the contact." : "Erro de sintaxe. Non foi posíbel abrir o contacto.",
    "The contact does not exist on the server anymore." : "O contacto xa non existe no servidor.",
    "Unable to retrieve the contact from the server, please check your network connection." : "Non é posíbel recuperar o contacto do servidor. Comprobe a súa conexión de rede.",
    "An error occurred while trying to move the contact" : "Produciuse un erro ao tentar mover o contacto",
    "An error occurred while trying to copy the contact" : "Produciuse un erro ao tentar copiar o contacto",
    "Unable to update contact" : "Non é posíbel actualizar o contacto",
    "Search contacts …" : "Buscar contactos…",
    "Add to {group}" : "Engadir a {group}",
    "Remove {type}" : "Retirar {type}",
    "Search {types}" : "Buscar {types}",
    "Search for people to add" : "Buscar persoas para engadir",
    "No results" : "Sen resultados",
    "Add to group" : "Engadir ao grupo",
    "Add {type}" : "Engadir {type}",
    "New circle name" : "Novo nome do círculo",
    "Personal circle" : "Círculo persoal",
    "This circle will only be visible to you. Other members will not be able to see or use it." : "Este círculo só será visíbel para Vde. Outros membros non poderán velo nin usalo.",
    "Local circle" : "Círculo local",
    "This circle will not be shared with the other instances of the global scale" : "Este círculo non se compartirá coas outras instancias da escala global",
    "Create circle" : "Crear círculo",
    "Loading members list …" : "Cargando a lista de membros…",
    "The list of members is only visible to members of this circle" : "A lista de membros só é visíbel para os participantes neste círculo",
    "You currently have no access to the member list" : "Agora non ten acceso á lista de membros",
    "Add members" : "Engadir membros",
    "Show circle details" : "Amosar detalles do círculo",
    "Add to {circle}" : "Engadir a {circle}",
    "Unable to get the recommendations list" : "Non é posíbel obter a lista de recomendacións",
    "Unable to get the results" : "Non é posíbel obter os resultados",
    "Some members could not be added" : "Non foi posíbel engadir algúns membros",
    "There was an issue adding members to the circle" : "Produciuse un problema ao engadir membros ao círculo",
    "Accept membership request" : "Aceptar a solicitude de pertenza",
    "Reject membership request" : "Rexeitar a solicitude de pertenza",
    "Manage level" : "Xestionar o nivel",
    "Remove member" : "Retirar membro",
    "Pending" : "Pendentes",
    "Promote as sole owner" : "Promover como propietario único",
    "Promote to {level}" : "Promover a {level}",
    "Demote to {level}" : "Relegar a {level}",
    "Could not delete the member {displayName}" : "Non foi posíbel eliminar o membro {displayName}",
    "Could not change the member level to {level}" : "Non foi posíbel cambiar o nivel do membro a {level}",
    "Could not accept membership request" : "Non foi posíbel aceptar a solicitude de pertenza",
    "Chart" : "Gráfico",
    "Select chart …" : "Seleccionar o gráfico…",
    "Select type" : "Seleccione o tipo",
    "Select Date" : "Seleccione a data",
    "Add contact in group" : "Engadir contacto en grupo",
    "none" : "ningún",
    "Select option" : "Seleccione a opción",
    "Add property of this type" : "Engada unha propiedade deste tipo",
    "New contact" : "Novo contacto",
    "Unable to create the contact." : "Non é posíbel crear o contacto.",
    "Contact not found" : "Non se atopou o contacto",
    "Group {group} not found" : "Non se atopou o grupo {group}",
    "Close" : "Pechar",
    "_{success} contact added to {name}_::_{success} contacts added to {name}_" : ["Engadiuse {success} contacto a {name}","Engadironse {success} contactos a {name}"],
    "_Adding {success} contact to {name}_::_Adding {success} contacts to {name}_" : ["Engadindo {success} contacto a {name}","Engadindo {success} contactos a {name}"],
    "_{count} error_::_{count} errors_" : ["{count} erro","{count} erros"],
    "_Importing %n contact into {addressbook}_::_Importing %n contacts into {addressbook}_" : ["Importando %n contacto en {addressbook}","Importando %n contactos en {addressbook}"],
    "_Done importing %n contact into {addressbook}_::_Done importing %n contacts into {addressbook}_" : ["Finalizada a importación de %n contactos en {addressbook}","Finalizada a importación de  %n contactos en {addressbook}"],
    "Import" : "Importar",
    "Could not copy" : "Non foi posíbel copiar",
    "Join circle" : "Unirse ao círculo",
    "You are about to leave {circle}.\nAre you sure?" : "Está a piques de saír de {circle}.\nConfirma que quere facelo?",
    "Please confirm circle leave" : "Confirme a saída do círculo",
    "Could not leave the circle {displayName}" : "Non foi posíbel deixar o círculo {displayName}",
    "Unable to join the circle" : "Non é posíbel unirse ao círculo",
    "You are about to delete {circle}.\nAre you sure?" : "Está a piques de eliminar {circle}.\nConfirma que quere facelo?",
    "Please confirm circle deletion" : "Confirme a eliminación do círculo",
    "Unable to delete the circle" : "Non é posíbel eliminar o círculo",
    "Link copied to the clipboard" : "Copiouse a ligazón no portapapeis",
    "Could not copy link to the clipboard." : "Non foi posíbel copiar a ligazón no portapapeis.",
    "Not grouped" : "Sen agrupar",
    "Recently contacted" : "Contactado recentemente",
    "Organization chart" : "Organigrama",
    "Circles are groups of people that you can create yourself and with whom you can share data. They can be made up of other accounts or groups of accounts of the Nextcloud instance, but also of contacts from your address book or even external people by simply entering their e-mail addresses." : "Os círculos son grupos de persoas que pode crear Vde. mesmo e cos que pode compartir datos. Poden estar formados por outras contas ou grupos de contas da instancia de Nextcloud, mais tamén por contactos do seu caderno de enderezos ou mesmo por persoas externas simplemente introducindo os seus enderezos de correo-e.",
    "Circle" : "Círculo",
    "User" : "Usuario",
    "Group" : "Grupo",
    "Email" : "Correo",
    "Contact" : "Contacto",
    "Member" : "Membro",
    "Moderator" : "Moderador",
    "Admin" : "Administración",
    "Owner" : "Propietario",
    "Invites" : "Convites",
    "Anyone can request membership" : "Calquera persoa pode solicitar a pertenza",
    "Members need to accept invitation" : "Os membros deben aceptar o convite",
    "Memberships must be confirmed/accepted by a Moderator (requires Open)" : "As pertenzas deben ser confirmadas/aceptadas por un moderador (precisa Aberto)",
    "Members can also invite" : "Os membros tamén poden convidar",
    "Visibility" : "Visibilidade",
    "Visible to everyone" : "Visíbel para todos",
    "Circle membership" : "Pertenza ao círculo",
    "Prevent circle from being a member of another circle" : "Evitar que o círculo sexa membro doutro círculo",
    "Users" : "Usuarios",
    "Email addresses" : "Enderezos de correo",
    "Detailed name" : "Nome completo",
    "Additional names" : "Nomes adicionais",
    "Prefix" : "Prefixo",
    "Suffix" : "Sufixo",
    "Nickname" : "Alcume",
    "Notes" : "Notas",
    "Website" : "Sitio web",
    "Location" : "Localización",
    "Federated Cloud ID" : "ID de nube federada",
    "Home" : "Particular",
    "Work" : "Traballo",
    "Other" : "Outro",
    "Address" : "Enderezo",
    "Post office box" : "Apartado de correos",
    "Extended address" : "Enderezo estendido",
    "City" : "Cidade",
    "State or province" : "Provincia ou estado",
    "Postal code" : "Código postal",
    "Country" : "País",
    "Birthday" : "Aniversario (nacemento)",
    "Anniversary" : "Aniversario (casamento)",
    "Date of death" : "Data do pasamento",
    "Instant messaging" : "Mensaxería instantánea",
    "Phone" : "Teléfono",
    "Mobile" : "Móbil",
    "Work mobile" : "Teléfono móbil do traballo",
    "Home mobile" : "Teléfono móbil particular",
    "Fax" : "Fax",
    "Fax home" : "Fax particular",
    "Fax work" : "Fax do traballo",
    "Pager" : "Buscapersoas",
    "Voice" : "Voz",
    "Car" : "Coche",
    "Work pager" : "Buscapersoas do traballo",
    "Manager" : "Xestor/a",
    "Social network" : "Rede social",
    "Relationship to you" : "Relación con Vde.",
    "Spouse" : "Muller",
    "Child" : "Fillo/a",
    "Mother" : "Nai",
    "Father" : "Pai",
    "Parent" : "Parente",
    "Brother" : "Irmán",
    "Sister" : "Irmá",
    "Relative" : "Achegado/a",
    "Friend" : "Amigo/a",
    "Colleague" : "Colega",
    "Assistant" : "Asistente",
    "Related contacts" : "Contactos relacionados",
    "Agent" : "Axente",
    "Emergency" : "Emerxencia",
    "Co-worker" : "Compañeiro de traballo",
    "Gender" : "Xénero",
    "Female" : "Muller",
    "Male" : "Home",
    "None" : "Ningún",
    "Unknown" : "Descoñecido",
    "Time zone" : "Fuso horario:",
    "Spoken languages" : "Idiomas falados",
    "_{failed} contact failed to be read_::_{failed} contacts failed to be read_" : ["Produciuse un fallo ao ler {failed} contacto","Produciuse un fallo ao ler {failed} contactos"],
    "An error has occurred in circle(s). Check the console for more details." : "Produciuse un erro no(s) círculo(s). Consulta a consola para obter máis detalles.",
    "Unable to create circle {circleName}" : "Non é posíbel crear o círculo {circleName}",
    "Unable to delete circle {circleId}" : "Non é posíbel eliminar o círculo {circleId}",
    "Unable to delete contact" : "Non é posíbel eliminar o contacto"
},
"nplurals=2; plural=(n != 1);");
