OC.L10N.register(
    "contacts",
    {
    "Contacts" : "Contacts",
    "Loading contacts …" : "Loading contacts …",
    "Download" : "Download",
    "Rename" : "Rename",
    "Delete" : "Delete",
    "Save" : "Save",
    "Cancel" : "Cancel",
    "Invalid image" : "Invalid image",
    "Name" : "Name",
    "Search contacts …" : "Search contacts …",
    "Pending" : "Pending",
    "Member" : "Member",
    "Admin" : "Admin",
    "Users" : "Users",
    "Notes" : "Notes",
    "Unknown" : "Unknown"
},
"nplurals=1; plural=0;");
