OC.L10N.register(
    "contacts",
    {
    "Details" : "Detalhs",
    "All contacts" : "Totes los contactes",
    "Contacts" : "Contactes",
    "Loading …" : "Cargament…",
    "General settings" : "Paramètres generals",
    "Send email" : "Enviar email",
    "Circles" : "Cercles",
    "Download" : "Telecargar",
    "Rename" : "Renomenar",
    "Delete" : "Suprimir",
    "Copy link" : "Copiar lo ligam",
    "can edit" : "pòt modificar",
    "First name" : "Prenom",
    "Last name" : "Nom",
    "Display name" : "Nom afichat",
    "Password protection" : "Proteccion per senhal",
    "Save" : "Enregistrar",
    "Description" : "Descripcion",
    "Cancel" : "Anullar",
    "Invalid image" : "Imatge invalid",
    "Name" : "Nom",
    "Title" : "Títol",
    "Company" : "Entrepresa",
    "Search contacts …" : "Cercar pels contactes…",
    "No results" : "Cap de resultat",
    "Pending" : "En espèra",
    "New contact" : "Contacte novèl",
    "Close" : "Tampar",
    "Import" : "Importar",
    "Not grouped" : "Pas gropats",
    "Recently contacted" : "Contactat recentament",
    "User" : "User",
    "Group" : "Grop",
    "Email" : "Adreça corrièl",
    "Contact" : "Contacte",
    "Admin" : "Admin",
    "Owner" : "Owner",
    "Visibility" : "Visibilitat",
    "Users" : "Utilizaires",
    "Additional names" : "Noms suplementaris",
    "Nickname" : "Escais",
    "Notes" : "Nòtas",
    "Website" : "Site web",
    "Location" : "Emplaçament",
    "Federated Cloud ID" : "Federated Cloud ID",
    "Home" : "Domicili",
    "Work" : "Professional(a)",
    "Other" : "Autre",
    "Address" : "Adreça",
    "City" : "Vila",
    "State or province" : "Estat o region",
    "Postal code" : "Còde postal",
    "Country" : "País",
    "Birthday" : "Anniversari",
    "Anniversary" : "Anniversari",
    "Instant messaging" : "Messatjariá instantanèa",
    "Phone" : "Telefòn",
    "Mobile" : "Mobil",
    "Fax" : "Fax",
    "Pager" : "Messatgièr",
    "Voice" : "Votz",
    "Relative" : "Relatiu",
    "None" : "Pas cap",
    "Unknown" : "Desconegut",
    "Spoken languages" : "Lengas parladas"
},
"nplurals=2; plural=(n > 1);");
