OC.L10N.register(
    "contacts",
    {
    "Details" : "Details",
    "All contacts" : "All contacts",
    "Contacts" : "Contacts",
    "A contacts app for Nextcloud" : "A contacts app for Nextcloud",
    "The Nextcloud contacts app is a user interface for Nextcloud's CardDAV server. Easily sync contacts from various devices with your Nextcloud and edit them online.\n\n* 🚀 **Integration with other Nextcloud apps!** Currently Mail and Calendar – more to come.\n* 🎉 **Never forget a birthday!** You can sync birthdays and other recurring events with your Nextcloud Calendar.\n* 👥 **Sharing of Adressbooks!** You want to share your contacts with your friends or coworkers? No problem!\n* 🙈 **We’re not reinventing the wheel!** Based on the great and open SabreDAV library." : "The Nextcloud contacts app is a user interface for Nextcloud's CardDAV server. Easily sync contacts from various devices with your Nextcloud and edit them online.\n\n* 🚀 **Integration with other Nextcloud apps!** Currently Mail and Calendar – more to come.\n* 🎉 **Never forget a birthday!** You can sync birthdays and other recurring events with your Nextcloud Calendar.\n* 👥 **Sharing of Adressbooks!** You want to share your contacts with your friends or coworkers? No problem!\n* 🙈 **We’re not reinventing the wheel!** Based on the great and open SabreDAV library.",
    "Copy to full name" : "Copy to full name",
    "Omit year" : "Omit year",
    "Allow updating avatars from social media" : "Allow updating avatars from social media",
    "Please select a circle" : "Please select a circle",
    "Loading circle …" : "Loading circle …",
    "Your request to join this circle is pending approval" : "Your request to join this circle is pending approval",
    "You are not a member of {circle}" : "You are not a member of {circle}",
    "There was an error fetching the member list" : "There was an error fetching the member list",
    "Loading contacts …" : "Loading contacts …",
    "There are no contacts yet" : "There are no contacts yet",
    "Create contact" : "Create contact",
    "There are no contacts in this group" : "There are no contacts in this group",
    "Create contacts" : "Create contacts",
    "Add contacts" : "Add contacts",
    "Loading …" : "Loading …",
    "Add member" : "Add member",
    "Leave circle" : "Leave circle",
    "Delete circle" : "Delete circle",
    "Contacts settings" : "Contacts settings",
    "General settings" : "General settings",
    "Update avatars from social media" : "Update avatars from social media",
    "(refreshed once per week)" : "(refreshed once per week)",
    "Address books" : "Address books",
    "Export" : "Export",
    "Send email" : "Send email",
    "Send email as BCC" : "Send email as BCC",
    "Contact groups" : "Contact groups",
    "Create a new contact group" : "Create a new contact group",
    "Contact group name" : "Contact group name",
    "Circles" : "Circles",
    "Create a new circle" : "Create a new circle",
    "Show all groups" : "Show all groups",
    "Collapse groups" : "Collapse groups",
    "Show all circles" : "Show all circles",
    "Collapse circles" : "Collapse circles",
    "This group already exists" : "This group already exists",
    "This circle already exists" : "This circle already exists",
    "An error happened during the creation of the circle" : "An error happened during the creation of the circle",
    "{addressbookname} (Disabled)" : "{addressbookname} (Disabled)",
    "Download" : "Download",
    "Show" : "Show",
    "Rename" : "Rename",
    "Delete" : "Delete",
    "Copied" : "Copied",
    "Cannot copy" : "Cannot copy",
    "Copy link" : "Copy link",
    "Toggling of address book was not successful" : "Toggling of address book was not successful",
    "This will delete the address book and every contacts within it" : "This will delete the address book and every contacts within it",
    "Delete {addressbook}?" : "Delete {addressbook}?",
    "Deletion of address book was not successful." : "Deletion of address book was not successful.",
    "Renaming of address book was not successful." : "Renaming of address book was not successful.",
    "_%n contact_::_%n contacts_" : ["%n contact","%n contacts"],
    "_%n group_::_%n groups_" : ["%n group","%n groups"],
    "_Shared with {num} entity_::_Shared with {num} entities_" : ["Shared with {num} entity","Shared with {num} entities"],
    "Share with users or groups" : "Share with users or groups",
    "Share with users" : "Share with users",
    "No users or groups" : "No users or groups",
    "can edit" : "can edit",
    "Unable to delete the share" : "Unable to delete the share",
    "Unable to change permissions" : "Unable to change permissions",
    "Import contacts" : "Import contacts",
    "Import into the {addressbookName} address book" : "Import into the {addressbookName} address book",
    "Select local file" : "Select local file",
    "Import from files" : "Import from files",
    "Importing is disabled because there are no address books available" : "Importing is disabled because there are no address books available",
    "Choose a vCard file to import" : "Choose a vCard file to import",
    "Add new address book" : "Add new address book",
    "An error occurred, unable to create the address book" : "An error occurred, unable to create the address book",
    "First name" : "First-name",
    "Last name" : "Surname",
    "Phonetic first name" : "Phonetic first name",
    "Phonetic last name" : "Phonetic last name",
    "Display name" : "Display name",
    "Last modified" : "Last modified",
    "Sort by {sorting}" : "Sort by {sorting}",
    "Manages" : "Manages",
    "Oversees" : "Oversees",
    "An error happened during the config change" : "An error happened during the config change",
    "Password protection" : "Password protection",
    "Enforce password protection on files shared to this circle" : "Enforce password protection on files shared to this circle",
    "Use a unique password for all shares to this circle" : "Use a unique password for all shares to this circle",
    "Unique password …" : "Unique password …",
    "Save" : "Save",
    "Change unique password" : "Change unique password",
    "Failed to save password. Please try again later." : "Failed to save password. Please try again later.",
    "Circle name" : "Circle name",
    "Circle owned by {owner}" : "Circle owned by {owner}",
    "Request to join" : "Request to join",
    "Description" : "Description",
    "There is no description for this circle" : "There is no description for this circle",
    "Enter a description for the circle" : "Enter a description for the circle",
    "An error happened during description sync" : "An error happened during description sync",
    "An error happened during name sync" : "An error happened during name sync",
    "Add more info" : "Add more info",
    "More fields" : "More fields",
    "Crop contact photo" : "Crop contact photo",
    "Cancel" : "Cancel",
    "Upload a new picture" : "Upload a new picture",
    "Choose from Files" : "Choose from Files",
    "Get from " : "Get from ",
    "Download picture" : "Download picture",
    "Delete picture" : "Delete picture",
    "Please select a valid format" : "Please select a valid format",
    "Invalid image" : "Invalid image",
    "Error cropping picture" : "Error cropping picture",
    "Pick an avatar" : "Pick an avatar",
    "Error while processing the picture." : "Error while processing the picture.",
    "Avatar downloaded from social network" : "Avatar downloaded from social network",
    "Avatar already up to date" : "Avatar already up to date",
    "Avatar download failed" : "Avatar download failed",
    "No contact selected" : "No contact selected",
    "Select a contact on the list to begin" : "Select a contact on the list to begin",
    "Name" : "Name",
    "Title" : "Title",
    "Company" : "Company",
    "This contact was broken and received a fix. Please review the content and click here to save it." : "This contact was broken and received a fix. Please review the content and click here to save it.",
    "Edit" : "Edit",
    "Clone contact" : "Clone contact",
    "Generate QR Code" : "Generate QR Code",
    "Contact vCard as QR code" : "Contact vCard as QR code",
    "Pick an address book" : "Pick an address book",
    "Select address book" : "Select address book",
    "Go to talk conversation" : "Go to talk conversation",
    "View profile" : "View profile",
    "Media shares with you" : "Media shares with you",
    "Talk conversations with you" : "Talk conversations with you",
    "Calendar events with you" : "Calendar events with you",
    "Deck cards with you" : "Deck cards with you",
    "No shared items with this contact" : "No shared items with this contact",
    "This contact is in read-only mode. You do not have permission to edit this contact." : "This contact is in read-only mode. You do not have permission to edit this contact.",
    "The contact you were trying to edit has changed. Please manually refresh the contact. Any further edits will be discarded." : "The contact you were trying to edit has changed. Please manually refresh the contact. Any further edits will be discarded.",
    "Address book" : "Address book",
    "Add contact to Birthday Calendar" : "Add contact to Birthday Calendar",
    "Exclude contact from Birthday Calendar" : "Exclude contact from Birthday Calendar",
    "{title} at {organization}" : "{title} at {organization}",
    "Syntax error. Cannot open the contact." : "Syntax error. Cannot open the contact.",
    "The contact does not exist on the server anymore." : "The contact does not exist on the server anymore.",
    "Unable to retrieve the contact from the server, please check your network connection." : "Unable to retrieve the contact from the server, please check your network connection.",
    "An error occurred while trying to move the contact" : "An error occurred while trying to move the contact",
    "An error occurred while trying to copy the contact" : "An error occurred while trying to copy the contact",
    "Unable to update contact" : "Unable to update contact",
    "Search contacts …" : "Search contacts …",
    "Add to {group}" : "Add to {group}",
    "Remove {type}" : "Remove {type}",
    "Search {types}" : "Search {types}",
    "Search for people to add" : "Search for people to add",
    "No results" : "No results",
    "Add to group" : "Add to group",
    "Add {type}" : "Add {type}",
    "New circle name" : "New circle name",
    "Personal circle" : "Personal circle",
    "This circle will only be visible to you. Other members will not be able to see or use it." : "This circle will only be visible to you. Other members will not be able to see or use it.",
    "Local circle" : "Local circle",
    "This circle will not be shared with the other instances of the global scale" : "This circle will not be shared with the other instances of the global scale",
    "Create circle" : "Create circle",
    "Loading members list …" : "Loading members list …",
    "The list of members is only visible to members of this circle" : "The list of members is only visible to members of this circle",
    "You currently have no access to the member list" : "You currently have no access to the member list",
    "Add members" : "Add members",
    "Show circle details" : "Show circle details",
    "Add to {circle}" : "Add to {circle}",
    "Unable to get the recommendations list" : "Unable to get the recommendations list",
    "Unable to get the results" : "Unable to get the results",
    "Some members could not be added" : "Some members could not be added",
    "There was an issue adding members to the circle" : "There was an issue adding members to the circle",
    "Accept membership request" : "Accept membership request",
    "Reject membership request" : "Reject membership request",
    "Manage level" : "Manage level",
    "Remove member" : "Remove member",
    "Pending" : "Pending",
    "Promote as sole owner" : "Promote as sole owner",
    "Promote to {level}" : "Promote to {level}",
    "Demote to {level}" : "Demote to {level}",
    "Could not delete the member {displayName}" : "Could not delete the member {displayName}",
    "Could not change the member level to {level}" : "Could not change the member level to {level}",
    "Could not accept membership request" : "Could not accept membership request",
    "Chart" : "Chart",
    "Select chart …" : "Select chart …",
    "Select type" : "Select type",
    "Select Date" : "Select Date",
    "Add contact in group" : "Add contact in group",
    "none" : "none",
    "Select option" : "Select option",
    "Add property of this type" : "Add property of this type",
    "New contact" : "New contact",
    "Unable to create the contact." : "Unable to create the contact.",
    "Contact not found" : "Contact not found",
    "Group {group} not found" : "Group {group} not found",
    "Close" : "Close",
    "_{success} contact added to {name}_::_{success} contacts added to {name}_" : ["{success} contact added to {name}","{success} contacts added to {name}"],
    "_Adding {success} contact to {name}_::_Adding {success} contacts to {name}_" : ["Adding {success} contact to {name}","Adding {success} contacts to {name}"],
    "_{count} error_::_{count} errors_" : ["{count} error","{count} errors"],
    "_Importing %n contact into {addressbook}_::_Importing %n contacts into {addressbook}_" : ["Importing %n contact into {addressbook}","Importing %n contacts into {addressbook}"],
    "_Done importing %n contact into {addressbook}_::_Done importing %n contacts into {addressbook}_" : ["Done importing %n contact into {addressbook}","Done importing %n contacts into {addressbook}"],
    "Import" : "Import",
    "Could not copy" : "Could not copy",
    "Join circle" : "Join circle",
    "You are about to leave {circle}.\nAre you sure?" : "You are about to leave {circle}.\nAre you sure?",
    "Please confirm circle leave" : "Please confirm circle leave",
    "Could not leave the circle {displayName}" : "Could not leave the circle {displayName}",
    "Unable to join the circle" : "Unable to join the circle",
    "You are about to delete {circle}.\nAre you sure?" : "You are about to delete {circle}.\nAre you sure?",
    "Please confirm circle deletion" : "Please confirm circle deletion",
    "Unable to delete the circle" : "Unable to delete the circle",
    "Link copied to the clipboard" : "Link copied to the clipboard",
    "Could not copy link to the clipboard." : "Could not copy link to the clipboard.",
    "Not grouped" : "Not grouped",
    "Recently contacted" : "Recently contacted",
    "Organization chart" : "Organization chart",
    "Circles are groups of people that you can create yourself and with whom you can share data. They can be made up of other accounts or groups of accounts of the Nextcloud instance, but also of contacts from your address book or even external people by simply entering their e-mail addresses." : "Circles are groups of people that you can create yourself and with whom you can share data. They can be made up of other accounts or groups of accounts of the Nextcloud instance, but also of contacts from your address book or even external people by simply entering their e-mail addresses.",
    "Circle" : "Circle",
    "User" : "User",
    "Group" : "Group",
    "Email" : "Email",
    "Contact" : "Contact",
    "Member" : "Member",
    "Moderator" : "Moderator",
    "Admin" : "Admin",
    "Owner" : "Owner",
    "Invites" : "Invites",
    "Anyone can request membership" : "Anyone can request membership",
    "Members need to accept invitation" : "Members need to accept invitation",
    "Memberships must be confirmed/accepted by a Moderator (requires Open)" : "Memberships must be confirmed/accepted by a Moderator (requires Open)",
    "Members can also invite" : "Members can also invite",
    "Visibility" : "Visibility",
    "Visible to everyone" : "Visible to everyone",
    "Circle membership" : "Circle membership",
    "Prevent circle from being a member of another circle" : "Prevent circle from being a member of another circle",
    "Users" : "Users",
    "Email addresses" : "Email addresses",
    "Detailed name" : "Detailed name",
    "Additional names" : "Middle names",
    "Prefix" : "Prefix",
    "Suffix" : "Suffix",
    "Nickname" : "Nickname",
    "Notes" : "Notes",
    "Website" : "Website",
    "Location" : "Location",
    "Federated Cloud ID" : "Federated Cloud ID",
    "Home" : "Home",
    "Work" : "Work",
    "Other" : "Other",
    "Address" : "Address",
    "Post office box" : "Post office box",
    "Extended address" : "Extended address",
    "City" : "City",
    "State or province" : "State or province",
    "Postal code" : "Postcode",
    "Country" : "Country",
    "Birthday" : "Birthday",
    "Anniversary" : "Anniversary",
    "Date of death" : "Date of death",
    "Instant messaging" : "Instant messaging",
    "Phone" : "Phone",
    "Mobile" : "Mobile",
    "Work mobile" : "Work mobile",
    "Home mobile" : "Home mobile",
    "Fax" : "Fax",
    "Fax home" : "Fax home",
    "Fax work" : "Fax work",
    "Pager" : "Pager",
    "Voice" : "Voice",
    "Car" : "Car",
    "Work pager" : "Work pager",
    "Manager" : "Manager",
    "Social network" : "Social network",
    "Relationship to you" : "Relationship to you",
    "Spouse" : "Spouse",
    "Child" : "Child",
    "Mother" : "Mother",
    "Father" : "Father",
    "Parent" : "Parent",
    "Brother" : "Brother",
    "Sister" : "Sister",
    "Relative" : "Relative",
    "Friend" : "Friend",
    "Colleague" : "Colleague",
    "Assistant" : "Assistant",
    "Related contacts" : "Related contacts",
    "Agent" : "Agent",
    "Emergency" : "Emergency",
    "Co-worker" : "Co-worker",
    "Gender" : "Gender",
    "Female" : "Female",
    "Male" : "Male",
    "None" : "None",
    "Unknown" : "Unknown",
    "Time zone" : "Time zone",
    "Spoken languages" : "Spoken languages",
    "_{failed} contact failed to be read_::_{failed} contacts failed to be read_" : ["{failed} contact failed to be read","{failed} contacts failed to be read"],
    "An error has occurred in circle(s). Check the console for more details." : "An error has occurred in circle(s). Check the console for more details.",
    "Unable to create circle {circleName}" : "Unable to create circle {circleName}",
    "Unable to delete circle {circleId}" : "Unable to delete circle {circleId}",
    "Unable to delete contact" : "Unable to delete contact"
},
"nplurals=2; plural=(n != 1);");
