OC.L10N.register(
    "contacts",
    {
    "Details" : "Details",
    "All contacts" : "Alle kontakte",
    "Contacts" : "Kontakte",
    "A contacts app for Nextcloud" : "’n Kontakte-toep vir Nextcloud",
    "Loading …" : "Laai …",
    "Download" : "Laai Af",
    "Rename" : "Hernoem",
    "Delete" : "Skrap",
    "Copied" : "Gekopieer",
    "Copy link" : "Kopieer skakel",
    "Share with users or groups" : "Deel met gebruikers of groepe",
    "No users or groups" : "Geen gebruikers of groepe",
    "can edit" : "kan wysig",
    "First name" : "Naam",
    "Last name" : "Van",
    "Display name" : "Vertoonnaam",
    "Last modified" : "Laas gewysig",
    "Save" : "Bewaar",
    "Description" : "Beskrywing",
    "Cancel" : "Kanselleer",
    "Invalid image" : "Ongeldige beeld",
    "Name" : "Naam",
    "Title" : "Titel",
    "Company" : "Maatskappy",
    "Edit" : "Wysig",
    "Search contacts …" : "Soek kontakte …",
    "Pending" : "Hangend",
    "Select type" : "Kies tipe",
    "Select Date" : "Kies Datum",
    "Select option" : "Kies opsie",
    "New contact" : "Nuwe kontak",
    "Close" : "Sluit",
    "Import" : "Voer In",
    "Not grouped" : "Nie gegroepeer",
    "User" : "Gebruiker",
    "Group" : "Groep",
    "Email" : "E-pos",
    "Contact" : "Kontak",
    "Admin" : "Admin",
    "Owner" : "Eienaar",
    "Users" : "Gebruikers",
    "Detailed name" : "Gedetailleerde naam",
    "Additional names" : "Addisionele name",
    "Prefix" : "Voorvoegsel",
    "Suffix" : "Agtervoegsel",
    "Nickname" : "Bynaam",
    "Notes" : "Notas",
    "Website" : "Webwerf",
    "Location" : "Ligging",
    "Federated Cloud ID" : "Gefedereerde Wolk-ID",
    "Home" : "Tuis",
    "Work" : "Werk",
    "Other" : "Ander",
    "Address" : "Adres",
    "Post office box" : "Posbus",
    "Extended address" : "Uitgebreide adres",
    "City" : "Stad/dorp",
    "State or province" : "Staat/provinsie",
    "Postal code" : "Poskode",
    "Country" : "Land",
    "Birthday" : "Verjaardag",
    "Anniversary" : "Herdenking",
    "Date of death" : "Sterfdatum",
    "Instant messaging" : "Kitsboodskapdiens",
    "Phone" : "Foon",
    "Mobile" : "Mobiel",
    "Work mobile" : "Werkmobiel",
    "Home mobile" : "Tuismobiel",
    "Fax" : "Faks",
    "Fax home" : "Faks tuis",
    "Fax work" : "Faks werk",
    "Pager" : "Pagineerder",
    "Voice" : "Stem",
    "Car" : "Motorkar",
    "Manager" : "Bestuurder",
    "Social network" : "Sosiale netwerk",
    "Spouse" : "Eggenoot",
    "Child" : "Kind",
    "Mother" : "Moeder",
    "Father" : "Vader",
    "Parent" : "Ouer",
    "Brother" : "Broer",
    "Sister" : "Suster",
    "Relative" : "Familielid",
    "Friend" : "Vriend",
    "Colleague" : "Kollega",
    "Assistant" : "Assistent",
    "Agent" : "Agent",
    "Emergency" : "Noodgeval",
    "Co-worker" : "Medewerker",
    "Gender" : "Geslag",
    "Female" : "Vroulik",
    "Male" : "Manlik",
    "None" : "Geen",
    "Unknown" : "Onbekend"
},
"nplurals=2; plural=(n != 1);");
