OC.L10N.register(
    "contacts",
    {
    "Details" : "Ayrıntılar",
    "All contacts" : "Tüm kişiler",
    "Contacts" : "Kişiler",
    "A contacts app for Nextcloud" : "Nextcloud kişiler uygulaması",
    "The Nextcloud contacts app is a user interface for Nextcloud's CardDAV server. Easily sync contacts from various devices with your Nextcloud and edit them online.\n\n* 🚀 **Integration with other Nextcloud apps!** Currently Mail and Calendar – more to come.\n* 🎉 **Never forget a birthday!** You can sync birthdays and other recurring events with your Nextcloud Calendar.\n* 👥 **Sharing of Adressbooks!** You want to share your contacts with your friends or coworkers? No problem!\n* 🙈 **We’re not reinventing the wheel!** Based on the great and open SabreDAV library." : "Kişiler uygulaması Nextcloud Card DAV sunucusunun ara yüzüdür. Çeşitli aygıtlar üzerindeki kişileri kolayca Nextcloud hesabınız ile eşitler ve çevrim içi olarak düzenlemenizi sağlar.\n\n* 🚀 **Diğer Nextcloud uygulamaları ile bütünleşiktir!** Şu anda Takvim, diğerleri yolda.\n* 🎉 **Doğum günlerini unutmayın!** Doğum günü ve diğer yinelenen etkinlikleri Nextcloud takviminiz üzerinden izleyebilirsiniz.\n* 👥 **Adres defterlerini paylaşma!** Kişilerinizi arkadaşlarınız ve iş arkadaşlarınız ile paylaşmak isterseniz sorun değil!\n* 🙈 **Tekerleği yeniden keşfetmiyoruz!** Harika açık SabreDAV kitaplığını kullanıyoruz.",
    "Copy to full name" : "Tam ada kopyala",
    "Omit year" : "Yıl dikkate alınmasın",
    "Allow updating avatars from social media" : "Avatarlar sosyal ağ üzerinden güncellenebilsin",
    "Please select a circle" : "Lütfen bir çevre seçin",
    "Loading circle …" : "Çevre yükleniyor …",
    "Your request to join this circle is pending approval" : "Bu çevreye girme isteğiniz onaylanmayı bekliyor",
    "You are not a member of {circle}" : "{circle} çevresinin üyesi değilsiniz ",
    "There was an error fetching the member list" : "Üye listesi alınırken bir sorun çıktı",
    "Loading contacts …" : "Kişiler yükleniyor…",
    "There are no contacts yet" : "Henüz bir kişi kaydı yok",
    "Create contact" : "Kişi ekle",
    "There are no contacts in this group" : "Bu grupta henüz bir kişi yok",
    "Create contacts" : "Kişiler ekle",
    "Add contacts" : "Kişileri ekle",
    "Loading …" : "Yükleniyor …",
    "Add member" : "Üye ekle",
    "Leave circle" : "Çevreden çık",
    "Delete circle" : "Çevreyi sil",
    "Contacts settings" : "Kişiler ayarları",
    "General settings" : "Genel ayarlar",
    "Update avatars from social media" : "Avatarlar sosyal ağ üzerinden güncellensin",
    "(refreshed once per week)" : "(haftada bir yenilenir)",
    "Address books" : "Adres defterleri",
    "Export" : "Dışa aktar",
    "Send email" : "E-posta gönder",
    "Send email as BCC" : "E-posta gizli kopya olarak gönderilsin",
    "Contact groups" : "Kişi grupları",
    "Create a new contact group" : "Yeni bir kişi grubu ekle",
    "Contact group name" : "Kişi grubu adı",
    "Circles" : "Çevreler",
    "Create a new circle" : "Yeni bir çevre ekle",
    "Show all groups" : "Tüm grupları görüntüle",
    "Collapse groups" : "Grupları daralt",
    "Show all circles" : "Tüm çevreleri görüntüle",
    "Collapse circles" : "Çevreleri daralt",
    "This group already exists" : "Bu grup zaten var",
    "This circle already exists" : "Bu çevre zaten var",
    "An error happened during the creation of the circle" : "Çevre eklenirken bir sorun çıktı",
    "{addressbookname} (Disabled)" : "{addressbookname} (devre dışı)",
    "Download" : "İndir",
    "Show" : "Görüntüle",
    "Rename" : "Yeniden adlandır",
    "Delete" : "Sil",
    "Copied" : "Kopyalandı",
    "Cannot copy" : "Kopyalanamadı",
    "Copy link" : "Bağlantıyı kopyala",
    "Toggling of address book was not successful" : "Adres defteri değiştirilemedi",
    "This will delete the address book and every contacts within it" : "Bu işlem adres defterini ve içindeki tüm kişileri siler",
    "Delete {addressbook}?" : "{addressbook} silinsin mi?",
    "Deletion of address book was not successful." : "Adres defteri silinemedi.",
    "Renaming of address book was not successful." : "Adres defteri yeniden adlandırılamadı.",
    "_%n contact_::_%n contacts_" : ["%n kişi","%n kişi"],
    "_%n group_::_%n groups_" : ["%n grup","%n grup"],
    "_Shared with {num} entity_::_Shared with {num} entities_" : ["{num} varlık ile paylaşılmış","{num} varlık ile paylaşılmış"],
    "Share with users or groups" : "Kullanıcı ve gruplarla paylaş",
    "Share with users" : "Kullanıcılarla paylaş",
    "No users or groups" : "Herhangi bir kullanıcı ya da grup yok",
    "can edit" : "düzenleyebilir",
    "Unable to delete the share" : "Paylaşım silinemedi",
    "Unable to change permissions" : "İzinler değiştirilemedi",
    "Import contacts" : "Kişileri içe aktar",
    "Import into the {addressbookName} address book" : "{addressbookName} adres defteri içine aktar",
    "Select local file" : "Yerel dosyayı seçin",
    "Import from files" : "Dosya ile içe aktar",
    "Importing is disabled because there are no address books available" : "Kullanılabilecek bir adres defteri bulunamadığından içe aktarım işlemi devre dışı bırakıldı",
    "Choose a vCard file to import" : "İçe aktarılacak vCard dosyasını seçin",
    "Add new address book" : "Adres defteri ekle",
    "An error occurred, unable to create the address book" : "Bir sorun çıktı, adres defteri oluşturulamadı",
    "First name" : "Ad",
    "Last name" : "Soyad",
    "Phonetic first name" : "Fonetik ad",
    "Phonetic last name" : "Fonetik soyad",
    "Display name" : "Görüntülenecek ad",
    "Last modified" : "Son değişiklik",
    "Sort by {sorting}" : "{sorting} alanına göre sırala",
    "Manages" : "Yönetici",
    "Oversees" : "Gözlemci",
    "An error happened during the config change" : "Yapılandırma değiştirilirken bir sorun çıktı",
    "Password protection" : "Parola koruması",
    "Enforce password protection on files shared to this circle" : "Bu çevreyle paylaşılan dosyalara parola koruması uygulansın",
    "Use a unique password for all shares to this circle" : "Bu çevrelerdeki tüm paylaşımlar için benzersiz bir parola kullanılsın",
    "Unique password …" : "Benzersiz parola…",
    "Save" : "Kaydet",
    "Change unique password" : "Benzersiz parolayı değiştir",
    "Failed to save password. Please try again later." : "Parola kaydedilemedi. Lütfen bir süre sonra yeniden deneyin.",
    "Circle name" : "Çevre adı",
    "Circle owned by {owner}" : "Sahibi {owner} olan çevreler ",
    "Request to join" : "Katılma isteğinde bulun",
    "Description" : "Açıklama",
    "There is no description for this circle" : "Bu çevre için bir açıklama yok",
    "Enter a description for the circle" : "Çevre için bir açıklama yazın",
    "An error happened during description sync" : "Açıklama eşitlenirken bir sorun çıktı",
    "An error happened during name sync" : "Ad eşitlenirken bir sorun çıktı",
    "Add more info" : "Başka bilgiler ekleyin",
    "More fields" : "Diğer alanlar",
    "Crop contact photo" : "Kişi görselini kırp",
    "Cancel" : "İptal",
    "Upload a new picture" : "Görsel yükle",
    "Choose from Files" : "Dosyalardan seçin",
    "Get from " : "Şuradan alınsın",
    "Download picture" : "Görseli indir",
    "Delete picture" : "Görseli sil",
    "Please select a valid format" : "Lütfen geçerli bir biçim seçin",
    "Invalid image" : "Görsel geçersiz",
    "Error cropping picture" : "Görsel kırpılırken sorun çıktı",
    "Pick an avatar" : "Bir avatar seçin",
    "Error while processing the picture." : "Görsel işlenirken sorun çıktı.",
    "Avatar downloaded from social network" : "Avatar sosyal ağ üzerinden indirildi",
    "Avatar already up to date" : "Avatar zaten güncel",
    "Avatar download failed" : "Avatar indirilemedi",
    "No contact selected" : "Herhangi bir kişi seçilmemiş",
    "Select a contact on the list to begin" : "Başlamak için listeden bir kişi seçin",
    "Name" : "Ad",
    "Title" : "Ünvan",
    "Company" : "Kuruluş",
    "This contact was broken and received a fix. Please review the content and click here to save it." : "Bu kişinin bilgileri hatalıydı ve bir düzeltme yapıldı. Lütfen içeriği gözden geçirip kaydetmek için buraya tıklayın.",
    "Edit" : "Düzenle",
    "Clone contact" : "Kişiyi kopyala",
    "Generate QR Code" : "QR kodu üret",
    "Contact vCard as QR code" : "QRkod olarak sanal kişi kartı",
    "Pick an address book" : "Bir adres defteri seçin",
    "Select address book" : "Adres defterini seçin",
    "Go to talk conversation" : "Talk görüşmesine git",
    "View profile" : "Profili görüntüle",
    "Media shares with you" : "Sizinle paylaşılan ortamlar",
    "Talk conversations with you" : "Sizinle yapılan Talk görüşmeleri",
    "Calendar events with you" : "Sizinle ilgili takvim etkinlikleri",
    "Deck cards with you" : "Sizinle ilgili tahta kartları",
    "No shared items with this contact" : "Bu kişi ile paylaşılmış bir öge yok",
    "This contact is in read-only mode. You do not have permission to edit this contact." : "Bu kişi salt okunur kipte olduğundan kişiyi düzenleme izniniz yok.",
    "The contact you were trying to edit has changed. Please manually refresh the contact. Any further edits will be discarded." : "Düzenlemeye çalıştığınız kişi değiştirilmiş. Lütfen kişiyi el ile yenileyin. Bundan sonra yapılacak düzenlemeler yok sayılacak.",
    "Address book" : "Adres defteri",
    "Add contact to Birthday Calendar" : "Kişiyi doğum günü takvimine ekle",
    "Exclude contact from Birthday Calendar" : "Kişiyi doğum günü takviminden çıkar",
    "{title} at {organization}" : "{organization} kuruluşundaki {title} ",
    "Syntax error. Cannot open the contact." : "Yazım hatası. Kişi bulunamadı.",
    "The contact does not exist on the server anymore." : "Kişi artık sunucu üzerinde değil.",
    "Unable to retrieve the contact from the server, please check your network connection." : "Kişi sunucudan alınamadı. Lütfen ağ bağlantınızı denetleyin.",
    "An error occurred while trying to move the contact" : "Kişi taşınırken bir sorun çıktı",
    "An error occurred while trying to copy the contact" : "Kişi kopyalanırken bir sorun çıktı",
    "Unable to update contact" : "Kişi güncellenemedi",
    "Search contacts …" : "Kişi arama…",
    "Add to {group}" : "{group} grubuna ekle",
    "Remove {type}" : "{type} sil",
    "Search {types}" : "{types} arama",
    "Search for people to add" : "Eklenecek kişileri ara",
    "No results" : "Herhangi bir sonuç bulunamadı",
    "Add to group" : "Gruba ekle",
    "Add {type}" : "{type} ekle",
    "New circle name" : "Yeni çevre adı",
    "Personal circle" : "Kişisel çevre",
    "This circle will only be visible to you. Other members will not be able to see or use it." : "Bu çevreyi yalnızca siz görebilirsiniz. Diğer üyeler bu çevreyi göremez ya da kullanamaz.",
    "Local circle" : "Yerel çevre",
    "This circle will not be shared with the other instances of the global scale" : "Bu çevre küresel ölçekte diğer kopyalar ile paylaşılamaz",
    "Create circle" : "Çevre ekle",
    "Loading members list …" : "Üye listesi ekleniyor …",
    "The list of members is only visible to members of this circle" : "Üye listesi yalnızca bu çevredeki üyeler tarafından görülebilir",
    "You currently have no access to the member list" : "Üye listesine erişme izniniz yok ",
    "Add members" : "Üye ekle",
    "Show circle details" : "Çevre ayrıntılarını görüntüle",
    "Add to {circle}" : "{circle} çevresine ekle",
    "Unable to get the recommendations list" : "Öneriler listesi alınamadı",
    "Unable to get the results" : "Sonuçlar alınamadı",
    "Some members could not be added" : "Bazı üyeler eklenemedi",
    "There was an issue adding members to the circle" : "Üyeler çevreye eklenirken bir sorun çıktı",
    "Accept membership request" : "Üyelik isteğini kabul et",
    "Reject membership request" : "Üyelik isteğini reddet",
    "Manage level" : "Düzeyi değiştir",
    "Remove member" : "Üyeyi sil",
    "Pending" : "Bekleyen",
    "Promote as sole owner" : "Sahip olarak ata",
    "Promote to {level}" : "{level} düzeyine yükselt",
    "Demote to {level}" : "{level} düzeyine düşür",
    "Could not delete the member {displayName}" : "{displayName} üyesi silinemedi",
    "Could not change the member level to {level}" : "Üye düzeyi {level} olarak değiştirilemedi",
    "Could not accept membership request" : "Üyelik isteği kabul edilemedi",
    "Chart" : "Çizelge",
    "Select chart …" : "Çizelge seçin…",
    "Select type" : "Türü seçin",
    "Select Date" : "Tarih seçin",
    "Add contact in group" : "Kişiyi şu gruba ekle",
    "none" : "Yok",
    "Select option" : "Seçeneği seçin",
    "Add property of this type" : "Bu türün özniteliğini ekle",
    "New contact" : "Yeni kişi",
    "Unable to create the contact." : "Kişi eklenemedi.",
    "Contact not found" : "Kişi bulunamadı",
    "Group {group} not found" : "{group} grubu bulunamadı",
    "Close" : "Kapat",
    "_{success} contact added to {name}_::_{success} contacts added to {name}_" : ["{success} kişi {name} üzerine eklendi","{success} kişi {name} üzerine eklendi"],
    "_Adding {success} contact to {name}_::_Adding {success} contacts to {name}_" : ["{name} üzerine {success} ekleniyor","{name} üzerine {success} ekleniyor"],
    "_{count} error_::_{count} errors_" : ["{count} hata","{count} hata"],
    "_Importing %n contact into {addressbook}_::_Importing %n contacts into {addressbook}_" : ["%n kişi {addressbook} içine aktarılıyor","%n kişi {addressbook} içine aktarılıyor"],
    "_Done importing %n contact into {addressbook}_::_Done importing %n contacts into {addressbook}_" : ["%n kişi {addressbook} içine aktarıldı","%n kişi {addressbook} içine aktarıldı"],
    "Import" : "İçe aktar",
    "Could not copy" : "Kopyalanamadı",
    "Join circle" : "Çevreye gir",
    "You are about to leave {circle}.\nAre you sure?" : "{circle} çevresinden çıkmak üzeresiniz.\nBunu yapmak istediğinize emin misiniz?",
    "Please confirm circle leave" : "Lütfen çevreden çıkmak istediğinizi onaylayın",
    "Could not leave the circle {displayName}" : "{displayName} çevresinden çıkılamadı",
    "Unable to join the circle" : "Çevreye girilemedi",
    "You are about to delete {circle}.\nAre you sure?" : "{circle} çevresini silmek üzeresiniz.\nBunu yapmak istediğinize emin misiniz?",
    "Please confirm circle deletion" : "Lütfen çevreyi silmek istediğinizi onaylayın",
    "Unable to delete the circle" : "Çevre silinemedi",
    "Link copied to the clipboard" : "Bağlantı panoya kopyalandı",
    "Could not copy link to the clipboard." : "Bağlantı panoya kopyalanamadı.",
    "Not grouped" : "Gruplanmamış",
    "Recently contacted" : "Son görüşülenler",
    "Organization chart" : "Organizasyon şeması",
    "Circles are groups of people that you can create yourself and with whom you can share data. They can be made up of other accounts or groups of accounts of the Nextcloud instance, but also of contacts from your address book or even external people by simply entering their e-mail addresses." : "Çevreler, kendi oluşturabileceğiniz ve verileri paylaşabileceğiniz kişi gruplarıdır. Bunlar, Nextcloud kopyasındaki diğer hesaplardan veya hesap gruplarından oluşabileceği gibi, adres defterinizdeki kişilerden ve hatta yalnızca e-posta adreslerini yazacağınız dışarıdaki kişilerden oluşabilir.",
    "Circle" : "Çevre",
    "User" : "Kullanıcı",
    "Group" : "Grup",
    "Email" : "E-posta",
    "Contact" : "Kişi",
    "Member" : "Üye",
    "Moderator" : "Sorumlu",
    "Admin" : "Yönetici",
    "Owner" : "Sahip",
    "Invites" : "Çağrılar",
    "Anyone can request membership" : "Herkes üyelik isteğinde bulunabilir",
    "Members need to accept invitation" : "Üyeler çağrıyı kabul etmelidir",
    "Memberships must be confirmed/accepted by a Moderator (requires Open)" : "Üyelikler bir sorumlu tarafından onaylanmalıdır (Open gereklidir)",
    "Members can also invite" : "Üyeler de çağrı gönderebilir",
    "Visibility" : "Görünürlük",
    "Visible to everyone" : "Herkes görebilir",
    "Circle membership" : "Çevre üyeliği",
    "Prevent circle from being a member of another circle" : "Bu çevre başka bir çevreye üye olarak eklenemesin",
    "Users" : "Kullanıcılar",
    "Email addresses" : "E-posta adresleri",
    "Detailed name" : "Ayrıntılı ad",
    "Additional names" : "Ek adlar",
    "Prefix" : "Ön ek",
    "Suffix" : "Son ek",
    "Nickname" : "Takma ad",
    "Notes" : "Notlar",
    "Website" : "Site",
    "Location" : "Konum",
    "Federated Cloud ID" : "Birleşik bulut kodu",
    "Home" : "Ev",
    "Work" : "İş",
    "Other" : "Diğer",
    "Address" : "Adres",
    "Post office box" : "Posta kutusu",
    "Extended address" : "Uzun adres",
    "City" : "İlçe",
    "State or province" : "İl",
    "Postal code" : "Posta kodu",
    "Country" : "Ülke",
    "Birthday" : "Doğum günü",
    "Anniversary" : "Yıl dönümü",
    "Date of death" : "Ölüm tarihi",
    "Instant messaging" : "Anlık iletişim",
    "Phone" : "Telefon",
    "Mobile" : "Cep telefonu",
    "Work mobile" : "İş cep telefonu",
    "Home mobile" : "Ev cep telefonu",
    "Fax" : "Faks",
    "Fax home" : "Ev faksı",
    "Fax work" : "İş faksı",
    "Pager" : "Çağrı cihazı",
    "Voice" : "Ses",
    "Car" : "Araç telefonu",
    "Work pager" : "İş çağrı cihazı",
    "Manager" : "Yönetici",
    "Social network" : "Sosyal ağ",
    "Relationship to you" : "Sizinle ilişkili",
    "Spouse" : "Eş",
    "Child" : "Çocuk",
    "Mother" : "Anne",
    "Father" : "Baba",
    "Parent" : "Ebeveyn",
    "Brother" : "Erkek kardeş",
    "Sister" : "Kız kardeş",
    "Relative" : "Akraba",
    "Friend" : "Arkadaş",
    "Colleague" : "Çalışma arkadaşı",
    "Assistant" : "Yardımcı",
    "Related contacts" : "İlişkili kişiler",
    "Agent" : "Ajan",
    "Emergency" : "Acil",
    "Co-worker" : "Çalışma arkadaşı",
    "Gender" : "Cinsiyet",
    "Female" : "Kadın",
    "Male" : "Erkek",
    "None" : "Yok",
    "Unknown" : "Bilinmiyor",
    "Time zone" : "Saat dilimi",
    "Spoken languages" : "Konuşulan diller",
    "_{failed} contact failed to be read_::_{failed} contacts failed to be read_" : ["{failed} kişi okunamadı","{failed} kişi okunamadı"],
    "An error has occurred in circle(s). Check the console for more details." : "Çevrelerde bir sorun çıktı. Ayrıntılı bilgi almak için konsola bakabilirsiniz.",
    "Unable to create circle {circleName}" : "{circleName} çevresi eklenemedi",
    "Unable to delete circle {circleId}" : "{circleName} çevresi silinemedi",
    "Unable to delete contact" : "Kişi silinemedi"
},
"nplurals=2; plural=(n > 1);");
