OC.L10N.register(
    "contacts",
    {
    "Details" : "Детали",
    "All contacts" : "Сите контакти",
    "Contacts" : "Контакти",
    "A contacts app for Nextcloud" : "Апликација за контакти за Nextcloud",
    "The Nextcloud contacts app is a user interface for Nextcloud's CardDAV server. Easily sync contacts from various devices with your Nextcloud and edit them online.\n\n* 🚀 **Integration with other Nextcloud apps!** Currently Mail and Calendar – more to come.\n* 🎉 **Never forget a birthday!** You can sync birthdays and other recurring events with your Nextcloud Calendar.\n* 👥 **Sharing of Adressbooks!** You want to share your contacts with your friends or coworkers? No problem!\n* 🙈 **We’re not reinventing the wheel!** Based on the great and open SabreDAV library." : "Апликацијата Контакти за Nextcloud е кориснички интерфејс за  „CardDAV“ на Nextcloud сервер. Лесно синхронизирајте контакти од разни уреди со вашиот Nextcloud и изменете ги на Интернет.\n\n* 🚀 ** Интеграција со други апликации Nextcloud! ** Моментално со Е-пошта и календар.\n* 🎉 ** Никогаш не заборавајте роденден! ** Може да ги синхронизирате родендените и другите настани од вашиот Календар.\n* 👥 ** Споделување на адресари! ** Дали сакате да ги споделите вашите контакти со вашите пријатели или соработници? Нема проблем!\n* 🙈 ** Ние не го реинвестираме тркалото! ** Врз основа на одличната и отворена библиотека SabreDAV .",
    "Copy to full name" : "Копирај во Име и презиме",
    "Omit year" : "Изостави година",
    "Allow updating avatars from social media" : "Дозволи ажурирање на аватарите од социјалните мрежи",
    "Please select a circle" : "Изберете круг",
    "Loading circle …" : "Вчитување круг...",
    "Your request to join this circle is pending approval" : "Вашето барање за приклучување во кругое е на чекање за одобрување",
    "You are not a member of {circle}" : "Вие не сте член на {circle}",
    "There was an error fetching the member list" : "Настана грешка при вчитувањето на листата на членови",
    "Loading contacts …" : "Вчитување на контактите ...",
    "There are no contacts yet" : "Сеуште нема контакти",
    "Create contact" : "Креирај контакт",
    "There are no contacts in this group" : "Нема контакти во оваа група",
    "Create contacts" : "Креирај контакти",
    "Add contacts" : "Додади контакти",
    "Loading …" : "Се вчитува…",
    "Add member" : "Додади член",
    "Leave circle" : "Напушти круг",
    "Delete circle" : "Избриши круг",
    "Contacts settings" : "Параметри за контактите",
    "General settings" : "Општи параметри",
    "Update avatars from social media" : "Ажурирај ги аватарите од социјалните мрежи",
    "(refreshed once per week)" : "(еднаш неделно)",
    "Address books" : "Адресари",
    "Send email" : "Испрати е-пошта",
    "Contact groups" : "Групи со контакти",
    "Create a new contact group" : "Креирај нова група со контакти",
    "Contact group name" : "Име на група со контакти",
    "Circles" : "Кругови",
    "Create a new circle" : "Креирај круг",
    "Show all groups" : "Прикажи ги сите групи",
    "Collapse groups" : "Сокриј ги групите",
    "Show all circles" : "Прикажи ги сите кругови",
    "Collapse circles" : "Сокриј ги круговите",
    "This group already exists" : "Оваа група веќе постои",
    "This circle already exists" : "Овој круг веќе постои",
    "An error happened during the creation of the circle" : "Настана грешка при обидот за креирање на круг",
    "Download" : "Преземи",
    "Rename" : "Преименувај",
    "Delete" : "Избриши",
    "Copied" : "Копирано",
    "Cannot copy" : "Не може да се копира",
    "Copy link" : "Копирај линк",
    "Toggling of address book was not successful" : "Промената во адресарот на беше успешна",
    "This will delete the address book and every contacts within it" : "Ова ќе ги избрише адресарот и сите контакти во него",
    "Delete {addressbook}?" : "Избриши {addressbook}?",
    "Deletion of address book was not successful." : "Неуспешно бришење на адресарот.",
    "Renaming of address book was not successful." : "Неуспешно преименување на адресарот",
    "_Shared with {num} entity_::_Shared with {num} entities_" : ["Споделено со едно {num} лице","Споделено со {num} лица"],
    "Share with users or groups" : "Сподели со корисници или групи",
    "No users or groups" : "Нема корисници или групи",
    "can edit" : "може да се измени",
    "Unable to delete the share" : "Неможе да се избрише споделениот контакт",
    "Unable to change permissions" : "Неможе да се променат дозволите",
    "Import contacts" : "Увези контакти",
    "Import into the {addressbookName} address book" : "Увези во адресарот {addressbookName}",
    "Select local file" : "Избери локална датотека",
    "Import from files" : "Увези од датотеките",
    "Importing is disabled because there are no address books available" : "Увезувањето е оневозможено бидејќи нема достапен адресар",
    "Choose a vCard file to import" : "Избери vCard датотека за увоз",
    "Add new address book" : "Додади нов адресар",
    "An error occurred, unable to create the address book" : "Настана грешка, неможе да се креира адресар",
    "First name" : "Име",
    "Last name" : "Презиме",
    "Phonetic first name" : "Име (Фонетски)",
    "Phonetic last name" : "Презиме (Фонетски)",
    "Display name" : "Име и презиме",
    "Last modified" : "Скоро изменети",
    "Sort by {sorting}" : "Подреди според {sorting}",
    "Manages" : "Менаџмент",
    "Oversees" : "Надгледувачи",
    "An error happened during the config change" : "Настана грешка при обидот за промена на конфигурацијата",
    "Password protection" : "Заштитено со лозинка",
    "Enforce password protection on files shared to this circle" : "Задолжителна лозинка за датотеките споделени во овој круг",
    "Use a unique password for all shares to this circle" : "Користи уникатна лозинка за сите споделувања во овој круг",
    "Unique password …" : "уникатна лозинка ...",
    "Save" : "Зачувај",
    "Change unique password" : "Промени лозинка",
    "Failed to save password. Please try again later." : "Неуспешно зачувување на лозинката. Обидете се повторно.",
    "Circle name" : "Име на кругот",
    "Circle owned by {owner}" : "Круг основан од {owner}",
    "Request to join" : "Барање за членство",
    "Description" : "Опис",
    "There is no description for this circle" : "Нема опис за овој круг",
    "Enter a description for the circle" : "Внеси опис за кругот",
    "An error happened during description sync" : "Настана грешка при обидот за синхронизација на описот",
    "An error happened during name sync" : "Настана грешка при обидот за синхронизација на името",
    "Cancel" : "Откажи",
    "Upload a new picture" : "Прикачи нова слика",
    "Choose from Files" : "Избери од датотеките",
    "Get from " : "Превземи од",
    "Download picture" : "Преземи слика",
    "Delete picture" : "Избриши слика",
    "Invalid image" : "Невалидна фотографија",
    "Pick an avatar" : "Избери аватар",
    "Error while processing the picture." : "Грешка при процесоирање на сликата",
    "Avatar downloaded from social network" : "Аватари превземени од социјалните мрежи",
    "Avatar already up to date" : "Аватарите се ажурирани",
    "Avatar download failed" : "Неуспешно превземање на аватар",
    "No contact selected" : "Нема избрано контакт",
    "Select a contact on the list to begin" : "Изберете контакт од листата со контакти",
    "Name" : "Име",
    "Title" : "Наслов",
    "Company" : "Фирма",
    "This contact was broken and received a fix. Please review the content and click here to save it." : "Овој контакт беше неточен и доби исправка. Прегледајте го контактот и кликнете тука за да го зачувате.",
    "Clone contact" : "Клинирај контакт",
    "Generate QR Code" : "Генерирај QR код",
    "Contact vCard as QR code" : "Картичка за контакт во QR-код",
    "Pick an address book" : "Избери адресар",
    "Select address book" : "Избери адресар",
    "This contact is in read-only mode. You do not have permission to edit this contact." : "Овој контакт е со дозволи само за читање. Немате дозвола за да го промените контактот.",
    "The contact you were trying to edit has changed. Please manually refresh the contact. Any further edits will be discarded." : "Контактот кој се обидувате да го измените веќе е изменет. Ве молиме проверете го контактот. Сите наредни измени ќе бидат отфрлени.",
    "Address book" : "Адресар",
    "Add contact to Birthday Calendar" : "Додади контакт во Роденденскиот календар",
    "Exclude contact from Birthday Calendar" : "Исклучи контакт од Роденденскиот календар",
    "Syntax error. Cannot open the contact." : "Грешка во синтаксата. Неможе да се отвори овој контакт.",
    "Unable to retrieve the contact from the server, please check your network connection." : "Неможе да се вчита контактот од серверот, проверете ја вашата конекција.",
    "An error occurred while trying to move the contact" : "Настана грешка при обидот за преместување на конктактот",
    "An error occurred while trying to copy the contact" : "Настана грешка при обидот за копирање на конктактот",
    "Search contacts …" : "Пребарување контакти ...",
    "Add to {group}" : "Додади во {group}",
    "Remove {type}" : "Отстрани {type}",
    "Search {types}" : "Барај {types}",
    "Search for people to add" : "Барај луѓе за да додадеш",
    "No results" : "Нема резултати",
    "Add to group" : "Додади во група",
    "Add {type}" : "Додади {type}",
    "New circle name" : "Име за нов круг",
    "Personal circle" : "Сопствен круг",
    "This circle will only be visible to you. Other members will not be able to see or use it." : "Овој круг ќе биде единствено видлив за вас. Другите членови нема да може да се гледаат помеѓу себе.",
    "Local circle" : "Локален круг",
    "This circle will not be shared with the other instances of the global scale" : "Овој круг нема да биде споделуван со други истанци",
    "Create circle" : "Креирај круг",
    "Loading members list …" : "Вчитување на листата со членови ...",
    "The list of members is only visible to members of this circle" : "Листата на членови е видлива само за членовите на овој круг",
    "You currently have no access to the member list" : "Немате пристап до листата со членови",
    "Add members" : "Додади членови",
    "Show circle details" : "Прикажи детали за кругот",
    "Add to {circle}" : "Додади во {circle}",
    "Unable to get the recommendations list" : "Неможе да се вчита листата на препораки",
    "Unable to get the results" : "Неможе да се вчитаат резултатите",
    "Some members could not be added" : "Некој членови неможе да бидат додадени",
    "There was an issue adding members to the circle" : "Има проблеми со додавање на членови во овој круг",
    "Accept membership request" : "Прифати барање за членство",
    "Reject membership request" : "Одбиј барање за членство",
    "Manage level" : "Уреди ги улогите",
    "Remove member" : "Отстрани член",
    "Pending" : "Чекање",
    "Promote as sole owner" : "Промовирај во единствен сопственик",
    "Promote to {level}" : "Промовирај во {level}",
    "Demote to {level}" : "Деградирај во {level}",
    "Could not delete the member {displayName}" : "Неможе да се избрише членот {displayName}",
    "Could not change the member level to {level}" : "Неможе да се промени улогата во {level}",
    "Could not accept membership request" : "Не може да се прифати барањето за членство",
    "Chart" : "График",
    "Select chart …" : "Избери график ...",
    "Select type" : "Избери вид",
    "Select Date" : "Избери датум",
    "Add contact in group" : "Додади контакт во група",
    "Select option" : "Изберете опција",
    "New contact" : "Нов контакт",
    "Unable to create the contact." : "Неможе да се креира контакт.",
    "Contact not found" : "Контактот не е пронајден",
    "Group {group} not found" : "Групата {group} не е пронајдена",
    "Close" : "Затвори",
    "_{success} contact added to {name}_::_{success} contacts added to {name}_" : ["1 контак додаден во {name}","{success} контакти додадени во {name}"],
    "_Adding {success} contact to {name}_::_Adding {success} contacts to {name}_" : ["Додавање 1контакт во {name}","Додавање {success} контакти во {name}"],
    "_{count} error_::_{count} errors_" : ["1 грешка","{count} грешки"],
    "_Importing %n contact into {addressbook}_::_Importing %n contacts into {addressbook}_" : ["Импортирање на %n контакт во {addressbook}","Импортирање на %n контакти во {addressbook}"],
    "_Done importing %n contact into {addressbook}_::_Done importing %n contacts into {addressbook}_" : ["Импортиран е  %n контакт во  {addressbook}","Импортирани се %n контакти во {addressbook}"],
    "Import" : "Увези",
    "Could not copy" : "Неможе да се копира",
    "Join circle" : "Приклучи се во кругот",
    "You are about to leave {circle}.\nAre you sure?" : "Сакате да го напуштите {circle}.\nДали сте сигурни?",
    "Please confirm circle leave" : "Потврдете го напуштањето на кругот",
    "Could not leave the circle {displayName}" : "{displayName} не може да го напуштите кругот ",
    "Unable to join the circle" : "Не може да се приклучите на кругот",
    "You are about to delete {circle}.\nAre you sure?" : "Сакате да го избришете {circle}.\nДали сте сигурни?",
    "Please confirm circle deletion" : "Потврдете го бришењето на кругот",
    "Unable to delete the circle" : "Неможе да се избрише кругот",
    "Link copied to the clipboard" : "Линкот е копиран во клипборд",
    "Could not copy link to the clipboard." : "Линкот неможе да се копира во клипборд.",
    "Not grouped" : "Не групирани",
    "Recently contacted" : "Неодамна контактирани",
    "Organization chart" : "Огранизациски графил",
    "Circle" : "Круг",
    "User" : "Корисник",
    "Group" : "Група",
    "Email" : "Е-пошта",
    "Contact" : "Контакт",
    "Member" : "Член",
    "Moderator" : "Модератор",
    "Admin" : "Администратор",
    "Owner" : "Сопственик",
    "Invites" : "Покани",
    "Anyone can request membership" : "Секој може да побара членство",
    "Members need to accept invitation" : "Членовите треба да го прифатат членството",
    "Memberships must be confirmed/accepted by a Moderator (requires Open)" : " Членството мора предходно да се одобри/прифати од модератор (барањето е отворено)",
    "Members can also invite" : "Членовите можат да испраќаат покани",
    "Visibility" : "Видливост",
    "Visible to everyone" : "Видлив за сите",
    "Circle membership" : "Членство во круг",
    "Prevent circle from being a member of another circle" : "Спречете кругот да биде член на друг круг",
    "Users" : "Корисници",
    "Email addresses" : "Е-пошта адреси",
    "Detailed name" : "Детално име",
    "Additional names" : "Дополнителни имиња",
    "Prefix" : "Префикс",
    "Suffix" : "Суфикс",
    "Nickname" : "Прекар",
    "Notes" : "Белешки",
    "Website" : "Веб сајт",
    "Location" : "Локација",
    "Federated Cloud ID" : "Federated Cloud ID",
    "Home" : "Дома",
    "Work" : "Работа",
    "Other" : "Останато",
    "Address" : "Адреса",
    "Post office box" : "Поштенска кутија",
    "Extended address" : "Целосна адреса",
    "City" : "Град",
    "State or province" : "Град или провинција",
    "Postal code" : "Поштенски број",
    "Country" : "Држава",
    "Birthday" : "Роденден",
    "Anniversary" : "Годишнина",
    "Date of death" : "Датум на смрт",
    "Instant messaging" : "Инстантни пораки",
    "Phone" : "Телефон",
    "Mobile" : "Мобилен",
    "Work mobile" : "Службен мобилен",
    "Home mobile" : "Приватен мобилен",
    "Fax" : "Факс",
    "Fax home" : "Fax дома",
    "Fax work" : "Fax на работа",
    "Pager" : "Пејџер",
    "Voice" : "Глас",
    "Car" : "Автомобил",
    "Work pager" : "Службен пејџер",
    "Manager" : "Менаџер",
    "Social network" : "Социјална мрежа",
    "Relationship to you" : "Врска со вас",
    "Spouse" : "Брачен другар",
    "Child" : "Дете",
    "Mother" : "Мајка",
    "Father" : "Татко",
    "Parent" : "Родител",
    "Brother" : "Брат",
    "Sister" : "Сестра",
    "Relative" : "Роднина",
    "Friend" : "Пријател",
    "Colleague" : "Колега",
    "Assistant" : "Асистент",
    "Related contacts" : "Поврзани контакти",
    "Agent" : "Агент",
    "Emergency" : "За итни случаи",
    "Co-worker" : "Соработник",
    "Gender" : "Пол",
    "Female" : "Женско",
    "Male" : "Машко",
    "None" : "Ништо",
    "Unknown" : "Непознат",
    "Time zone" : "Временска зона",
    "Spoken languages" : "Говорни јазици",
    "_{failed} contact failed to be read_::_{failed} contacts failed to be read_" : ["{failed} еден контакт неможе да се прочита","{failed} контакти неможат да се прочитат"],
    "An error has occurred in circle(s). Check the console for more details." : "Настана грешка во некои круг(ови). Проверете ја конзолата за повеќе детали.",
    "Unable to create circle {circleName}" : "Неможе да се креира круг {circleName}",
    "Unable to delete circle {circleId}" : "Неможе да се избрише кругот {circleId}",
    "Unable to delete contact" : "Неможе да се избрише контакт"
},
"nplurals=2; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : 1;");
