OC.L10N.register(
    "contacts",
    {
    "Details" : "Detalhes",
    "All contacts" : "Todos os contactos",
    "Contacts" : "Contactos",
    "A contacts app for Nextcloud" : "Uma  aplicação de contactos para o Nextcloud",
    "The Nextcloud contacts app is a user interface for Nextcloud's CardDAV server. Easily sync contacts from various devices with your Nextcloud and edit them online.\n\n* 🚀 **Integration with other Nextcloud apps!** Currently Mail and Calendar – more to come.\n* 🎉 **Never forget a birthday!** You can sync birthdays and other recurring events with your Nextcloud Calendar.\n* 👥 **Sharing of Adressbooks!** You want to share your contacts with your friends or coworkers? No problem!\n* 🙈 **We’re not reinventing the wheel!** Based on the great and open SabreDAV library." : "A aplicação de contactos do Nextcloud disponibiliza ao utilizador uma interface para o servidor Nextcloud's CardDAV. Sincronize contactos facilmente a partir de vários dispositivos com o seu Nextcloud e edite-os online.\n\n* 🚀 **Integração com outras aplicações Nextcloud!** Atualmente apenas o Mail e o Calendar - mais se seguirão.\n* 🎉 **Nunca mais se esqueça de uma aniversário!** Pode sincronizar aniversários e outros eventos recorrentes com o seu Nextcloud Calendar.\n* 👥 **Partilha de livros de endereços!**Quer partilhar os seus contactos com amigos ou colegas? Sem problema!\n* 🙈 **Não estamos a reinventar a roda!** Esta aplicação é baseada na livre e fantástica biblioteca SabreDAV.",
    "Copy to full name" : "Copiar para o Nome Completo",
    "Omit year" : "Omitir o ano",
    "Allow updating avatars from social media" : "Permitir atualização do avatar a partir das redes sociais",
    "Please select a circle" : "Selecione um círculo",
    "Loading circle …" : "A carregar o círculo…",
    "Your request to join this circle is pending approval" : "O seu pedido para aderir a este circulo está à espera de aprovação",
    "You are not a member of {circle}" : "Não é um membro de {circle}",
    "There was an error fetching the member list" : "Ocorreu um erro ao transferir a lista de membros",
    "Loading contacts …" : "A carregar contactos …",
    "There are no contacts yet" : "Ainda não existem contactos",
    "Create contact" : "Criar contacto",
    "There are no contacts in this group" : "Não existem contactos neste grupo",
    "Create contacts" : "Criar contactos",
    "Add contacts" : "Adicionar contactos",
    "Loading …" : "A carregar...",
    "Add member" : "Adicionar membro",
    "Leave circle" : "Deixar círculo",
    "Delete circle" : "Eliminar círculo",
    "Contacts settings" : "Definições dos contactos",
    "General settings" : "Definições Gerais",
    "Update avatars from social media" : "Atualizar avatar a partir das redes sociais",
    "(refreshed once per week)" : "(actualizado uma vez por semana)",
    "Address books" : "Livros de endereços",
    "Send email" : "Enviar e-mail",
    "Contact groups" : "Grupos de contactos",
    "Create a new contact group" : "Criar um novo grupo de contactos",
    "Contact group name" : "Nome do grupo de contactos",
    "Circles" : "Círculos",
    "Create a new circle" : "Criar um novo círculo",
    "Show all groups" : "Mostrar todos os grupos",
    "Show all circles" : "Mostrar todos os círculos",
    "This group already exists" : "Este grupo já existe",
    "This circle already exists" : "Este círculo já existe",
    "An error happened during the creation of the circle" : "Ocorreu um erro durante a criação do círculo ",
    "Download" : "Transferir",
    "Rename" : "Renomear",
    "Delete" : "Apagar",
    "Copied" : "Copiado",
    "Cannot copy" : "Não é possível copiar",
    "Copy link" : "Copiar hiperligação",
    "Toggling of address book was not successful" : "A alternância da agenda não pode ser realizada",
    "This will delete the address book and every contacts within it" : "Isso irá remover o livro de endereços e todos os contatos contidos nele",
    "Delete {addressbook}?" : "Remover {addressbook}?",
    "Deletion of address book was not successful." : "Não foi possível eliminar o livro de endereços.",
    "Renaming of address book was not successful." : "Não foi possível renomear o livro de endereços.",
    "_Shared with {num} entity_::_Shared with {num} entities_" : ["Partilhado com {num} entidades","Partilhado com {num} entidades","Partilhado com {num} entidades"],
    "Share with users or groups" : "Partilhe com os utilizadores ou grupos",
    "No users or groups" : "Sem utilizadores ou grupos",
    "can edit" : "pode editar",
    "Unable to delete the share" : "Não é possível eliminar a partilha",
    "Unable to change permissions" : "Não é possível alterar as permissões.",
    "Import contacts" : "Importar contactos",
    "Import into the {addressbookName} address book" : "Importar para o livro de endereços {addressbookName}",
    "Select local file" : "Escolher um ficheiro local",
    "Import from files" : "Importar a partir dos arquivos",
    "Importing is disabled because there are no address books available" : "Importação não está ativa, porque não existe nenhuma livro de endereços disponível",
    "Choose a vCard file to import" : "Escolher um vCard para importar",
    "An error occurred, unable to create the address book" : "Ocorreu um erro. Não é possível criar o livro de endereços.",
    "First name" : "Primeiro Nome",
    "Last name" : "Ultimo Nome",
    "Phonetic first name" : "Nome fonético",
    "Phonetic last name" : "Apelido fonético",
    "Display name" : "Nome de apresentação",
    "Last modified" : "Última modificação",
    "Sort by {sorting}" : "Ordenar por {sorting}",
    "Password protection" : "Protegido por palavra-passe",
    "Save" : "Guardar",
    "Description" : "Descrição",
    "Cancel" : "Cancelar",
    "Upload a new picture" : "Carregar nova imagem",
    "Choose from Files" : "Escolher a partir dos ficheiros",
    "Get from " : "Obter de",
    "Download picture" : "Transferir imagem",
    "Delete picture" : "Apagar imagem",
    "Invalid image" : "Imagem inválida",
    "Pick an avatar" : "Escolhe um avatar",
    "Error while processing the picture." : "Erro no processamento da imagem.",
    "No contact selected" : "Nenhum contacto selecionado",
    "Select a contact on the list to begin" : "Para começar, escolhe um contacto desta lista",
    "Name" : "Nome",
    "Title" : "Título",
    "Company" : "Empresa",
    "This contact was broken and received a fix. Please review the content and click here to save it." : "Os dados deste contacto estavam corrompidos e foram recuperados. Verifique se estão corretos e clique aqui para gravar.",
    "Generate QR Code" : "Gera um código QR",
    "Pick an address book" : "Escolha livro de endereços",
    "Select address book" : "Seleccionar livro de endereços",
    "This contact is in read-only mode. You do not have permission to edit this contact." : "Este contacto está protegido contra escrita. Não tem permissão para o modificar.",
    "The contact you were trying to edit has changed. Please manually refresh the contact. Any further edits will be discarded." : "Este contacto que está a editar foi já modificado por outrem. Carregue-o novamente sff. Qualquer modificação será descartada.",
    "Address book" : "Livro de endereços",
    "Syntax error. Cannot open the contact." : "Erro de sintaxe. É impossível mostrar o contacto.",
    "Search contacts …" : "Pesquisar contactos...",
    "No results" : "Sem resultados",
    "Add to group" : "Adicionar ao grupo",
    "Add {type}" : "Adicionar (tipo)",
    "Personal circle" : "Círculo pessoal",
    "Pending" : "Pendente",
    "Chart" : "Gráfico",
    "Select type" : "Escolha o tipo",
    "Select Date" : "Escolha a data",
    "Add contact in group" : "Adicionar contacto ao grupo",
    "Select option" : "Escolher uma opção",
    "New contact" : "Novo contacto",
    "Unable to create the contact." : "Não é possível criar o contacto.",
    "Contact not found" : "Contacto não encontrado",
    "Close" : "Fechar",
    "_Importing %n contact into {addressbook}_::_Importing %n contacts into {addressbook}_" : ["Importar %n contactos para o {addressbook}","Importar %n contactos para o {addressbook}","Importar %n contactos para o {addressbook}"],
    "_Done importing %n contact into {addressbook}_::_Done importing %n contacts into {addressbook}_" : ["Importação de %n contactos para o {addressbook} está concluída.","Importação de %n contactos para o {addressbook} está concluída.","Importação de %n contactos para o {addressbook} está concluída."],
    "Import" : "Importar",
    "Not grouped" : "Não agrupados",
    "Recently contacted" : "Contactados recentemente",
    "Circle" : "Círculo",
    "User" : "Utilizador",
    "Group" : "Grupo",
    "Email" : "Correio Eletrónico",
    "Contact" : "Contacto",
    "Member" : "membro",
    "Moderator" : "Moderador",
    "Admin" : "Administrador",
    "Owner" : "Proprietário",
    "Users" : "Utilizadores",
    "Detailed name" : "Nome em detalhe",
    "Additional names" : "Nomes adicionais",
    "Prefix" : "Prefixo",
    "Suffix" : "Sufixo",
    "Nickname" : "Alcunha",
    "Notes" : "Notas",
    "Website" : "Site da Internet",
    "Location" : "Localização",
    "Federated Cloud ID" : "Id. da Nuvem Federada",
    "Home" : "Casa",
    "Work" : "Emprego",
    "Other" : "Outro",
    "Address" : "Endereço",
    "Post office box" : "Apartado",
    "Extended address" : "Endereço completo",
    "City" : "Cidade",
    "State or province" : "Distrito",
    "Postal code" : "Código Postal",
    "Country" : "País",
    "Birthday" : "Data de nascimento",
    "Anniversary" : "Aniversário",
    "Date of death" : "Data de falecimento",
    "Instant messaging" : "Mensagens Instantâneas",
    "Phone" : "Telefone",
    "Mobile" : "Telemóvel",
    "Work mobile" : "Telefone de emprego",
    "Home mobile" : "Telefone móvel de casa",
    "Fax" : "Fax",
    "Fax home" : "Fax de casa",
    "Fax work" : "Fax do emprego",
    "Pager" : "Pager",
    "Voice" : "Voz",
    "Car" : "Carro",
    "Work pager" : "Pager de trabalho",
    "Manager" : "Gestor",
    "Social network" : "Rede Social",
    "Spouse" : "Cônjuge",
    "Child" : "Filho",
    "Mother" : "Mãe",
    "Father" : "Pai",
    "Parent" : "Progenitor",
    "Brother" : "Irmão",
    "Sister" : "Irmã",
    "Relative" : "Parente",
    "Friend" : "Amigo",
    "Colleague" : "Colega",
    "Assistant" : "Assistente",
    "Related contacts" : "Contactos relacionados",
    "Agent" : "Agente",
    "Emergency" : "Emergência",
    "Co-worker" : "Colega de trabalho",
    "Gender" : "Género",
    "Female" : "Feminino",
    "Male" : "Masculino",
    "None" : "Nenhum",
    "Unknown" : "Desconhecido",
    "Time zone" : "Fuso horário",
    "Spoken languages" : "Línguas faladas",
    "_{failed} contact failed to be read_::_{failed} contacts failed to be read_" : ["{failed} contactos cuja leitura falhou","{failed} contactos cuja leitura falhou","{failed} contactos cuja leitura falhou"],
    "Unable to delete contact" : "Não é possível eliminar o contacto."
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
