OC.L10N.register(
    "contacts",
    {
    "Details" : "Tiedot",
    "All contacts" : "Kaikki yhteystiedot",
    "Contacts" : "Yhteystiedot",
    "A contacts app for Nextcloud" : "Yhteystietosovellus Nextcloudille",
    "The Nextcloud contacts app is a user interface for Nextcloud's CardDAV server. Easily sync contacts from various devices with your Nextcloud and edit them online.\n\n* 🚀 **Integration with other Nextcloud apps!** Currently Mail and Calendar – more to come.\n* 🎉 **Never forget a birthday!** You can sync birthdays and other recurring events with your Nextcloud Calendar.\n* 👥 **Sharing of Adressbooks!** You want to share your contacts with your friends or coworkers? No problem!\n* 🙈 **We’re not reinventing the wheel!** Based on the great and open SabreDAV library." : "Nextcloud kontaktit -sovellus on käyttölittymä Nextcloudin CardDAV palvelimeen. Synkronoi kontakteja helposti eri laitteilta Nextcloudilla ja muokkaa niitä netissä.\n\n* 🚀 **Yhteensopiva muiden Nextcloud-sovellusten kanssa!** Tällä hetkellä sähkoposti ja kalenteri ja lisää on tulossa\n* 🎉 **Et enää ikinä unohda yhtään syntymäpäivää!** voit synkronoida syntymäpäivät ja muut toistuvat tapahtumat Nextcloud kalenterilla\n* 👥 **Osoitekirjojen jakaminen!** Haluatko jakaa kontaktisi kaverien tai työkaverien kanssa? Onnistuu!\n* 🙈 **Emme ole keksineet pyörää uudestaan!** Perustuu mahtavaan ja avoimeen SabreDAV kirjastoon.",
    "Copy to full name" : "Kopioi koko nimeksi",
    "Omit year" : "Jätä vuosiluku pois",
    "Allow updating avatars from social media" : "Salli avatar-kuvien päivittäminen sosiaalisesta mediasta",
    "Please select a circle" : "Valitse piiri",
    "Loading circle …" : "Ladataan piiriä...",
    "Your request to join this circle is pending approval" : "Pyyntösi liittyä piiriin odottaa hyväksyntää",
    "You are not a member of {circle}" : "Et ole piirin {circle} jäsen",
    "There was an error fetching the member list" : "Jäsen listan hakemisessa tapahtui virhe",
    "Loading contacts …" : "Ladataan yhteystietoja…",
    "There are no contacts yet" : "Ei yhtään jäsentä vielä",
    "Create contact" : "Luo yhteystieto",
    "There are no contacts in this group" : "Tässä ryhmässä ei ole yhteystietoja",
    "Create contacts" : "Luo yhteystietoja",
    "Add contacts" : "Lisää yhteystietoja",
    "Loading …" : "Ladataan…",
    "Add member" : "Lisää jäsen",
    "Leave circle" : "Poistu piiristä",
    "Delete circle" : "Poista piiri",
    "Contacts settings" : "Yhteystietojen asetukset",
    "General settings" : "Yleiset asetukset",
    "Update avatars from social media" : "Päivitä avatar-kuvat sosiaalisesta mediasta",
    "(refreshed once per week)" : "(päivitetään kerran viikossa)",
    "Address books" : "Osoitekirjat",
    "Export" : "Vie",
    "Send email" : "Lähetä sähköposti",
    "Send email as BCC" : "Lähetä sähköposti piilokopiona",
    "Contact groups" : "Yhteystietoryhmät",
    "Create a new contact group" : "Luo uusi yhteystietoryhmä",
    "Contact group name" : "Yhteystietoryhmän nimi",
    "Circles" : "Piirit",
    "Create a new circle" : "Luo uusi piiri",
    "Show all groups" : "Näytä kaikki ryhmät",
    "Collapse groups" : "Supista ryhmät",
    "Show all circles" : "Näytä kaikki piirit",
    "Collapse circles" : "Supista piirit",
    "This group already exists" : "Tämä ryhmä on jo olemassa",
    "This circle already exists" : "Piiri on jo olemassa",
    "An error happened during the creation of the circle" : "Piirin luomisen yhteydessä tapahtui virhe",
    "{addressbookname} (Disabled)" : "{addressbookname} (pois käytöstä)",
    "Download" : "Lataa",
    "Show" : "Näytä",
    "Rename" : "Nimeä uudelleen",
    "Delete" : "Poista",
    "Copied" : "Kopioitu",
    "Cannot copy" : "Ei voida kopioida",
    "Copy link" : "Kopioi linkki",
    "Toggling of address book was not successful" : "Osoitekirjan vaihtaminen epäonnistui",
    "This will delete the address book and every contacts within it" : "Tämä poistaa osoitekirjan ja kaikki siinä olevat yhteystiedot",
    "Delete {addressbook}?" : "Poistetaanko {addressbook}?",
    "Deletion of address book was not successful." : "Osoitekirjan poistaminen ei onnistunut.",
    "Renaming of address book was not successful." : "Osoitekirjan nimeäminen uudelleen ei onnistunut.",
    "_%n contact_::_%n contacts_" : ["%n yhteystieto","%n yhteystietoa"],
    "_%n group_::_%n groups_" : ["%n ryhmä","%n ryhmää"],
    "_Shared with {num} entity_::_Shared with {num} entities_" : ["Jaettu {num} entiteetin kanssa","Jaettu {num} entiteetin kanssa"],
    "Share with users or groups" : "Jaa käyttäjien tai ryhmien kanssa",
    "Share with users" : "Jaa käyttäjien kanssa",
    "No users or groups" : "Ei käyttäjiä tai ryhmiä",
    "can edit" : "voi muokata",
    "Unable to delete the share" : "Jakoa ei voitu poistaa",
    "Unable to change permissions" : "Käyttöoikeuksia ei voitu muuttaa",
    "Import contacts" : "Tuo yhteystietoja",
    "Import into the {addressbookName} address book" : "Tuo osoitekirjaan \"{addressbookName}\"",
    "Select local file" : "Valitse paikallinen tiedosto",
    "Import from files" : "Tuo tiedostoista",
    "Importing is disabled because there are no address books available" : "Tuonti on pois käytöstä, koska osoitekirjoja ei ole käytettävissä",
    "Choose a vCard file to import" : "Valitse tuotava vCard-tiedosto",
    "Add new address book" : "Lisää uusi osoitekirja",
    "An error occurred, unable to create the address book" : "Tapahtui virhe, osoitekirjaa ei voitu luoda",
    "First name" : "Etunimi",
    "Last name" : "Sukunimi",
    "Phonetic first name" : "Foneettinen etunimi",
    "Phonetic last name" : "Foneettinen sukunimi",
    "Display name" : "Näyttönimi",
    "Last modified" : "Viimeksi muokattu",
    "Sort by {sorting}" : "Järjestysperuste {sorting}",
    "Manages" : "Johtaa",
    "Oversees" : "Valvoo",
    "Password protection" : "Salasanasuojaus",
    "Enforce password protection on files shared to this circle" : "Pakota salasanasuojaus tässä piirissä jaettuihin tiedostoihin",
    "Use a unique password for all shares to this circle" : "Käytä eri salasanaa kaikille tämän piirin jaoille",
    "Unique password …" : "Ainutkertainen salasana…",
    "Save" : "Tallenna",
    "Change unique password" : "Vaihda yksilöllinen salasana",
    "Failed to save password. Please try again later." : "Salasanan tallentaminen epäonnistui. Yritä myöhemmin uudelleen.",
    "Circle name" : "Piirin nimi",
    "Circle owned by {owner}" : "Piirin omistaa {owner}",
    "Request to join" : "Pyydä liittymistä",
    "Description" : "Kuvaus",
    "There is no description for this circle" : "Tällä piirillä ei ole kuvausta",
    "Enter a description for the circle" : "Anna kuvaus piirille",
    "An error happened during description sync" : "Kuvaussynkronoinnin aikana tapahtui virhe",
    "An error happened during name sync" : "Nimisynkronoinnin aikana tapahtui virhe",
    "Add more info" : "Lisää enemmän tietoja",
    "More fields" : "Lisää kenttiä",
    "Crop contact photo" : "Rajaa yhteystiedon kuva",
    "Cancel" : "Peruuta",
    "Upload a new picture" : "Lähetä uusi kuva",
    "Choose from Files" : "Valitse Tiedostoista",
    "Get from " : "Ota kohteesta",
    "Download picture" : "Lataa kuva",
    "Delete picture" : "Poista kuva",
    "Please select a valid format" : "Valitse kelvollinen muoto",
    "Invalid image" : "Virheellinen kuva",
    "Error cropping picture" : "Virhe kuvaa rajatessa",
    "Pick an avatar" : "Valitse avatar",
    "Error while processing the picture." : "Virhe kuvan käsittelyn aikana.",
    "Avatar downloaded from social network" : "Avatar-kuva ladattu sosiaalisesta verkosta",
    "Avatar already up to date" : "Avatar on jo ajan tasalla",
    "Avatar download failed" : "Avatarin lataus epäonnistui",
    "No contact selected" : "Yhteystietoa ei ole valittu",
    "Select a contact on the list to begin" : "Valitse yhteystieto luettelosta aloittaaksesi",
    "Name" : "Nimi",
    "Title" : "Nimeke",
    "Company" : "Yritys",
    "This contact was broken and received a fix. Please review the content and click here to save it." : "Tämä yhteystieto oli rikki ja sai korjauksen. Ole hyvä ja tarkista sisältö, ja sitten paina tästä tallentaaksesi.",
    "Edit" : "Muokkaa",
    "Clone contact" : "Kloonaa yhteystieto",
    "Generate QR Code" : "Luo QR-koodi",
    "Contact vCard as QR code" : "Yhteystiedon vCard QR-koodina",
    "Pick an address book" : "Valitse osoitekirja",
    "Select address book" : "Valitse osoitekirja",
    "This contact is in read-only mode. You do not have permission to edit this contact." : "Tämä yhteystieto on \"vain luku\"-tilassa. Sinulla ei ole oikeuksia muokata tätä yhteystietoa.",
    "The contact you were trying to edit has changed. Please manually refresh the contact. Any further edits will be discarded." : "Yhteystieto, jota yritit muokata, muuttui. Ole hyvä ja päivitä yhteystieto manuaalisesti. Seuraavia muutoksia ei tallenneta.",
    "Address book" : "Osoitekirja",
    "Add contact to Birthday Calendar" : "Lisää yhteystieto syntymäpäiväkalenteriin",
    "Exclude contact from Birthday Calendar" : "Älä sisällytä yhteystietoa syntymäpäiväkalenteriin",
    "{title} at {organization}" : "{title} organisaatiossa {organization}",
    "Syntax error. Cannot open the contact." : "Syntaksivirhe. Yhteystietoa ei voi avata.",
    "The contact does not exist on the server anymore." : "Yhteystietoa ei ole enää olemassa palvelimella.",
    "Unable to retrieve the contact from the server, please check your network connection." : "Yhteystietoa ei kyetty hakemaan palvelimelta. Ole hyvä ja tarkista yhteytesi internetiin.",
    "An error occurred while trying to move the contact" : "Yhteystietoa siirtäessä tapahtui virhe",
    "An error occurred while trying to copy the contact" : "Yhteystietoa kopioitaessa tapahtui virhe",
    "Unable to update contact" : "Yhteystietoa ei voitu päivittää",
    "Search contacts …" : "Etsi yhteystietoja…",
    "Add to {group}" : "Lisää ryhmään {group}",
    "Remove {type}" : "Poista {type}",
    "Search {types}" : "Hae {types}",
    "Search for people to add" : "Etsi ihmisiä lisättäväksi",
    "No results" : "Ei tuloksia",
    "Add to group" : "Lisää ryhmään",
    "Add {type}" : "Lisää {type}",
    "New circle name" : "Uusi piirin nimi",
    "Personal circle" : "Henkilökohtainen piiri",
    "This circle will only be visible to you. Other members will not be able to see or use it." : "Tämä piiri on näkyvissä vain sinulle. Muut jäsenet eivät näe sitä tai voi käyttää sitä.",
    "Local circle" : "Paikallinen piiri",
    "Create circle" : "Luo piiri",
    "Loading members list …" : "Ladataan jäsenluetteloa…",
    "The list of members is only visible to members of this circle" : "Jäsenlista on näkyvissä vain muille tämän piirin jäsenille",
    "You currently have no access to the member list" : "Sinulla ei ole pääsyä käyttäjälistaan",
    "Add members" : "Lisää jäseniä",
    "Show circle details" : "Näytä piirin tiedot",
    "Add to {circle}" : "Lisää piiriin {circle}",
    "Unable to get the recommendations list" : "Suositusluetteloa ei saatu",
    "Unable to get the results" : "Tuloksia ei saatu",
    "Some members could not be added" : "Joitain jäseniä ei voitu lisätä",
    "There was an issue adding members to the circle" : "Jäsentä lisättäessä piiriin ilmeni ongelma",
    "Accept membership request" : "Hyväksy jäsenyyspyyntö",
    "Reject membership request" : "Hylkää jäsenyyspyyntö",
    "Manage level" : "Hallinnoi tasoa",
    "Remove member" : "Poista jäsen",
    "Pending" : "Odottaa",
    "Promote as sole owner" : "Siirrä omistajuus",
    "Promote to {level}" : "Ylennsä tasolle {level}",
    "Demote to {level}" : "Alenna tasolle {level}",
    "Could not delete the member {displayName}" : "Ei voitu poistaa jäsentä {displayName}",
    "Could not change the member level to {level}" : "Jäsenen tasoksi ei voitu vaihtaa {level}",
    "Could not accept membership request" : "Jäsenyyspyyntöä ei voitu hyväksyä",
    "Chart" : "Kaavio",
    "Select chart …" : "Valitse kaavio…",
    "Select type" : "Valitse tyyppi",
    "Select Date" : "Valitse päivä",
    "Add contact in group" : "Lisää yhteystieto ryhmään",
    "none" : "ei mitään",
    "Select option" : "Valitse valinta",
    "Add property of this type" : "Lisää tätä tyyppiä oleva ominaisuus",
    "New contact" : "Uusi yhteystieto",
    "Unable to create the contact." : "Yhteystiedon luominen ei onnistunut.",
    "Contact not found" : "Yhteytietoa ei löytynyt",
    "Group {group} not found" : "Ryhmää {group} ei löydy",
    "Close" : "Sulje",
    "_{success} contact added to {name}_::_{success} contacts added to {name}_" : ["{success} yhteystieto lisätty ryhmään {name}","{success} yhteystietoa lisätty ryhmään {name}"],
    "_Adding {success} contact to {name}_::_Adding {success} contacts to {name}_" : ["Lisätään {success} yhteystieto ryhmään {name}","Lisätään {success} yhteystietoa ryhmään {name}"],
    "_{count} error_::_{count} errors_" : ["{count} virhe","{count} virhettä"],
    "_Importing %n contact into {addressbook}_::_Importing %n contacts into {addressbook}_" : ["Tuodaan %n yhteystieto osoitekirjaan {addressbook}","Tuodaan %n yhteystietoa osoitekirjaan {addressbook}"],
    "_Done importing %n contact into {addressbook}_::_Done importing %n contacts into {addressbook}_" : ["%n yhteystiedon tuominen osoitekirjaan {addressbook} valmistui","%n yhteystiedon tuominen osoitekirjaan {addressbook} onnistui"],
    "Import" : "Tuo",
    "Could not copy" : "Ei voitu kopioida",
    "Join circle" : "Liity piiriin",
    "You are about to leave {circle}.\nAre you sure?" : "Olet aikeissa poistua piiristä {circle}.\nOletko varma?",
    "Please confirm circle leave" : "Vahvista piiristä poistuminen",
    "Could not leave the circle {displayName}" : "Ei voitu poistua piiristä {displayName}",
    "Unable to join the circle" : "Piiriin ei voitu liittyä",
    "You are about to delete {circle}.\nAre you sure?" : "Olet aikeissa poistaa piirin {circle}.\nOletko varma?",
    "Please confirm circle deletion" : "Vahvista piirin poistaminen",
    "Unable to delete the circle" : "Piiriä ei voitu poistaa",
    "Link copied to the clipboard" : "Linkki kopioitu leikepöydälle",
    "Could not copy link to the clipboard." : "Linkkiä ei voitu kopioida leikepöydälle.",
    "Not grouped" : "Ei ryhmitelty",
    "Recently contacted" : "Äskettäin yhteydessä",
    "Organization chart" : "Organisaatiokaavio",
    "Circle" : "Piiri",
    "User" : "Käyttäjä",
    "Group" : "Ryhmä",
    "Email" : "Sähköpostiosoite",
    "Contact" : "Yhteystieto",
    "Member" : "Jäsen",
    "Moderator" : "Moderaattori",
    "Admin" : "Ylläpitäjä",
    "Owner" : "Omistaja",
    "Invites" : "Kutsut",
    "Anyone can request membership" : "Kuka tahansa voi pyytää jäsenyyttä",
    "Members need to accept invitation" : "Jäsenten tulee hyväksyä kutsu",
    "Memberships must be confirmed/accepted by a Moderator (requires Open)" : "Jäsenyydet tulee vahvistaa/hyväksyä moderaattorin toimesta (vaatii avoimen)",
    "Members can also invite" : "Myös jäsenet voivat kutsua",
    "Visibility" : "Näkyvyys",
    "Visible to everyone" : "Näkyy kaikille",
    "Circle membership" : "Piirin jäsenyys",
    "Prevent circle from being a member of another circle" : "Estä piirin jäsenyys toisessa piirissä",
    "Users" : "Käyttäjät",
    "Email addresses" : "Sähköpostiosoitteet",
    "Detailed name" : "Täsmällinen nimi",
    "Additional names" : "Lisänimet",
    "Prefix" : "Etuliite",
    "Suffix" : "Takaliite",
    "Nickname" : "Kutsumanimi",
    "Notes" : "Huomiot",
    "Website" : "Verkkosivusto",
    "Location" : "Sijainti",
    "Federated Cloud ID" : "Federoidun pilven tunniste",
    "Home" : "Koti",
    "Work" : "Työ",
    "Other" : "Muu",
    "Address" : "Osoite",
    "Post office box" : "Postilokero",
    "Extended address" : "Laajennettu osoite",
    "City" : "Paikkakunta",
    "State or province" : "Maakunta tai osavaltio",
    "Postal code" : "Postinumero",
    "Country" : "Maa",
    "Birthday" : "Syntymäpäivä",
    "Anniversary" : "Vuosipäivä",
    "Date of death" : "Kuolinpäivä",
    "Instant messaging" : "Pikaviestintä",
    "Phone" : "Puhelin",
    "Mobile" : "Mobiili",
    "Work mobile" : "Työmatkapuhelin",
    "Home mobile" : "Kotimatkapuhelin",
    "Fax" : "Faksi",
    "Fax home" : "Faksi, koti",
    "Fax work" : "Faksi, työ",
    "Pager" : "Hakulaite",
    "Voice" : "Ääni",
    "Car" : "Auto",
    "Work pager" : "Työhakulaite",
    "Manager" : "Esimies",
    "Social network" : "Sosiaalinen verkosto",
    "Relationship to you" : "Suhde sinuun",
    "Spouse" : "Puoliso",
    "Child" : "Lapsi",
    "Mother" : "Äiti",
    "Father" : "Isä",
    "Parent" : "Vanhempi",
    "Brother" : "Veli",
    "Sister" : "Sisko",
    "Relative" : "Sukulainen",
    "Friend" : "Kaveri",
    "Colleague" : "Työkaveri",
    "Assistant" : "Avustaja",
    "Related contacts" : "Samanlaiset kontaktit",
    "Agent" : "Agentti",
    "Emergency" : "Hätä",
    "Co-worker" : "Työkaveri",
    "Gender" : "Sukupuoli",
    "Female" : "Nainen",
    "Male" : "Mies",
    "None" : "Ei mitään",
    "Unknown" : "Tuntematon",
    "Time zone" : "Aikavyöhyke",
    "Spoken languages" : "Puhutut kielet",
    "_{failed} contact failed to be read_::_{failed} contacts failed to be read_" : ["{failed} yhteystietoa ei voitu lukea","{failed} yhteystietoa ei voitu lukea"],
    "An error has occurred in circle(s). Check the console for more details." : "Piirissä tai piireissä tapahtui virhe. Katso lisätiedot konsolista.",
    "Unable to create circle {circleName}" : "Ei voitu luoda piiriä {circleName}",
    "Unable to delete circle {circleId}" : "Ei voitu poistaa piiriä {circleId}",
    "Unable to delete contact" : "Yhteystietoa ei voitu poistaa"
},
"nplurals=2; plural=(n != 1);");
