/**
 * @copyright Copyright (c) 2018 John Molakvoæ <skjnldsv@protonmail.com>
 *
 * @author John Molakvoæ <skjnldsv@protonmail.com>
 * @author Team Popcorn <teampopcornberlin@gmail.com>
 * @author Richard Steinmetz <richard@steinmetz.cloud>
 *
 * @license GNU AGPL version 3 or any later version
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 *
 */

$grid-height-unit: 40px;
$grid-input-padding: 7px;
$grid-input-margin: 3px;
$grid-input-height-with-margin: $grid-height-unit - $grid-input-margin * 2;

// components
@import 'SettingsSection';
@import 'Settings/SettingsAddressbookShares';
@import 'Settings/SettingsAddressbookSharee';
@import 'ContactsListItem';
@import 'Properties/Properties';
@import 'ImportScreen';

// various
@import 'animations';

.app-content-details {
	padding: calc(var(--default-grid-baseline) * 2);
	padding-top: 0;
	height: 100%;
	overflow: auto;

	// Compensate top padding reserved for the back button on mobile
	@media (max-width: 1024px) {
		height: calc(100% - 44px);
	}
}

.app-content-list {
	// Cancel scrolling
	overflow: visible;
}
