OC.L10N.register(
    "contacts",
    {
    "Details" : "Detalios",
    "All contacts" : "Tote contactos",
    "Contacts" : "Contactos",
    "Send email" : "Inviar message de e-posta",
    "Download" : "Discargar",
    "Rename" : "Renominar",
    "Delete" : "Deler",
    "Copy link" : "Copiar ligamine",
    "Share with users or groups" : "Compartir con usatores o gruppos",
    "can edit" : "pote modificar",
    "First name" : "Prime nomine",
    "Last name" : "Ultime nomine",
    "Display name" : "Monstrar nomine",
    "Password protection" : "Password protection",
    "Save" : "Salveguardar",
    "Description" : "Description",
    "Cancel" : "Cancellar",
    "Invalid image" : "Imagine invalide",
    "Name" : "Nomine",
    "Title" : "Titulo",
    "Pending" : "Pendente",
    "New contact" : "Nove contacto",
    "Close" : "Clauder",
    "Import" : "Importar",
    "Not grouped" : "Non gruppate",
    "User" : "User",
    "Group" : "Gruppo",
    "Email" : "E-posta",
    "Owner" : "Owner",
    "Users" : "Usatores",
    "Detailed name" : "Nomine detaliate",
    "Additional names" : "Nomines additional",
    "Prefix" : "Prefixo",
    "Suffix" : "Suffixo",
    "Nickname" : "Pseudonymo",
    "Notes" : "Notas",
    "Website" : "Sito web",
    "Location" : "Loco",
    "Federated Cloud ID" : "ID del Nube Federate",
    "Home" : "Domo",
    "Work" : "Travalio",
    "Other" : "Altere",
    "Address" : "Adresse",
    "Post office box" : "Cassa postal",
    "City" : "Citate",
    "State or province" : "Stato o provincia",
    "Postal code" : "Codice postal",
    "Country" : "Pais",
    "Birthday" : "Anniversario de nativitate",
    "Anniversary" : "Anniversario de evento",
    "Date of death" : "Data de morte",
    "Instant messaging" : "Messageria instantanee",
    "Phone" : "Phono",
    "Mobile" : "Mobile",
    "Fax" : "Fax",
    "Fax home" : "Fax a domicilio",
    "Fax work" : "Fax a travalio",
    "Pager" : "Pager",
    "Voice" : "Voce",
    "Social network" : "Medios Social",
    "Relative" : "Relative",
    "None" : "Nulle",
    "Unknown" : "Incognite"
},
"nplurals=2; plural=(n != 1);");
