OC.L10N.register(
    "contacts",
    {
    "Contacts" : "ئالاقەداشلار",
    "Download" : "چۈشۈر",
    "Rename" : "ئات ئۆزگەرت",
    "Delete" : "ئۆچۈر",
    "First name" : "ئاتى",
    "Password protection" : "Password protection",
    "Save" : "ساقلا",
    "Description" : "چۈشەندۈرۈش",
    "Cancel" : "ۋاز كەچ",
    "Name" : "ئاتى",
    "Title" : "ماۋزۇ",
    "Pending" : "كۈتۈۋاتىدۇ",
    "Close" : "ياپ",
    "Import" : "ئەكىر",
    "User" : "User",
    "Group" : "Group",
    "Email" : "تورخەت",
    "Owner" : "Owner",
    "Users" : "ئىشلەتكۈچىلەر",
    "Nickname" : "تەخەللۇس",
    "Notes" : "ئىزاھاتلار",
    "Location" : "ئورنى",
    "Home" : "ئۆي",
    "Work" : "ئىش",
    "Other" : "باشقا",
    "Address" : "ئادرېس",
    "City" : "شەھەر",
    "Postal code" : "پوچتا نومۇرى",
    "Country" : "دۆلەت",
    "Birthday" : "تۇغۇلغان كۈن",
    "Phone" : "تېلېفون",
    "Mobile" : "كۆچمە",
    "Fax" : "فاكىس",
    "Pager" : "چاقىرغۇ",
    "Voice" : "ئاۋاز",
    "None" : "يوق"
},
"nplurals=2; plural=(n != 1);");
