OC.L10N.register(
    "contacts",
    {
    "Contacts" : "Kontakti",
    "Send email" : "Pošalji e-poštu",
    "Download" : "Preuzmi",
    "Rename" : "Preimenuj",
    "Delete" : "Obriši",
    "can edit" : "mogu mijenjati",
    "First name" : "Ime",
    "Last name" : "Prezime",
    "Password protection" : "Password protection",
    "Save" : "Spremi",
    "Description" : "Opis",
    "Cancel" : "Otkaži",
    "Invalid image" : "Nevažeća datoteka",
    "Name" : "Ime",
    "Title" : "Naslov",
    "Personal circle" : "Osobni krug",
    "Pending" : "Na čekanju",
    "New contact" : "Novi kontakt",
    "Close" : "Zatvori",
    "Import" : "Uvoz",
    "Not grouped" : "Nije grupirano",
    "Circle" : "Krug",
    "User" : "User",
    "Group" : "Grupa",
    "Email" : "E-pošta",
    "Member" : "Član",
    "Admin" : "Administrator",
    "Owner" : "Vlasnik",
    "Users" : "Korisnici",
    "Additional names" : "Dodatna imena",
    "Nickname" : "Nadimak",
    "Notes" : "Notes",
    "Website" : "Web-prezentacija",
    "Location" : "Lokacija",
    "Home" : "Kuća",
    "Work" : "Posao",
    "Other" : "Ostali",
    "Address" : "Adresa",
    "City" : "Grad",
    "State or province" : "Savezna država ili pokrajina",
    "Postal code" : "Poštanski broj",
    "Country" : "Država",
    "Birthday" : "Rođendan",
    "Instant messaging" : "Razmjena izravnih poruka",
    "Phone" : "Telefon",
    "Mobile" : "Mobitel",
    "Fax" : "Faks",
    "Pager" : "Dojavljivač",
    "Voice" : "Glas",
    "None" : "Ništa",
    "Unknown" : "Nepoznato"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
