OC.L10N.register(
    "contacts",
    {
    "Details" : "বিসতারিত",
    "Contacts" : "পরিচিতজন",
    "Send email" : "ইমেইল পাঠান ",
    "Download" : "ডাউনলোড",
    "Rename" : "পূনঃনামকরণ",
    "Delete" : "মুছে",
    "Copy link" : "লিঙ্ক কপি করো",
    "can edit" : "সম্পাদনা করতে পারবেন",
    "First name" : "নামের প্রথমাংশ ",
    "Last name" : "নামের শেষাংশ",
    "Password protection" : "Password protection",
    "Save" : "সংরক্ষণ",
    "Description" : "বিবরণ",
    "Cancel" : "বাতির",
    "Invalid image" : "অবৈধ চিত্র",
    "Name" : "নাম",
    "Title" : "শিরোনাম",
    "Pending" : "মুলতুবি",
    "New contact" : "নতুন ঠিকানা",
    "Close" : "বন্ধ",
    "Import" : "আমদানি",
    "Not grouped" : "দলবদ্ধ নয়",
    "User" : "User",
    "Group" : "গোষ্ঠীসমূহ",
    "Email" : "ইমেইল",
    "Admin" : "প্রশাসন",
    "Owner" : "Owner",
    "Users" : "ব্যবহারকারী",
    "Additional names" : "অতিরিক্ত নামসমূহ",
    "Nickname" : "ছদ্মনাম",
    "Notes" : "নোট",
    "Website" : "ওয়েবসাইট",
    "Location" : "অবস্থান",
    "Home" : "নিবাস",
    "Work" : "কর্মস্থল",
    "Other" : "অন্যান্য",
    "Address" : "ঠিকানা",
    "City" : "শহর",
    "State or province" : "রাজ্য কিংবা প্রদেশ",
    "Postal code" : "পোস্টাল কোড",
    "Country" : "দেশ",
    "Birthday" : "জন্মদিন",
    "Instant messaging" : "তাৎক্ষণিক বার্তা",
    "Phone" : "ফোন",
    "Mobile" : "মোবাইল",
    "Fax" : "ফ্যাক্স",
    "Pager" : "পেজার",
    "Voice" : "কন্ঠ",
    "None" : "কোনটিই নয়",
    "Unknown" : "অজানা"
},
"nplurals=2; plural=(n != 1);");
