OC.L10N.register(
    "contacts",
    {
    "Details" : "Részletek",
    "All contacts" : "Összes névjegy",
    "Contacts" : "Névjegyek",
    "A contacts app for Nextcloud" : "Névjegyek alkalmazás a Nextcloudhoz",
    "The Nextcloud contacts app is a user interface for Nextcloud's CardDAV server. Easily sync contacts from various devices with your Nextcloud and edit them online.\n\n* 🚀 **Integration with other Nextcloud apps!** Currently Mail and Calendar – more to come.\n* 🎉 **Never forget a birthday!** You can sync birthdays and other recurring events with your Nextcloud Calendar.\n* 👥 **Sharing of Adressbooks!** You want to share your contacts with your friends or coworkers? No problem!\n* 🙈 **We’re not reinventing the wheel!** Based on the great and open SabreDAV library." : "A Nextcloud Névjegyek alkalmazás egy felhasználói felület a Nextcloud CardDAV-kiszolgálójához. Az alkalmazás segítségével könnyedén szinkronizálható a többféle eszközön meglévő névjegylista, amely szinkronizálás után online szerkeszthető.\n\n* 🚀 **Integráció más nextcloudos alkalmazásokkal!** Jelenleg a Levelek és a Naptár alkalmazással – de továbbiak várhatóak.\n* 🎉 **Ne hagyjon ki egy születésnapot sem!** A névjegyekben található születésnapok és más események szinkronizálhatók a Naptár alkalmazással.\n* 👥 **Névjegyek megosztása!** Meg akarja osztani a névjegyeit a barátaival vagy kollégáival? Nem probléma!\n* 🙈 **Nem találtuk fel újra kereket!** A nagyszerű és nyílt forráskódú SabreDav programkönyvtárra építünk.",
    "Copy to full name" : "Másolás a teljes névbe",
    "Omit year" : "Év kihagyása",
    "Allow updating avatars from social media" : "A profilképek közösségi médiából történő frissítésének engedélyezése",
    "Please select a circle" : "Válasszon egy kört",
    "Loading circle …" : "Kör betöltése…",
    "Your request to join this circle is pending approval" : "A körhöz való csatlakozási kérés jóváhagyásra vár",
    "You are not a member of {circle}" : "Nem tagja a(z) {circle} körnek",
    "There was an error fetching the member list" : "Hiba történt a taglista lekérésekor",
    "Loading contacts …" : "Névjegyek betöltése…",
    "There are no contacts yet" : "Még nincsenek névjegyek",
    "Create contact" : "Névjegy létrehozása",
    "There are no contacts in this group" : "Ebben a csoportban nincsenek névjegyek",
    "Create contacts" : "Névjegyek létrehozása",
    "Add contacts" : "Névjegyek hozzáadása",
    "Loading …" : "Betöltés…",
    "Add member" : "Tag felvétele",
    "Leave circle" : "Kör elhagyása",
    "Delete circle" : "Kör törlése",
    "Contacts settings" : "Névjegyek beállításai",
    "General settings" : "Általános beállítások",
    "Update avatars from social media" : "Profilképek frissítése a közösségi médiából",
    "(refreshed once per week)" : "(hetente egyszer frissítve)",
    "Address books" : "Címjegyzékek",
    "Export" : "Exportálás",
    "Send email" : "E-mail küldése",
    "Send email as BCC" : "E-mail küldése rejtett másolatként",
    "Contact groups" : "Névjegycsoportok",
    "Create a new contact group" : "Új nébjegycsoport létrehozása",
    "Contact group name" : "Névjegycsoport neve",
    "Circles" : "Körök",
    "Create a new circle" : "Új kör létrehozása",
    "Show all groups" : "Összes csoport megjelenítése",
    "Collapse groups" : "Csoportok összecsukása",
    "Show all circles" : "Összes kör megjelenítése",
    "Collapse circles" : "Körök összecsukása",
    "This group already exists" : "Ez a csoport már létezik",
    "This circle already exists" : "Ez a kör már létezik",
    "An error happened during the creation of the circle" : "Hiba történt a kör létrehozása során",
    "{addressbookname} (Disabled)" : "{addressbookname} (Letiltva)",
    "Download" : "Letöltés",
    "Show" : "Megjelenítés",
    "Rename" : "Átnevezés",
    "Delete" : "Törlés",
    "Copied" : "Másolva",
    "Cannot copy" : "Nem lehet másolni",
    "Copy link" : "Hivatkozás másolása",
    "Toggling of address book was not successful" : "A címjegyzék átváltása sikertelen",
    "This will delete the address book and every contacts within it" : "Ez törli a címjegyzéket és a benne található összes névjegyet",
    "Delete {addressbook}?" : "Törli a(z) {addressbook} címjegyzéket?",
    "Deletion of address book was not successful." : "A címjegyzék törlése sikertelen.",
    "Renaming of address book was not successful." : "A címjegyzék átnevezése sikertelen.",
    "_%n contact_::_%n contacts_" : ["%n névjegy","%n névjegy"],
    "_%n group_::_%n groups_" : ["%n csoport","%n csoport"],
    "_Shared with {num} entity_::_Shared with {num} entities_" : ["Megosztva {num} entitással","Megosztva {num} entitással"],
    "Share with users or groups" : "Megosztás felhasználókkal vagy csoportokkal",
    "Share with users" : "Megosztás felhasználókkal",
    "No users or groups" : "Nincsenek felhasználók vagy csoportok",
    "can edit" : "szerkesztheti",
    "Unable to delete the share" : "Nem lehet törölni a megosztást",
    "Unable to change permissions" : "Nem lehet megváltoztatni a jogosultságokat",
    "Import contacts" : "Névjegyek importálása",
    "Import into the {addressbookName} address book" : "Importálás a(z) {addressbookName} címjegyzékbe",
    "Select local file" : "Helyi fájl kiválasztása",
    "Import from files" : "Importálás fájlokból",
    "Importing is disabled because there are no address books available" : "Az importálás nincs engedélyezve mert nem található címjegyzék",
    "Choose a vCard file to import" : "Válasszon egy importálandó vCard fájlt",
    "Add new address book" : "Új címjegyzék hozzáadása",
    "An error occurred, unable to create the address book" : "Hiba történt, nem sikerült létrehozni a címjegyzéket",
    "First name" : "Utónév",
    "Last name" : "Vezetéknév",
    "Phonetic first name" : "Fonetikus utónév",
    "Phonetic last name" : "Fonetikus vezetéknév",
    "Display name" : "Név megjelenítés",
    "Last modified" : "Utoljára módosítva",
    "Sort by {sorting}" : "Rendezés {sorting} szerint",
    "Manages" : "Kezeli",
    "Oversees" : "Felügyeli",
    "An error happened during the config change" : "Hiba történt a konfiguráció módosításakor",
    "Password protection" : "Jelszavas védelem",
    "Enforce password protection on files shared to this circle" : "Jelszavas védelem kikényszerítése a körrel megosztott fájlok esetén",
    "Use a unique password for all shares to this circle" : "Egyéni jelszavak használata a kör összes megosztása esetén",
    "Unique password …" : "Egyedi jelszó…",
    "Save" : "Mentés",
    "Change unique password" : "Egyedi jelszó módosítása",
    "Failed to save password. Please try again later." : "A jelszó mentése sikertelen. Próbálja újra később.",
    "Circle name" : "Kör neve",
    "Circle owned by {owner}" : "A körnek {owner} a tulajdonosa",
    "Request to join" : "Csatlakozás kérése",
    "Description" : "Leírás",
    "There is no description for this circle" : "Ennek a körnek nincs leírása",
    "Enter a description for the circle" : "Adja meg a kör leírását",
    "An error happened during description sync" : "Hiba történt a leírás szinkronizálása során",
    "An error happened during name sync" : "Hiba történt a név szinkronizálása során",
    "Add more info" : "További információk hozzáadása",
    "More fields" : "További mezők",
    "Crop contact photo" : "Névjegy fényképének levágása",
    "Cancel" : "Mégse",
    "Upload a new picture" : "Új kép feltöltése",
    "Choose from Files" : "Válasszon a Fájlokból",
    "Get from " : "Lekérés innen: ",
    "Download picture" : "Kép letöltése",
    "Delete picture" : "Kép törlése",
    "Please select a valid format" : "Válasszon egy érvényes formátumot",
    "Invalid image" : "Érvénytelen kép",
    "Error cropping picture" : "Hiba a kép levágása során",
    "Pick an avatar" : "Profilkép választása",
    "Error while processing the picture." : "Hiba a kép feldolgozása során.",
    "Avatar downloaded from social network" : "Profilkép letöltve a közösségi hálózatról",
    "Avatar already up to date" : "A profilkép már naprakész",
    "Avatar download failed" : "Profilkép letöltése sikertelen",
    "No contact selected" : "Nincs névjegy kiválasztva",
    "Select a contact on the list to begin" : "Válasszon egy névjegyet a listából a kezdéshez",
    "Name" : "Név",
    "Title" : "Cím",
    "Company" : "Vállalat",
    "This contact was broken and received a fix. Please review the content and click here to save it." : "Ez a névjegy hibás volt és javítást kapott. Tekintse át a tartalmat, és kattintson ide a mentéshez.",
    "Edit" : "Szerkesztés",
    "Clone contact" : "Névjegy klónozása",
    "Generate QR Code" : "QR-kód másolása",
    "Contact vCard as QR code" : "Névjegy vCard QR-kódként",
    "Pick an address book" : "Válasszon címjegyzéket",
    "Select address book" : "Válasszon címjegyzéket",
    "Go to talk conversation" : "Ugrás a beszélgetéshez",
    "View profile" : "Profil megtekintése",
    "This contact is in read-only mode. You do not have permission to edit this contact." : "Ez a névjegy csak olvasható. Nincs jogosultsága szerkeszteni ezt a névjegyet.",
    "The contact you were trying to edit has changed. Please manually refresh the contact. Any further edits will be discarded." : "A szerkesztett névjegy megváltozott. Frissítse kézileg a névjegyet. Minden további módosítás figyelmen kívül lesz hagyva.",
    "Address book" : "Címjegyzék",
    "Add contact to Birthday Calendar" : "Névjegy hozzáadása a születésnapok naptárához",
    "Exclude contact from Birthday Calendar" : "Névjegy kihagyása a születésnapok naptárából",
    "{title} at {organization}" : "{title} a következőnél: {organization}",
    "Syntax error. Cannot open the contact." : "Szintaktikai hiba. Nem lehet megnyitni a kapcsolatot.",
    "The contact does not exist on the server anymore." : "A névjegy már nem létezik a kiszolgálón.",
    "Unable to retrieve the contact from the server, please check your network connection." : "Nem sikerült lekérni a névjegyet a kiszolgálóról, ellenőrizze a hálózati kapcsolatot.",
    "An error occurred while trying to move the contact" : "Hiba történt a névjegy áthelyezése során",
    "An error occurred while trying to copy the contact" : "Hiba történt a névjegy másolása során",
    "Unable to update contact" : "A névjegy nem frissíthető",
    "Search contacts …" : "Névjegyek keresése…",
    "Add to {group}" : "Hozzáadás a(z) {group} csoporthoz",
    "Remove {type}" : "{type} eltávolítása",
    "Search {types}" : "{types} keresése",
    "Search for people to add" : "Hozzáadandó emberek keresése",
    "No results" : "Nincs találat",
    "Add to group" : "Hozzáadás a csoporthoz",
    "Add {type}" : "{type} hozzáadása",
    "New circle name" : "Új kör neve",
    "Personal circle" : "Személyes kör",
    "This circle will only be visible to you. Other members will not be able to see or use it." : "Ez a kör csak az Ön számára látható. Más tagok nem fogják látni, és nem fogják tudni használni.",
    "Local circle" : "Helyi kör",
    "This circle will not be shared with the other instances of the global scale" : "Ez a kör nem lesz megosztva más globális léptékű példányokkal",
    "Create circle" : "Kör létrehozása",
    "Loading members list …" : "Taglista betöltése…",
    "The list of members is only visible to members of this circle" : "A taglista csak a kör tagjai számára látható",
    "You currently have no access to the member list" : "Jelenleg nem fér hozzá a taglistához",
    "Add members" : "Tagok hozzáadása",
    "Show circle details" : "Kör részleteinek megjelenítése",
    "Add to {circle}" : "Hozzáadása a(z) {circle} körhöz",
    "Unable to get the recommendations list" : "A javaslatok nem kérhetők le",
    "Unable to get the results" : "A találatok nem kérhetők le",
    "Some members could not be added" : "Egyes tagok nem adhatók hozzá",
    "There was an issue adding members to the circle" : "Probléma lépett fel a tagok körhöz történő hozzáadásakor",
    "Accept membership request" : "Csatlakozási kérés elfogadása",
    "Reject membership request" : "Csatlakozási kérés visszautasítása",
    "Manage level" : "Szint kezelése",
    "Remove member" : "Tag eltávolítása",
    "Pending" : "Függőben",
    "Promote as sole owner" : "Előléptetés egyedüli tulajdonossá",
    "Promote to {level}" : "Előléptetés {level} szintre",
    "Demote to {level}" : "Lefokozás {level} szintre",
    "Could not delete the member {displayName}" : "{displayName} tagot nem sikerült törölni",
    "Could not change the member level to {level}" : "Nem sikerült a tag szintjét erre állítani: {level}",
    "Could not accept membership request" : "A tagsági kérést nem sikerült elfogadni",
    "Chart" : "Diagram",
    "Select chart …" : "Válasszon diagramot…",
    "Select type" : "Válasszon típust",
    "Select Date" : "Válasszon dátumot",
    "Add contact in group" : "Névjegy hozzáadása a csoporthoz",
    "none" : "egyik sem",
    "Select option" : "Válasszon egy lehetőséget",
    "Add property of this type" : "Ilyen tulajdonság hozzáadása",
    "New contact" : "Új névjegy",
    "Unable to create the contact." : "Nem lehet létrehozni a névjegyet.",
    "Contact not found" : "A névjegy nem található",
    "Group {group} not found" : "A(z) {group} csoport nem található",
    "Close" : "Bezárás",
    "_{success} contact added to {name}_::_{success} contacts added to {name}_" : ["{success} névjegy hozzáadva a következőhöz: {name}","{success} névjegy hozzáadva a következőhöz: {name}"],
    "_Adding {success} contact to {name}_::_Adding {success} contacts to {name}_" : ["{success} névjegy hozzáadása a következőhöz: {name}","{success} névjegy hozzáadása a következőhöz: {name}"],
    "_{count} error_::_{count} errors_" : ["{count} hiba","{count} hiba"],
    "_Importing %n contact into {addressbook}_::_Importing %n contacts into {addressbook}_" : ["%n névjegy importálása a(z) {addressbook} címjegyzékbe","%n névjegy importálása a(z) {addressbook} címjegyzékbe"],
    "_Done importing %n contact into {addressbook}_::_Done importing %n contacts into {addressbook}_" : ["%n névjegy importálása a(z) {addressbook} címjegyzékbe befejeződött","%n névjegy importálása a(z) {addressbook} címjegyzékbe befejeződött"],
    "Import" : "Importálás",
    "Could not copy" : "A másolás nem sikerült",
    "Join circle" : "Csatlakozás a körhöz",
    "You are about to leave {circle}.\nAre you sure?" : "A(z) {circle} kör elhagyására készül.\nBiztos benne?",
    "Please confirm circle leave" : "Erősítse meg a kör elhagyását",
    "Could not leave the circle {displayName}" : "A(z) {displayName} kör elhagyása sikertelen",
    "Unable to join the circle" : "Nem csatlakozhat ehhez a körhöz",
    "You are about to delete {circle}.\nAre you sure?" : "A(z) {circle} kör törlésére készül.\nBiztos benne?",
    "Please confirm circle deletion" : "Erősítse meg a kör törlését",
    "Unable to delete the circle" : "Nem törölheti ezt a kört",
    "Link copied to the clipboard" : "Hivatkozás a vágólapra másolva",
    "Could not copy link to the clipboard." : "A hivatkozás másolása a vágólapra sikertelen.",
    "Not grouped" : "Nem csoportosított",
    "Recently contacted" : "Legutóbbi kapcsolatfelvételek",
    "Organization chart" : "Szervezeti diagram",
    "Circles are groups of people that you can create yourself and with whom you can share data. They can be made up of other accounts or groups of accounts of the Nextcloud instance, but also of contacts from your address book or even external people by simply entering their e-mail addresses." : "A Körök emberek csoportjai, amelyeket Ön is létrehozhat, és akikkel adatokat oszthat meg. Állhatnak a Nextcloud-példányon lévő más fiókokból vagy fiókok csoportjából, de akár állhatnak címjegyzékekben szereplő névjegyekből, vagy az e-mail-címük felsorolásával megadott külsősökből is.",
    "Circle" : "Kör",
    "User" : "Felhasználó",
    "Group" : "Csoport",
    "Email" : "E-mail",
    "Contact" : "Névjegy",
    "Member" : "Tag",
    "Moderator" : "Moderátor",
    "Admin" : "Adminisztrátor",
    "Owner" : "Tulajdonos",
    "Invites" : "Meghívók",
    "Anyone can request membership" : "Bárki kérheti a csatlakozást",
    "Members need to accept invitation" : "A tagoknak el kell fogadniuk a meghívást",
    "Memberships must be confirmed/accepted by a Moderator (requires Open)" : "A tagságokat meg kell erősítenie/el kell fogadnia egy moderátornak (Nyílt beállítás szükséges)",
    "Members can also invite" : "A tagok meghívhatnak másokat",
    "Visibility" : "Láthatóság",
    "Visible to everyone" : "Mindenki számára látható",
    "Circle membership" : "Körtagság",
    "Prevent circle from being a member of another circle" : "Annak megakadályozása, hogy a kör egy másik kör tagja legyen",
    "Users" : "Felhasználók",
    "Email addresses" : "E-mail-címek",
    "Detailed name" : "Részletes név",
    "Additional names" : "További nevek",
    "Prefix" : "Előtag",
    "Suffix" : "Utótag",
    "Nickname" : "Becenév",
    "Notes" : "Jegyzetek",
    "Website" : "Weboldal",
    "Location" : "Hely",
    "Federated Cloud ID" : "Föderált felhőazonosító",
    "Home" : "Otthoni",
    "Work" : "Munkahelyi",
    "Other" : "Egyéb",
    "Address" : "Cím",
    "Post office box" : "Postafiók",
    "Extended address" : "Bővített cím",
    "City" : "Város",
    "State or province" : "Állam vagy tartomány",
    "Postal code" : "Irányítószám",
    "Country" : "Ország",
    "Birthday" : "Születésnap",
    "Anniversary" : "Évforduló",
    "Date of death" : "Halálozás dátuma",
    "Instant messaging" : "Azonnali üzenetküldés",
    "Phone" : "Telefonszám",
    "Mobile" : "Mobil",
    "Work mobile" : "Munkahelyi mobil",
    "Home mobile" : "Otthoni mobil",
    "Fax" : "Fax",
    "Fax home" : "Otthoni fax",
    "Fax work" : "Munkahelyi fax",
    "Pager" : "Személyhívó",
    "Voice" : "Hang",
    "Car" : "Autó",
    "Work pager" : "Munkahelyi csipogó",
    "Manager" : "Vezető",
    "Social network" : "Közösségi hálózat",
    "Relationship to you" : "Kapcsolat Önnel",
    "Spouse" : "Házastárs",
    "Child" : "Gyermek",
    "Mother" : "Anya",
    "Father" : "Apa",
    "Parent" : "Szülő",
    "Brother" : "Fiútestvér",
    "Sister" : "Lánytestvér",
    "Relative" : "Rokon",
    "Friend" : "Ismerős",
    "Colleague" : "Kolléga",
    "Assistant" : "Asszisztens",
    "Related contacts" : "Kapcsolódó névjegyek",
    "Agent" : "Ügynök",
    "Emergency" : "Vészhelyzet",
    "Co-worker" : "Munkatárs",
    "Gender" : "Nem",
    "Female" : "Nő",
    "Male" : "Férfi",
    "None" : "Egyik sem",
    "Unknown" : "Ismeretlen",
    "Time zone" : "Időzóna",
    "Spoken languages" : "Beszélt nyelvek",
    "_{failed} contact failed to be read_::_{failed} contacts failed to be read_" : ["{failed} névjegyet nem sikerült olvasni","{failed} névjegyet nem sikerült olvasni"],
    "An error has occurred in circle(s). Check the console for more details." : "Hiba történt a körökben. További részletekért nézze meg a konzolt.",
    "Unable to create circle {circleName}" : "A(z) {circleName} kör nem hozható létre",
    "Unable to delete circle {circleId}" : "A(z) {circleId} kör nem törölhető",
    "Unable to delete contact" : "A névjegy törlése sikertelen"
},
"nplurals=2; plural=(n != 1);");
