OC.L10N.register(
    "contacts",
    {
    "Details" : "Detajet",
    "All contacts" : "Të gjithë kontaktet",
    "Contacts" : "Kontaktet",
    "A contacts app for Nextcloud" : "Një aplikacion kontaktesh për Nextcloud",
    "Copy to full name" : "Kopje të emrit të plotë ",
    "Omit year" : "Shmang vitin",
    "Loading contacts …" : "Duke ngarkuar kontaktet ...",
    "Delete circle" : "Fshini rrethin",
    "General settings" : "Opsjonet e Pergjithshme",
    "Send email" : "Dërgo email",
    "Circles" : "Rrethet",
    "Create a new circle" : "Krijo një rreth të ri",
    "Download" : "Shkarko",
    "Rename" : "Riemëro",
    "Delete" : "Fshije",
    "Copied" : "Kopjuar",
    "Copy link" : "Kopjo linkun",
    "Share with users or groups" : "Nda me përdoruesit ose grupet",
    "can edit" : "mund të modifikoni",
    "First name" : "Emër",
    "Last name" : "Mbiemër",
    "Display name" : "Shfaq emrin",
    "Last modified" : "Ndryshuar së fundmi",
    "Password protection" : "Password protection",
    "Save" : "Ruaj",
    "Description" : "Përshkrim",
    "Cancel" : "Anullo",
    "Upload a new picture" : "Ngarko një foto të re",
    "Download picture" : "Shkarko foton",
    "Delete picture" : "Fshi foton",
    "Invalid image" : "Figurë e pavlefshme",
    "Pick an avatar" : "Zgjidh një avatar",
    "Error while processing the picture." : "Gabim gjatë procesimit të figurës.",
    "Avatar already up to date" : "Avatari është i përditësuar.",
    "Avatar download failed" : "Shkarkimi i avatarit dështoi.",
    "No contact selected" : "Nuk është zgjedhur asnjë kontakt",
    "Select a contact on the list to begin" : "Zgjidh një kontakt nga lista për të filluar",
    "Name" : "Emri",
    "Title" : "Titulli",
    "Company" : "Kompania",
    "This contact was broken and received a fix. Please review the content and click here to save it." : "Ky kontakt ishte prishur dhe u rregullua. Ju lutem rishikoni përmbajtjen dhe klikoni këtu për ta ruajtur atë.",
    "Generate QR Code" : "Gjeneroni Kodin QR",
    "This contact is in read-only mode. You do not have permission to edit this contact." : "Ky kontakt është në gjendjen vetëm-lexo. Ju nuk keni të drejtë ta ndryshoni këtë kontakt.",
    "The contact you were trying to edit has changed. Please manually refresh the contact. Any further edits will be discarded." : "Kontakti që po përpiqeni të përditësoni, ka ndryshuar. Ju lutem rifreskoni manualisht kontaktin. Çdo ndryshim i mëtejshëm nuk do të ruhet.",
    "Address book" : "Libri i adresave",
    "Syntax error. Cannot open the contact." : "Gabim sintakse. Kontakti nuk mund të hapet.",
    "Search contacts …" : "Kërko kontakte ...",
    "No results" : "Asnjë rezultat",
    "Personal circle" : "Rreth personal",
    "Pending" : "Në Pritje të Konfirmimit",
    "Select type" : "Zgjidhni llojin",
    "Select Date" : "Zgjidhni Datën",
    "Add contact in group" : "Shto kontaktin në grup",
    "New contact" : "Kontakt i ri",
    "Close" : "Mbylleni",
    "Import" : "Import",
    "Not grouped" : "I pagrupuar",
    "Circle" : "Rreth",
    "User" : "Përdorues",
    "Group" : "Grup",
    "Email" : "Email",
    "Contact" : "Kontakt",
    "Member" : "Anëtar",
    "Moderator" : "Moderator",
    "Admin" : "Administrator",
    "Owner" : "Zotëruesi",
    "Users" : "Përdoruesit",
    "Detailed name" : "Emri i hollësishëm",
    "Additional names" : "Emra shtesë",
    "Prefix" : "Parashtesë",
    "Suffix" : "Prapashtesë",
    "Nickname" : "Nofkë",
    "Notes" : "Shënime",
    "Website" : "Faqe interneti",
    "Location" : "Vendndodhje",
    "Federated Cloud ID" : "ID Federated Cloud",
    "Home" : "Kreu",
    "Work" : "Punë",
    "Other" : "Tjetër",
    "Address" : "Adresë",
    "Post office box" : "Kuti postare në postë",
    "City" : "Qytet",
    "State or province" : "Shtet ose provincë",
    "Postal code" : "Kod postar",
    "Country" : "Vend",
    "Birthday" : "Datëlindje",
    "Anniversary" : "Përvjetor",
    "Date of death" : "Datë vdekjeje",
    "Instant messaging" : "Shkëmbim i atypëratyshëm mesazhesh",
    "Phone" : "Telefon",
    "Mobile" : "Celular",
    "Fax" : "Faks",
    "Fax home" : "Faks shtëpie",
    "Fax work" : "Faks pune",
    "Pager" : "Faques",
    "Voice" : "Zë",
    "Car" : "Makine",
    "Manager" : "Manaxher/e",
    "Social network" : "Rrjet social",
    "Spouse" : "Bashkëshort/e",
    "Child" : "Fëmijë",
    "Mother" : "Nënë",
    "Father" : "Atë",
    "Parent" : "Prind",
    "Brother" : "Vëlla",
    "Sister" : "Motër",
    "Relative" : "Kushëri",
    "Friend" : "Shok/shoqe",
    "Colleague" : "Koleg/e",
    "Assistant" : "Asistent/e",
    "Agent" : "Agjent",
    "Emergency" : "Emergjencë",
    "Co-worker" : "Koleg",
    "Gender" : "Gjinia",
    "Female" : "Femër",
    "Male" : "Mashkull",
    "None" : "Asnjë",
    "Unknown" : "I/E panjohur"
},
"nplurals=2; plural=(n != 1);");
