OC.L10N.register(
    "contacts",
    {
    "Details" : "Detailer",
    "Contacts" : "Kontakter",
    "Download" : "Eroflueden",
    "Rename" : "Ëmbenennen",
    "Delete" : "Läschen",
    "Copy link" : "Link kopéieren",
    "Share with users or groups" : "Mat Benotzer oder Gruppen deelen",
    "can edit" : "kann änneren",
    "First name" : "Virnumm",
    "Last name" : "Famillje Numm",
    "Password protection" : "Password protection",
    "Save" : "Späicheren",
    "Description" : "Beschreiwung",
    "Cancel" : "Ofbriechen",
    "Invalid image" : "Ongülteg d'Bild",
    "Name" : "Numm",
    "Title" : "Titel",
    "Pending" : "Ausstoend",
    "Close" : "Zoumaachen",
    "Import" : "Importéieren",
    "User" : "User",
    "Group" : "Grupp",
    "Email" : "Email",
    "Admin" : "Admin",
    "Owner" : "Owner",
    "Users" : "Benotzer",
    "Additional names" : "Weider Nimm",
    "Nickname" : "Spëtznumm",
    "Notes" : "Notizen",
    "Location" : "Uert",
    "Home" : "Doheem",
    "Work" : "Aarbecht",
    "Other" : "Aner",
    "Address" : "Adress",
    "City" : "Staat",
    "Country" : "Land",
    "Birthday" : "Gebuertsdag",
    "Phone" : "Telefon",
    "Mobile" : "GSM",
    "Fax" : "Fax",
    "Pager" : "Pager",
    "Voice" : "Voice",
    "Relative" : "Relativ",
    "None" : "Keng",
    "Unknown" : "Onbekannt"
},
"nplurals=2; plural=(n != 1);");
