OC.L10N.register(
    "contacts",
    {
    "Details" : "Xehetasuna",
    "All contacts" : "Kontaktu guztiak",
    "Contacts" : "Kontaktuak",
    "A contacts app for Nextcloud" : "Nextclouderako kontaktu aplikazio bat",
    "The Nextcloud contacts app is a user interface for Nextcloud's CardDAV server. Easily sync contacts from various devices with your Nextcloud and edit them online.\n\n* 🚀 **Integration with other Nextcloud apps!** Currently Mail and Calendar – more to come.\n* 🎉 **Never forget a birthday!** You can sync birthdays and other recurring events with your Nextcloud Calendar.\n* 👥 **Sharing of Adressbooks!** You want to share your contacts with your friends or coworkers? No problem!\n* 🙈 **We’re not reinventing the wheel!** Based on the great and open SabreDAV library." : "Nextclouden kontaktuen apliazioa Nextcloudeko CardDAV zerbitzariarentzako erabiltzaile-interfaze bat da. Sinkronizatu hainbat gailuen kontaktuak erraz eta editatu itzazu linean.\n\n* 🚀 **Beste Nextcloud aplikazioekin integratuta!** Oraingoz Posta eta Egutegia – laster gehiago.\n* 🎉 **Ez ezazu urtebetetze bat inoiz ahaztu!** Urtebetetzeak eta beste gertaera errepikariak sinkronizatu ditzakezu Nextcloud Egutegian.\n* 👥 **Helbide-liburuen partekatzea!** Zure kontaktuak partekatu nahi dituzu lagun eta lankideekin? Arazorik ez!\n* 🙈 **Ez gaude gurpila berriro asmatzen!** SabreDAV liburutegi bikain eta irekian oinarrituta.",
    "Copy to full name" : "Kopiatu izen osora",
    "Omit year" : "Kendu urtea",
    "Allow updating avatars from social media" : "Baimendu abatarrak eguneratzea sare sozialetatik",
    "Please select a circle" : "Mesedez, hautatu zirkulu bat",
    "Loading circle …" : "Zirkulua kargatzen …",
    "Your request to join this circle is pending approval" : "Zirkulura batzeko egin duzun eskaera onarpenaren zain dago",
    "You are not a member of {circle}" : "Zu ez zara  {circle}-ko kidea",
    "There was an error fetching the member list" : "Errore bat gertatu da kideen zerrenda eskuratzean",
    "Loading contacts …" : "Kontaktuak kargatzen...",
    "There are no contacts yet" : "Oraindik ez dago kontakturik",
    "Create contact" : "Sortu kontaktua",
    "There are no contacts in this group" : "Ez dago kontakturik talde honetan",
    "Create contacts" : "Sortu kontaktuak",
    "Add contacts" : "Gehitu kontaktuak",
    "Loading …" : "Kargatzen …",
    "Add member" : "Gehitu kidea",
    "Leave circle" : "Atera zirkulutik",
    "Delete circle" : "Ezabatu zirkulua",
    "Contacts settings" : "Kontaktuen ezarpenak",
    "General settings" : "Ezarpen orokorrak",
    "Update avatars from social media" : "Eguneratu avatarrak sare sozialetatik",
    "(refreshed once per week)" : "(astean behin freskatzen da)",
    "Address books" : "Helbide liburuak",
    "Export" : "Esportatu",
    "Send email" : "Bidali posta-mezua",
    "Send email as BCC" : "Bidali mezu elektronikoa BCC moduan",
    "Contact groups" : "Kontaktuen taldeak",
    "Create a new contact group" : "Sortu kontaktu-talde berria",
    "Contact group name" : "Kontaktu taldearen izena",
    "Circles" : "Zirkuluak",
    "Create a new circle" : "Sortu zirkulu berria",
    "Show all groups" : "Erakutsi talde guztiak",
    "Collapse groups" : "Tolestu taldeak",
    "Show all circles" : "Erakutsi zirkulu guztiak",
    "Collapse circles" : "Tolestu zirkuluak",
    "This group already exists" : "Talde hau existitzen da dagoeneko",
    "This circle already exists" : "Zirkulu hau existitzen da dagoeneko",
    "An error happened during the creation of the circle" : "Errore bat gertatu da zirkulua sortzerakoan",
    "{addressbookname} (Disabled)" : "{addressbookname} (Desgaituta)",
    "Download" : "Deskargatu",
    "Show" : "Erakutsi",
    "Rename" : "Aldatu izena",
    "Delete" : "Ezabatu",
    "Copied" : "Kopiatuta",
    "Cannot copy" : "Ezin da kopiatu",
    "Copy link" : "Esteka kopiatu",
    "Toggling of address book was not successful" : "Ezin izan da helbide-liburuaren egoera aldatu",
    "This will delete the address book and every contacts within it" : "Honek helbide-liburua eta bere barruan dauden kontaktu guztiak ezabatuko ditu",
    "Delete {addressbook}?" : "Ezabatu {addressbook}?",
    "Deletion of address book was not successful." : "Ezin izan da helbide-liburua ezabatu.",
    "Renaming of address book was not successful." : "Ezin izan da helbide-liburua berrizendatu",
    "_%n contact_::_%n contacts_" : ["Kontaktu %n","%n kontaktu"],
    "_%n group_::_%n groups_" : ["Talde %n","%n talde"],
    "_Shared with {num} entity_::_Shared with {num} entities_" : ["Entitate {num}ekin partekatuta","{num} entitaterekin partekatuta"],
    "Share with users or groups" : "Erabiltzaile edo taldeekin partekatu",
    "Share with users" : "Partekatu erabiltzaileekin",
    "No users or groups" : "Erabiltzaile edo talderik ez",
    "can edit" : "edita daiteke",
    "Unable to delete the share" : "Ezin izan da partekatzea ezabatu",
    "Unable to change permissions" : "Ezin dira baimenak aldatu",
    "Import contacts" : "Inportatu kontaktuak",
    "Import into the {addressbookName} address book" : "Inportatu {addressbookName} helbide-liburura",
    "Select local file" : "Hautatu fitxategi lokala",
    "Import from files" : "Inportatu fitxategietatik",
    "Importing is disabled because there are no address books available" : "Inportatzea desgaituta dago ez dagoelako helbide-libururik eskuragarri",
    "Choose a vCard file to import" : "Aukeratu inportatzeko vCard fitxategi bat",
    "Add new address book" : "Gehitu helbide-liburu berria",
    "An error occurred, unable to create the address book" : "Errore bat gertatu da, ezin izan da helbide liburua sortu",
    "First name" : "Izena",
    "Last name" : "Abizena",
    "Phonetic first name" : "Izen fonetikoa",
    "Phonetic last name" : "Abizen fonetikoa",
    "Display name" : "Pantaila-izena",
    "Last modified" : "Azken aldaketa",
    "Sort by {sorting}" : "{sorting}(r)en arabera ordenatu",
    "Manages" : "Kudeatzen du",
    "Oversees" : "Gainbegiratzen du",
    "An error happened during the config change" : "Errore bat gertatu da ezarpenak aldatzerakoan",
    "Password protection" : "Pasahitz bidezko babesa",
    "Enforce password protection on files shared to this circle" : "Erabili pasahitz babesa zirkulu honekin partekatutako fitxategietan",
    "Use a unique password for all shares to this circle" : "Erabili pasahitz esklusibo bat zirkulu honen partekatzetarako",
    "Unique password …" : "Pasahitz bakarra…",
    "Save" : "Gorde",
    "Change unique password" : "Aldatu pasahitz bakarra",
    "Failed to save password. Please try again later." : "Ezin izan da pasahitza gorde. Saiatu berriro geroago.",
    "Circle name" : "Zirkuluaren izena",
    "Circle owned by {owner}" : "Zirkulu honen jabea {owner} da",
    "Request to join" : "Eskatu elkartzeko baimena",
    "Description" : "Deskribapena",
    "There is no description for this circle" : "Ez dago deskribapenik zirkulu honentzat",
    "Enter a description for the circle" : "Gehitu deskribapen bat zirkulu honentzat",
    "An error happened during description sync" : "Errore bat gertatu da deskribapena sinkronizatzean",
    "An error happened during name sync" : "Errore bat gertatu da izena sinkronizatzean",
    "Add more info" : "Gehitu informazio gehiago",
    "More fields" : "Eremu gehiago",
    "Crop contact photo" : "Moztu kontaktuaren argazkia",
    "Cancel" : "Utzi",
    "Upload a new picture" : "Igo irudi berri bat",
    "Choose from Files" : "Aukeratu Fitxategiak-etik",
    "Get from " : "Hartu hemendik",
    "Download picture" : "Deskargatu irudia",
    "Delete picture" : "Ezabatu irudia",
    "Please select a valid format" : "Hautatu baliozko formatu bat",
    "Invalid image" : "Baliogabeko irudia",
    "Error cropping picture" : "Errore bat gertatu da argazkia moztean",
    "Pick an avatar" : "Aukeratu avatar bat",
    "Error while processing the picture." : "Errorea irudia prozesatzen.",
    "Avatar downloaded from social network" : "Abatarra deskargatu da sare sozialetik ",
    "Avatar already up to date" : "Abatarra eguneratuta",
    "Avatar download failed" : "Abatarra deskargatzeak huts egin du",
    "No contact selected" : "Ez dago kontakturik hautatuta",
    "Select a contact on the list to begin" : "Hautatu zerrendako kontaktu bat lanean hasteko",
    "Name" : "Izena",
    "Title" : "Izenburua",
    "Company" : "Konpainia",
    "This contact was broken and received a fix. Please review the content and click here to save it." : "Kontaktu hau apurtuta zegoen eta konpondu egin da. Mesedez berrikusi edukia eta egin klik hemen gordetzeko.",
    "Edit" : "Aldatu",
    "Clone contact" : "Klonatu kontaktua",
    "Generate QR Code" : "Sortu QR kodea",
    "Contact vCard as QR code" : "Kontaktuaren vCard QR kode bezala",
    "Pick an address book" : "Aukeratu helbide-liburu bat",
    "Select address book" : "Hautatu helbide-liburua",
    "Go to talk conversation" : "Joan talk elkarrizketara",
    "View profile" : "Ikusi profila",
    "This contact is in read-only mode. You do not have permission to edit this contact." : "Kontaktu hau irakurtzeko soilik moduan dago. Ez daukazu baimenik kontaktu hau editatzeko.",
    "The contact you were trying to edit has changed. Please manually refresh the contact. Any further edits will be discarded." : "Editatzen saiatu zaren kontaktua aldatu egin da. Mesedez freskatu kontaktua eskuz. Hurrengo editatze guztiak baztertu egingo dira.",
    "Address book" : "Helbide liburua",
    "Add contact to Birthday Calendar" : "Gehitu kontaktua urtebetetze egutegira",
    "Exclude contact from Birthday Calendar" : "Kendu kontaktua urtebetetze egutegitik",
    "{title} at {organization}" : "{organization}-ko {title}",
    "Syntax error. Cannot open the contact." : "Sintaxi-errorea. Ezin da kontaktua ireki.",
    "The contact does not exist on the server anymore." : "Kontaktua ez dago jada zerbitzarian.",
    "Unable to retrieve the contact from the server, please check your network connection." : "Ezin izan da kontaktua lortu zerbitzaritik, begiratu internet konexio ona duzun.",
    "An error occurred while trying to move the contact" : "Errorea gertatu da kontaktua mugitzen saiatzerakoan",
    "An error occurred while trying to copy the contact" : "Errorea gertatu da kontaktua kopiatzen saiatzerakoan",
    "Unable to update contact" : "Ezin da eguneratu kontaktua",
    "Search contacts …" : "Bilatu kontaktuak...",
    "Add to {group}" : "Gehitu {group} taldera",
    "Remove {type}" : "Kendu {type}",
    "Search {types}" : "Bilatu {types}",
    "Search for people to add" : "Bilatu gehitzeko pertsonak",
    "No results" : "Emaitzarik ez",
    "Add to group" : "Gehitu taldera",
    "Add {type}" : "Gehitu {type}",
    "New circle name" : "Zirkulu izen berria",
    "Personal circle" : "Zirkulu pertsonala",
    "This circle will only be visible to you. Other members will not be able to see or use it." : "Zirkulu hau zuretzat bakarrik egongo da ikusgarri. Beste kideek ezingo dute ikusi edo erabili.",
    "Local circle" : "Zirkulu lokala",
    "This circle will not be shared with the other instances of the global scale" : "Zirkulu hau ez da eskala globaleko beste instantziekin partekatuko.",
    "Create circle" : "Sortu zirkulua",
    "Loading members list …" : "Kideen zerrenda kargatzen...",
    "The list of members is only visible to members of this circle" : "Kideen zerrenda zirkulu honetako kideentzat bakarrik dago ikusgarri",
    "You currently have no access to the member list" : "Ez duzu sarbiderik kideen zerrendara",
    "Add members" : "Gehitu kideak",
    "Show circle details" : "Erakutsi zirkuluaren xehetasunak",
    "Add to {circle}" : "Gehitu {circle} zirkulura",
    "Unable to get the recommendations list" : "Ezin da gomendatuen zerrenda eskuratu",
    "Unable to get the results" : "Ezin dira emaitzak eskuratu",
    "Some members could not be added" : "Kide batzuk ezin izan dira gehitu",
    "There was an issue adding members to the circle" : "Arazo bat izan da kideak zirkulura gehitzean",
    "Accept membership request" : "Onartu kidetze eskaera",
    "Reject membership request" : "Ukatu kidetze eskaera",
    "Manage level" : "Kudeatu maila",
    "Remove member" : "Kendu kidea",
    "Pending" : "Zain",
    "Promote as sole owner" : "Igo jabe bakar mailara",
    "Promote to {level}" : "Igo {level} mailara",
    "Demote to {level}" : "Jaitsi {level} mailara",
    "Could not delete the member {displayName}" : "Ezin izan da {displayName} kidea ezabatu",
    "Could not change the member level to {level}" : "Ezin izan da kidearen maila {level} mailara aldatu",
    "Could not accept membership request" : "Ezin izan da kidetze eskaera onartu",
    "Chart" : "Diagrama",
    "Select chart …" : "Hautatu diagrama ...",
    "Select type" : "Hautatu mota",
    "Select Date" : "Hautatu data",
    "Add contact in group" : "Gehitu kontaktua taldera",
    "none" : "bat ere ez",
    "Select option" : "Hautatu aukera",
    "Add property of this type" : "Gehitu mota honetako propietatea",
    "New contact" : "Kontaktu berria",
    "Unable to create the contact." : "Ezin izan da kontaktua sortu.",
    "Contact not found" : "Kontaktua ez da aurkitu",
    "Group {group} not found" : "Ez da {group} taldea aurkitu",
    "Close" : "Itxi",
    "_{success} contact added to {name}_::_{success} contacts added to {name}_" : ["{success} kontaktuak gehitu dira {name}-ra","{success} kontaktuak gehitu dira {name}-ra"],
    "_Adding {success} contact to {name}_::_Adding {success} contacts to {name}_" : ["{success} kontaktuak {name}-ra gehitzen","{success} kontaktuak gehitu dira {name}-ra"],
    "_{count} error_::_{count} errors_" : ["{count} errorea","{count} erroreak"],
    "_Importing %n contact into {addressbook}_::_Importing %n contacts into {addressbook}_" : ["Kontaktu %n inportatzen {addressbook}(e)ra","%n kontaktu inportaten {addressbook}(e)ra"],
    "_Done importing %n contact into {addressbook}_::_Done importing %n contacts into {addressbook}_" : ["Kontaktu %n inportatu da {addressbook}(e)ra"," %n kontaktu inportatu dira {addressbook}(e)ra"],
    "Import" : "Inportatu",
    "Could not copy" : "Ezin izan da kopiatu",
    "Join circle" : "Batu zirkulura",
    "You are about to leave {circle}.\nAre you sure?" : "{circle} zirkulua uztear zaude. \nZiur zaude?",
    "Please confirm circle leave" : "Baieztatu zirkulua uztea",
    "Could not leave the circle {displayName}" : "Ezin izan da {displayName} zirkulua utzi",
    "Unable to join the circle" : "Ezin izan da zirkulura batu",
    "You are about to delete {circle}.\nAre you sure?" : "{circle} zirkulua ezabatzear zaude.\nZiur zaude?",
    "Please confirm circle deletion" : "Baieztatu zirkulua ezabatzea",
    "Unable to delete the circle" : "Ezin izan da zirkulua ezabatu",
    "Link copied to the clipboard" : "Esteka arbelera kopiatu da",
    "Could not copy link to the clipboard." : "Ezin izan da esteka arbelera kopiatu",
    "Not grouped" : "Taldekatu gabe",
    "Recently contacted" : "Berriki kontaktatuak",
    "Organization chart" : "Erakundearen diagrama",
    "Circles are groups of people that you can create yourself and with whom you can share data. They can be made up of other accounts or groups of accounts of the Nextcloud instance, but also of contacts from your address book or even external people by simply entering their e-mail addresses." : "Zirkuluak zuk zeuk sortu ditzakezun eta haiekin datuak parteka ditzakezun pertsona-taldeak dira. Nextcloud instantziaren beste kontu edo kontu talde batzuek osatuta egon daitezke, baina baita zure helbide-liburuko kontaktuek edo baita kanpoko pertsonek ere haien helbide elektronikoak sartuta.",
    "Circle" : "Zirkulua",
    "User" : "Erabiltzailea",
    "Group" : "Taldea",
    "Email" : "E-posta",
    "Contact" : "Kontaktua",
    "Member" : "Kidea",
    "Moderator" : "Moderatzailea",
    "Admin" : "Administratzailea",
    "Owner" : "Jabea",
    "Invites" : "Gonbidapenak",
    "Anyone can request membership" : "Edonork eskatu dezake kidetza",
    "Members need to accept invitation" : "Kideek gonbidapena onartu behar dute",
    "Memberships must be confirmed/accepted by a Moderator (requires Open)" : "Moderatzaile batek berretsi / onartu behar ditu kidetzak (Irekia behar du)",
    "Members can also invite" : "Kideek ere gonbidapenak egin ditzakete",
    "Visibility" : "Ikusgarritasuna",
    "Visible to everyone" : "Denontzat ikusgai",
    "Circle membership" : "Zirkulu kidetza",
    "Prevent circle from being a member of another circle" : "Zirkulu bat beste zirkulu baten kidea izatea ukatu",
    "Users" : "Erabiltzaileak",
    "Email addresses" : "E-posta helbideak",
    "Detailed name" : "Izen osoa",
    "Additional names" : "Tarteko izenak",
    "Prefix" : "Aurrizkia",
    "Suffix" : "Atzizkia",
    "Nickname" : "Ezizena",
    "Notes" : "Oharrak",
    "Website" : "Webgunea",
    "Location" : "Kokapena",
    "Federated Cloud ID" : "Federatutako hodei IDa",
    "Home" : "Etxekoa",
    "Work" : "Lanekoa",
    "Other" : "Bestelakoa",
    "Address" : "Helbidea",
    "Post office box" : "Posta kutxatila",
    "Extended address" : "Helbide hedatua",
    "City" : "Hiria",
    "State or province" : "Estatu edo probintzia",
    "Postal code" : "Posta kodea",
    "Country" : "Herrialdea",
    "Birthday" : "Jaioteguna",
    "Anniversary" : "Urtebetetzea / urteurrena",
    "Date of death" : "Heriotza data",
    "Instant messaging" : "Istanteko mezularitza",
    "Phone" : "Telefonoa",
    "Mobile" : "Mugikorra",
    "Work mobile" : "Laneko mugikorra",
    "Home mobile" : "Etxeko mugikorra",
    "Fax" : "Faxa",
    "Fax home" : "Etxeko Faxa",
    "Fax work" : "Laneko faxa",
    "Pager" : "Bilagailua",
    "Voice" : "Ahotsa",
    "Car" : "Kotxea",
    "Work pager" : "Laneko orriztapena",
    "Manager" : "Zuzendaria",
    "Social network" : "Sare soziala",
    "Relationship to you" : "Zureganako erlazioa",
    "Spouse" : "Emaztea",
    "Child" : "Semea",
    "Mother" : "Ama",
    "Father" : "Aita",
    "Parent" : "Ondokoa",
    "Brother" : "Anaia",
    "Sister" : "Arreba",
    "Relative" : "Familiakoa",
    "Friend" : "Laguna",
    "Colleague" : "Lankidea",
    "Assistant" : "Asistentea",
    "Related contacts" : "Erlazionatutako kontaktuak",
    "Agent" : "Agentea",
    "Emergency" : "Larrialdia",
    "Co-worker" : "Lankidea",
    "Gender" : "Generoa",
    "Female" : "Emakumea",
    "Male" : "Gizonezkoa",
    "None" : "Bat ere ez",
    "Unknown" : "Ezezaguna",
    "Time zone" : "Ordu-zona",
    "Spoken languages" : "Hitz egiteko erabilitako hizkuntzak",
    "_{failed} contact failed to be read_::_{failed} contacts failed to be read_" : ["Ezin izan da kontaktu {failed} irakurri","Ezin izan dira {failed} kontaktu irakurri"],
    "An error has occurred in circle(s). Check the console for more details." : "Errore bat gertatu da zirkuluetan. Begiratu kontsola xehetasun gehiago lortzeko.",
    "Unable to create circle {circleName}" : "Ezin izan da {circleName} zirkulua sortu",
    "Unable to delete circle {circleId}" : "Ezin izan da zirkulua ezabatu",
    "Unable to delete contact" : "Ezin izan da kontaktua ezabatu"
},
"nplurals=2; plural=(n != 1);");
