/**
 * @copyright Copyright (c) 2018 John Molakvoæ <skjnldsv@protonmail.com>
 *
 * @author John Molakvoæ <skjnldsv@protonmail.com>
 * @author Team Popcorn <teampopcornberlin@gmail.com>
 *
 * @license GNU AGPL version 3 or any later version
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 *
 */

.addressbook-shares {
	width: 100%;
	&__list {
		margin-top: 8px;
		margin-bottom: 12px;
		display: flex;
		flex-direction: column;
	}

	&__shareematch--bold {
		font-weight: bold;
	}
	
	.icon-loading::after {
		top: 70%;
		left: 95%;
		height: 14px;
		width: 14px;
	}

	.multiselect {
		width: inherit;
		margin: 0;
		.multiselect__tags:focus-within, 
		.multiselect__tags:hover {
			border-color: var(--color-primary-element);
		}

		&:not(.showContent) .multiselect__content-wrapper {
			display: none;
		}
	}
}