OC.L10N.register(
    "contacts",
    {
    "Details" : "Detaloj",
    "All contacts" : "Ĉiuj kontaktoj",
    "Contacts" : "Kontaktaro",
    "A contacts app for Nextcloud" : "Aplikaĵo pri kontaktoj por Nextcloud",
    "The Nextcloud contacts app is a user interface for Nextcloud's CardDAV server. Easily sync contacts from various devices with your Nextcloud and edit them online.\n\n* 🚀 **Integration with other Nextcloud apps!** Currently Mail and Calendar – more to come.\n* 🎉 **Never forget a birthday!** You can sync birthdays and other recurring events with your Nextcloud Calendar.\n* 👥 **Sharing of Adressbooks!** You want to share your contacts with your friends or coworkers? No problem!\n* 🙈 **We’re not reinventing the wheel!** Based on the great and open SabreDAV library." : "Tiu aplikaĵo estas interfaco por la CardDAV-servilo de Nextcloud. Senpene sinkronigu viajn kontaktojn el diversaj aparatoj al Nextcloud kaj redaktu ilin rete.\n\n* 🚀 **Integrado kun aliaj Nextcloud-aplikaĵoj!** Nuntempe Retmesagô (Mail) kaj Kalendaro (Calendar), pli en la estonteco.\n* 🎉 **Neniam forgesu datrevenon!** Vi povas sinkronigi datrevenojn kaj aliaj ripetiĝantajn eventoj.\n* 👥 **Kunhavigo de adresaro!** Ĉu vi volas kunhavigi kontaktojn kun amikoj aŭ kolegoj? Neniu problemo!\n* 🙈 **Ni ne elpensis la radon!** Devenigita de la granda kaj malferma biblioteko SabreDAV.",
    "Copy to full name" : "Kopii al plena nomo",
    "Omit year" : "Ne uzi jaron",
    "Loading …" : "Ŝargas …",
    "Delete circle" : "Forigi rondon",
    "Send email" : "Sendi retpoŝtmesaĝon",
    "Circles" : "Rondoj",
    "Create a new circle" : "Krei novan rondon",
    "Download" : "Elŝuti",
    "Rename" : "Alinomi",
    "Delete" : "Forigi",
    "Copied" : "Kopiita",
    "Copy link" : "Kopii ligilon",
    "_Shared with {num} entity_::_Shared with {num} entities_" : ["Kunhavigitaj kun {num} entoj","Kunhavigitaj kun {num} entoj"],
    "Share with users or groups" : "Kunhavigi kun uzantoj aŭ grupoj",
    "No users or groups" : "Neniu uzanto aŭ grupo",
    "can edit" : "povas redakti",
    "Importing is disabled because there are no address books available" : "Importado estas malebligita, ĉar neniu adresaro disponeblas",
    "First name" : "Persona nomo",
    "Last name" : "Familia nomo",
    "Display name" : "Montra nomo",
    "Last modified" : "Laste modifita",
    "Sort by {sorting}" : "Ordigi laŭ {sorting}",
    "Password protection" : "Protektita per pasvorto",
    "Save" : "Konservi",
    "Description" : "Priskribo",
    "Cancel" : "Nuligi",
    "Upload a new picture" : "Alŝuti novan bildon",
    "Download picture" : "Elŝuti bildon",
    "Delete picture" : "Forigi bildon",
    "Invalid image" : "Nevalida bildo",
    "Pick an avatar" : "Elekti avataron",
    "Error while processing the picture." : "Eraro dum prilaboro de la bildo.",
    "No contact selected" : "Neniu kontakto elektita",
    "Select a contact on the list to begin" : "Elektu kontakto en la listo por komenci",
    "Name" : "Nomo",
    "Title" : "Titolo",
    "Company" : "Firmao",
    "This contact was broken and received a fix. Please review the content and click here to save it." : "Tiu kontakto difektiĝis kaj estis riparita. Kontrolu la enhavon kaj alklaku ĉi tie por konservi ĝin.",
    "Generate QR Code" : "Generi rapidrespondan (QR) kodon",
    "This contact is in read-only mode. You do not have permission to edit this contact." : "Tiu ĉi kontakto estas nur legebla. Vi ne rajtas redakti ĝin.",
    "The contact you were trying to edit has changed. Please manually refresh the contact. Any further edits will be discarded." : "La kontakto, kiun vi ĵus provis redakti, ŝanĝiĝis. Bonvolu mane aktualigi la kontakton. Ĉiuj pliaj redaktoj ne estos konservitaj.",
    "Syntax error. Cannot open the contact." : "Sintakseraro. Ne eblas malfermi la kontakton.",
    "Search contacts …" : "Serĉi kontaktojn…",
    "No results" : "Neniu rezulto",
    "Personal circle" : "Persona rondo",
    "Pending" : "Pritraktota",
    "Select type" : "Elekti tipon",
    "Select Date" : "Elekti daton",
    "Add contact in group" : "Aldoni kontakton en grupon",
    "Select option" : "Elekti opcion",
    "New contact" : "Nova kontakto",
    "Unable to create the contact." : "Ne eblas krei kontakton.",
    "Contact not found" : "Kontakto ne trovebla",
    "Close" : "Malfermi",
    "Import" : "Importi",
    "Not grouped" : "Ne grupigita",
    "Circle" : "Rondo",
    "User" : "Uzanto",
    "Group" : "Grupo",
    "Email" : "Retpoŝto",
    "Contact" : "Kontakto",
    "Member" : "Membro",
    "Moderator" : "Kontrolanto",
    "Admin" : "Administranto",
    "Owner" : "Posedanto",
    "Users" : "Uzantoj",
    "Detailed name" : "Detala nomo",
    "Additional names" : "Pliaj nomoj",
    "Prefix" : "Prefikso",
    "Suffix" : "Sufikso",
    "Nickname" : "Kromnomo",
    "Notes" : "Notoj",
    "Website" : "TTT-ejo",
    "Location" : "Loko",
    "Federated Cloud ID" : "Identigilo de federa nubo",
    "Home" : "Hejmo",
    "Work" : "Laboro",
    "Other" : "Alia",
    "Address" : "Adreso",
    "Post office box" : "Poŝta abonkesto",
    "Extended address" : "Plia adreso",
    "City" : "Urbo",
    "State or province" : "Ŝtato aŭ provinco",
    "Postal code" : "Poŝtkodo",
    "Country" : "Lando",
    "Birthday" : "Naskiĝotago",
    "Anniversary" : "Datreveno",
    "Date of death" : "Mortotago",
    "Instant messaging" : "Tujmesaĝado",
    "Phone" : "Telefono",
    "Mobile" : "Poŝtelefono",
    "Work mobile" : "Labora poŝtelefono",
    "Home mobile" : "Hejma poŝtelefono",
    "Fax" : "Fakso",
    "Fax home" : "Hejma fakso",
    "Fax work" : "Labora fakso",
    "Pager" : "Televokilo",
    "Voice" : "Voĉo",
    "Car" : "Aŭto",
    "Work pager" : "Labora televokilo",
    "Manager" : "Estr(in)o",
    "Social network" : "Socia reto",
    "Spouse" : "Edz(in)o",
    "Child" : "Infano",
    "Mother" : "Patrino",
    "Father" : "Patro",
    "Parent" : "Gepatroj",
    "Brother" : "Frato",
    "Sister" : "Fratino",
    "Relative" : "Parenco",
    "Friend" : "Amik(in)o",
    "Colleague" : "Koleg(in)o",
    "Assistant" : "Asistant(in)o",
    "Agent" : "Agent(in)o",
    "Emergency" : "Urĝeco",
    "Co-worker" : "Kunlaborant(in)o",
    "Gender" : "Sekso",
    "Female" : "Ina",
    "Male" : "Vira",
    "None" : "Nenio",
    "Unknown" : "Nekonata",
    "Spoken languages" : "Lingvoj parolataj",
    "_{failed} contact failed to be read_::_{failed} contacts failed to be read_" : ["{failed} kontakto malsukcesis esti legita","{failed} kontaktoj malsukcesis esti legitaj"]
},
"nplurals=2; plural=(n != 1);");
