<?php

// autoload_classmap.php @generated by Composer

$vendorDir = dirname(__DIR__);
$baseDir = dirname($vendorDir);

return array(
    'Composer\\InstalledVersions' => $vendorDir . '/composer/InstalledVersions.php',
    'OCA\\Contacts\\AppInfo\\Application' => $baseDir . '/lib/AppInfo/Application.php',
    'OCA\\Contacts\\ContactsMenu\\Providers\\DetailsProvider' => $baseDir . '/lib/ContactsMenu/Providers/DetailsProvider.php',
    'OCA\\Contacts\\Controller\\ContactsController' => $baseDir . '/lib/Controller/ContactsController.php',
    'OCA\\Contacts\\Controller\\PageController' => $baseDir . '/lib/Controller/PageController.php',
    'OCA\\Contacts\\Controller\\SocialApiController' => $baseDir . '/lib/Controller/SocialApiController.php',
    'OCA\\Contacts\\Cron\\SocialUpdate' => $baseDir . '/lib/Cron/SocialUpdate.php',
    'OCA\\Contacts\\Cron\\SocialUpdateRegistration' => $baseDir . '/lib/Cron/SocialUpdateRegistration.php',
    'OCA\\Contacts\\Dav\\PatchPlugin' => $baseDir . '/lib/Dav/PatchPlugin.php',
    'OCA\\Contacts\\Listener\\LoadContactsFilesActions' => $baseDir . '/lib/Listener/LoadContactsFilesActions.php',
    'OCA\\Contacts\\Service\\ImageResizer' => $baseDir . '/lib/Service/ImageResizer.php',
    'OCA\\Contacts\\Service\\SocialApiService' => $baseDir . '/lib/Service/SocialApiService.php',
    'OCA\\Contacts\\Service\\Social\\CompositeSocialProvider' => $baseDir . '/lib/Service/Social/CompositeSocialProvider.php',
    'OCA\\Contacts\\Service\\Social\\DiasporaProvider' => $baseDir . '/lib/Service/Social/DiasporaProvider.php',
    'OCA\\Contacts\\Service\\Social\\FacebookProvider' => $baseDir . '/lib/Service/Social/FacebookProvider.php',
    'OCA\\Contacts\\Service\\Social\\GravatarProvider' => $baseDir . '/lib/Service/Social/GravatarProvider.php',
    'OCA\\Contacts\\Service\\Social\\ISocialProvider' => $baseDir . '/lib/Service/Social/ISocialProvider.php',
    'OCA\\Contacts\\Service\\Social\\InstagramProvider' => $baseDir . '/lib/Service/Social/InstagramProvider.php',
    'OCA\\Contacts\\Service\\Social\\MastodonProvider' => $baseDir . '/lib/Service/Social/MastodonProvider.php',
    'OCA\\Contacts\\Service\\Social\\TelegramProvider' => $baseDir . '/lib/Service/Social/TelegramProvider.php',
    'OCA\\Contacts\\Service\\Social\\TumblrProvider' => $baseDir . '/lib/Service/Social/TumblrProvider.php',
    'OCA\\Contacts\\Service\\Social\\XingProvider' => $baseDir . '/lib/Service/Social/XingProvider.php',
    'OCA\\Contacts\\Settings\\AdminSettings' => $baseDir . '/lib/Settings/AdminSettings.php',
);
