OC.L10N.register(
    "contacts",
    {
    "Details" : "Chi tiết",
    "All contacts" : "Tất cả các tên liên lạc",
    "Contacts" : "Danh bạ",
    "A contacts app for Nextcloud" : "Một ứng dụng danh bạ cho vWorkspace",
    "The Nextcloud contacts app is a user interface for Nextcloud's CardDAV server. Easily sync contacts from various devices with your Nextcloud and edit them online.\n\n* 🚀 **Integration with other Nextcloud apps!** Currently Mail and Calendar – more to come.\n* 🎉 **Never forget a birthday!** You can sync birthdays and other recurring events with your Nextcloud Calendar.\n* 👥 **Sharing of Adressbooks!** You want to share your contacts with your friends or coworkers? No problem!\n* 🙈 **We’re not reinventing the wheel!** Based on the great and open SabreDAV library." : "Ứng dụng danh bạ vWorkspace là một ứng dụng tương tác cho người dùng dành cho máy chủ CardDAV của vWorkspace. Dễ dàng đồng bộ danh bạ từ đa dạng các thiết bị với vWorkspace của bạn và sửa đổi chúng trực tuyến.\n\n* 🚀 **Tương tác với các ứng dụng vWorkspace khác!** Ứng dụng Thư và Lịch hiện hành - Và nhiều hơn nữa sẽ ra mắt.\n\n* 🎉 **Không bao giờ quyên một ngày sinh nhật!\"\" Bạn muốn đồng bộ các ngày sinh nhật và các sự kiện định kỳ với bạn và đồng nghiệp của bạn? Không thành vấn đề!\n\n* 🙈 ** Chúng tôi không tạo ra những thay đổi khác lạ!** Chỉ dựa trên sự tuyệt vời và nguồn mở của thư viện SabreDAV",
    "Copy to full name" : "Sao chép sang tên đầy đủ",
    "Omit year" : "Bỏ qua năm",
    "Allow updating avatars from social media" : "Cho phép cập nhật ảnh đại diện từ mạng xã hội",
    "Loading contacts …" : "Đang nạp tên liên lạc",
    "There are no contacts yet" : "Chưa có liên hệ nào",
    "Create contact" : "Tạo liên hệ",
    "There are no contacts in this group" : "Không có liên hệ nào trong nhóm này",
    "Create contacts" : "Tạo các liên hệ",
    "Add contacts" : "Thêm liên hệ",
    "Loading …" : "Đang tải...",
    "Delete circle" : "Xóa vòng kết nối",
    "General settings" : "Cài đặt chung",
    "Update avatars from social media" : "Cập nhật ảnh đại diện từ mạng xã hội",
    "(refreshed once per week)" : "(được làm mới một lần mỗi tuần)",
    "Send email" : "Gửi email",
    "Circles" : "Vòng kết nối",
    "Create a new circle" : "Tạo một vòng kết nối mới",
    "This group already exists" : "Nhóm này đã tồn tại",
    "Download" : "Tải về",
    "Rename" : "Đổi tên",
    "Delete" : "Xóa",
    "Copied" : "Đã sao chép",
    "Copy link" : "Sao chép liên kết",
    "Toggling of address book was not successful" : "Chuyển đổi sổ địa chỉ không thành công",
    "This will delete the address book and every contacts within it" : "Điều này sẽ xóa sổ địa chỉ và tất cả các liên hệ bên trong nó",
    "Deletion of address book was not successful." : "Sự xóa bỏ sổ địa chỉ đã không thành công.",
    "Renaming of address book was not successful." : "Đổi tên sổ địa chỉ không thành công.",
    "_Shared with {num} entity_::_Shared with {num} entities_" : ["Được chia sẻ với {num} thực thể"],
    "Share with users or groups" : "Chia sẻ với nhiều người sử dụng hoặc nhiều nhóm người sử dụng",
    "No users or groups" : "Không có người dùng hay nhóm",
    "can edit" : "Có thể chỉnh sửa",
    "Unable to delete the share" : "Không thể xóa chia sẻ",
    "Unable to change permissions" : "Không thể thay đổi quyền",
    "Import contacts" : "Nhập liên hệ",
    "Select local file" : "Chọn tệp từ máy",
    "Import from files" : "Nhập từ tệp",
    "Importing is disabled because there are no address books available" : "Nhập đã bị tắt do không có sổ địa chỉ nào hiện hành",
    "Choose a vCard file to import" : "Chọn một tệp vCard để nhập",
    "An error occurred, unable to create the address book" : "Đã xảy ra lỗi, không thể tạo sổ địa chỉ",
    "First name" : "Tên",
    "Last name" : "Họ",
    "Phonetic first name" : "Tên phiên âm",
    "Phonetic last name" : "Họ phiên âm",
    "Display name" : "Tên hiển thị",
    "Last modified" : "Lần cuối chỉnh sửa",
    "Sort by {sorting}" : "Sắp xếp theo {sorting}",
    "Password protection" : "Password protection",
    "Save" : "Lưu",
    "Description" : "Mô tả",
    "Cancel" : "Hủy bỏ",
    "Upload a new picture" : "Tải lên một ảnh mới",
    "Choose from Files" : "Chọn từ Tệp",
    "Get from " : "Lấy từ",
    "Download picture" : "Tải xuống hình ảnh",
    "Delete picture" : "Xóa hình ảnh",
    "Invalid image" : "Hình ảnh không hợp lệ",
    "Pick an avatar" : "Chọn 1 ảnh đại diện",
    "Error while processing the picture." : "Lỗi xảy ra khi xử lý hình ảnh",
    "Avatar downloaded from social network" : "Hình đại diện tải xuống từ mạng xã hội",
    "Avatar already up to date" : "Hình đại diện đã được cập nhật",
    "Avatar download failed" : "Tải xuống hình đại diện không thành công",
    "No contact selected" : "Không có liên hệ nào được chọn",
    "Select a contact on the list to begin" : "Chọn một liên hệ trên danh sách để bắt đầu",
    "Name" : "Tên",
    "Title" : "Tiêu đề",
    "Company" : "Công ty",
    "This contact was broken and received a fix. Please review the content and click here to save it." : "Liên hệ này đã bị lỗi và đã được sửa lại. Vui lòng kiểm tra lại nội dung và bấm vào đây để lưu lại",
    "Clone contact" : "Liên hệ nhân bản",
    "Generate QR Code" : "Tạo lập mã QR",
    "Pick an address book" : "Chọn một sổ địa chỉ",
    "Select address book" : "Chọn sổ địa chỉ",
    "This contact is in read-only mode. You do not have permission to edit this contact." : "Liên hệ này đang trong chế độ chỉ đọc. Bạn không có quyền để sửa đổi liên hệ này.",
    "The contact you were trying to edit has changed. Please manually refresh the contact. Any further edits will be discarded." : "Liên hệ bạn cố gắng sửa đổi đã thay đổi. Vui lòng làm mới thủ công liên hệ này. Bất cứ sửa đổi nào xa hơn sẽ bị loại bỏ. ",
    "Address book" : "Sổ địa chỉ",
    "Syntax error. Cannot open the contact." : "Lỗi cú pháp. Không thể mở liên hệ. ",
    "Unable to retrieve the contact from the server, please check your network connection." : "Không thể truy xuất liên hệ từ máy chủ, vui lòng kiểm tra kết nối mạng của bạn.",
    "An error occurred while trying to move the contact" : "Một lỗi đã xảy ra khi đang cố gắng di chuyẻn liên hệ",
    "An error occurred while trying to copy the contact" : "Một lỗi đã xảy ra khi đang cố gắng sao chép liên hệ",
    "Search contacts …" : "Tìm liên hệ ...",
    "Remove {type}" : "Xóa {type}",
    "Search {types}" : "Tìm kiếm {type}",
    "No results" : "Không có kết quả",
    "Add to group" : "Thêm vào nhóm",
    "Add {type}" : "Thêm {type}",
    "Personal circle" : "Vòng cá nhân",
    "Pending" : "Đang dừng",
    "Select type" : "Chọn loại",
    "Select Date" : "Chọn ngày",
    "Add contact in group" : "Thêm liên hệ vào nhóm",
    "Select option" : "Chọn lựa chọn",
    "New contact" : "Thêm liên lạc",
    "Unable to create the contact." : "Không thể tạo liên hệ.",
    "Contact not found" : "Liên hệ không được tìm thấy",
    "Close" : "Đóng",
    "_{success} contact added to {name}_::_{success} contacts added to {name}_" : ["{success} đã thêm địa chỉ liên hệ vào {name}"],
    "_Adding {success} contact to {name}_::_Adding {success} contacts to {name}_" : ["Thêm {success} địa chỉ liên hệ vào {name}"],
    "_{count} error_::_{count} errors_" : ["{count} lỗi"],
    "_Importing %n contact into {addressbook}_::_Importing %n contacts into {addressbook}_" : ["Đang nhập %n liên hệ vào {addressbook}"],
    "_Done importing %n contact into {addressbook}_::_Done importing %n contacts into {addressbook}_" : ["Hoàn thành nhập %n liên hệ vào {addressbook}"],
    "Import" : "Nhập vào",
    "Not grouped" : "Không được nhóm",
    "Recently contacted" : "Liên hệ gần đây",
    "Circle" : "Vòng kết nối",
    "User" : "Người dùng",
    "Group" : "Nhóm",
    "Email" : "Email",
    "Contact" : "Liên hệ",
    "Member" : "Thành viên",
    "Moderator" : "Kiểm duyệt",
    "Admin" : "Quản trị viên",
    "Owner" : "Chủ",
    "Visibility" : "Hiển thị",
    "Users" : "Người dùng",
    "Detailed name" : "Tên chi tiết",
    "Additional names" : "Tên bổ sung",
    "Prefix" : "Tiền tố",
    "Suffix" : "Hậu tố",
    "Nickname" : "Biệt danh",
    "Notes" : "Ghi chép",
    "Website" : "Website",
    "Location" : "Vị trí",
    "Federated Cloud ID" : "Federated Cloud ID",
    "Home" : "Nhà",
    "Work" : "Công việc",
    "Other" : "Khác",
    "Address" : "Địa chỉ",
    "Post office box" : "Hòm thư bưu điện",
    "Extended address" : "Địa chỉ mở rộng",
    "City" : "Thành phố",
    "State or province" : "Bang hay tỉnh/thành",
    "Postal code" : "Mã bưu chính",
    "Country" : "Quốc gia",
    "Birthday" : "Ngày sinh nhật",
    "Anniversary" : "Ngày kỷ niệm",
    "Date of death" : "Ngày mất",
    "Instant messaging" : "Tin khẩn",
    "Phone" : "Điện thoại",
    "Mobile" : "Di động",
    "Work mobile" : "Điện thoại làm việc",
    "Home mobile" : "Điện thoại nhà",
    "Fax" : "Fax",
    "Fax home" : "Số Fax ở nhà",
    "Fax work" : "Số Fax  nơi làm việc",
    "Pager" : "số trang",
    "Voice" : "Giọng nói",
    "Car" : "Xe",
    "Work pager" : "Máy nhắn tin",
    "Manager" : "Trưởng phòng",
    "Social network" : "Mạng xã hội",
    "Relationship to you" : "Quan hệ với bạn",
    "Spouse" : "Vợ / chồng",
    "Child" : "Con",
    "Mother" : "Mẹ",
    "Father" : "Bố",
    "Parent" : "Bố mẹ",
    "Brother" : "Anh/em",
    "Sister" : "Chị/em gái",
    "Relative" : "Quan hệ nhân thân",
    "Friend" : "Bạn bè",
    "Colleague" : "Đồng nghiệp",
    "Assistant" : "Trợ lý",
    "Related contacts" : "Liên hệ có liên quan",
    "Agent" : "Người quản lý",
    "Emergency" : "Khẩn cấp",
    "Co-worker" : "Đồng nghiệp",
    "Gender" : "Giới tính",
    "Female" : "Nữ",
    "Male" : "Nam",
    "None" : "Không có",
    "Unknown" : "Không xác định",
    "Spoken languages" : "Ngôn ngữ có thể nói",
    "_{failed} contact failed to be read_::_{failed} contacts failed to be read_" : ["{failed} liên hệ không thể đọc được"],
    "Unable to delete contact" : "Không thể xoá liên hệ"
},
"nplurals=1; plural=0;");
