OC.L10N.register(
    "contacts",
    {
    "Details" : "Išsamiau",
    "All contacts" : "Visi adresatai",
    "Contacts" : "Adresatai",
    "A contacts app for Nextcloud" : "Adresatų programėlė, skirta Nextcloud",
    "The Nextcloud contacts app is a user interface for Nextcloud's CardDAV server. Easily sync contacts from various devices with your Nextcloud and edit them online.\n\n* 🚀 **Integration with other Nextcloud apps!** Currently Mail and Calendar – more to come.\n* 🎉 **Never forget a birthday!** You can sync birthdays and other recurring events with your Nextcloud Calendar.\n* 👥 **Sharing of Adressbooks!** You want to share your contacts with your friends or coworkers? No problem!\n* 🙈 **We’re not reinventing the wheel!** Based on the great and open SabreDAV library." : "Nextcloud adresatų programėlė yra Nextcloud CardDAV serverio naudotojo sąsaja. Naudodami savo Nextcloud, lengvai sinchronizuokite adresatus iš įvairių įrenginių ir taisykite juos internete.\n\n* 🚀 **Integracija su kitomis Nextcloud programėlėmis!** Šiuo metu su Paštu ir Kalendoriumi – greitu laiku ir su kitomis.\n* 🎉 **Niekada nepamirškite apie gimtadienį!** Galite sinchronizuoti gimtadienius ir kitus pasikartojančius įvykius naudodami savo Nextcloud Kalendorių.\n* 👥 **Adresų knygų bendrinimas!** Norite bendrinti adresatus su savo draugais ar kolegomis? Jokių problemų!\n* 🙈 **Mes neišradinėjame dviračio!** Pagrįsta puikia ir atvira SabreDAV biblioteka.",
    "Copy to full name" : "Kopijuoti į vardą, pavardę",
    "Omit year" : "Neįtraukti metų",
    "Allow updating avatars from social media" : "Leisti atnaujinti avatarus iš socialinių tinklų",
    "Please select a circle" : "Pasirinkite ratą",
    "Loading circle …" : "Įkeliamas ratas…",
    "Your request to join this circle is pending approval" : "Jūsų užklausa prisijungti prie šio rato laukia patvirtinimo",
    "You are not a member of {circle}" : "Jūs nesate rato {circle} narys",
    "There was an error fetching the member list" : "Gaunant narių sąrašą įvyko klaida",
    "Loading contacts …" : "Įkeliami adresatai…",
    "There are no contacts yet" : "Kol kas nėra adresatų",
    "Create contact" : "Sukurti adresatą",
    "There are no contacts in this group" : "Šioje grupėje nėra adresatų",
    "Create contacts" : "Sukurti adresatus",
    "Add contacts" : "Pridėti adresatus",
    "Loading …" : "Įkeliama…",
    "Add member" : "Pridėti narį",
    "Leave circle" : "Išeiti iš rato",
    "Delete circle" : "Ištrinti ratą",
    "Contacts settings" : "Adresatų nustatymai",
    "General settings" : "Bendri nustatymai",
    "Update avatars from social media" : "Atnaujinti avatarus iš socialinių tinklų",
    "(refreshed once per week)" : "(įkeliama iš naujo kartą per savaitę)",
    "Address books" : "Adresų knygos",
    "Export" : "Eksportuoti",
    "Send email" : "Siųsti elektroninį laišką",
    "Contact groups" : "Adresatų grupės",
    "Create a new contact group" : "Sukurti naują adresatų grupę",
    "Contact group name" : "Adresatų grupės pavadinimas",
    "Circles" : "Ratai",
    "Create a new circle" : "Sukurti naują ratą",
    "Show all groups" : "Rodyti visas grupes",
    "Collapse groups" : "Suskleisti grupes",
    "Show all circles" : "Rodyti visus ratus",
    "Collapse circles" : "Suskleisti ratus",
    "This group already exists" : "Ši grupė jau yra",
    "This circle already exists" : "Šis ratas jau yra",
    "An error happened during the creation of the circle" : "Sukuriant ratą įvyko klaida",
    "Download" : "Atsisiųsti",
    "Show" : "Rodyti",
    "Rename" : "Pervadinti",
    "Delete" : "Ištrinti",
    "Copied" : "Nukopijuota",
    "Cannot copy" : "Nepavyksta nukopijuoti",
    "Copy link" : "Kopijuoti nuorodą",
    "Toggling of address book was not successful" : "Adresų knygos perjungimas buvo nesėkmingas",
    "This will delete the address book and every contacts within it" : "Tai ištrins adresų knygą ir visus joje esančius adresatus",
    "Delete {addressbook}?" : "Ištrinti {addressbook}?",
    "Deletion of address book was not successful." : "Adresų knygos ištrynimas buvo nesėkmingas",
    "Renaming of address book was not successful." : "Adresų knygos pervadinimas buvo nesėkmingas",
    "_%n contact_::_%n contacts_" : ["%n adresatas","%n adresatai","%n adresatų","%n adresatas"],
    "_%n group_::_%n groups_" : ["%n grupė","%n grupės","%n grupių","%n grupė"],
    "_Shared with {num} entity_::_Shared with {num} entities_" : ["Bendrinama su {num} esybe","Bendrinama su {num} esybėmis","Bendrinama su {num} esybių","Bendrinama su {num} esybe"],
    "Share with users or groups" : "Bendrinti su naudotojais ar grupėmis",
    "No users or groups" : "Nėra jokių naudotojų ar grupių",
    "can edit" : "gali redaguoti",
    "Unable to delete the share" : "Nepavyko ištrinti viešinio",
    "Unable to change permissions" : "Nepavyko pakeisti leidimų",
    "Import contacts" : "Importuoti adresatus",
    "Import into the {addressbookName} address book" : "Importuoti į {addressbookName} adresų knygą",
    "Select local file" : "Pasirinkti vietinį failą",
    "Import from files" : "Importuoti iš failų",
    "Importing is disabled because there are no address books available" : "Importavimas yra išjungtas, nes nėra prieinamų adresų knygų",
    "Choose a vCard file to import" : "Pasirinkite norimą importuoti vCard failą",
    "Add new address book" : "Pridėti naują adresų knygą",
    "An error occurred, unable to create the address book" : "Įvyko klaida, nepavyko sukurti adresų knygos",
    "First name" : "Vardas",
    "Last name" : "Pavardė",
    "Phonetic first name" : "Fonetinis vardas",
    "Phonetic last name" : "Fonetinė pavardė",
    "Display name" : "Rodomas vardas",
    "Last modified" : "Paskutinis modifikavimas",
    "Sort by {sorting}" : "Rikiuoti pagal {sorting}",
    "Manages" : "Tvarko",
    "Oversees" : "Prižiūri",
    "An error happened during the config change" : "Keičiant konfigūraciją įvyko klaida",
    "Password protection" : "Apsauga slaptažodžiu",
    "Save" : "Įrašyti",
    "Failed to save password. Please try again later." : "Nepavyko įrašyti slaptažodžio. Vėliau bandykite dar kartą.",
    "Circle name" : "Rato pavadinimas",
    "Circle owned by {owner}" : "Ratas, kurio savininkas yra {owner}",
    "Description" : "Aprašas",
    "There is no description for this circle" : "Šis ratas neturi aprašo",
    "Enter a description for the circle" : "Įveskite rato aprašą",
    "An error happened during description sync" : "Sinchronizuojant aprašą įvyko klaida",
    "An error happened during name sync" : "Sinchronizuojant pavadinimą įvyko klaida",
    "Add more info" : "Pridėti daugiau informacijos",
    "Crop contact photo" : "Apkirpti adresato nuotrauką",
    "Cancel" : "Atsisakyti",
    "Upload a new picture" : "Įkelti naują paveikslą",
    "Choose from Files" : "Pasirinkti iš failų",
    "Get from " : "Gauti iš ",
    "Download picture" : "Atsisiųsti paveikslėlį",
    "Delete picture" : "Ištrinti paveikslėlį",
    "Please select a valid format" : "Pasirinkite tinkamą formatą",
    "Invalid image" : "Netinkamas paveikslas",
    "Error cropping picture" : "Klaida apkerpant nuotrauką",
    "Pick an avatar" : "Pasirinkite avatarą",
    "Error while processing the picture." : "Klaida apdorojant paveikslėlį.",
    "Avatar downloaded from social network" : "Avataras atsiųstas iš socialinio tinklo",
    "Avatar already up to date" : "Avataras jau yra naujausias",
    "Avatar download failed" : "Avataro atsiuntimas nepavyko",
    "No contact selected" : "Nepasirinktas joks adresatas",
    "Select a contact on the list to begin" : "Norėdami pradėti, pasirinkite adresatą iš sąrašo",
    "Name" : "Vardas",
    "Title" : "Pareigos",
    "Company" : "Kompanija",
    "This contact was broken and received a fix. Please review the content and click here to save it." : "Šis adresatas buvo sugadintas ir pataisytas. Peržiūrėkite turinį ir spustelėkite čia, norėdami adresatą įrašyti.",
    "Edit" : "Taisyt",
    "Clone contact" : "Dubliuoti adresatą",
    "Generate QR Code" : "Generuoti QR kodą",
    "Contact vCard as QR code" : "Adresato vCard kaip QR kodas",
    "Pick an address book" : "Pasirinkti adresų knygą",
    "Select address book" : "Pasirinkti adresų knygą",
    "This contact is in read-only mode. You do not have permission to edit this contact." : "Šis adresatas yra tik skaitymo veiksenoje. Jūs neturite leidimo taisyti šį adresatą.",
    "The contact you were trying to edit has changed. Please manually refresh the contact. Any further edits will be discarded." : "Adresatas, kurį bandote taisyti, pasikeitė. Įkelkite rankiniu būdu adresatą iš naujo. Bet kokie tolimesni taisymai bus atmesti.",
    "Address book" : "Adresatų knyga",
    "{title} at {organization}" : "{title} iš {organization}",
    "Syntax error. Cannot open the contact." : "Sintaksės klaida. Nepavyko atverti adresato.",
    "The contact does not exist on the server anymore." : "Adresato šiame serveryje daugiau nebėra.",
    "Unable to retrieve the contact from the server, please check your network connection." : "Nepavyko gauti adresato iš serverio, patikrinkite savo tinklo ryšį.",
    "An error occurred while trying to move the contact" : "Bandant perkelti adresatą, įvyko klaida",
    "An error occurred while trying to copy the contact" : "Bandant nukopijuoti adresatą, įvyko klaida",
    "Search contacts …" : "Ieškoti adresatų…",
    "Add to {group}" : "Pridėti į {group}",
    "Remove {type}" : "Šalinti {type}",
    "Search {types}" : "Ieškoti {types}",
    "Search for people to add" : "Ieškoti norimų pridėti žmonių",
    "No results" : "Rezultatų nėra",
    "Add to group" : "Pridėti į grupę",
    "Add {type}" : "Pridėti {type}",
    "New circle name" : "Naujo rato pavadinimas",
    "Personal circle" : "Asmeninis ratas",
    "This circle will only be visible to you. Other members will not be able to see or use it." : "Šis ratas bus matomas tik jums. Kiti nariai negalės jo matyti ar juo naudotis.",
    "Local circle" : "Vietinis ratas",
    "Create circle" : "Sukurti ratą",
    "Loading members list …" : "Įkeliamas narių sąrašas…",
    "The list of members is only visible to members of this circle" : "Narių sąrašas yra matomas tik šio rato nariams",
    "Add members" : "Pridėti narius",
    "Show circle details" : "Rodyti išsamesnę rato informaciją",
    "Add to {circle}" : "Pridėti į {circle}",
    "Unable to get the recommendations list" : "Nepavyko gauti rekomendacijų sąrašo",
    "Unable to get the results" : "Nepavyko gauti rezultatų",
    "Some members could not be added" : "Kai kurių narių nepavyko pridėti",
    "Remove member" : "Šalinti narį",
    "Pending" : "Laukiantis",
    "Promote to {level}" : "Paaukštinti į {level}",
    "Demote to {level}" : "Pažeminti iki {level}",
    "Select type" : "Pasirinkite tipą",
    "Select Date" : "Pasirinkti datą",
    "Add contact in group" : "Pridėti adresatą į grupę",
    "Select option" : "Pasirinkite parinktį",
    "New contact" : "Naujas adresatas",
    "Unable to create the contact." : "Nepavyko sukurti adresato.",
    "Contact not found" : "Adresatas nerastas",
    "Group {group} not found" : "Grupė {group} nerasta",
    "Close" : "Užverti",
    "_{success} contact added to {name}_::_{success} contacts added to {name}_" : ["{success} adresatas sėkmingai pridėtas į {name}","{success} adresatai sėkmingai pridėti į {name}","{success} adresatų sėkmingai pridėta į {name}","{success} adresatas sėkmingai pridėtas į {name}"],
    "_Adding {success} contact to {name}_::_Adding {success} contacts to {name}_" : ["Pridedamas {success} adresatas į {name}","Pridedami {success} adresatai į {name}","Pridedama {success} adresatų į {name}","Pridedamas {success} adresatas į {name}"],
    "_{count} error_::_{count} errors_" : ["{count} klaida","{count} klaidos","{count} klaidų","{count} klaida"],
    "_Importing %n contact into {addressbook}_::_Importing %n contacts into {addressbook}_" : ["%n adresatas importuojamas į {addressbook}","%n adresatai importuojami į {addressbook}","%n adresatų importuojama į {addressbook}","%n adresatas importuojamas į {addressbook}"],
    "_Done importing %n contact into {addressbook}_::_Done importing %n contacts into {addressbook}_" : ["Atliktas %n adresato importavimas į {addressbook}","Atliktas %n adresatų importavimas į {addressbook}","Atliktas %n adresatų importavimas į {addressbook}","Atliktas %n adresato importavimas į {addressbook}"],
    "Import" : "Importuoti",
    "Could not copy" : "Nepavyko nukopijuoti",
    "Join circle" : "Prisijungti prie rato",
    "You are about to leave {circle}.\nAre you sure?" : "Jūs ketinate išeiti iš {circle}.\nAr esate tikri?",
    "Please confirm circle leave" : "Patvirtinkite išėjimą iš rato",
    "Could not leave the circle {displayName}" : "Nepavyko išeiti iš rato {displayName}",
    "Unable to join the circle" : "Nepavyko prisijungti prie rato",
    "You are about to delete {circle}.\nAre you sure?" : "Jūs ketinate ištrinti {circle}.\nAr esate tikri?",
    "Please confirm circle deletion" : "Patvirtinkite rato ištrynimą",
    "Unable to delete the circle" : "Nepavyko ištrinti rato",
    "Link copied to the clipboard" : "Nuoroda nukopijuota į iškarpinę",
    "Could not copy link to the clipboard." : "Nepavyko nukopijuoti nuorodos į iškarpinę.",
    "Not grouped" : "Nesugrupuoti",
    "Recently contacted" : "Paskiausiai susisiekta",
    "Circle" : "Ratas",
    "User" : "Naudotojas",
    "Group" : "Grupė",
    "Email" : "El. paštas",
    "Contact" : "Adresatas",
    "Member" : "Narys",
    "Moderator" : "Moderatorius",
    "Admin" : "Administratorius",
    "Owner" : "Savininkas",
    "Invites" : "Pakvietimai",
    "Visibility" : "Matomumas",
    "Visible to everyone" : "Matomas visiems",
    "Circle membership" : "Ratų narystė",
    "Prevent circle from being a member of another circle" : "Neleisti ratui būti kito rato nariu",
    "Users" : "Naudotojai",
    "Email addresses" : "El. pašto adresai",
    "Detailed name" : "Išsamus vardas",
    "Additional names" : "Papildomi vardai",
    "Prefix" : "Priešvardis",
    "Suffix" : "Povardis",
    "Nickname" : "Slapyvardis",
    "Notes" : "Pastabos",
    "Website" : "Svetainė",
    "Location" : "Vieta",
    "Federated Cloud ID" : "Federacinės debesijos ID",
    "Home" : "Namų",
    "Work" : "Darbo",
    "Other" : "Kita",
    "Address" : "Adresas",
    "Post office box" : "Pašto dėžutė",
    "Extended address" : "Išplėstinis adresas",
    "City" : "Miestas",
    "State or province" : "Regionas ar apskritis",
    "Postal code" : "Pašto kodas",
    "Country" : "Šalis",
    "Birthday" : "Gimtadienis",
    "Anniversary" : "Metinės",
    "Date of death" : "Mirties data",
    "Instant messaging" : "Pokalbių programa",
    "Phone" : "Telefonas",
    "Mobile" : "Mobilusis",
    "Work mobile" : "Darbo mobilusis",
    "Home mobile" : "Namų mobilusis",
    "Fax" : "Faksas",
    "Fax home" : "Namų faksas",
    "Fax work" : "Darbo faksas",
    "Pager" : "Pranešimų gaviklis",
    "Voice" : "Balso pašto",
    "Car" : "Automobilis",
    "Work pager" : "Darbo pranešimų gaviklis",
    "Manager" : "Vadovas",
    "Social network" : "Socialinis tinklas",
    "Relationship to you" : "Ryšys su jumis",
    "Spouse" : "Sutuoktinis",
    "Child" : "Vaikas",
    "Mother" : "Mama",
    "Father" : "Tėtis",
    "Parent" : "Tėvai",
    "Brother" : "Brolis",
    "Sister" : "Sesuo",
    "Relative" : "Giminaitis",
    "Friend" : "Draugas",
    "Colleague" : "Bendradarbis",
    "Assistant" : "Asistentas",
    "Related contacts" : "Susiję adresatai",
    "Agent" : "Agentas",
    "Emergency" : "Skubus atvejis",
    "Co-worker" : "Bendradarbis",
    "Gender" : "Lytis",
    "Female" : "Moteris",
    "Male" : "Vyras",
    "None" : "Nėra",
    "Unknown" : "Nežinoma",
    "Time zone" : "Laiko juosta",
    "Spoken languages" : "Šnekamosios kalbos",
    "_{failed} contact failed to be read_::_{failed} contacts failed to be read_" : ["Nepavyko perskaityti {failed} adresato","Nepavyko perskaityti {failed} adresatų","Nepavyko perskaityti {failed} adresatų","Nepavyko perskaityti {failed} adresato"],
    "Unable to create circle {circleName}" : "Nepavyko sukurti rato {circleName}",
    "Unable to delete circle {circleId}" : "Nepavyko ištrinti rato {circleId}",
    "Unable to delete contact" : "Nepavyko ištrinti adresato"
},
"nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");
