OC.L10N.register(
    "contacts",
    {
    "Details" : "Detalji",
    "Download" : "Preuzmi",
    "Rename" : "Rename",
    "Delete" : "Delete",
    "Copy link" : "Kopiraj vezu",
    "can edit" : "može da menja",
    "Password protection" : "Password protection",
    "Save" : "Sačuvaj",
    "Description" : "Opis",
    "Cancel" : "Otkaži",
    "Name" : "naziv",
    "Title" : "Naslov",
    "No results" : "Nema rezultata",
    "Pending" : "Na čekanju",
    "Close" : "Zatvori",
    "Import" : "Uvezi",
    "User" : "Korisnik",
    "Group" : "Group",
    "Email" : "email",
    "Moderator" : "Moderator",
    "Owner" : "Vlasnik",
    "Notes" : "Notes",
    "Website" : "Sajt",
    "Home" : "Почетна",
    "Work" : "Posao",
    "Other" : "Ostali",
    "Address" : "Adresa",
    "None" : "Ništa",
    "Unknown" : "Nepoznato"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
