OC.L10N.register(
    "contacts",
    {
    "Details" : "විස්තර",
    "Loading …" : "පූරණය වෙමින් …",
    "Download" : "බාගන්න",
    "Rename" : "නැවත නම් කරන්න",
    "Copy link" : "සබැඳිය පිටපත් කරන්න",
    "First name" : "මුල් නම",
    "Last name" : "අවසන් නම",
    "Password protection" : "මුරපද ආරක්ෂාව",
    "Save" : "සුරකින්න",
    "Description" : "විස්තරය",
    "Cancel" : "අවලංගු කරන්න",
    "Invalid image" : "වලංගු නොවන පින්තූරයකි",
    "Name" : "නම",
    "Company" : "සමාගම",
    "Remove {type}" : "{type} ඉවත් කරන්න",
    "Search {types}" : "{types}  සොයන්න",
    "No results" : "ප්‍රතිථල නැත",
    "Add to group" : "සමූහයට එකතු කරන්න ",
    "Select Date" : "දිනය තෝරන්න",
    "Close" : "වසන්න",
    "_{count} error_::_{count} errors_" : ["දෝෂ {count}","දෝෂ {count}"],
    "User" : "පරිශීලක",
    "Group" : "සමූහය",
    "Email" : "විද්‍යුත් තැපෑල",
    "Member" : "සාමාජික",
    "Admin" : "පරිපාලක",
    "Owner" : "හිමිකරු",
    "Users" : "පරිශීලකයින්",
    "Detailed name" : "විස්තරාත්මක නම",
    "Additional names" : "අමතර නම්",
    "Nickname" : "අන්වර්ථ නාමය",
    "Notes" : "සටහන්",
    "Website" : "වියමන අඩවිය",
    "Location" : "ස්ථානය",
    "Home" : "මුල් පිටුව",
    "Other" : "වෙනත්",
    "Address" : "ලිපිනය",
    "City" : "නගරය",
    "State or province" : "ප්‍රාන්තය හෝ පළාත",
    "Postal code" : "තැපැල් කේතය",
    "Country" : "රට",
    "Birthday" : "උපන් දිනය",
    "Anniversary" : "සංවත්සරය",
    "Date of death" : "විපත වු දිනය",
    "Phone" : "දුරකථනය",
    "Mobile" : "ජංගම",
    "Fax" : "ෆැක්ස්",
    "Social network" : "සමාජ ජාලය",
    "Spouse" : "කලත්‍රයා",
    "Mother" : "මව",
    "Father" : "පියා",
    "Unknown" : "නොදන්නා"
},
"nplurals=2; plural=(n != 1);");
