OC.L10N.register(
    "contacts",
    {
    "Details" : "ព័ត៌មាន​លម្អិត",
    "Contacts" : "ទំនាក់​ទំនង",
    "Send email" : "ផ្ញើ​អ៊ីមែល",
    "Download" : "ទាញយក",
    "Rename" : "ប្ដូរ​ឈ្មោះ",
    "Delete" : "លុប",
    "can edit" : "អាច​កែប្រែ",
    "Password protection" : "Password protection",
    "Save" : "រក្សាទុក",
    "Description" : "ការ​អធិប្បាយ",
    "Cancel" : "បោះបង់",
    "Invalid image" : "រូបភាព​មិន​ត្រឹម​ត្រូវ",
    "Name" : "ឈ្មោះ",
    "Title" : "ចំណងជើង",
    "Pending" : "កំពុង​រង់ចាំ",
    "Chart" : "ក្រាប",
    "Close" : "បិទ",
    "Import" : "នាំយកចូល",
    "Not grouped" : "គ្មាន​ក្រុម",
    "User" : "User",
    "Group" : "Group",
    "Email" : "អ៊ីមែល",
    "Admin" : "អ្នក​គ្រប់​គ្រង",
    "Owner" : "Owner",
    "Users" : "អ្នកប្រើ",
    "Notes" : "កំណត់​ចំណាំ",
    "Location" : "ទីតាំង",
    "Work" : "ធ្វើការ",
    "Other" : "ផ្សេងៗ",
    "Address" : "អាសយដ្ឋាន",
    "Birthday" : "ថ្ងៃ​កំណើត",
    "None" : "គ្មាន"
},
"nplurals=1; plural=0;");
