OC.L10N.register(
    "contacts",
    {
    "Details" : "Detalhes",
    "All contacts" : "Todos os contatos",
    "Contacts" : "Contatos",
    "A contacts app for Nextcloud" : "Um aplicativo de contatos para Nextcloud",
    "The Nextcloud contacts app is a user interface for Nextcloud's CardDAV server. Easily sync contacts from various devices with your Nextcloud and edit them online.\n\n* 🚀 **Integration with other Nextcloud apps!** Currently Mail and Calendar – more to come.\n* 🎉 **Never forget a birthday!** You can sync birthdays and other recurring events with your Nextcloud Calendar.\n* 👥 **Sharing of Adressbooks!** You want to share your contacts with your friends or coworkers? No problem!\n* 🙈 **We’re not reinventing the wheel!** Based on the great and open SabreDAV library." : "O aplicativo de contatos Nextcloud é uma interface de usuário para o servidor CardDAV do Nextcloud. Sincronize facilmente os contatos em vários dispositivos e edite-os online.\n\n* 🚀 **Integração com outros aplicativos Nextcloud!** Atualmente, E-mail e Calendário - mais por vir.\n* 🎉 **Nunca esqueça um aniversário!** Você pode sincronizar aniversários e outros eventos recorrentes com o seu Calendário Nextcloud.\n* 👥 **Compartilhamento de Catálogo de Endereços!** Você quer compartilhar seus contatos com seus amigos ou colegas de trabalho? Sem problemas!\n* 🙈 **Não estamos reinventando a roda!** Com base na grande e aberta biblioteca SabreDAV.",
    "Copy to full name" : "Copiar para o nome completo",
    "Omit year" : "Omitir ano",
    "Allow updating avatars from social media" : "Permitir atualização de avatares das mídias sociais",
    "Please select a circle" : "Selecione um círculo",
    "Loading circle …" : "Carregando círculo…",
    "Your request to join this circle is pending approval" : "Sua solicitação para ingressar neste círculo está com aprovação pendente",
    "You are not a member of {circle}" : "Você não é membro de {circle}",
    "There was an error fetching the member list" : "Ocorreu um erro ao obter a lista de membros",
    "Loading contacts …" : "Carregando contatos...",
    "There are no contacts yet" : "Ainda não há contatos",
    "Create contact" : "Criar contato",
    "There are no contacts in this group" : "Não há contatos neste grupo",
    "Create contacts" : "Criar contatos",
    "Add contacts" : "Adicionar contatos",
    "Loading …" : "Carregando...",
    "Add member" : "Adicionar membro",
    "Leave circle" : "Sair do círculo",
    "Delete circle" : "Excluir o círculo",
    "Contacts settings" : "Configurações de contatos",
    "General settings" : "Configurações gerais",
    "Update avatars from social media" : "Atualizar avatares pela mídia social",
    "(refreshed once per week)" : "(atualizado uma vez por semana)",
    "Address books" : "Catálogos de endereços ",
    "Export" : "Exportar",
    "Send email" : "Enviar email",
    "Send email as BCC" : "Enviar e-mail como BCC",
    "Contact groups" : "Grupos de contato",
    "Create a new contact group" : "Criar um novo grupo de contatos",
    "Contact group name" : "Nome do grupo de contato",
    "Circles" : "Círculos",
    "Create a new circle" : "Criar um novo círculo",
    "Show all groups" : "Mostrar todos os grupos",
    "Collapse groups" : "Recolher grupos",
    "Show all circles" : "Mostrar todos os círculos",
    "Collapse circles" : "Recolher círculos",
    "This group already exists" : "Este grupo já existe",
    "This circle already exists" : "Este círculo já existe",
    "An error happened during the creation of the circle" : "Ocorreu um erro durante a criação do círculo ",
    "{addressbookname} (Disabled)" : "{addressbookname} (desativado)",
    "Download" : "Baixar",
    "Show" : "Show",
    "Rename" : "Renomear",
    "Delete" : "Excluir",
    "Copied" : "Copiado",
    "Cannot copy" : "Não pode copiar ",
    "Copy link" : "Copiar link",
    "Toggling of address book was not successful" : "A alternância da agenda não foi concluída.",
    "This will delete the address book and every contacts within it" : "Isso irá excluir a agenda e os contatos dela",
    "Delete {addressbook}?" : "Excluir {addressbook}?",
    "Deletion of address book was not successful." : "A exclusão da agenda não foi concluída.",
    "Renaming of address book was not successful." : "A renomeação da agenda não foi concluída.",
    "_%n contact_::_%n contacts_" : ["%n contato","%n contatos","%n contatos"],
    "_%n group_::_%n groups_" : ["%n grupo","%n grupos","%n grupos"],
    "_Shared with {num} entity_::_Shared with {num} entities_" : ["Compartilhado com {num} entidade","Compartilhado com {num} entidades","Compartilhado com {num} entidades"],
    "Share with users or groups" : "Compartilhar com usuários ou grupos",
    "Share with users" : "Compartilhar com usuários",
    "No users or groups" : "Nenhum usuário ou grupo",
    "can edit" : "pode editar",
    "Unable to delete the share" : "Não foi possível excluir o compartilhamento",
    "Unable to change permissions" : "Não é possível alterar as permissões",
    "Import contacts" : "Importar contatos",
    "Import into the {addressbookName} address book" : "Importar para o catálogo de endereços de {addressbookName}",
    "Select local file" : "Selecionar um arquivo local",
    "Import from files" : "Importar de Arquivos",
    "Importing is disabled because there are no address books available" : "A importação está desativada porque não há catálogos de endereços disponíveis",
    "Choose a vCard file to import" : "Escolha um arquivo vCard para importar",
    "Add new address book" : "Adicionar novo catálogo de endereços",
    "An error occurred, unable to create the address book" : "Ocorreu um erro ao criar o catálogo de endereços",
    "First name" : "Primeiro nome",
    "Last name" : "Sobrenome",
    "Phonetic first name" : "Primeiro nome fonético",
    "Phonetic last name" : "Último nome fonético",
    "Display name" : "Nome de exibição",
    "Last modified" : "Última modificação",
    "Sort by {sorting}" : "Classificar por {sorting}",
    "Manages" : "Gerencia",
    "Oversees" : "Supervisiona",
    "An error happened during the config change" : "Ocorreu um erro durante a mudança de configuração",
    "Password protection" : "Proteção de senha",
    "Enforce password protection on files shared to this circle" : "Impor proteção por senha em arquivos compartilhados com este círculo",
    "Use a unique password for all shares to this circle" : "Use uma senha exclusiva para todos os compartilhamentos neste círculo",
    "Unique password …" : "Senha exclusiva…",
    "Save" : "Salvar",
    "Change unique password" : "Alterar senha exclusiva",
    "Failed to save password. Please try again later." : "Falha ao salvar a senha. Por favor, tente novamente mais tarde.",
    "Circle name" : "Nome do círculo",
    "Circle owned by {owner}" : "Círculo de propriedade de {owner}",
    "Request to join" : "Solicitar adesão",
    "Description" : "Descrição",
    "There is no description for this circle" : "Não há descrição para este círculo",
    "Enter a description for the circle" : "Insira uma descrição para o círculo",
    "An error happened during description sync" : "Ocorreu um erro durante a sincronização da descrição",
    "An error happened during name sync" : "Ocorreu um erro durante a sincronização do nome ",
    "Add more info" : "Adicionar mais informações",
    "More fields" : "Mais campos",
    "Crop contact photo" : "Cortar foto de contato",
    "Cancel" : "Cancelar",
    "Upload a new picture" : "Enviar uma nova imagem",
    "Choose from Files" : "Escolher de Arquivos",
    "Get from " : "Obter de",
    "Download picture" : "Baixar imagem",
    "Delete picture" : "Excluir imagem",
    "Please select a valid format" : "Selecione um formato válido",
    "Invalid image" : "Imagem inválida",
    "Error cropping picture" : "Erro ao recortar a imagem",
    "Pick an avatar" : "Escolha um avatar",
    "Error while processing the picture." : "Erro ao processar a imagem.",
    "Avatar downloaded from social network" : "Avatar baixado da rede social",
    "Avatar already up to date" : "Avatar já atualizado",
    "Avatar download failed" : "Falha no download do avatar",
    "No contact selected" : "Nenhum contato selecionado",
    "Select a contact on the list to begin" : "Selecione um contato na lista para começar",
    "Name" : "Nome",
    "Title" : "Título",
    "Company" : "Companhia",
    "This contact was broken and received a fix. Please review the content and click here to save it." : "Este contato foi corrompido e recebeu uma correção. Revise o conteúdo e clique aqui para salvá-lo.",
    "Edit" : "Editar",
    "Clone contact" : "Clonar contato",
    "Generate QR Code" : "Gerar QR Code",
    "Contact vCard as QR code" : "Contato vCard como QR Code",
    "Pick an address book" : "Pegar uma agenda",
    "Select address book" : "Selecionar agenda",
    "Go to talk conversation" : "Ir para falar conversação",
    "View profile" : "Ver perfil",
    "This contact is in read-only mode. You do not have permission to edit this contact." : "Este contato é somente leitura. Você não tem permissão para editar este contato.",
    "The contact you were trying to edit has changed. Please manually refresh the contact. Any further edits will be discarded." : "O contato que você estava tentando editar foi alterado. Atualize manualmente o contato. Qualquer outra edição será descartada.",
    "Address book" : "Catálogo de endereços",
    "Add contact to Birthday Calendar" : "Adicionar contato ao Calendário de Aniversários",
    "Exclude contact from Birthday Calendar" : "Excluir contato do Calendário de Aniversários",
    "{title} at {organization}" : "{title} em {organization}",
    "Syntax error. Cannot open the contact." : "Erro de sintaxe. Não é possível abrir o contato.",
    "The contact does not exist on the server anymore." : "The contact does not exist on the server anymore.",
    "Unable to retrieve the contact from the server, please check your network connection." : "Não foi possível recuperar o contato do servidor, verifique sua conexão de rede.",
    "An error occurred while trying to move the contact" : "Ocorreu um erro ao mover o contato",
    "An error occurred while trying to copy the contact" : "Ocorreu um erro ao copiar o contato",
    "Unable to update contact" : "Não foi possível atualizar o contato",
    "Search contacts …" : "Procurar contatos...",
    "Add to {group}" : "Adicionar a {group}",
    "Remove {type}" : "Excluir {type}",
    "Search {types}" : "Pesquisar {types}",
    "Search for people to add" : "Procure pessoas para adicionar",
    "No results" : "Sem resultados",
    "Add to group" : "Adicionar ao grupo",
    "Add {type}" : "Adicionar {type}",
    "New circle name" : "Novo nome do círculo",
    "Personal circle" : "Círculo pessoal",
    "This circle will only be visible to you. Other members will not be able to see or use it." : "Este círculo ficará visível apenas para você. Outros membros não poderão ver ou usá-lo.",
    "Local circle" : "Círculo local",
    "This circle will not be shared with the other instances of the global scale" : "Este círculo não será compartilhado com as outras instâncias da escala global",
    "Create circle" : "Criar um círculo",
    "Loading members list …" : "Carregando lista de membros…",
    "The list of members is only visible to members of this circle" : "A lista de membros é visível apenas para os membros deste círculo",
    "You currently have no access to the member list" : "Atualmente você não tem acesso à lista de membros",
    "Add members" : "Adicionar membros",
    "Show circle details" : "Mostrar detalhes do círculo",
    "Add to {circle}" : "Adicionar a {circle}",
    "Unable to get the recommendations list" : "Não foi possível obter a lista de recomendações",
    "Unable to get the results" : "Incapaz de obter os resultados",
    "Some members could not be added" : "Alguns membros não puderam ser adicionados",
    "There was an issue adding members to the circle" : "Ocorreu um problema ao adicionar membros ao círculo",
    "Accept membership request" : "Aceitar o pedido de adesão ",
    "Reject membership request" : "Rejeitar o pedido de adesão ",
    "Manage level" : "Gerenciar nível",
    "Remove member" : "Remover membro",
    "Pending" : "Pendente",
    "Promote as sole owner" : "Promover como único proprietário",
    "Promote to {level}" : "Promova para {level}",
    "Demote to {level}" : "Rebaixar para {level}",
    "Could not delete the member {displayName}" : "Não foi possível excluir o membro {displayName}",
    "Could not change the member level to {level}" : "Não foi possível alterar o nível de membro para {level}",
    "Could not accept membership request" : "Não foi possível aceitar o pedido de adesão ",
    "Chart" : "Gráfico",
    "Select chart …" : "Selecionar gráfico…",
    "Select type" : "Selecionar tipo",
    "Select Date" : "Selecionar Data",
    "Add contact in group" : "Adicionar contato ao grupo",
    "none" : "nenhum",
    "Select option" : "Selecionar a opção",
    "Add property of this type" : "Adicionar propriedade deste tipo",
    "New contact" : "Novo contato",
    "Unable to create the contact." : "Não foi possível criar o contato.",
    "Contact not found" : "Contato não encontrado",
    "Group {group} not found" : "Grupo {group} não encontrado",
    "Close" : "Fechar",
    "_{success} contact added to {name}_::_{success} contacts added to {name}_" : ["{success} contato adicionado em {name}","{success} contatos adicionados em {name}","{success} contatos adicionados em {name}"],
    "_Adding {success} contact to {name}_::_Adding {success} contacts to {name}_" : ["Adicionando {success} contato em {name}","Adicionando {success} contatos em {name}","Adicionando {success} contatos em {name}"],
    "_{count} error_::_{count} errors_" : ["{count} erro","{count} erros","{count} erros"],
    "_Importing %n contact into {addressbook}_::_Importing %n contacts into {addressbook}_" : ["Importando %n contato para {addressbook}","Importando %n contatos para {addressbook}","Importando %n contatos para {addressbook}"],
    "_Done importing %n contact into {addressbook}_::_Done importing %n contacts into {addressbook}_" : ["Concluída a importação de %n contato para {addressbook}","Concluída a importação de %n contatos para {addressbook}","Concluída a importação de %n contatos para {addressbook}"],
    "Import" : "Importar",
    "Could not copy" : "Não foi possível copiar",
    "Join circle" : "Junte-se ao círculo",
    "You are about to leave {circle}.\nAre you sure?" : "Você está prestes a sair do {circle}.\nTem certeza?",
    "Please confirm circle leave" : "Por favor, confirme a saída do círculo",
    "Could not leave the circle {displayName}" : "Não foi possível sair do círculo {displayName}",
    "Unable to join the circle" : "Incapaz de aderir ao círculo",
    "You are about to delete {circle}.\nAre you sure?" : "Você está prestes a excluir  {circle}.\nTem certeza?",
    "Please confirm circle deletion" : "Por favor, confirme a exclusão do círculo",
    "Unable to delete the circle" : "Incapaz de excluir o círculo",
    "Link copied to the clipboard" : "Link copiado para a área de transferência",
    "Could not copy link to the clipboard." : "Não foi possível copiar o link para a área de transferência.",
    "Not grouped" : "Não agrupado",
    "Recently contacted" : "Contactados recentemente",
    "Organization chart" : "Organograma",
    "Circles are groups of people that you can create yourself and with whom you can share data. They can be made up of other accounts or groups of accounts of the Nextcloud instance, but also of contacts from your address book or even external people by simply entering their e-mail addresses." : "Círculos são grupos de pessoas que você mesmo pode criar e com quem pode compartilhar dados. Podem ser constituídas por outras contas ou grupos de contas da instância Nextcloud, mas também por contactos da sua agenda de endereços ou mesmo por pessoas externas, bastando para isso introduzir os seus endereços de e-mail.",
    "Circle" : "Círculo",
    "User" : "Usuário",
    "Group" : "Grupo",
    "Email" : "E-mail",
    "Contact" : "Contactar",
    "Member" : "Membro",
    "Moderator" : "Moderador",
    "Admin" : "Admin",
    "Owner" : "Proprietário",
    "Invites" : "Convites",
    "Anyone can request membership" : "Qualquer pessoa pode solicitar adesão",
    "Members need to accept invitation" : "Os membros precisam aceitar o convite",
    "Memberships must be confirmed/accepted by a Moderator (requires Open)" : "As adesões devem ser confirmadas/aceitas por um moderador (requer Aberto)",
    "Members can also invite" : "Os membros também podem convidar",
    "Visibility" : "Visibilidade",
    "Visible to everyone" : "Visível para todos",
    "Circle membership" : "Membros do círculo",
    "Prevent circle from being a member of another circle" : "Impedir que o círculo seja membro de outro círculo",
    "Users" : "Usuários",
    "Email addresses" : "Endereço de e-mail",
    "Detailed name" : "Nome detalhado",
    "Additional names" : "Nomes adicionais",
    "Prefix" : "Prefixo",
    "Suffix" : "Sufixo",
    "Nickname" : "Apelido",
    "Notes" : "Anotações",
    "Website" : "Website",
    "Location" : "Localização",
    "Federated Cloud ID" : "ID da Nuvem Federada",
    "Home" : "Casa",
    "Work" : "Trabalho",
    "Other" : "Outro",
    "Address" : "Endereço",
    "Post office box" : "Caixa de correio",
    "Extended address" : "Endereço estendido",
    "City" : "Cidade",
    "State or province" : "Estado ou província",
    "Postal code" : "Código postal",
    "Country" : "País",
    "Birthday" : "Aniversário",
    "Anniversary" : "Aniversário",
    "Date of death" : "Data da morte",
    "Instant messaging" : "Mensagem instantânea",
    "Phone" : "Telefone",
    "Mobile" : "Celular",
    "Work mobile" : "Celular do trabalho",
    "Home mobile" : "Celular pessoal",
    "Fax" : "Fax",
    "Fax home" : "Fax de casa",
    "Fax work" : "Fax do trabalho",
    "Pager" : "Pager",
    "Voice" : "Voz",
    "Car" : "Carro",
    "Work pager" : "Pager do trabalho",
    "Manager" : "Gerente",
    "Social network" : "Rede social",
    "Relationship to you" : "Relacionado com você",
    "Spouse" : "Esposo(a)",
    "Child" : "Filho(a)",
    "Mother" : "Mãe",
    "Father" : "Pai",
    "Parent" : "Pais",
    "Brother" : "Irmão",
    "Sister" : "Irmã",
    "Relative" : "Parente",
    "Friend" : "Amigo",
    "Colleague" : "Colega",
    "Assistant" : "Assistente",
    "Related contacts" : "Contatos relacionados",
    "Agent" : "Agente",
    "Emergency" : "Emergência",
    "Co-worker" : "Colega de trabalho",
    "Gender" : "Gênero",
    "Female" : "Mulher",
    "Male" : "Homem",
    "None" : "Nenhum",
    "Unknown" : "Desconhecido",
    "Time zone" : "Fuso horário ",
    "Spoken languages" : "Idiomas falados",
    "_{failed} contact failed to be read_::_{failed} contacts failed to be read_" : ["{failed} contato falhou ao ler","{failed} contatos falharam ao ler","{failed} contatos falharam ao ler"],
    "An error has occurred in circle(s). Check the console for more details." : "An error has occurred in circle(s). Check the console for more details.",
    "Unable to create circle {circleName}" : "Não foi possível criar o círculo {circleName}",
    "Unable to delete circle {circleId}" : "Não foi possível excluir o círculo {circleId}",
    "Unable to delete contact" : "Não foi possível excluir o contato"
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
