OC.L10N.register(
    "contacts",
    {
    "Details" : "ລາຍລະອຽດ",
    "Contacts" : "ຕິດຕໍ່",
    "Loading …" : "ກຳລັງໂຫຼດ",
    "Download" : "ດາວໂຫລດ",
    "Rename" : "ປ່ຽນຊື່",
    "Delete" : "ລຶບ",
    "Copy link" : "ສຳເນົາລິງ",
    "Password protection" : "ລະຫັດປ້ອງກັນ",
    "Save" : "ບັນທຶກ",
    "Cancel" : "ຍົກເລີກ",
    "Invalid image" : "ບໍ່ມີຮູບພາບ",
    "Name" : "ຊື່",
    "Company" : "ບໍລິສັດ",
    "Search contacts …" : "ຄົ້ນຫາຕິດຕໍ່ ...",
    "No results" : "ບໍ່ມີຜົນ",
    "Pending" : "ທີ່ກໍາລັງລໍຖ້າ",
    "Close" : "ປິດ",
    "User" : "ຜູ້ໃຊ້",
    "Group" : "ກຸ່ມ",
    "Email" : "ອິເມວ",
    "Admin" : "ຜູ້ເບິ່ງເເຍງລະບົບ",
    "Owner" : "ເຈົ້າຂອງ",
    "Users" : "ຜູ້ໃຊ້",
    "Website" : "ເວັບໄຊ",
    "Home" : "ໜ້າຫຼັກ",
    "Address" : "ທີ່ຢູ່",
    "City" : "ເມືອງ",
    "Country" : "ປະເທດ",
    "None" : "ບໍ່ມີ",
    "Unknown" : "ບໍ່ຮູ້"
},
"nplurals=1; plural=0;");
