OC.L10N.register(
    "contacts",
    {
    "Details" : "Detaljar",
    "Contacts" : "Kontaktar",
    "Circles" : "Sirklar",
    "Download" : "Last ned",
    "Rename" : "Gje nytt namn",
    "Delete" : "Ta bort",
    "can edit" : "kan endra",
    "First name" : "Fornamn",
    "Last name" : "Etternamn",
    "Last modified" : "Siste endra",
    "Password protection" : "Password protection",
    "Save" : "Lagre",
    "Description" : "Skildring",
    "Cancel" : "Avbryt",
    "Invalid image" : "Ugyldig bilete",
    "Name" : "Namn",
    "Title" : "Tittel",
    "Pending" : "Under vegs",
    "Close" : "Lukk",
    "Import" : "Importer",
    "Not grouped" : "Ikkje gruppert",
    "Circle" : "Sirkel",
    "User" : "Bruker",
    "Group" : "Gruppe",
    "Email" : "E-post",
    "Moderator" : "Moderator",
    "Admin" : "Administrer",
    "Owner" : "Owner",
    "Users" : "Brukarare",
    "Additional names" : "Andre namn",
    "Nickname" : "Kallenamn",
    "Notes" : "Notat",
    "Location" : "Stad",
    "Home" : "Heime",
    "Work" : "Arbeid",
    "Other" : "Anna",
    "Address" : "Adresse",
    "City" : "Stad",
    "State or province" : "Fylke, stat eller region",
    "Postal code" : "Postkode",
    "Country" : "Land",
    "Birthday" : "Bursdag",
    "Phone" : "Telefonnummer",
    "Mobile" : "Mobil",
    "Fax" : "Faks",
    "Pager" : "Personsøkjar",
    "Voice" : "Tale",
    "None" : "Ingen",
    "Unknown" : "Ukjend"
},
"nplurals=2; plural=(n != 1);");
