OC.L10N.register(
    "contacts",
    {
    "Details" : "Detalles",
    "All contacts" : "Todos los contactos",
    "Contacts" : "Contactos",
    "A contacts app for Nextcloud" : "Una aplicación de contactos para Nextcloud",
    "The Nextcloud contacts app is a user interface for Nextcloud's CardDAV server. Easily sync contacts from various devices with your Nextcloud and edit them online.\n\n* 🚀 **Integration with other Nextcloud apps!** Currently Mail and Calendar – more to come.\n* 🎉 **Never forget a birthday!** You can sync birthdays and other recurring events with your Nextcloud Calendar.\n* 👥 **Sharing of Adressbooks!** You want to share your contacts with your friends or coworkers? No problem!\n* 🙈 **We’re not reinventing the wheel!** Based on the great and open SabreDAV library." : "La aplicación de contactos de Nextcloud es una interfaz de usuario para el servidor CardDAV de Nextcloud. Sincroniza fácilmente los contactos desde varios dispositivos con tu Nextcloud y edítalos en línea.\n      \n      * 🚀 **Integración con otras aplicaciones de Nextcloud**: Actualmente con Correo y Calendario, ¡más por venir!\n      * 🎉 **¡Nunca olvides un cumpleaños!**: Puedes sincronizar cumpleaños y otros eventos recurrentes con tu Calendario de Nextcloud.\n      * 👥 **¡Comparte libretas de direcciones!**: ¿Quieres compartir tus contactos con amigos o compañeros de trabajo? ¡No hay problema!\n      * 🙈 **¡No estamos reinventando la rueda!**: Basado en la gran y abierta biblioteca SabreDAV.",
    "Copy to full name" : "Copiar al nombre completo",
    "Omit year" : "Omitir año",
    "Allow updating avatars from social media" : "Permitir actualizar avatares desde redes sociales",
    "Please select a circle" : "Por favor, selecciona un círculo",
    "Loading circle …" : "Cargando círculo...",
    "Your request to join this circle is pending approval" : "Tu solicitud para unirte a este círculo está pendiente de aprobación",
    "You are not a member of {circle}" : "No eres miembro de {circle}",
    "There was an error fetching the member list" : "Ocurrió un error al obtener la lista de miembros",
    "Loading contacts …" : "Cargando contactos ...",
    "There are no contacts yet" : "Aún no hay contactos",
    "Create contact" : "Crear contacto",
    "There are no contacts in this group" : "No hay contactos en este grupo",
    "Create contacts" : "Crear contactos",
    "Add contacts" : "Añadir contactos",
    "Loading …" : "Cargando...",
    "Add member" : "Añadir miembro",
    "Leave circle" : "Abandonar círculo",
    "Delete circle" : "Borrar círculo",
    "Contacts settings" : "Configuración de contactos",
    "General settings" : "Configuraciones generales",
    "Update avatars from social media" : "Actualizar avatares desde redes sociales",
    "(refreshed once per week)" : "(actualizado una vez por semana)",
    "Address books" : "Libretas de direcciones",
    "Export" : "Exportar",
    "Send email" : "Enviar correo electrónico",
    "Send email as BCC" : "Enviar correo electrónico como CCO",
    "Contact groups" : "Grupos de contactos",
    "Create a new contact group" : "Crear un nuevo grupo de contactos",
    "Contact group name" : "Nombre del grupo de contactos",
    "Circles" : "Círculos",
    "Create a new circle" : "Crear un nuevo círculo",
    "Show all groups" : "Mostrar todos los grupos",
    "Collapse groups" : "Colapsar grupos",
    "Show all circles" : "Mostrar todos los círculos",
    "Collapse circles" : "Colapsar círculos",
    "This group already exists" : "Este grupo ya existe",
    "This circle already exists" : "Este círculo ya existe",
    "An error happened during the creation of the circle" : "Ocurrió un error durante la creación del círculo",
    "{addressbookname} (Disabled)" : "{addressbookname} (Desactivado)",
    "Download" : "Descargar",
    "Show" : "Mostrar",
    "Rename" : "Renombrar",
    "Delete" : "Borrar",
    "Copied" : "Copiado",
    "Cannot copy" : "No se puede copiar",
    "Copy link" : "Copiar liga",
    "Toggling of address book was not successful" : "No se pudo cambiar el estado de la libreta de direcciones",
    "This will delete the address book and every contacts within it" : "Esto eliminará la libreta de direcciones y todos los contactos dentro de ella",
    "Delete {addressbook}?" : "¿Eliminar {addressbook}?",
    "Deletion of address book was not successful." : "No se pudo eliminar la libreta de direcciones",
    "Renaming of address book was not successful." : "No se pudo cambiar el nombre de la libreta de direcciones",
    "_%n contact_::_%n contacts_" : ["%n contacto","%n contactos","%n contactos"],
    "_%n group_::_%n groups_" : ["%n grupo","%n grupos","%n grupos"],
    "_Shared with {num} entity_::_Shared with {num} entities_" : ["Compartido con {num} entidad","Compartido con {num} entidades","Compartido con {num} entidades"],
    "Share with users or groups" : "Compartir con otros usuarios o grupos",
    "Share with users" : "Compartir con usuarios",
    "No users or groups" : "No hay usuarios o grupos",
    "can edit" : "puede editar",
    "Unable to delete the share" : "No se pudo eliminar la compartición",
    "Unable to change permissions" : "No se pudieron cambiar los permisos",
    "Import contacts" : "Importar contactos",
    "Import into the {addressbookName} address book" : "Importar a la libreta de direcciones {addressbookName}",
    "Select local file" : "Seleccionar archivo local",
    "Importing is disabled because there are no address books available" : "La importación está desactivada porque no hay libretas de direcciones disponibles",
    "Choose a vCard file to import" : "Elige un archivo vCard para importar",
    "Add new address book" : "Añadir nueva libreta de direcciones",
    "An error occurred, unable to create the address book" : "Ocurrió un error, no se pudo crear la libreta de direcciones",
    "First name" : "Nombre",
    "Last name" : "Apellido",
    "Phonetic first name" : "Nombre fonético",
    "Phonetic last name" : "Apellido fonético",
    "Display name" : "Nombre a desplegar",
    "Last modified" : "Última modificación",
    "Sort by {sorting}" : "Ordenar por {sorting}",
    "Manages" : "Gestiona",
    "Oversees" : "Supervisa",
    "An error happened during the config change" : "Ocurrió un error durante el cambio de configuración",
    "Password protection" : "Protección con contraseña",
    "Enforce password protection on files shared to this circle" : "Aplicar protección con contraseña a los archivos compartidos en este círculo",
    "Use a unique password for all shares to this circle" : "Usar una contraseña única para todas las comparticiones en este círculo",
    "Unique password …" : "Contraseña única...",
    "Save" : "Guardar",
    "Change unique password" : "Cambiar contraseña única",
    "Failed to save password. Please try again later." : "Error al guardar la contraseña. Por favor, inténtalo de nuevo más tarde.",
    "Circle name" : "Nombre del círculo",
    "Circle owned by {owner}" : "Círculo propiedad de {owner}",
    "Request to join" : "Solicitud para unirse",
    "Description" : "Descripción",
    "There is no description for this circle" : "No hay una descripción para este círculo",
    "Enter a description for the circle" : "Introduce una descripción para el círculo",
    "An error happened during description sync" : "Ocurrió un error durante la sincronización de la descripción",
    "An error happened during name sync" : "Ocurrió un error durante la sincronización del nombre",
    "Add more info" : "Añadir más información",
    "More fields" : "Más campos",
    "Crop contact photo" : "Recortar foto de contacto",
    "Cancel" : "Cancelar",
    "Upload a new picture" : "Cargar una nueva imagen",
    "Choose from Files" : "Elegir desde Archivos",
    "Get from " : "Obtener de ",
    "Download picture" : "Descargar imagen",
    "Delete picture" : "Eliminar imagen",
    "Please select a valid format" : "Por favor, selecciona un formato válido",
    "Invalid image" : "Imagen inválida",
    "Error cropping picture" : "Error al recortar la imagen",
    "Pick an avatar" : "Elegir un avatar",
    "Error while processing the picture." : "Error al procesar la imagen.",
    "Avatar downloaded from social network" : "Avatar descargado desde la red social",
    "Avatar already up to date" : "El avatar ya está actualizado",
    "Avatar download failed" : "Error al descargar el avatar",
    "No contact selected" : "Ningún contacto seleccionado",
    "Select a contact on the list to begin" : "Selecciona un contacto de la lista para comenzar",
    "Name" : "Nombre",
    "Title" : "Título",
    "Company" : "Empresa",
    "This contact was broken and received a fix. Please review the content and click here to save it." : "Este contacto estaba dañado y se ha corregido. Por favor, revisa el contenido y haz clic aquí para guardarlo.",
    "Edit" : "Editar",
    "Clone contact" : "Clonar contacto",
    "Generate QR Code" : "Generar código QR",
    "Contact vCard as QR code" : "vCard de contacto como código QR",
    "Pick an address book" : "Elegir una libreta de direcciones",
    "Select address book" : "Seleccionar libreta de direcciones",
    "This contact is in read-only mode. You do not have permission to edit this contact." : "Este contacto está en modo de solo lectura. No tienes permiso para editar este contacto.",
    "The contact you were trying to edit has changed. Please manually refresh the contact. Any further edits will be discarded." : "El contacto que intentabas editar ha cambiado. Actualiza manualmente el contacto. Cualquier edición adicional se descartará.",
    "Address book" : "Libreta de direcciones",
    "Add contact to Birthday Calendar" : "Añadir contacto al Calendario de Cumpleaños",
    "Exclude contact from Birthday Calendar" : "Excluir contacto del Calendario de Cumpleaños",
    "{title} at {organization}" : "{title} en {organization}",
    "Syntax error. Cannot open the contact." : "Error de sintaxis. No se puede abrir el contacto.",
    "The contact does not exist on the server anymore." : "El contacto ya no existe en el servidor.",
    "Unable to retrieve the contact from the server, please check your network connection." : "No se pudo recuperar el contacto del servidor, por favor verifica tu conexión de red.",
    "An error occurred while trying to move the contact" : "Ocurrió un error al intentar mover el contacto",
    "An error occurred while trying to copy the contact" : "Ocurrió un error al intentar copiar el contacto",
    "Unable to update contact" : "No se pudo actualizar el contacto",
    "Search contacts …" : "Buscar contactos ...",
    "Add to {group}" : "Añadir a {group}",
    "Remove {type}" : "Eliminar {type}",
    "Search {types}" : "Buscar {types}",
    "Search for people to add" : "Buscar personas para añadir",
    "No results" : "No hay resultados",
    "Add to group" : "Añadir a grupo",
    "Add {type}" : "Añadir {type}",
    "New circle name" : "Nombre del nuevo círculo",
    "Personal circle" : "Círculo personal",
    "This circle will only be visible to you. Other members will not be able to see or use it." : "Este círculo solo será visible para ti. Otros miembros no podrán verlo ni usarlo.",
    "Local circle" : "Círculo local",
    "This circle will not be shared with the other instances of the global scale" : "Este círculo no se compartirá con las otras instancias de la escala global",
    "Create circle" : "Crear círculo",
    "Loading members list …" : "Cargando lista de miembros...",
    "The list of members is only visible to members of this circle" : "La lista de miembros solo es visible para los miembros de este círculo",
    "You currently have no access to the member list" : "Actualmente no tienes acceso a la lista de miembros",
    "Add members" : "Añadir miembros",
    "Show circle details" : "Mostrar detalles del círculo",
    "Add to {circle}" : "Añadir a {circle}",
    "Unable to get the recommendations list" : "No se pudo obtener la lista de recomendaciones",
    "Unable to get the results" : "No se pudieron obtener los resultados",
    "Some members could not be added" : "No se pudieron agregar algunos miembros",
    "There was an issue adding members to the circle" : "Ocurrió un problema al agregar miembros al círculo",
    "Accept membership request" : "Aceptar solicitud de membresía",
    "Reject membership request" : "Rechazar solicitud de membresía",
    "Manage level" : "Gestionar nivel",
    "Remove member" : "Eliminar miembro",
    "Pending" : "Pendiente",
    "Promote as sole owner" : "Promover a único propietario",
    "Promote to {level}" : "Promover a {level}",
    "Demote to {level}" : "Degradar a {level}",
    "Could not delete the member {displayName}" : "No se pudo eliminar el miembro {displayName}",
    "Could not change the member level to {level}" : "No se pudo cambiar el nivel del miembro a {level}",
    "Could not accept membership request" : "No se pudo aceptar la solicitud de membresía",
    "Chart" : "Gráfico",
    "Select chart …" : "Seleccionar gráfico...",
    "Select type" : "Seleccionar tipo",
    "Select Date" : "Seleccionar fecha",
    "Add contact in group" : "Añadir contacto en grupo",
    "none" : "ninguno",
    "Select option" : "Seleccionar opción",
    "Add property of this type" : "Añadir propiedad de este tipo",
    "New contact" : "Nuevo contacto",
    "Unable to create the contact." : "No se puede crear el contacto.",
    "Contact not found" : "Contacto no encontrado",
    "Group {group} not found" : "No se encontró el grupo {group}",
    "Close" : "Cerrar",
    "_{success} contact added to {name}_::_{success} contacts added to {name}_" : ["{success} contacto añadido a {name}","{success} contactos añadidos a {name}","{success} contactos añadidos a {name}"],
    "_Adding {success} contact to {name}_::_Adding {success} contacts to {name}_" : ["Añadiendo {success} contacto a {name}","Añadiendo {success} contactos a {name}","Añadiendo {success} contactos a {name}"],
    "_{count} error_::_{count} errors_" : ["{count} error","{count} errores","{count} errores"],
    "_Importing %n contact into {addressbook}_::_Importing %n contacts into {addressbook}_" : ["Importando %n contacto en {addressbook}","Importando %n contactos en {addressbook}","Importando %n contactos en {addressbook}"],
    "_Done importing %n contact into {addressbook}_::_Done importing %n contacts into {addressbook}_" : ["Importación de %n contacto en {addressbook} finalizada","Importación de %n contactos en {addressbook} finalizada","Importación de %n contactos en {addressbook} finalizada"],
    "Import" : "Importar",
    "Could not copy" : "No se pudo copiar",
    "Join circle" : "Unirse al círculo",
    "You are about to leave {circle}.\nAre you sure?" : "Estás a punto de abandonar {circle}.\n      ¿Estás seguro/a?",
    "Please confirm circle leave" : "Por favor, confirma salir del círculo",
    "Could not leave the circle {displayName}" : "No se pudo abandonar el círculo {displayName}",
    "Unable to join the circle" : "No se pudo unir al círculo",
    "You are about to delete {circle}.\nAre you sure?" : "Estás a punto de eliminar {circle}.\n      ¿Estás seguro/a?",
    "Please confirm circle deletion" : "Por favor, confirma la eliminación del círculo",
    "Unable to delete the circle" : "No se pudo eliminar el círculo",
    "Link copied to the clipboard" : "Enlace copiado al portapapeles",
    "Could not copy link to the clipboard." : "No se pudo copiar el enlace al portapapeles.",
    "Not grouped" : "No agrupado",
    "Recently contacted" : "Contactados recientemente",
    "Organization chart" : "Organigrama",
    "Circles are groups of people that you can create yourself and with whom you can share data. They can be made up of other accounts or groups of accounts of the Nextcloud instance, but also of contacts from your address book or even external people by simply entering their e-mail addresses." : "Los círculos son grupos de personas que puedes crear tú mismo/a y con quienes puedes compartir datos. Pueden estar compuestos por otras cuentas o grupos de cuentas de la instancia de Nextcloud, pero también por contactos de tu libreta de direcciones o incluso por personas externas simplemente ingresando sus direcciones de correo electrónico.",
    "Circle" : "Círculo",
    "User" : "Usuario",
    "Group" : "Grupo",
    "Email" : "Correo electrónico",
    "Contact" : "Contacto",
    "Member" : "Miembro",
    "Moderator" : "Moderador",
    "Admin" : "Admin",
    "Owner" : "Dueño",
    "Invites" : "Invitaciones",
    "Anyone can request membership" : "Cualquiera puede solicitar membresía",
    "Members need to accept invitation" : "Los miembros deben aceptar la invitación",
    "Memberships must be confirmed/accepted by a Moderator (requires Open)" : "Las membresías deben ser confirmadas/aceptadas por un Moderador (requiere Apertura)",
    "Members can also invite" : "Los miembros también pueden invitar",
    "Visibility" : "Visibilidad",
    "Visible to everyone" : "Visible para todos",
    "Circle membership" : "Pertenencia al círculo",
    "Prevent circle from being a member of another circle" : "Evitar que el círculo sea miembro de otro círculo",
    "Users" : "Usuarios",
    "Email addresses" : "Direcciones de correo electrónico",
    "Detailed name" : "Nombre detallado",
    "Additional names" : "Nombres adicionales",
    "Prefix" : "Prefijo",
    "Suffix" : "Sufijo",
    "Nickname" : "Apodo",
    "Notes" : "Notas",
    "Website" : "Sitio web",
    "Location" : "Ubicación",
    "Federated Cloud ID" : "Id de nube federada",
    "Home" : "Particular",
    "Work" : "Trabajo",
    "Other" : "Otro",
    "Address" : "Dirección",
    "Post office box" : "Apartado postal",
    "Extended address" : "Dirección extendida",
    "City" : "Ciudad",
    "State or province" : "Estado o provincia",
    "Postal code" : "Código postal",
    "Country" : "País",
    "Birthday" : "Fecha de nacimiento",
    "Anniversary" : "Aniversario",
    "Date of death" : "Fecha de defunción",
    "Instant messaging" : "Mensajería instantánea",
    "Phone" : "Teléfono fijo",
    "Mobile" : "Teléfono móvil",
    "Work mobile" : "Número celular de trabajo",
    "Home mobile" : "Teléfono móvil personal",
    "Fax" : "Fax",
    "Fax home" : "Fax de casa",
    "Fax work" : "Fax de trabajo",
    "Pager" : "Localizador",
    "Voice" : "Voz",
    "Car" : "Auto",
    "Work pager" : "Localizador de trabajo",
    "Manager" : "Gerente",
    "Social network" : "Red social",
    "Relationship to you" : "Relación contigo",
    "Spouse" : "Cónyuge",
    "Child" : "Hijo",
    "Mother" : "Madre",
    "Father" : "Padre",
    "Parent" : "Padre",
    "Brother" : "Hermano",
    "Sister" : "Hermana",
    "Relative" : "Familiar",
    "Friend" : "Amigo",
    "Colleague" : "Colega",
    "Assistant" : "Asistente",
    "Related contacts" : "Contactos relacionados",
    "Agent" : "Agente",
    "Emergency" : "Emergencia",
    "Co-worker" : "Compañero de trabajo",
    "Gender" : "Género",
    "Female" : "Femenino",
    "Male" : "Masculino",
    "None" : "Ninguno",
    "Unknown" : "Desconocido",
    "Time zone" : "Zona horaria",
    "Spoken languages" : "Idiomas hablados",
    "_{failed} contact failed to be read_::_{failed} contacts failed to be read_" : ["{failed} contacto no se pudo leer","{failed} contactos no se pudieron leer","{failed} contactos no se pudieron leer"],
    "An error has occurred in circle(s). Check the console for more details." : "Ha ocurrido un error en el/los círculo(s). Consulta la consola para obtener más detalles.",
    "Unable to create circle {circleName}" : "No se pudo crear el círculo {circleName}",
    "Unable to delete circle {circleId}" : "No se pudo eliminar el círculo {circleId}",
    "Unable to delete contact" : "No se pudo eliminar el contacto"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
