OC.L10N.register(
    "contacts",
    {
    "Details" : "Szczegóły",
    "All contacts" : "Wszystkie kontakty",
    "Contacts" : "Kontakty",
    "A contacts app for Nextcloud" : "Aplikacja Kontakty dla Nextcloud",
    "The Nextcloud contacts app is a user interface for Nextcloud's CardDAV server. Easily sync contacts from various devices with your Nextcloud and edit them online.\n\n* 🚀 **Integration with other Nextcloud apps!** Currently Mail and Calendar – more to come.\n* 🎉 **Never forget a birthday!** You can sync birthdays and other recurring events with your Nextcloud Calendar.\n* 👥 **Sharing of Adressbooks!** You want to share your contacts with your friends or coworkers? No problem!\n* 🙈 **We’re not reinventing the wheel!** Based on the great and open SabreDAV library." : "Aplikacja kontaktów Nextcloud to interfejs użytkownika dla serwera CardDAV Nextcloud. Łatwo synchronizuj kontakty z różnych urządzeń z Nextcloud i edytuj je online.\n\n* 🚀 **Integracja z innymi aplikacjami Nextcloud!** Obecnie Mail i Kalendarz - więcej w przyszłości.\n* 🎉 **Nigdy nie zapomnisz o urodzinach!** Możesz synchronizować urodziny i inne powtarzające się wydarzenia z kalendarzem Nextcloud.\n* 👥 **Udostępnianie książek adresowych!** Chcesz udostępnić swoje kontakty znajomym lub współpracownikom? Nie ma problemu!\n* 🙈 **Nie wynajdujemy koła na nowo!** Na podstawie znakomitej i otwartej biblioteki SabreDAV.",
    "Copy to full name" : "Kopiuj do pełnej nazwy",
    "Omit year" : "Pomiń rok",
    "Allow updating avatars from social media" : "Pozwól aktualizować awatary z mediów społecznościowych",
    "Please select a circle" : "Wybierz krąg",
    "Loading circle …" : "Wczytywanie kręgu…",
    "Your request to join this circle is pending approval" : "Twoja prośba o dołączenie do tego kręgu oczekuje na zatwierdzenie",
    "You are not a member of {circle}" : "Nie jesteś członkiem {circle}",
    "There was an error fetching the member list" : "Podczas pobierania listy członków wystąpił błąd",
    "Loading contacts …" : "Wczytywanie kontaktów…",
    "There are no contacts yet" : "Nie ma jeszcze żadnych kontaktów",
    "Create contact" : "Stworzyć kontakt",
    "There are no contacts in this group" : "W tej grupie nie ma żadnych kontaktów",
    "Create contacts" : "Utwórz kontakty",
    "Add contacts" : "Dodaj kontakty",
    "Loading …" : "Wczytywanie…",
    "Add member" : "Dodaj członka",
    "Leave circle" : "Opuść krąg",
    "Delete circle" : "Usuń krąg",
    "Contacts settings" : "Ustawienia Kontaktów",
    "General settings" : "Ustawienia główne",
    "Update avatars from social media" : "Zaktualizuj awatary z mediów społecznościowych",
    "(refreshed once per week)" : "(odświeżane raz w tygodniu)",
    "Address books" : "Książki adresowe",
    "Export" : "Eksportuj",
    "Send email" : "Wyślij e-mail",
    "Send email as BCC" : "Wyślij e-mail jako UDW",
    "Contact groups" : "Grupy kontaktów",
    "Create a new contact group" : "Utwórz nową grupę kontaktów",
    "Contact group name" : "Nazwa grupy kontaktów",
    "Circles" : "Kręgi",
    "Create a new circle" : "Utwórz nowy krąg",
    "Show all groups" : "Pokaż wszystkie grupy",
    "Collapse groups" : "Zwiń grupy",
    "Show all circles" : "Pokaż wszystkie kręgi",
    "Collapse circles" : "Zwiń kręgi",
    "This group already exists" : "Ta grupa już istnieje",
    "This circle already exists" : "Ten krąg już istnieje",
    "An error happened during the creation of the circle" : "Wystąpił błąd podczas tworzenia kręgu",
    "Download" : "Pobierz",
    "Show" : "Pokaż",
    "Rename" : "Zmień nazwę",
    "Delete" : "Usuń",
    "Copied" : "Skopiowano",
    "Cannot copy" : "Nie można skopiować",
    "Copy link" : "Kopiuj link",
    "Toggling of address book was not successful" : "Przełączanie książki adresowej nie powiodło się",
    "This will delete the address book and every contacts within it" : "Spowoduje to usunięcie książki adresowej i wszystkich kontaktów zawartych w niej",
    "Delete {addressbook}?" : "Usunąć {addressbook}?",
    "Deletion of address book was not successful." : "Usunięcie książki adresowej nie powiodło się.",
    "Renaming of address book was not successful." : "Zmiana nazwy książki adresowej nie powiodła się.",
    "_Shared with {num} entity_::_Shared with {num} entities_" : ["Udostępnione z {num} jednostką","Udostępnione z {num} jednostkami","Udostępnione z {num} jednostkami","Udostępnione z {num} jednostkami"],
    "Share with users or groups" : "Udostępnij użytkownikom lub grupom",
    "No users or groups" : "Brak użytkowników i grup",
    "can edit" : "może edytować",
    "Unable to delete the share" : "Nie można usunąć udostępnienia",
    "Unable to change permissions" : "Nie można zmienić uprawnień",
    "Import contacts" : "Importuj kontakty",
    "Import into the {addressbookName} address book" : "Zaimportuj do książki adresowej {addressbookName}",
    "Select local file" : "Wybierz plik lokalny",
    "Import from files" : "Importuj z plików",
    "Importing is disabled because there are no address books available" : "Importowanie jest wyłączone, ponieważ nie ma dostępnych książek adresowych",
    "Choose a vCard file to import" : "Wybierz plik vCard do zaimportowania",
    "Add new address book" : "Dodaj nową książkę adresową",
    "An error occurred, unable to create the address book" : "Wystąpił błąd, nie można utworzyć książki adresowej",
    "First name" : "Imię",
    "Last name" : "Nazwisko",
    "Phonetic first name" : "Imię fonetycznie",
    "Phonetic last name" : "Nazwisko fonetyczne",
    "Display name" : "Nazwa wyświetlana",
    "Last modified" : "Ostatnio zmodyfikowany",
    "Sort by {sorting}" : "Sortuj według {sorting}",
    "Manages" : "Zarządza",
    "Oversees" : "Nadzoruje",
    "An error happened during the config change" : "Wystąpił błąd podczas zmiany konfiguracji",
    "Password protection" : "Ochrona hasłem",
    "Enforce password protection on files shared to this circle" : "Wymuszaj ochronę hasłem udostępnionych plików w tym kręgu",
    "Use a unique password for all shares to this circle" : "Użyj unikalnego hasła do wszystkich udostępnień w tym kręgu",
    "Unique password …" : "Unikalne hasło…",
    "Save" : "Zapisz",
    "Change unique password" : "Zmień unikalne hasło",
    "Failed to save password. Please try again later." : "Nie udało się zapisać hasła. Spróbuj ponownie później.",
    "Circle name" : "Nazwa kręgu",
    "Circle owned by {owner}" : "Krąg należący do {owner}",
    "Request to join" : "Prośba o dołączenie",
    "Description" : "Opis",
    "There is no description for this circle" : "Brak opisu dla tego kręgu",
    "Enter a description for the circle" : "Podaj opis dla tego kręgu",
    "An error happened during description sync" : "Wystąpił błąd podczas synchronizacji opisu",
    "An error happened during name sync" : "Wystąpił błąd podczas synchronizacji nazw",
    "Add more info" : "Dodaj więcej informacji",
    "More fields" : "Więcej pól",
    "Crop contact photo" : "Przytnij zdjęcie kontaktu",
    "Cancel" : "Anuluj",
    "Upload a new picture" : "Wyślij nowe zdjęcie",
    "Choose from Files" : "Wybierz z Plików",
    "Get from " : "Pobierać z ",
    "Download picture" : "Pobierz zdjęcie",
    "Delete picture" : "Usuń zdjęcie",
    "Please select a valid format" : "Proszę wybrać prawidłowy format",
    "Invalid image" : "Nieprawidłowy obraz",
    "Error cropping picture" : "Błąd podczas przycinania zdjęcia",
    "Pick an avatar" : "Wybierz awatar",
    "Error while processing the picture." : "Błąd podczas przetwarzania obrazu.",
    "Avatar downloaded from social network" : "Awatar pobrany z sieci społecznościowej",
    "Avatar already up to date" : "Awatar już zaktualizowany",
    "Avatar download failed" : "Pobieranie awatara nie powiodło się",
    "No contact selected" : "Nie wybrano kontaktu",
    "Select a contact on the list to begin" : "Wybierz kontakt z listy, aby rozpocząć",
    "Name" : "Nazwa",
    "Title" : "Tytuł",
    "Company" : "Firma",
    "This contact was broken and received a fix. Please review the content and click here to save it." : "Ten kontakt został zerwany i otrzymał poprawkę. Przejrzyj treść i kliknij tutaj, aby ją zapisać.",
    "Edit" : "Edytuj",
    "Clone contact" : "Klonuj kontakt",
    "Generate QR Code" : "Wygeneruj kod QR",
    "Contact vCard as QR code" : "Kontakt vCard jako kod QR",
    "Pick an address book" : "Wybierz z książki adresowej",
    "Select address book" : "Wybierz książkę adresową",
    "This contact is in read-only mode. You do not have permission to edit this contact." : "Ten kontakt jest w trybie \"tylko do odczytu\". Nie masz uprawnień do modyfikowania tego kontaktu.",
    "The contact you were trying to edit has changed. Please manually refresh the contact. Any further edits will be discarded." : "Kontakt który próbujesz zmodyfikować został zmieniony. Odśwież kontakt ręcznie. Wszystkie przyszłe zmiany zostaną odrzucone.",
    "Address book" : "Książka adresowa",
    "Add contact to Birthday Calendar" : "Dodaj kontakt do Kalendarza urodzin",
    "Exclude contact from Birthday Calendar" : "Wyklucz kontakt z Kalendarza urodzin",
    "{title} at {organization}" : "{title} w {organization}",
    "Syntax error. Cannot open the contact." : "Błąd składni. Nie można otworzyć kontaktu.",
    "The contact does not exist on the server anymore." : "Kontakt nie istnieje na serwerze.",
    "Unable to retrieve the contact from the server, please check your network connection." : "Nie można pobrać kontaktu z serwera, sprawdź połączenie sieciowe.",
    "An error occurred while trying to move the contact" : "Wystąpił błąd podczas próby przeniesienia kontaktu",
    "An error occurred while trying to copy the contact" : "Wystąpił błąd podczas próby skopiowania kontaktu",
    "Search contacts …" : "Wyszukiwanie kontaktów…",
    "Add to {group}" : "Dodaj do {group}",
    "Remove {type}" : "Usuń {type}",
    "Search {types}" : "Szukaj {types}",
    "Search for people to add" : "Szukaj osoby do dodania",
    "No results" : "Brak wyników",
    "Add to group" : "Dodaj do grupy",
    "Add {type}" : "Dodaj {type}",
    "New circle name" : "Nowa nazwa kręgu",
    "Personal circle" : "Krąg osobisty",
    "This circle will only be visible to you. Other members will not be able to see or use it." : "Krąg będzie widoczny tylko dla Ciebie. Inni członkowie nie będą mogli go zobaczyć ani z niego korzystać.",
    "Local circle" : "Krąg lokalny",
    "This circle will not be shared with the other instances of the global scale" : "Krąg nie będzie udostępniony dla innych instancji w skali globalnej",
    "Create circle" : "Utwórz krąg",
    "Loading members list …" : "Wczytywanie listy członków…",
    "The list of members is only visible to members of this circle" : "Lista członków jest widoczna tylko dla członków tego kręgu",
    "You currently have no access to the member list" : "Obecnie nie masz dostępu do listy członków",
    "Add members" : "Dodaj członków",
    "Show circle details" : "Pokaż szczegóły kręgu",
    "Add to {circle}" : "Dodaj do {circle}",
    "Unable to get the recommendations list" : "Nie można uzyskać listy rekomendacji",
    "Unable to get the results" : "Nie można uzyskać wyników",
    "Some members could not be added" : "Nie można dodać niektórych członków",
    "There was an issue adding members to the circle" : "Wystąpił problem podczas dodawania członków do kręgu",
    "Accept membership request" : "Zaakceptuj prośbę o członkostwo",
    "Reject membership request" : "Odrzuć prośbę o członkostwo",
    "Manage level" : "Zarządzaj poziomem",
    "Remove member" : "Usuń członka",
    "Pending" : "Oczekuje",
    "Promote as sole owner" : "Promuj jako jedynego właściciela",
    "Promote to {level}" : "Promuj na {level}",
    "Demote to {level}" : "Zdegraduj do {level}",
    "Could not delete the member {displayName}" : "Nie można usunąć członka {displayName}",
    "Could not change the member level to {level}" : "Nie można zmienić poziomu członkostwa na {level}",
    "Could not accept membership request" : "Nie można zaakceptować prośby o członkostwo",
    "Chart" : "Wykres",
    "Select chart …" : "Wybierz wykres…",
    "Select type" : "Wybierz rodzaj",
    "Select Date" : "Wybierz datę",
    "Add contact in group" : "Dodaj kontakt do grupy",
    "Select option" : "Wybierz opcję",
    "Add property of this type" : "Dodaj właściwość do tego typu",
    "New contact" : "Nowy kontakt",
    "Unable to create the contact." : "Nie można utworzyć kontaktu.",
    "Contact not found" : "Nie znaleziono kontaktu",
    "Group {group} not found" : "Nie znaleziono grupy {group}",
    "Close" : "Zamknij ",
    "_{success} contact added to {name}_::_{success} contacts added to {name}_" : ["{success} kontakt dodany do {name}","{success} kontakty dodane do {name}","{success} kontaktów dodanych do {name}","{success} kontaktów dodanych do {name}"],
    "_Adding {success} contact to {name}_::_Adding {success} contacts to {name}_" : ["Dodawanie {success} kontaktu do {name}","Dodawanie {success} kontaktów do {name}","Dodawanie {success} kontaktów do {name}","Dodawanie {success} kontaktów do {name}"],
    "_{count} error_::_{count} errors_" : ["{count} błąd","{count} błędy","{count} błędów","{count} błędów"],
    "_Importing %n contact into {addressbook}_::_Importing %n contacts into {addressbook}_" : ["Importowanie %n kontaktu do {addressbook}","Importowanie %n kontaktów do {addressbook}","Importowanie %n kontaktów do {addressbook}","Importowanie %n kontaktów do {addressbook}"],
    "_Done importing %n contact into {addressbook}_::_Done importing %n contacts into {addressbook}_" : ["Zakończono importowanie %n kontaktu do {addressbook}","Zakończono importowanie %n kontaktów do {addressbook}","Zakończono importowanie %n kontaktów do {addressbook}","Zakończono importowanie %n kontaktów do {addressbook}"],
    "Import" : "Importuj",
    "Could not copy" : "Nie można skopiować",
    "Join circle" : "Dołącz do kręgu",
    "You are about to leave {circle}.\nAre you sure?" : "Zamierzasz opuścić {circle}.\nJesteś pewny?",
    "Please confirm circle leave" : "Potwierdź opuszczenie kręgu",
    "Could not leave the circle {displayName}" : "Nie można opuścić kręgu {displayName}",
    "Unable to join the circle" : "Nie możesz dołączyć do kręgu",
    "You are about to delete {circle}.\nAre you sure?" : "Zamierzasz usunąć {circle}.\nJesteś pewny?",
    "Please confirm circle deletion" : "Potwierdź usunięcie kręgu",
    "Unable to delete the circle" : "Nie można usunąć kręgu",
    "Link copied to the clipboard" : "Link skopiowany do schowka",
    "Could not copy link to the clipboard." : "Nie można skopiować linku do schowka.",
    "Not grouped" : "Nie pogrupowane",
    "Recently contacted" : "Ostatnio skontaktowano się",
    "Organization chart" : "Schemat organizacyjny",
    "Circle" : "Krąg",
    "User" : "Użytkownik",
    "Group" : "Grupa",
    "Email" : "E-mail",
    "Contact" : "Kontakt",
    "Member" : "Członek",
    "Moderator" : "Moderator",
    "Admin" : "Administrator",
    "Owner" : "Właściciel",
    "Invites" : "Zaprasza",
    "Anyone can request membership" : "Każdy może poprosić o członkostwo",
    "Members need to accept invitation" : "Członkowie muszą zaakceptować zaproszenie",
    "Memberships must be confirmed/accepted by a Moderator (requires Open)" : "Członkostwo musi być potwierdzone/zaakceptowane przez moderatora (wymaga otwarcia)",
    "Members can also invite" : "Członkowie mogą również zapraszać",
    "Visibility" : "Widoczność",
    "Visible to everyone" : "Widoczne dla wszystkich",
    "Circle membership" : "Członkostwo w kręgu",
    "Prevent circle from being a member of another circle" : "Uniemożliwienie kręgowi przynależności członka do innego kręgu",
    "Users" : "Użytkownicy",
    "Email addresses" : "Adresy e-mail",
    "Detailed name" : "Szczegółowa nazwa",
    "Additional names" : "Dodatkowe nazwy",
    "Prefix" : "Przedrostek",
    "Suffix" : "Przyrostek",
    "Nickname" : "Pseudonim",
    "Notes" : "Notatki",
    "Website" : "Strona internetowa",
    "Location" : "Lokalizacja",
    "Federated Cloud ID" : "ID Chmury Federacyjnej",
    "Home" : "Dom",
    "Work" : "Praca",
    "Other" : "Inne",
    "Address" : "Adres",
    "Post office box" : "Skrytka pocztowa",
    "Extended address" : "Rozszerzony adres",
    "City" : "Miasto",
    "State or province" : "Województwo ",
    "Postal code" : "Kod pocztowy",
    "Country" : "Kraj",
    "Birthday" : "Urodziny",
    "Anniversary" : "Rocznica",
    "Date of death" : "Data śmierci",
    "Instant messaging" : "Wiadomości natychmiastowe",
    "Phone" : "Telefon",
    "Mobile" : "Komórka",
    "Work mobile" : "Telefon służbowy",
    "Home mobile" : "Telefon domowy",
    "Fax" : "Faks",
    "Fax home" : "Faks domowy",
    "Fax work" : "Faks służbowy",
    "Pager" : "Pager",
    "Voice" : "Połączenie głosowe",
    "Car" : "Samochód",
    "Work pager" : "Pager służbowy",
    "Manager" : "Menadżer",
    "Social network" : "Sieć społecznościowa",
    "Relationship to you" : "Powiązane z Tobą",
    "Spouse" : "Współmałżonek",
    "Child" : "Dziecko",
    "Mother" : "Matka",
    "Father" : "Ojciec",
    "Parent" : "Rodzic",
    "Brother" : "Brat",
    "Sister" : "Siostra",
    "Relative" : "Krewny",
    "Friend" : "Przyjaciel",
    "Colleague" : "Kolega/Koleżanka",
    "Assistant" : "Asystent",
    "Related contacts" : "Powiązane kontakty",
    "Agent" : "Agent",
    "Emergency" : "Nagła pomoc",
    "Co-worker" : "Współpracownik",
    "Gender" : "Płeć",
    "Female" : "Kobieta",
    "Male" : "Mężczyzna",
    "None" : "Brak",
    "Unknown" : "Nieznany",
    "Time zone" : "Strefa czasowa",
    "Spoken languages" : "Języki mówione",
    "_{failed} contact failed to be read_::_{failed} contacts failed to be read_" : ["Nie udało się odczytać {failed} kontaktu","Nie udało się odczytać {failed} kontaktów","Nie udało się odczytać {failed} kontaktów","Nie udało się odczytać {failed} kontaktów"],
    "An error has occurred in circle(s). Check the console for more details." : "Wystąpił błąd w kręgach. Sprawdź konsolę po więcej informacji.",
    "Unable to create circle {circleName}" : "Nie można utworzyć kręgu {circleName}",
    "Unable to delete circle {circleId}" : "Nie można usunąć kręgu {circleId}",
    "Unable to delete contact" : "Nie można usunąć kontaktu"
},
"nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");
