OC.L10N.register(
    "contacts",
    {
    "Details" : "Üksikasjad",
    "All contacts" : "Kõik kontaktid",
    "Contacts" : "Kontaktid",
    "Loading contacts …" : "Laen kontakte ...",
    "Send email" : "Saada kiri",
    "Download" : "Lae alla",
    "Rename" : "Nimeta ümber",
    "Delete" : "Kustuta",
    "Copy link" : "Kopeeri link",
    "_%n contact_::_%n contacts_" : ["%n kontakt","%nkontakti"],
    "_%n group_::_%n groups_" : ["%n grupp","%n gruppi"],
    "Share with users or groups" : "Jaga kasutajate või gruppidega",
    "No users or groups" : "Ei ole kasutajaid või gruppe",
    "can edit" : "saab redigeerida",
    "First name" : "Eesnimi",
    "Last name" : "Perekonnanimi",
    "Display name" : "Kuvatav nimi",
    "Last modified" : "Viimati muudetud",
    "Password protection" : "Password protection",
    "Save" : "Salvesta",
    "Description" : "Kirjeldus",
    "Cancel" : "Loobu",
    "Delete picture" : "Kustuta pilt",
    "Invalid image" : "Vigane pilt",
    "Name" : "Nimi",
    "Title" : "Pealkiri",
    "Address book" : "Aadressiraamat",
    "Search contacts …" : "Otsi kontakte",
    "No results" : "Vasteid ei leitud",
    "Personal circle" : "Isiklik ring",
    "Pending" : "Ootel",
    "New contact" : "Uus kontakt",
    "Close" : "Sulge",
    "Import" : "Impordi",
    "Not grouped" : "Pole grupeeritud",
    "Circle" : "Ring",
    "User" : "Kasutaja",
    "Group" : "Grupp",
    "Email" : "E-post",
    "Contact" : "Kontakt",
    "Member" : "Liige",
    "Moderator" : "Moderaator",
    "Admin" : "Admin",
    "Owner" : "Omanik",
    "Users" : "Kasutajad",
    "Detailed name" : "Üksikasjalik nimi",
    "Additional names" : "Lisanimed",
    "Prefix" : "Eesliide",
    "Suffix" : "Järelliide",
    "Nickname" : "Hüüdnimi",
    "Notes" : "Märkmed",
    "Website" : "Veebileht",
    "Location" : "Asukoht",
    "Federated Cloud ID" : "Liitpilve ID",
    "Home" : "Kodu",
    "Work" : "Töö",
    "Other" : "Muu",
    "Address" : "Aadress",
    "Post office box" : "Postkast",
    "City" : "Linn",
    "State or province" : "Maakond",
    "Postal code" : "Postiindeks",
    "Country" : "Riik",
    "Birthday" : "Sünnipäev",
    "Anniversary" : "Aastapäev",
    "Date of death" : "Surma kuupäev",
    "Instant messaging" : "Kiirsõnumid",
    "Phone" : "Telefon",
    "Mobile" : "Mobiil",
    "Work mobile" : "Töötelefon (mobiil)",
    "Fax" : "Faks",
    "Fax home" : "Faks kodus",
    "Fax work" : "Faks tööl",
    "Pager" : "Piipar",
    "Voice" : "Hääl",
    "Car" : "Auto",
    "Work pager" : "Piipar (tööl)",
    "Manager" : "Juht",
    "Social network" : "Sotsiaalvõrk",
    "Spouse" : "Abikaasa",
    "Child" : "Laps",
    "Mother" : "Ema",
    "Father" : "Isa",
    "Parent" : "Vanem",
    "Brother" : "Vend",
    "Sister" : "Õde",
    "Relative" : "Sugulane",
    "Friend" : "Sõber",
    "Colleague" : "Kolleeg",
    "Assistant" : "Assistent",
    "Gender" : "Sugu",
    "Female" : "Naine",
    "Male" : "Mees",
    "None" : "Pole",
    "Unknown" : "Teadmata"
},
"nplurals=2; plural=(n != 1);");
