OC.L10N.register(
    "contacts",
    {
    "Download" : "ڈاؤن لوڈ",
    "Rename" : "Rename",
    "Delete" : "حذف کریں",
    "can edit" : "تبدیل کر سکے ھیں",
    "Password protection" : "Password protection",
    "Save" : "حفظ",
    "Description" : "تصریح",
    "Cancel" : "منسوخ کریں",
    "Invalid image" : "غلط تصویر",
    "Name" : "اسم",
    "Title" : "عنوان",
    "Close" : "بند ",
    "User" : "User",
    "Group" : "Group",
    "Email" : "email",
    "Admin" : "ایڈمن",
    "Owner" : "Owner",
    "Users" : "صارفین",
    "Notes" : "Notes",
    "Location" : "مقام",
    "Work" : "کام",
    "Other" : "دیگر",
    "Birthday" : "سالگرہ"
},
"nplurals=2; plural=(n != 1);");
