OC.L10N.register(
    "contacts",
    {
    "Details" : "Подробно",
    "All contacts" : "Все контакты",
    "Contacts" : "Контакты",
    "A contacts app for Nextcloud" : "Контакты для Nextcloud",
    "The Nextcloud contacts app is a user interface for Nextcloud's CardDAV server. Easily sync contacts from various devices with your Nextcloud and edit them online.\n\n* 🚀 **Integration with other Nextcloud apps!** Currently Mail and Calendar – more to come.\n* 🎉 **Never forget a birthday!** You can sync birthdays and other recurring events with your Nextcloud Calendar.\n* 👥 **Sharing of Adressbooks!** You want to share your contacts with your friends or coworkers? No problem!\n* 🙈 **We’re not reinventing the wheel!** Based on the great and open SabreDAV library." : "Приложение контакты для Nextcloud предоставляет интерфейс для сервера CardDAV, являющегося частью Nextcloud. Приложение позволяет просто настроить синхронизацию  контактов на различных устройствах с помощью Nextcloud, а также редактировать контакты, используя браузер.\n * 🚀 ** Интеграция с другими приложениями Nextcloud** Сейчас — почта и календарь, в будущем ещё больше.\n * 🎉 ** Не забывайте про дни рождения** Синхронизация дней рождения и других повторяющихся событий с календарем Nextcloud.\n * 👥 **Совместное использование адресных книг** Поделиться своими контактами с друзьями или коллегами? Нет проблем!\n* 🙈 **Мы не изобретаем колесо** Приложение основано на отличной открытой библиотеке SabreDAV.",
    "Copy to full name" : "Скопировать в полное имя",
    "Omit year" : "Пропустить год",
    "Allow updating avatars from social media" : "Разрешить обновление аватарок из соцсетей",
    "Please select a circle" : "Выберите круг",
    "Loading circle …" : "Круг загружается…",
    "Your request to join this circle is pending approval" : "Вас запрос на присоединение к этому кругу ожидает одобрения",
    "You are not a member of {circle}" : "Вы не являетесь участником круга {circle}",
    "There was an error fetching the member list" : "Не удалось получить список участников",
    "Loading contacts …" : "Загрузка контактов…",
    "There are no contacts yet" : "Нет ни одного контакта",
    "Create contact" : "Создать контакт",
    "There are no contacts in this group" : "В этой группе нет ни одного контакта",
    "Create contacts" : "Создать контакты",
    "Add contacts" : "Добавить контакты",
    "Loading …" : "Загрузка…",
    "Add member" : "Добавить участника",
    "Leave circle" : "Покинуть круг",
    "Delete circle" : "Удалить круг",
    "Contacts settings" : "Параметры контактов",
    "General settings" : "Общие параметры",
    "Update avatars from social media" : "Обновлять изображения из соц. сетей",
    "(refreshed once per week)" : "(еженедельное обновление)",
    "Address books" : "Адресные книги",
    "Export" : "Экспорт",
    "Send email" : "Отправить письмо",
    "Send email as BCC" : "Отправить электронное письмо как BCC",
    "Contact groups" : "Группы контакта",
    "Create a new contact group" : "Создать новую группу контактов",
    "Contact group name" : "Название группы",
    "Circles" : "Круги",
    "Create a new circle" : "Создать круг",
    "Show all groups" : "Показать все группы",
    "Collapse groups" : "Свернуть группы",
    "Show all circles" : "Показать все круги",
    "Collapse circles" : "Свернуть круги",
    "This group already exists" : "Такая группа уже существует",
    "This circle already exists" : "Такой круг уже существует",
    "An error happened during the creation of the circle" : "При создании круга произошла ошибка",
    "{addressbookname} (Disabled)" : "{addressbookname} (Отключено)",
    "Download" : "Скачать",
    "Show" : "Показать",
    "Rename" : "Переименовать",
    "Delete" : "Удалить",
    "Copied" : "Скопировано",
    "Cannot copy" : "Не удалось скопировать",
    "Copy link" : "Копировать ссылку",
    "Toggling of address book was not successful" : "Переключение адресной книги не удалось",
    "This will delete the address book and every contacts within it" : "Это удалит адресную книгу и все контакты в ней",
    "Delete {addressbook}?" : "Удалить {addressbook}?",
    "Deletion of address book was not successful." : "Удаление адресной книги не удалось.",
    "Renaming of address book was not successful." : "Переименование адресной книги не удалось.",
    "_%n contact_::_%n contacts_" : ["%n контакт","%n контакта","%n контактов","%n контактов"],
    "_%n group_::_%n groups_" : ["%n группа","%n группы","%n групп","%n групп"],
    "_Shared with {num} entity_::_Shared with {num} entities_" : ["Общее для одной записи","Общее для {num} записей","Общее для {num} записей","Общее для {num} записей"],
    "Share with users or groups" : "Поделиться с пользователями или группами",
    "Share with users" : "Поделиться с пользователями",
    "No users or groups" : "Пользователи или группы отсутствуют",
    "can edit" : "разрешить редактировать",
    "Unable to delete the share" : "Невозможно закрыть общий доступ",
    "Unable to change permissions" : "Невозможно изменить права доступа",
    "Import contacts" : "Импорт контактов",
    "Import into the {addressbookName} address book" : "Импортировать в адресную книгу «{addressbookName}»",
    "Select local file" : "Загрузить с ПК",
    "Import from files" : "Выбрать в Nextcloud",
    "Importing is disabled because there are no address books available" : "Возможность импорта отключена, т.к. отсутствуют адресные книги, в которые можно выполнить запись",
    "Choose a vCard file to import" : "Выберите файл в формате vCard для импорта",
    "Add new address book" : "Создать адресную книгу",
    "An error occurred, unable to create the address book" : "Произошла ошибка, невозможно создать адресную книгу",
    "First name" : "Имя",
    "Last name" : "Фамилия",
    "Phonetic first name" : "Имя (фонетическое написание)",
    "Phonetic last name" : "Фамилия (фонетическое написание)",
    "Display name" : "Отображаемое имя",
    "Last modified" : "Последнее изменение",
    "Sort by {sorting}" : "Поле сортировки: {sorting}",
    "Manages" : "Управляет",
    "Oversees" : "Наблюдает",
    "An error happened during the config change" : "Не удалось изменить конфигурацию",
    "Password protection" : "Защита паролем",
    "Enforce password protection on files shared to this circle" : "Обеспечьте защиту файлов, переданных в этот круг, паролем",
    "Use a unique password for all shares to this circle" : "Используйте уникальный пароль для всех общих ресурсов этого круга",
    "Unique password …" : "Уникальный пароль ...",
    "Save" : "Сохранить",
    "Change unique password" : "Изменение уникального пароля",
    "Failed to save password. Please try again later." : "Не удалось сохранить пароль. Пожалуйста, повторите попытку позже.",
    "Circle name" : "Название круга",
    "Circle owned by {owner}" : "Владелец круга: {owner}",
    "Request to join" : "Присоединиться",
    "Description" : "Описание",
    "There is no description for this circle" : "Для этого круга описание отсуствует",
    "Enter a description for the circle" : "Введите описание этого круга",
    "An error happened during description sync" : "Не удалось синхронизировать описание круга",
    "An error happened during name sync" : "Не удалось синхронизировать название круга",
    "Add more info" : "Добавить больше информации",
    "More fields" : "Дополнительные поля",
    "Crop contact photo" : "Обрезать фотографию контакта",
    "Cancel" : "Отмена",
    "Upload a new picture" : "Загрузить новое изображение",
    "Choose from Files" : "Выбрать в приложении Файлы",
    "Get from " : "Получить из",
    "Download picture" : "Скачать изображение",
    "Delete picture" : "Удалить изображение",
    "Please select a valid format" : "Пожалуйста, выберите верный формат",
    "Invalid image" : "Изображение повреждено",
    "Error cropping picture" : "Ошибка обрезки изображения",
    "Pick an avatar" : "Выбрать аватар",
    "Error while processing the picture." : "Ошибка при обработке изображения.",
    "Avatar downloaded from social network" : "Аватар загружен из соцсетей",
    "Avatar already up to date" : "Аватар уже обновлен",
    "Avatar download failed" : "Загрузка аватара не удалась",
    "No contact selected" : "Не выбрано ни одного контакта",
    "Select a contact on the list to begin" : "Выберете контакт в списке чтобы начать",
    "Name" : "Имя",
    "Title" : "Должность",
    "Company" : "Компания",
    "This contact was broken and received a fix. Please review the content and click here to save it." : "Поля записи контакта содержали некорректные данные, которые были исправлены. Проверьте данные и нажмите для сохранения.",
    "Edit" : "Править",
    "Clone contact" : "Копировать контакт",
    "Generate QR Code" : "Создать QR-код",
    "Contact vCard as QR code" : "Визитная карточка в виде QR-кода",
    "Pick an address book" : "Выберите адресную книгу",
    "Select address book" : "Выберите адресную книгу",
    "Go to talk conversation" : "Перейти в обсуждение",
    "View profile" : "Показать профиль",
    "This contact is in read-only mode. You do not have permission to edit this contact." : "Контакт открыт в режиме «только чтение», для изменения недостаточно прав.",
    "The contact you were trying to edit has changed. Please manually refresh the contact. Any further edits will be discarded." : "Контакт, который вы пытаетесь редактировать, был изменен. Выполните обновление контакта вручную. Все внесённые изменения не будут сохранены.",
    "Address book" : "Адресная книга",
    "Add contact to Birthday Calendar" : "Добавить контакт в календарь Дней Рождений",
    "Exclude contact from Birthday Calendar" : "Исключить контакт из календаря Дней Рождений",
    "{title} at {organization}" : "{title} в {organization}",
    "Syntax error. Cannot open the contact." : "Ошибка разбора синтаксиса, невозможно открыть контакт.",
    "The contact does not exist on the server anymore." : "Этого контакта больше нет на сервере.",
    "Unable to retrieve the contact from the server, please check your network connection." : "Невозможно получить контакт с сервера, пожалуйста, проверьте ваше подключение к сети.",
    "An error occurred while trying to move the contact" : "Произошла ошибка при попытке переместить контакт",
    "An error occurred while trying to copy the contact" : "Произошла ошибка при попытке скопировать контакт",
    "Unable to update contact" : "Невозможно обновить контакт",
    "Search contacts …" : "Поиск контакта…",
    "Add to {group}" : "Добавить в {group}",
    "Remove {type}" : "Удалить {type}",
    "Search {types}" : "Поиск {types}",
    "Search for people to add" : "Поиск людей для добавления",
    "No results" : "Результаты отсутствуют",
    "Add to group" : "Добавить в группу",
    "Add {type}" : "Добавить {type}",
    "New circle name" : "Название нового круга",
    "Personal circle" : "Личный круг",
    "This circle will only be visible to you. Other members will not be able to see or use it." : "Личный круг доступен только вам, остальные участники не смогут найти или присоединиться к нему.",
    "Local circle" : "Локальный круг",
    "This circle will not be shared with the other instances of the global scale" : "Локальный круг не будет доступен с других серверов",
    "Create circle" : "Создать круг",
    "Loading members list …" : "Загрузка списка участников…",
    "The list of members is only visible to members of this circle" : "Просмотр списка участников этого круга ограничен его участниками",
    "You currently have no access to the member list" : "В настоящее время у вас нет доступа к списку участников",
    "Add members" : "Добавить участников",
    "Show circle details" : "Подробные сведения о круге",
    "Add to {circle}" : "Добавить в круг {circle}",
    "Unable to get the recommendations list" : "Не удалось получить список рекомендаций",
    "Unable to get the results" : "Не удалось получить результаты запроса",
    "Some members could not be added" : "Не удалось добавить некоторых участников",
    "There was an issue adding members to the circle" : "Ошибка добавления участника в круг",
    "Accept membership request" : "Принять запрос на присоединение к кругу",
    "Reject membership request" : "Отклонить запрос на присоединение к кругу",
    "Manage level" : "Управлять уровнем",
    "Remove member" : "Удалить участника",
    "Pending" : "В очереди",
    "Promote as sole owner" : "Повысить до единственного владельца",
    "Promote to {level}" : "Повысить до уровня «{level}»",
    "Demote to {level}" : "Понизить до уровня «{level}»",
    "Could not delete the member {displayName}" : "Не удалось удалить участника {displayName}",
    "Could not change the member level to {level}" : "Не удалось изменить уровень участника на «{level}»",
    "Could not accept membership request" : "Не удалось принять запрос на участие",
    "Chart" : "График",
    "Select chart …" : "Выберите структуру…",
    "Select type" : "Выбор типа",
    "Select Date" : "Выберите дату",
    "Add contact in group" : "Добавить контакт в группу",
    "none" : "отсутствует",
    "Select option" : "Выберете вариант",
    "Add property of this type" : "Добавить свойство этого типа",
    "New contact" : "Создать контакт",
    "Unable to create the contact." : "Невозможно создать контакт.",
    "Contact not found" : "Контакт не найден",
    "Group {group} not found" : "Группа «{group}» не найдена",
    "Close" : "Закрыть",
    "_{success} contact added to {name}_::_{success} contacts added to {name}_" : ["{success} контакт добавлен в «{name}»","{success} контакта добавлено в «{name}»","{success} контактов добавлено в «{name}»","{success} контакта добавлено в «{name}»"],
    "_Adding {success} contact to {name}_::_Adding {success} contacts to {name}_" : ["Добавление {success} контакта в «{name}»","Добавление {success} контактов в «{name}»","Добавление {success} контактов в «{name}»","Добавление {success} контактов в «{name}»"],
    "_{count} error_::_{count} errors_" : ["{count} ошибка","{count} ошибки","{count} ошибок","{count} ошибки"],
    "_Importing %n contact into {addressbook}_::_Importing %n contacts into {addressbook}_" : ["Импорт %n контакта в {addressbook}","Импорт %n контактов в {addressbook}","Импорт %n контактов в {addressbook}","Импорт %n контактов в {addressbook}"],
    "_Done importing %n contact into {addressbook}_::_Done importing %n contacts into {addressbook}_" : ["В {addressbook} импортирован %n контакт","В {addressbook} импортировано %n контакта","В {addressbook} импортировано %n контактов","В {addressbook} импортировано %n контакта"],
    "Import" : "Импортировать",
    "Could not copy" : "Не удалось скопировать",
    "Join circle" : "Присоединиться к этому кругу",
    "You are about to leave {circle}.\nAre you sure?" : "Подтвердите выход из круга «{circle}»",
    "Please confirm circle leave" : "Подтвердите выход из круга",
    "Could not leave the circle {displayName}" : "Участнику {displayName} не удалось покинуть круг",
    "Unable to join the circle" : "Не удалось присоединиться к кругу",
    "You are about to delete {circle}.\nAre you sure?" : "Подтвердите удаление круга «{circle}»",
    "Please confirm circle deletion" : "Подтвердите удаление круга",
    "Unable to delete the circle" : "Не удалось удалить круг",
    "Link copied to the clipboard" : "Ссылка скопирована в буфер обмена",
    "Could not copy link to the clipboard." : "Не удалось скопировать ссылку в буфер обмена",
    "Not grouped" : "Без группы",
    "Recently contacted" : "Недавние контакты",
    "Organization chart" : "Организационная структура",
    "Circles are groups of people that you can create yourself and with whom you can share data. They can be made up of other accounts or groups of accounts of the Nextcloud instance, but also of contacts from your address book or even external people by simply entering their e-mail addresses." : "Круги - это группы людей, созданные вами и с которыми вы можете делиться данными. Они могут состоять как из дргих учётных записей или групп из сервера Nextcloud, так и из контактов из вашей адресной книги или даже внешних людей, добавленных просто вводом их адреса электронной почты.",
    "Circle" : "Круг",
    "User" : "Пользователь",
    "Group" : "Группа",
    "Email" : "Эл. почта",
    "Contact" : "Контакт",
    "Member" : "Участник",
    "Moderator" : "Модератор",
    "Admin" : "Администратор",
    "Owner" : "Владелец",
    "Invites" : "Приглашения",
    "Anyone can request membership" : "Участие в круге доступно для всех",
    "Members need to accept invitation" : "Необходимо принятие приглашений пользователями",
    "Memberships must be confirmed/accepted by a Moderator (requires Open)" : "Участие должно быть одобрено модератором (требуется открытый тип круга)",
    "Members can also invite" : "Разрешить приглашать участникам",
    "Visibility" : "Видимость",
    "Visible to everyone" : "Видим для всех",
    "Circle membership" : "Включение к другие круги",
    "Prevent circle from being a member of another circle" : "Запретить добавление круга в другие круги",
    "Users" : "Пользователи",
    "Email addresses" : "Адреса электронной почты",
    "Detailed name" : "Подробное имя",
    "Additional names" : "Отчество",
    "Prefix" : "Префикс",
    "Suffix" : "Суффикс",
    "Nickname" : "Псевдоним",
    "Notes" : "Заметки",
    "Website" : "Сайт",
    "Location" : "Местоположение",
    "Federated Cloud ID" : "ID в объединении облачных хранилищ",
    "Home" : "Домашний",
    "Work" : "Рабочий",
    "Other" : "Другой",
    "Address" : "Адрес",
    "Post office box" : "Абонентский ящик",
    "Extended address" : "Расширенный адрес",
    "City" : "Город",
    "State or province" : "Область или район",
    "Postal code" : "Почтовый индекс",
    "Country" : "Страна",
    "Birthday" : "День рождения",
    "Anniversary" : "Годовщина",
    "Date of death" : "Дата смерти",
    "Instant messaging" : "Мгновенные сообщения",
    "Phone" : "Телефон",
    "Mobile" : "Мобильный",
    "Work mobile" : "Рабочий мобильный",
    "Home mobile" : "Домашний мобильный",
    "Fax" : "Факс",
    "Fax home" : "Факс домашний",
    "Fax work" : "Факс рабочий",
    "Pager" : "Пейджер",
    "Voice" : "Голосовая почта",
    "Car" : "Номер в авто",
    "Work pager" : "Рабочий пейджер",
    "Manager" : "Руководитель",
    "Social network" : "Социальная сеть",
    "Relationship to you" : "Отношение к вам",
    "Spouse" : "Супруг",
    "Child" : "Ребёнок",
    "Mother" : "Мать",
    "Father" : "Отец",
    "Parent" : "Родитель",
    "Brother" : "Брат",
    "Sister" : "Сестра",
    "Relative" : "Родственник",
    "Friend" : "Друг",
    "Colleague" : "Коллега",
    "Assistant" : "Помощник",
    "Related contacts" : "Связанные контакты",
    "Agent" : "Агент",
    "Emergency" : "Экстренный случай",
    "Co-worker" : "Коллега",
    "Gender" : "Пол",
    "Female" : "Женщина",
    "Male" : "Мужчина",
    "None" : "Никто",
    "Unknown" : "Неизвестно",
    "Time zone" : "Часовой пояс",
    "Spoken languages" : "Разговорные языки",
    "_{failed} contact failed to be read_::_{failed} contacts failed to be read_" : ["{failed} контакт не удалось прочесть","{failed} контакта не удалось прочесть","{failed} контактов не удалось прочесть","{failed} контактов не удалось прочесть"],
    "An error has occurred in circle(s). Check the console for more details." : "Произошла ошибка в круге (кругах). Проверьте консоль для получения более подробной информации.",
    "Unable to create circle {circleName}" : "Не удалось создать круг «{circleName}»",
    "Unable to delete circle {circleId}" : "Не удалось удалить круг «{circleName}»",
    "Unable to delete contact" : "Невозможно удалить контакт"
},
"nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
