OC.L10N.register(
    "contacts",
    {
    "Details" : "Nánar",
    "All contacts" : "Allir tengiliðir",
    "Contacts" : "Tengiliðir",
    "A contacts app for Nextcloud" : "Tengiliðaforrit fyrir Nextcloud",
    "The Nextcloud contacts app is a user interface for Nextcloud's CardDAV server. Easily sync contacts from various devices with your Nextcloud and edit them online.\n\n* 🚀 **Integration with other Nextcloud apps!** Currently Mail and Calendar – more to come.\n* 🎉 **Never forget a birthday!** You can sync birthdays and other recurring events with your Nextcloud Calendar.\n* 👥 **Sharing of Adressbooks!** You want to share your contacts with your friends or coworkers? No problem!\n* 🙈 **We’re not reinventing the wheel!** Based on the great and open SabreDAV library." : "Tengiliðaforritið (Contacts) er notandaviðmót fyrir CardDAV-þjón Nextcloud. Samstilltu á einfaldan máta tengilði af ýmsum tækjum við Nextcloud tölvuskýið og breyttu þeim á netinu.\n\n* 🚀 **Samþætting við önnur Nextcloud forrit!** Nú er það þegar hægt við Tölvupóst (Mail) og Dagatal (Calendar) - fleira er í bígerð.\n* 🎉 **Ekki gleyma framar afmælisdögum!** Þú getur samstillt afmælisdaga og aðra endurtekna atburði við Nextcloud dagatalið þitt.\n* 👥 **Deildu nafnaskránum þínum!** Viltu deila tengiliðum með vinum þínum eða samstarfsmönnum? Ekki vandamál!\n* 🙈 **Við erum ekki að finna upp hjólið!** Byggist á hinu frábæra SabreDAV aðgerðasafni.",
    "Copy to full name" : "Afrita í fullt nafn",
    "Omit year" : "Sleppa ártali",
    "Allow updating avatars from social media" : "Leyfa uppfærslu auðkennismynda af samfélagsnetum",
    "Loading contacts …" : "Hleð inn tengiliðum …",
    "Loading …" : "Hleð inn …",
    "Delete circle" : "Eyða hring",
    "General settings" : "Almennar stillingar",
    "Send email" : "Senda tölvupóst",
    "Circles" : "Hringir",
    "Create a new circle" : "Búa til nýjan hring",
    "Download" : "Niðurhal",
    "Rename" : "Endurnefna",
    "Delete" : "Eyða",
    "Copied" : "Afritað",
    "Copy link" : "Afrita tengil",
    "Toggling of address book was not successful" : "Tókst ekki að víxla nafnaskrá af/á",
    "This will delete the address book and every contacts within it" : "Þetta mun eyða nafnaskránni og öllum tengiliðum í henni",
    "Deletion of address book was not successful." : "Tókst ekki að eyða nafnaskrá.",
    "Renaming of address book was not successful." : "Tókst ekki að endurnefna nafnaskrá.",
    "_Shared with {num} entity_::_Shared with {num} entities_" : ["Deilt með {num} einindi","Deilt með {num} einindum"],
    "Share with users or groups" : "Deila með notendum eða hópum",
    "No users or groups" : "Engir notendur eða hópar",
    "can edit" : "getur breytt",
    "Import contacts" : "Flytja inn tengiliði",
    "Select local file" : "Veldu skrá á tölvunni",
    "Import from files" : "Flytja inn úr skrám",
    "Importing is disabled because there are no address books available" : "Innflutningur er óvirkur því engar nafnaskrár eru tiltækar",
    "Choose a vCard file to import" : "Veldu vCard-skrá sem á að flytja inn",
    "First name" : "Eiginnafn",
    "Last name" : "Kenninafn",
    "Display name" : "Birtingarnafn",
    "Last modified" : "Síðast breytt",
    "Sort by {sorting}" : "Raða eftir {sorting}",
    "Password protection" : "Verndun með lykilorði",
    "Save" : "Vista",
    "Description" : "Lýsing",
    "Cancel" : "Hætta við",
    "Upload a new picture" : "Senda inn nýja mynd",
    "Get from " : "Sækja frá ",
    "Download picture" : "Sækja mynd",
    "Delete picture" : "Eyða mynd",
    "Invalid image" : "Ógild mynd",
    "Pick an avatar" : "Veldu auðkennismynd",
    "Error while processing the picture." : "Villa kom upp við vinnslu myndar.",
    "Avatar downloaded from social network" : "Aðkennismynd hlaðið inn af samfélagsneti",
    "Avatar already up to date" : "Auðkennismynd er af nýjustu útgáfu",
    "Avatar download failed" : "Niðurhal auðkennismyndar tókst ekki",
    "No contact selected" : "Enginn tengiliður valinn",
    "Select a contact on the list to begin" : "Veldu fyrst tengilið á listanum",
    "Name" : "Nafn",
    "Title" : "Starfsheiti",
    "Company" : "Fyrirtæki",
    "This contact was broken and received a fix. Please review the content and click here to save it." : "Þessi tengiliður var gallaður og var hann lagfærður. Yfirfarðu upplýsingarnar og smelltu síðan hér til að vista tengiliðinn.",
    "Clone contact" : "Klóna tengilið",
    "Generate QR Code" : "Útbúa QR-kóða",
    "Pick an address book" : "Veldu nafnaskrá",
    "Select address book" : "Veldu nafnaskrá",
    "This contact is in read-only mode. You do not have permission to edit this contact." : "Þessi tengiliður er skrifvarinn. Þú hefur ekki heimild til að breyta þessum tengilið.",
    "The contact you were trying to edit has changed. Please manually refresh the contact. Any further edits will be discarded." : "Tengiliðurinn sem þú ert að reyna að breyta hefur breyst. Endurlestu hann handvirkt. Öllum frekari breytingum verður hent.",
    "Address book" : "Nafnaskrá",
    "Syntax error. Cannot open the contact." : "Villa í málskipan. Get ekki opnað tengiliðinn.",
    "Unable to retrieve the contact from the server, please check your network connection." : "Ekki er hægt að sækja tengiliðinn frá netþjóninum, athugaðu nettenginguna þína.",
    "An error occurred while trying to move the contact" : "Villa kom upp þegar reynt var að færa tengiliðinn",
    "An error occurred while trying to copy the contact" : "Villa kom upp þegar reynt var að afrita tengiliðinn",
    "Search contacts …" : "Leita í tengiliðum ",
    "No results" : "Engar niðurstöður",
    "Personal circle" : "Persónulegur hringur",
    "Pending" : "Í bið",
    "Select type" : "Veldu gerð",
    "Select Date" : "Veldu dagsetningu",
    "Add contact in group" : "Bæta tengilið í hóp",
    "Select option" : "Veldu valkost",
    "New contact" : "Nýr tengiliður",
    "Unable to create the contact." : "Tókst ekki að búa til tengiliðinn.",
    "Contact not found" : "Tengiliður fannst ekki",
    "Close" : "Loka",
    "_Importing %n contact into {addressbook}_::_Importing %n contacts into {addressbook}_" : ["Flyt %n tengilið inn í {addressbook}","Flyt %n tengiliði inn í {addressbook}"],
    "_Done importing %n contact into {addressbook}_::_Done importing %n contacts into {addressbook}_" : ["Kláraði að flytja %n tengilið inn í {addressbook}","Kláraði að flytja %n tengiliði inn í {addressbook}"],
    "Import" : "Flytja inn",
    "Not grouped" : "Ekki hópaður",
    "Circle" : "Hringur",
    "User" : "Notandi",
    "Group" : "Hópur",
    "Email" : "Netfang",
    "Contact" : "Tengiliður",
    "Member" : "Meðlimur",
    "Moderator" : "Umsjónarmaður",
    "Admin" : "Stjórnun",
    "Owner" : "Eigandi",
    "Users" : "Notendur",
    "Detailed name" : "Ítarlegt nafn",
    "Additional names" : "Aukanöfn",
    "Prefix" : "Forskeyti",
    "Suffix" : "Viðskeyti",
    "Nickname" : "Gælunafn",
    "Notes" : "Minnispunktar",
    "Website" : "Vefsvæði",
    "Location" : "Staðsetning",
    "Federated Cloud ID" : "Skýjasambandsauðkenni (Federated Cloud ID)",
    "Home" : "Heima",
    "Work" : "Vinna",
    "Other" : "Annað",
    "Address" : "Slóð",
    "Post office box" : "Pósthólf",
    "Extended address" : "Ítarlegt heimilisfang",
    "City" : "Borg",
    "State or province" : "Ríki eða fylki",
    "Postal code" : "Póstnúmer",
    "Country" : "Land",
    "Birthday" : "Afmælisdagur",
    "Anniversary" : "Afmæli",
    "Date of death" : "Dánardægur",
    "Instant messaging" : "Snarskilaboð",
    "Phone" : "Sími",
    "Mobile" : "Farsími",
    "Work mobile" : "Vinnufarsími",
    "Home mobile" : "Einkafarsími",
    "Fax" : "Fax",
    "Fax home" : "Heimafax",
    "Fax work" : "Vinnufax",
    "Pager" : "Símboði",
    "Voice" : "Raddskilaboð",
    "Car" : "Bíll",
    "Work pager" : "Vinnufriðþjófur",
    "Manager" : "Yfirmaður",
    "Social network" : "Samfélagsnet",
    "Spouse" : "Maki",
    "Child" : "Barn",
    "Mother" : "Móðir",
    "Father" : "Faðir",
    "Parent" : "Foreldri",
    "Brother" : "Bróðir",
    "Sister" : "Systir",
    "Relative" : "Ættingi",
    "Friend" : "Vinur",
    "Colleague" : "Samstarfsmaður",
    "Assistant" : "Aðstoðarmaður",
    "Agent" : "Umboðsaðili",
    "Emergency" : "Neyðartilfelli",
    "Co-worker" : "Samstarfsmaður",
    "Gender" : "Kyn",
    "Female" : "Kona",
    "Male" : "Karl",
    "None" : "Ekkert",
    "Unknown" : "Óþekkt",
    "Spoken languages" : "Töluð tungumál",
    "_{failed} contact failed to be read_::_{failed} contacts failed to be read_" : ["Mistókst að lesa {failed} tengilið","Mistókst að lesa {failed} tengiliði"]
},
"nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");
