OC.L10N.register(
    "contacts",
    {
    "Details" : "Detaljer",
    "All contacts" : "Alla kontakter",
    "Contacts" : "Kontakter",
    "A contacts app for Nextcloud" : "En kontakt-app för Nextcloud",
    "The Nextcloud contacts app is a user interface for Nextcloud's CardDAV server. Easily sync contacts from various devices with your Nextcloud and edit them online.\n\n* 🚀 **Integration with other Nextcloud apps!** Currently Mail and Calendar – more to come.\n* 🎉 **Never forget a birthday!** You can sync birthdays and other recurring events with your Nextcloud Calendar.\n* 👥 **Sharing of Adressbooks!** You want to share your contacts with your friends or coworkers? No problem!\n* 🙈 **We’re not reinventing the wheel!** Based on the great and open SabreDAV library." : "Nextclouds kontakt-app är ett gränssnitt för Nextclouds CardDAV-server. Synkronisera enkelt kontakter mellan olika apparater och ditt Nextcloud och redigera dem online.\n\n* 🚀 **Integration med andra Nextcloud-appar!** För närvarande E-post och Kalendrar – fler är på gång.\n* 🎉 **Glöm inte en födelsedag!** Du kan synkronisera födelsedagar och andra återkommande händelser med din Nextcloud-kalender.\n* 👥 **Dela adressböcker!** Vill du dela kontakter med dina vänner eller kollegor? Inga problem!\n* 🙈 **Vi uppfinner inte hjulet igen!** Kontakter är baserat på det utmärkta och öppna SabreDAV-biblioteket.",
    "Copy to full name" : "Kopiera till fullständigt namn",
    "Omit year" : "Utelämna år",
    "Allow updating avatars from social media" : "Tillåt uppdatering av profilbilder från sociala nätverk",
    "Please select a circle" : "Välj en cirkel",
    "Loading circle …" : "Laddar cirkel …",
    "Your request to join this circle is pending approval" : "Din begäran att ansluta till denna cirkel inväntar godkännande",
    "You are not a member of {circle}" : "Du är inte med i {circle}",
    "There was an error fetching the member list" : "Ett fel inträffade när medlemslistan hämtades",
    "Loading contacts …" : "Laddar kontakter ...",
    "There are no contacts yet" : "Det finns inga kontakter ännu",
    "Create contact" : "Skapa kontakt",
    "There are no contacts in this group" : "Det finns inga kontakter i denna grupp",
    "Create contacts" : "Skapa kontakter",
    "Add contacts" : "Lägg till kontakter",
    "Loading …" : "Läser in ...",
    "Add member" : "Lägg till medlem",
    "Leave circle" : "Lämna cirkel",
    "Delete circle" : "Radera cirkel",
    "Contacts settings" : "Kontaktinställningar",
    "General settings" : "Allmänna inställningar",
    "Update avatars from social media" : "Uppdatera avatarer från sociala medier",
    "(refreshed once per week)" : "(uppdateras en gång i veckan)",
    "Address books" : "Adressböcker",
    "Export" : "Exportera",
    "Send email" : "Skicka e-post",
    "Send email as BCC" : "Skicka e-post som BCC",
    "Contact groups" : "Kontaktgrupper",
    "Create a new contact group" : "Skapa en ny kontaktgrupp",
    "Contact group name" : "Namn på kontaktgrupp",
    "Circles" : "Cirklar",
    "Create a new circle" : "Skapa en ny cirkel",
    "Show all groups" : "Visa alla grupper",
    "Collapse groups" : "Dölj grupper",
    "Show all circles" : "Visa alla cirklar",
    "Collapse circles" : "Dölj cirklar",
    "This group already exists" : "Denna grupp existerar redan",
    "This circle already exists" : "Cirkeln finns redan",
    "An error happened during the creation of the circle" : "Ett fel inträffade när cirkeln skapades",
    "{addressbookname} (Disabled)" : "{addressbookname} (Inaktiverad)",
    "Download" : "Hämta",
    "Show" : "Visa",
    "Rename" : "Byt namn",
    "Delete" : "Ta bort",
    "Copied" : "Kopierad",
    "Cannot copy" : "Kan inte kopieria",
    "Copy link" : "Kopiera länk",
    "Toggling of address book was not successful" : "Växling av adressbok lyckades inte",
    "This will delete the address book and every contacts within it" : "Detta tar bort adressboken och alla kontakter i den",
    "Delete {addressbook}?" : "Vill du radera {addressbook}?",
    "Deletion of address book was not successful." : "Radering av adressboken lyckades inte.",
    "Renaming of address book was not successful." : "Namnbyte av adressboken lyckades inte.",
    "_%n contact_::_%n contacts_" : ["%n kontakt","%n kontakter"],
    "_%n group_::_%n groups_" : ["%n grupp","%n grupper"],
    "_Shared with {num} entity_::_Shared with {num} entities_" : ["Delad med {num} enhet","Delad med {num} enheter"],
    "Share with users or groups" : "Dela med användare eller grupper",
    "Share with users" : "Dela med användare",
    "No users or groups" : "Inga användare eller grupper",
    "can edit" : "kan redigera",
    "Unable to delete the share" : "Kunde inte radera delningen",
    "Unable to change permissions" : "Kunde inte ändra behörigheter",
    "Import contacts" : "Importera kontakter",
    "Import into the {addressbookName} address book" : "Importera till adressboken {addressbookName}",
    "Select local file" : "Välj lokal fil",
    "Import from files" : "Importera från filer",
    "Importing is disabled because there are no address books available" : "Importering är inaktiverat eftersom att det inte finns några adressböcker tillgängliga",
    "Choose a vCard file to import" : "Välj en vCard-fil att importera",
    "Add new address book" : "Lägg till ny adressbok",
    "An error occurred, unable to create the address book" : "Ett fel uppstod, kunde inte skapa adressboken",
    "First name" : "Förnamn",
    "Last name" : "Efternamn",
    "Phonetic first name" : "Fonetiskt förnamn",
    "Phonetic last name" : "Fonetiskt efternamn",
    "Display name" : "Visningsnamn",
    "Last modified" : "Senast ändrad",
    "Sort by {sorting}" : "Sortera efter {sorting}",
    "Manages" : "Leder",
    "Oversees" : "Har uppsikt över",
    "An error happened during the config change" : "Ett fel uppstod vid inställningsändringen",
    "Password protection" : "Lösenordsskydd",
    "Enforce password protection on files shared to this circle" : "Påtvinga lösenordsskydd på filer som delas med denna cirkel",
    "Use a unique password for all shares to this circle" : "Använd ett unikt lösenord för alla delningar till denna cirkel",
    "Unique password …" : "Unikt lösenord …",
    "Save" : "Spara",
    "Change unique password" : "Ändra unikt lösenord",
    "Failed to save password. Please try again later." : "Misslyckades att lagra lösenord. Försök igen senare.",
    "Circle name" : "Cirkelnamn",
    "Circle owned by {owner}" : "Cirkel ägs av {owner}",
    "Request to join" : "Medlemsförfrågan",
    "Description" : "Beskrivning",
    "There is no description for this circle" : "Det finns ingen beskrivning för denna cirkel",
    "Enter a description for the circle" : "Ange en beskrivningtext för cirkeln",
    "An error happened during description sync" : "Ett fel inträffade vid avstämning av beskrivningstext",
    "An error happened during name sync" : "Ett fel inträffade vid avstämning av namn",
    "Add more info" : "Lägg till mer information",
    "More fields" : "Fler fält",
    "Crop contact photo" : "Beskär kontaktfoto",
    "Cancel" : "Avbryt",
    "Upload a new picture" : "Ladda upp en ny bild",
    "Choose from Files" : "Välj från Filer",
    "Get from " : "Hämta från",
    "Download picture" : "Hämta bild",
    "Delete picture" : "Ta bort bild",
    "Please select a valid format" : "Välj ett giltigt format",
    "Invalid image" : "Ogiltig bild",
    "Error cropping picture" : "Det gick inte att beskära bilden",
    "Pick an avatar" : "Välj en avatar",
    "Error while processing the picture." : "Fel vid bearbetning av bilden.",
    "Avatar downloaded from social network" : "Avatar hämtades från socialt nätverk",
    "Avatar already up to date" : "Avatar är redan den aktuella",
    "Avatar download failed" : "Avatar misslyckades att hämtas",
    "No contact selected" : "Ingen kontakt vald",
    "Select a contact on the list to begin" : "Välj en kontakt i listan för att börja",
    "Name" : "Namn",
    "Title" : "Titel",
    "Company" : "Företag",
    "This contact was broken and received a fix. Please review the content and click here to save it." : "Denna kontakt var felaktig och åtgärdades. Granska innehållet och klicka här för att spara det.",
    "Edit" : "Redigera",
    "Clone contact" : "Klona kontakt",
    "Generate QR Code" : "Generera QR-kod",
    "Contact vCard as QR code" : "Kontaktens vCard som QR-kod",
    "Pick an address book" : "Välj en adressbok",
    "Select address book" : "Välj adressbok",
    "Go to talk conversation" : "Gå till Talk-konversation",
    "View profile" : "Visa profil",
    "This contact is in read-only mode. You do not have permission to edit this contact." : "Den här kontakten är skrivskyddad. Du har inte behörighet att redigera den här kontakten.",
    "The contact you were trying to edit has changed. Please manually refresh the contact. Any further edits will be discarded." : "Kontakten du försökte redigera har ändrats. Uppdatera kontakten manuellt. Eventuella ytterligare ändringar kommer att kasseras.",
    "Address book" : "Adressbok",
    "Add contact to Birthday Calendar" : "Lägg till kontakt i födelsedagskalendern",
    "Exclude contact from Birthday Calendar" : "Uteslut kontakt från födelsedagskalendern",
    "{title} at {organization}" : "{title} på {organization}",
    "Syntax error. Cannot open the contact." : "Syntaxfel. Kan inte öppna kontakten.",
    "The contact does not exist on the server anymore." : "Kontakten finns inte längre på servern.",
    "Unable to retrieve the contact from the server, please check your network connection." : "Kan inte hämta kontakten från servern, vänligen kontrollera nätverksanslutningen.",
    "An error occurred while trying to move the contact" : "Ett fel uppstod när du försökte flytta kontakten",
    "An error occurred while trying to copy the contact" : "Ett fel uppstod vid försök att kopiera kontakten",
    "Unable to update contact" : "Det gick inte att uppdatera kontakten",
    "Search contacts …" : "Sök kontakter ...",
    "Add to {group}" : "Lägg till i {group}",
    "Remove {type}" : "Ta bort {type}",
    "Search {types}" : "Sök {types}",
    "Search for people to add" : "Sök efter personer att lägga till",
    "No results" : "Inga resultat",
    "Add to group" : "Lägg till grupp",
    "Add {type}" : "Lägg till {type}",
    "New circle name" : "Nytt namn på cirkel",
    "Personal circle" : "Personlig cirkel",
    "This circle will only be visible to you. Other members will not be able to see or use it." : "Denna cirkel är enbart synlig för dig. Andra medlemmar kan inte se eller använda den.",
    "Local circle" : "Lokal cirkel",
    "This circle will not be shared with the other instances of the global scale" : "Denna cirkel kommer inte att delas med andra instanser på den globala skalan",
    "Create circle" : "Skapa cirkel",
    "Loading members list …" : "Hämtar lista över medlemmar …",
    "The list of members is only visible to members of this circle" : "Medlemslistan är bara synlig för cirkelns medlemmar",
    "You currently have no access to the member list" : "Du har för närvarande inte tillgång till medlemslistan",
    "Add members" : "Lägg till medlemmar",
    "Show circle details" : "Visa information om cirkeln",
    "Add to {circle}" : "Lägg till i {circle}",
    "Unable to get the recommendations list" : "Kunde inte hämta listan över rekommendationer",
    "Unable to get the results" : "Kunde inte hämta resultaten",
    "Some members could not be added" : "Vissa medlemmar kunde inte läggas till",
    "There was an issue adding members to the circle" : "Misslyckades att lägga till medlemmar till cirkeln",
    "Accept membership request" : "Acceptera medlemsförfrågan",
    "Reject membership request" : "Avslå medlemsförfrågan",
    "Manage level" : "Hantera nivå",
    "Remove member" : "Ta bort medlem",
    "Pending" : "Väntande",
    "Promote as sole owner" : "Gör till ensam ägare",
    "Promote to {level}" : "Befordra till {level}",
    "Demote to {level}" : "Degradera till {level}",
    "Could not delete the member {displayName}" : "Kunde inte radera medlemmen {displayName}",
    "Could not change the member level to {level}" : "Kunde inte ändra medlemmens behörighet till {level}",
    "Could not accept membership request" : "Kunde inte godkänna medlemsskapsbegäran",
    "Chart" : "Diagram",
    "Select chart …" : "Välj schema ...",
    "Select type" : "Välj typ",
    "Select Date" : "Välj datum",
    "Add contact in group" : "Lägg till kontakt i grupp",
    "none" : "ingen",
    "Select option" : "Välj alternativ",
    "Add property of this type" : "Lägg till egenskap av denna typ",
    "New contact" : "Ny kontakt",
    "Unable to create the contact." : "Kunde inte skapa kontakten.",
    "Contact not found" : "Kontakt hittades inte",
    "Group {group} not found" : "Gruppen {group} hittades inte",
    "Close" : "Stäng",
    "_{success} contact added to {name}_::_{success} contacts added to {name}_" : ["{success} kontakt tillagd till  {name}","{success} kontakter tillagda till {name}"],
    "_Adding {success} contact to {name}_::_Adding {success} contacts to {name}_" : ["Lägger till {success} kontakt till {name}","Lägger till {success} kontakter till {name}"],
    "_{count} error_::_{count} errors_" : ["{count} fel","{count} fel"],
    "_Importing %n contact into {addressbook}_::_Importing %n contacts into {addressbook}_" : ["Importerar %n kontakt till {addressbook}","Importerar %n kontakter till {addressbook}"],
    "_Done importing %n contact into {addressbook}_::_Done importing %n contacts into {addressbook}_" : ["Klar med import av %n kontakt till {addressbook}","Klar med import av %n kontakter till {addressbook}"],
    "Import" : "Importera",
    "Could not copy" : "Kunde inte kopiera",
    "Join circle" : "Gå med i crikel",
    "You are about to leave {circle}.\nAre you sure?" : "Du är på väg att lämna {circle}.\nÄr du säker?",
    "Please confirm circle leave" : "Bekräfta utträde ur cirkeln",
    "Could not leave the circle {displayName}" : "Kunde inte lämna cirkeln {displayName}",
    "Unable to join the circle" : "Kunde inte gå med i cirkeln",
    "You are about to delete {circle}.\nAre you sure?" : "Du är på väg att radera {circle}.\nÄr du säker?",
    "Please confirm circle deletion" : "Bekräfta radering av cirkeln",
    "Unable to delete the circle" : "Kunde inte radera cirkeln",
    "Link copied to the clipboard" : "Länken har kopierats till urklipp",
    "Could not copy link to the clipboard." : "Kunde inte kopiera länken till urklipp.",
    "Not grouped" : "Inte grupperad",
    "Recently contacted" : "Nyligen kontaktade",
    "Organization chart" : "Organisationsschema",
    "Circles are groups of people that you can create yourself and with whom you can share data. They can be made up of other accounts or groups of accounts of the Nextcloud instance, but also of contacts from your address book or even external people by simply entering their e-mail addresses." : "Cirklar är grupper av människor som du kan skapa själv och som du kan dela data med. De kan bestå av andra konton eller grupper av konton från Nextcloud, men också av kontakter från din adressbok eller till och med externa personer genom att helt enkelt ange deras e-postadresser.",
    "Circle" : "Cirkel",
    "User" : "Användare",
    "Group" : "Grupp",
    "Email" : "E-post",
    "Contact" : "Kontakt",
    "Member" : "Medlem",
    "Moderator" : "Moderator",
    "Admin" : "Administratör",
    "Owner" : "Ägare",
    "Invites" : "Inbjudningar",
    "Anyone can request membership" : "Vem som helst kan begära medlemskap",
    "Members need to accept invitation" : "Medlemmar måste godkänna inbjudan",
    "Memberships must be confirmed/accepted by a Moderator (requires Open)" : "Medlemsskap måste bekräftas/godkännas av en moderator (requires Open)",
    "Members can also invite" : "Medlemmar kan också bjuda in",
    "Visibility" : "Synlighet",
    "Visible to everyone" : "Synlig för alla",
    "Circle membership" : "Cirkelmedlemmar",
    "Prevent circle from being a member of another circle" : "Förhindra cirkel från att bli medlem av en annan cirkel",
    "Users" : "Användare",
    "Email addresses" : "E-postadresser",
    "Detailed name" : "Detaljerat namn",
    "Additional names" : "Mellannamn",
    "Prefix" : "Prefix",
    "Suffix" : "Suffix",
    "Nickname" : "Smeknamn",
    "Notes" : "Anteckningar",
    "Website" : "Webbplats",
    "Location" : "Plats",
    "Federated Cloud ID" : "Federerat Moln-ID",
    "Home" : "Hem",
    "Work" : "Arbete",
    "Other" : "Övrigt",
    "Address" : "Adress",
    "Post office box" : "Postbox",
    "Extended address" : "Utökad adress",
    "City" : "Stad",
    "State or province" : "Län eller Kommun",
    "Postal code" : "Postnummer",
    "Country" : "Land",
    "Birthday" : "Födelsedag",
    "Anniversary" : "Jubileum",
    "Date of death" : "Dödsdag",
    "Instant messaging" : "Snabbmeddelanden",
    "Phone" : "Telefon",
    "Mobile" : "Mobil",
    "Work mobile" : "Mobil arbete",
    "Home mobile" : "Mobil hem",
    "Fax" : "Fax",
    "Fax home" : "Fax hem",
    "Fax work" : "Fax arbete",
    "Pager" : "Personsökare",
    "Voice" : "Röst",
    "Car" : "Bil",
    "Work pager" : "Personsökare Arbete",
    "Manager" : "Chef",
    "Social network" : "Socialt nätverk",
    "Relationship to you" : "Relation till dig",
    "Spouse" : "Make/Maka",
    "Child" : "Barn",
    "Mother" : "Mor",
    "Father" : "Far",
    "Parent" : "Förälder",
    "Brother" : "Bror",
    "Sister" : "Syster",
    "Relative" : "Släkting",
    "Friend" : "Vän",
    "Colleague" : "Kollega",
    "Assistant" : "Assistent",
    "Related contacts" : "Förknippade kontakter",
    "Agent" : "Agent",
    "Emergency" : "Nödsituation",
    "Co-worker" : "Kollega",
    "Gender" : "Kön",
    "Female" : "Kvinna",
    "Male" : "Man",
    "None" : "Ingen",
    "Unknown" : "Okänd",
    "Time zone" : "Tidszon",
    "Spoken languages" : "Talade språk",
    "_{failed} contact failed to be read_::_{failed} contacts failed to be read_" : ["{failed} kontakt kunde inte läsas","{failed} kontakter kunde inte läsas"],
    "An error has occurred in circle(s). Check the console for more details." : "Ett fel har uppstått i cirklar. Kontrollera konsolen för mer information.",
    "Unable to create circle {circleName}" : "Kunde inte skapa cirkeln {circleName}",
    "Unable to delete circle {circleId}" : "Kunde inte radera cirkeln {circleId}",
    "Unable to delete contact" : "Kunde inte radera kontakten"
},
"nplurals=2; plural=(n != 1);");
