OC.L10N.register(
    "contacts",
    {
    "Details" : "Detàllios",
    "All contacts" : "Totu is cuntatos",
    "Contacts" : "Cuntatos",
    "A contacts app for Nextcloud" : "Un'aplicatzione de cuntatos pro Nextcloud",
    "The Nextcloud contacts app is a user interface for Nextcloud's CardDAV server. Easily sync contacts from various devices with your Nextcloud and edit them online.\n\n* 🚀 **Integration with other Nextcloud apps!** Currently Mail and Calendar – more to come.\n* 🎉 **Never forget a birthday!** You can sync birthdays and other recurring events with your Nextcloud Calendar.\n* 👥 **Sharing of Adressbooks!** You want to share your contacts with your friends or coworkers? No problem!\n* 🙈 **We’re not reinventing the wheel!** Based on the great and open SabreDAV library." : "S'aplicatzione Cuntatos de Nextcloud est un'interfache utente pro su serbidore CardDAV de Nextcloud. Sincroniza is cuntatos in manera simpre dae prus dispositivos cun su Nextcloud tuo e ddos modìficat in lìnia.\n\n* 🚀 **Integrazione cun àteras aplicatziones de Nextcloud!** Immoe Posta e Calendàriu – àteras ant a arribbare.\n* 🎉 ***Non t'iscaressas mai de un'anniversàriu!** Podes sincronizare is anniversàrios e is àteros eventos recurrentes cun su calendàriu tuo de Nextcloud.\n* 👥 Cumpartzidura de rubricas!** Cheres cumpartzire is cuntatos tuos cun is amigos o is collegas tuos? Perunu problema!\n* 🙈 **Non nos semus torrende a imbentare sa roda!** Basada subra de sa libreria de còdighe abertu bella a beru de SabreDAV.",
    "Copy to full name" : "Còpia in su nùmene cumpretu",
    "Omit year" : "Omite s'annu",
    "Allow updating avatars from social media" : "Permite s'agiornamentu de s'avatar dae sas retes sotziales",
    "Please select a circle" : "Seletziona unu giru",
    "Loading circle …" : "Carrighende giru …",
    "Your request to join this circle is pending approval" : "Sa rechesta tua de intrare in su giru depet èssere ancora aprovada",
    "You are not a member of {circle}" : "No ses parte de  {circle}",
    "There was an error fetching the member list" : "B'at àpidu un'errore in su recùperu de s'elencu de is partetzipantes",
    "Loading contacts …" : "Carrighende is cuntatos ...",
    "There are no contacts yet" : "Non ddoe at cuntatos ancora",
    "Create contact" : "Crea cuntatos",
    "There are no contacts in this group" : "Non ddoe at cuntatos in custu grupu",
    "Create contacts" : "Crea cuntatos ",
    "Add contacts" : "Agiunghe cuntatos",
    "Loading …" : "Carrrighende …",
    "Add member" : "Agiunghe partetzipante",
    "Leave circle" : "Lassa giru",
    "Delete circle" : "Cantzella giru",
    "General settings" : "Impostatziones genales",
    "Update avatars from social media" : "Agiorna is avatar de is retes sotziales",
    "(refreshed once per week)" : "(agiornadu una borta a sa chida)",
    "Address books" : "Rubricas",
    "Send email" : "Imbia messàgiu de posta eletrònica",
    "Circles" : "Giros",
    "Create a new circle" : "Crea unu giru nou",
    "Show all groups" : "Mustra totu is grupos",
    "Collapse groups" : "Istringhe is grupos",
    "Show all circles" : "Mustra totu is giros",
    "Collapse circles" : "Istringhe is giros",
    "This group already exists" : "Custu grupu ddoe est giai",
    "This circle already exists" : "Custu giru esistit giai",
    "An error happened during the creation of the circle" : "B'at àpidu un'errore in sa creatzione de su giru",
    "Download" : "Iscàrriga",
    "Rename" : "Torra a numenare",
    "Delete" : "Cantzella",
    "Copied" : "Copiadu",
    "Cannot copy" : "Non faghet a copiare",
    "Copy link" : "Còpia ligòngiu",
    "Toggling of address book was not successful" : "No at fatu a ativare sa rubrica",
    "This will delete the address book and every contacts within it" : "Custu at a cantzellare sa rubrica e ogni cuntatu chi ddoe est in intro.",
    "Delete {addressbook}?" : "Cantzella {addressbook}?",
    "Deletion of address book was not successful." : "No at fatu a cantzellare sa rubrica.",
    "Renaming of address book was not successful." : "No at fatu a torrare a numenare sa rubrica.",
    "_Shared with {num} entity_::_Shared with {num} entities_" : ["Cumpartzidu cun {num} entidades","Cumpartzidu cun {num} entidades"],
    "Share with users or groups" : "Cumpartzi cun utentes e grupos",
    "No users or groups" : "Peruna utèntzia o grupu",
    "can edit" : "podet modificare",
    "Unable to delete the share" : "Non faghet a cantzellare sa cumpartzidura",
    "Unable to change permissions" : "Non faghet a cambiare is permissos",
    "Import contacts" : "Importa cuntatos",
    "Import into the {addressbookName} address book" : "Importa in sa rubrica {addressbookName}",
    "Select local file" : "Sèbera archìviu locale",
    "Import from files" : "Importa dae is archìvios",
    "Importing is disabled because there are no address books available" : "S'importatzione est istada disativada ca non ddoe at rubricas a disponimentu",
    "Choose a vCard file to import" : "Sèbera un'archìviu vCard de importare",
    "Add new address book" : "Agiunghe una rubrica noa",
    "An error occurred, unable to create the address book" : "B'at àpidu un'errore, non faghet a creare sa rubrica",
    "First name" : "Nùmene",
    "Last name" : "Sambenadu",
    "Phonetic first name" : "Nùmene fonèticu",
    "Phonetic last name" : "Sambenadu fonèticu",
    "Display name" : "Nùmene visualizadu",
    "Last modified" : "Ùrtima modìfica",
    "Sort by {sorting}" : "Assenta segundu {sorting}",
    "An error happened during the config change" : "B'at àpidu un'errore in su càmbiu de cunfigratzione",
    "Password protection" : "Bardiadura de sa crae",
    "Save" : "Sarva",
    "Circle name" : "Nùmene de su giru",
    "Circle owned by {owner}" : "Giru de propiedade de {owner}",
    "Request to join" : "Rechesta de intrare",
    "Description" : "Descritzione",
    "There is no description for this circle" : "No b'at peruna descritzione pro custu giru",
    "Enter a description for the circle" : "Inserta•nche una descritzione pro su giru",
    "An error happened during description sync" : "B'at àpidu un'errore in sa sincronizatzione de sa descritzione",
    "An error happened during name sync" : "B'at àpidu un'errore in sa sincronizatzione de su nùmene",
    "Cancel" : "Annulla",
    "Upload a new picture" : "Càrriga·nche un'immàgine noa",
    "Choose from Files" : "Sèbera dae Archìvios",
    "Get from " : "Piga dae",
    "Download picture" : "Iscàrriga immàgine",
    "Delete picture" : "Cantzella immàgine",
    "Invalid image" : "Immàgine non bàlida",
    "Pick an avatar" : "Sèbera un'avatar",
    "Error while processing the picture." : "Errore elaborende s'immàgine.",
    "Avatar downloaded from social network" : "Avatar iscarrigadu dae sa rete sotziale",
    "Avatar already up to date" : "Avatar giai agiornadu",
    "Avatar download failed" : "No at fatu a iscarrigare s'avatar",
    "No contact selected" : "Perunu cuntatu seletzionadu",
    "Select a contact on the list to begin" : "Seletziona unu cuntatu in sa lista pro cumintzare",
    "Name" : "Nùmene",
    "Title" : "Tìtulu",
    "Company" : "Azienda",
    "This contact was broken and received a fix. Please review the content and click here to save it." : "Custu cuntatu fiat dannegiadu e ddoe at àpidu una curretzione. Pro praghere, revisiona su cuntenutu e incarca inoghe pro ddu sarvare.",
    "Clone contact" : "Clona cuntatu",
    "Generate QR Code" : "Gènera còdighe QR",
    "Contact vCard as QR code" : "vCard de cuntatu comente còdighe QR",
    "Pick an address book" : "Sèbera una rubrica",
    "Select address book" : "Seletziona una rubrica",
    "This contact is in read-only mode. You do not have permission to edit this contact." : "Custu cuntatu est in modalidade de letura sola. Non tenes su permissu pro modificare custu cuntatu.",
    "The contact you were trying to edit has changed. Please manually refresh the contact. Any further edits will be discarded." : "Su cuntatu chi ses proende a modificare est cambiadu. Pro praghere, agiorna tue etotu su cuntatu. Cale si siat àtera modìfica at a èssere iscartada. ",
    "Address book" : "Rubrica",
    "Syntax error. Cannot open the contact." : "Errore de sintassi. Non si podet abèrrere su cuntatu.",
    "Unable to retrieve the contact from the server, please check your network connection." : "Non faghet a recuperare su cuntatu dae su serbidore, controlla s'istadu de sa connessione.",
    "An error occurred while trying to move the contact" : "Ddoe at àpidu un'errore proende a tramudare su cuntatu",
    "An error occurred while trying to copy the contact" : "Ddoe at àpidu un'errore proende a copiare su cuntatu",
    "Search contacts …" : "Chirca cuntatos ...",
    "Add to {group}" : "Agiunghe a {group}",
    "Remove {type}" : "Boga {type}",
    "Search {types}" : "Chirca {types}",
    "Search for people to add" : "Chirca persones de agiùnghere",
    "No results" : "Perunu resultadu",
    "Add to group" : "Agiunghe a su grupu",
    "Add {type}" : "Agiunghe {type}",
    "New circle name" : "Nùmene nou de su giru",
    "Personal circle" : "Giru personale",
    "This circle will only be visible to you. Other members will not be able to see or use it." : "Custu giru ddu podes bìdere isceti tue. Is àteros membros no dd'ant pòdere bìdere o impreare.",
    "Local circle" : "Giru locale",
    "This circle will not be shared with the other instances of the global scale" : "Custu giru no s'at a cumpartzire cun is àteras istàntzias de s'iscala globale",
    "Create circle" : "Crea giru",
    "Loading members list …" : "Carrighende s'elencu de is membros ... ",
    "The list of members is only visible to members of this circle" : "Sa lista de is membros dda podent bìdere isceti is membros de custu giru",
    "Add members" : "Agiunghe partetzipante",
    "Show circle details" : "Mustra detàllios de su giru",
    "Add to {circle}" : "Agiunghe a {circle}",
    "Unable to get the recommendations list" : "No faghet a otènnere sa lista de incumendatziones",
    "Unable to get the results" : "No faghet a otènnere resurtados",
    "Some members could not be added" : "B'at membros chi no si podent agiùnghere",
    "There was an issue adding members to the circle" : "B'at àpidu unu problema agiunghende membros a su giru",
    "Accept membership request" : "Atzeta sa rechesta de partetzipatzione",
    "Reject membership request" : "Refuda sa rechesta de partetzipatzione",
    "Manage level" : "Gesti su livellu",
    "Remove member" : "Boga•nche partetzipante",
    "Pending" : "In suspesu",
    "Promote as sole owner" : "Promove a mere",
    "Promote to {level}" : "Promove a {level}",
    "Demote to {level}" : "Torra a coa a {level}",
    "Could not delete the member {displayName}" : "No at fatu a cantzellare su membru {displayName}",
    "Could not change the member level to {level}" : "No at fatu a cambiare su livellu de su membru a {level}",
    "Could not accept membership request" : "No at fatu a atzetare sa rechesta de partetzipatzione",
    "Chart" : "Gràficu",
    "Select type" : "Sèbera genia",
    "Select Date" : "Seletziona data",
    "Add contact in group" : "Agiunghe cuntatu a su grupu",
    "Select option" : "Seletziona sèberu",
    "New contact" : "Cuntatu nou",
    "Unable to create the contact." : "Non faghet a creare su cuntatu.",
    "Contact not found" : "Cuntatu no agatadu",
    "Group {group} not found" : "Grupu {group} no agatadu",
    "Close" : "Serra",
    "_{success} contact added to {name}_::_{success} contacts added to {name}_" : ["{success} cuntatos agiuntos a {name}","{success} cuntatos agiuntos a {name}"],
    "_Adding {success} contact to {name}_::_Adding {success} contacts to {name}_" : ["Agiunta de {success} contatos a {name}","Agiunta {success} contacts to {name}"],
    "_{count} error_::_{count} errors_" : ["{count} errores","{count} errores"],
    "_Importing %n contact into {addressbook}_::_Importing %n contacts into {addressbook}_" : ["Importende %n cuntatos in {addressbook}","Importing %n contacts into {addressbook}"],
    "_Done importing %n contact into {addressbook}_::_Done importing %n contacts into {addressbook}_" : ["Importados %n cuntatos in {addressbook}","Done importing %n contacts into {addressbook}"],
    "Import" : "Importa",
    "Could not copy" : "No at fatu a copiare",
    "Join circle" : "Intra in su giru",
    "You are about to leave {circle}.\nAre you sure?" : "Ses acanta de nche essire dae {circle}.\nA beru ddu boles lassare?",
    "Please confirm circle leave" : "Cunfirma ca lassas su giru",
    "Could not leave the circle {displayName}" : "No at fatu a lassare su giru {displayName}",
    "Unable to join the circle" : "No faghet a intrare in su giru",
    "You are about to delete {circle}.\nAre you sure?" : "Ses acanta de cantzellare {circle}.\nA beru ddu boles fàghere?",
    "Please confirm circle deletion" : "Cunfirma sa cantzelladura de su giru",
    "Unable to delete the circle" : "No faghet a cantzellare su giru",
    "Link copied to the clipboard" : "Ligòngiu copiadu in punta de billete",
    "Could not copy link to the clipboard." : "No at fatu a copiare su ligòngiu in punta de billete.",
    "Not grouped" : "Non ammuntonados",
    "Recently contacted" : "Cuntatados pag'ora",
    "Circle" : "Giru",
    "User" : "Utente",
    "Group" : "Grupu",
    "Email" : "Posta eletrònica",
    "Contact" : "Cuntatu",
    "Member" : "Membru",
    "Moderator" : "Chie moderat",
    "Admin" : "Amministratzione",
    "Owner" : "Mere",
    "Invites" : "Invitos",
    "Anyone can request membership" : "Chie si siat podet pedire sa partetzipatzione",
    "Members need to accept invitation" : "Is membros depent atzetare s'invitu",
    "Memberships must be confirmed/accepted by a Moderator (requires Open)" : "Sa partetzipatzione depet èssere cunfirmada/atzetada dae una persone chi moderat (Open est rechèdidu)",
    "Members can also invite" : "Puru is membros podent invitare",
    "Visibility" : "Visibilidade",
    "Visible to everyone" : "Visìbile pro totus",
    "Circle membership" : "Apartenèntzia a su giru",
    "Prevent circle from being a member of another circle" : "Evita a unu giru de èssere membru de un'àteru giru",
    "Users" : "Utentes",
    "Detailed name" : "Nùmene a sa minuda",
    "Additional names" : "Nùmenes in agiunta",
    "Prefix" : "Prefissu",
    "Suffix" : "Sufissu",
    "Nickname" : "Gistru",
    "Notes" : "Notas",
    "Website" : "Situ ìnternet",
    "Location" : "Positzione",
    "Federated Cloud ID" : "ID de sa nue federada",
    "Home" : "Pàgina printzipale",
    "Work" : "Traballu",
    "Other" : "Àteru ",
    "Address" : "Indiritzu",
    "Post office box" : "Casedda postale",
    "Extended address" : "Indiritzu istèrridu",
    "City" : "Tzitade",
    "State or province" : "Istadu o provìntzia",
    "Postal code" : "Còdighe postale",
    "Country" : "Paisu",
    "Birthday" : "Cumpleannu",
    "Anniversary" : "Anniversàriu",
    "Date of death" : "Data de morte",
    "Instant messaging" : "Messagìstica lestra",
    "Phone" : "Telèfonu",
    "Mobile" : "Telefoneddu",
    "Work mobile" : "Telefoneddu de traballu",
    "Home mobile" : "Telefoneddu personale",
    "Fax" : "Fax",
    "Fax home" : "Fax personale",
    "Fax work" : "Fax de traballu",
    "Pager" : "Chircapersones",
    "Voice" : "Boghe",
    "Car" : "Vetura",
    "Work pager" : "Chircapersones de traballu",
    "Manager" : "Responsàbile",
    "Social network" : "Rete sotziale",
    "Relationship to you" : "Amorende cun tegus",
    "Spouse" : "Còjube",
    "Child" : "Figiàmine",
    "Mother" : "Mama",
    "Father" : "Babu",
    "Parent" : "Genitore",
    "Brother" : "Frade ",
    "Sister" : "Sorre",
    "Relative" : "Parente",
    "Friend" : "Amighèntzia",
    "Colleague" : "Collega",
    "Assistant" : "Agiudante",
    "Related contacts" : "Cuntatos ligados",
    "Agent" : "Agente",
    "Emergency" : "Emergèntzia",
    "Co-worker" : "Collega de traballu",
    "Gender" : "Gèneru",
    "Female" : "Fèmina",
    "Male" : "Òmine",
    "None" : "Nessunu",
    "Unknown" : "Disconnotu",
    "Time zone" : "Zona orària",
    "Spoken languages" : "Limbas faeddadas",
    "_{failed} contact failed to be read_::_{failed} contacts failed to be read_" : ["no at fatu a lèghere {failed} ","{failed} contacts failed to be read"],
    "Unable to create circle {circleName}" : "No faghet a creare su giru {circleName}",
    "Unable to delete circle {circleId}" : "No faghet a cantzellare su giru {circleId}",
    "Unable to delete contact" : "Non faghet a cantzellare su cuntatu"
},
"nplurals=2; plural=(n != 1);");
