OC.L10N.register(
    "contacts",
    {
    "Details" : "詳細資料",
    "All contacts" : "所有聯絡人",
    "Contacts" : "通訊錄",
    "A contacts app for Nextcloud" : "Nextcloud 的通訊錄應用程式",
    "The Nextcloud contacts app is a user interface for Nextcloud's CardDAV server. Easily sync contacts from various devices with your Nextcloud and edit them online.\n\n* 🚀 **Integration with other Nextcloud apps!** Currently Mail and Calendar – more to come.\n* 🎉 **Never forget a birthday!** You can sync birthdays and other recurring events with your Nextcloud Calendar.\n* 👥 **Sharing of Adressbooks!** You want to share your contacts with your friends or coworkers? No problem!\n* 🙈 **We’re not reinventing the wheel!** Based on the great and open SabreDAV library." : "Nextcloud 通訊錄應用程式是 Nextcloud 的 CardDAV 伺服器的使用者介面。可輕鬆使用您的 Nextcloud 同步各個裝置上的聯絡人，並在線上編輯。\n\n* 🚀 **與其他 Nextcloud 應用程式整合！** 目前有電子郵件與日曆，還會有更多。\n* 🎉 **不會忘記生日！** 您可以將生日與其他重複的活動與您的 Nextcloud 日曆同步。\n* 👥 **分享通訊錄！** 您想與您的朋友或同事分享您的聯絡人嗎？沒問題！\n* 🙈 **我們並沒有重新發明輪子！** 以超棒且開放的 SabreDAV 函式庫為基礎。",
    "Copy to full name" : "複製到全名",
    "Omit year" : "省略年份",
    "Allow updating avatars from social media" : "允許從社群媒體更新大頭照",
    "Please select a circle" : "請選取一個小圈圈",
    "Loading circle …" : "正在載入小圈圈……",
    "Your request to join this circle is pending approval" : "您加入此小圈圈的請求正在等待批准",
    "You are not a member of {circle}" : "您不是 {circle} 的成員",
    "There was an error fetching the member list" : "擷取成員清單時發生錯誤",
    "Loading contacts …" : "正在載入聯絡人……",
    "There are no contacts yet" : "目前沒有連絡人",
    "Create contact" : "建立聯絡人",
    "There are no contacts in this group" : "群組中沒有連絡人",
    "Create contacts" : "建立聯絡人",
    "Add contacts" : "新增聯絡人",
    "Loading …" : "正在載入……",
    "Add member" : "新增成員",
    "Leave circle" : "離開小圈圈",
    "Delete circle" : "刪除小圈圈",
    "Contacts settings" : "聯絡人設定",
    "General settings" : "一般設定",
    "Update avatars from social media" : "從社群媒體更新大頭照",
    "(refreshed once per week)" : "（每週重新整理一次）",
    "Address books" : "通訊錄",
    "Export" : "匯出",
    "Send email" : "傳送電子郵件",
    "Send email as BCC" : "以密件副本傳送電子郵件",
    "Contact groups" : "聯絡人群組",
    "Create a new contact group" : "建立新聯絡人群組",
    "Contact group name" : "聯絡人群組名稱",
    "Circles" : "小圈圈",
    "Create a new circle" : "建立新的小圈圈",
    "Show all groups" : "顯示所有群組",
    "Collapse groups" : "折疊群組",
    "Show all circles" : "顯示所有小圈圈",
    "Collapse circles" : "折疊小圈圈",
    "This group already exists" : "該群組已存在",
    "This circle already exists" : "此小圈圈已存在",
    "An error happened during the creation of the circle" : "建立小圈圈時發生錯誤",
    "{addressbookname} (Disabled)" : "{addressbookname}（已停用）",
    "Download" : "下載",
    "Show" : "顯示",
    "Rename" : "重新命名",
    "Delete" : "刪除",
    "Copied" : "已複製",
    "Cannot copy" : "無法複製",
    "Copy link" : "複製連結",
    "Toggling of address book was not successful" : "通訊錄切換失敗",
    "This will delete the address book and every contacts within it" : "這將會刪除通訊與其中的每個聯絡人",
    "Delete {addressbook}?" : "刪除 {addressbook}？",
    "Deletion of address book was not successful." : "刪除通訊錄失敗。",
    "Renaming of address book was not successful." : "重新命名通訊錄失敗。",
    "_%n contact_::_%n contacts_" : ["%n 位聯絡人"],
    "_%n group_::_%n groups_" : ["%n 個群組"],
    "_Shared with {num} entity_::_Shared with {num} entities_" : ["與 {num} 個實體分享"],
    "Share with users or groups" : "與使用者或群組分享",
    "Share with users" : "與使用者分享",
    "No users or groups" : "沒有使用者或群組",
    "can edit" : "允許編輯",
    "Unable to delete the share" : "無法刪除這個分享",
    "Unable to change permissions" : "無法變更權限",
    "Import contacts" : "匯入連絡人",
    "Import into the {addressbookName} address book" : "匯入至 {addressbookName} 通訊錄",
    "Select local file" : "選取本機檔案",
    "Import from files" : "從檔案匯入",
    "Importing is disabled because there are no address books available" : "已停用匯入，因為沒有可用的通訊錄",
    "Choose a vCard file to import" : "選取要匯入的 vCard 檔案",
    "Add new address book" : "加入新的通訊錄",
    "An error occurred, unable to create the address book" : "發生錯誤，無法建立通訊錄",
    "First name" : "名",
    "Last name" : "姓",
    "Phonetic first name" : "語音名",
    "Phonetic last name" : "語音姓",
    "Display name" : "顯示名稱",
    "Last modified" : "上次修改",
    "Sort by {sorting}" : "按 {sorting} 排序",
    "Manages" : "管理",
    "Oversees" : "監督",
    "An error happened during the config change" : "變更設定時發生錯誤",
    "Password protection" : "密碼保護",
    "Enforce password protection on files shared to this circle" : "對分享到此小圈圈的檔案加上密碼保護",
    "Use a unique password for all shares to this circle" : "對此小圈圈的所有分享使用獨一無二的密碼",
    "Unique password …" : "獨一無二的密碼……",
    "Save" : "儲存",
    "Change unique password" : "變更獨一無二的密碼",
    "Failed to save password. Please try again later." : "儲存密碼失敗。請稍後再試。",
    "Circle name" : "小圈圈名稱",
    "Circle owned by {owner}" : "{owner} 擁有的小圈圈",
    "Request to join" : "要求加入",
    "Description" : "描述",
    "There is no description for this circle" : "此小圈圈沒有描述",
    "Enter a description for the circle" : "輸入小圈圈的描述",
    "An error happened during description sync" : "描述同步時發生錯誤",
    "An error happened during name sync" : "名稱同步時發生錯誤",
    "Add more info" : "新增更多資訊",
    "More fields" : "更多欄位",
    "Crop contact photo" : "裁剪聯絡人照片",
    "Cancel" : "取消",
    "Upload a new picture" : "上傳一張新的圖片",
    "Choose from Files" : "從檔案選取",
    "Get from " : "取得自",
    "Download picture" : "下載圖片",
    "Delete picture" : "刪除圖片",
    "Please select a valid format" : "請選取有效格式",
    "Invalid image" : "圖片無效",
    "Error cropping picture" : "裁剪照片時發生錯誤",
    "Pick an avatar" : "選擇一個大頭照",
    "Error while processing the picture." : "處理相片時錯誤。",
    "Avatar downloaded from social network" : "從社群網路下載大頭照",
    "Avatar already up to date" : "大頭照已是最新",
    "Avatar download failed" : "大頭照下載失敗",
    "No contact selected" : "未選擇聯絡人",
    "Select a contact on the list to begin" : "在列表中選擇一個聯絡人以開始",
    "Name" : "名稱",
    "Title" : "標題",
    "Company" : "公司",
    "This contact was broken and received a fix. Please review the content and click here to save it." : "此聯絡人的資料有問題，已修復。請審閱內容並點擊此處以儲存。",
    "Edit" : "編輯",
    "Clone contact" : "再製連絡人",
    "Generate QR Code" : "產生 QR Code",
    "Contact vCard as QR code" : "QR Code 形式的聯絡人 vCard",
    "Pick an address book" : "選取一個通訊錄",
    "Select address book" : "選擇通訊錄",
    "Go to talk conversation" : "前往對話",
    "View profile" : "檢視個人檔案",
    "Media shares with you" : "與您分享的媒體",
    "Talk conversations with you" : "與您的 Talk 對話",
    "Calendar events with you" : "有您的日曆事件",
    "Deck cards with you" : "有您的 Deck 卡片",
    "No shared items with this contact" : "沒有與該聯絡人分享的項目",
    "This contact is in read-only mode. You do not have permission to edit this contact." : "此聯絡人處於唯讀模式。您無權編輯此聯絡人。",
    "The contact you were trying to edit has changed. Please manually refresh the contact. Any further edits will be discarded." : "您嘗試編輯的聯絡人已變更。請手動重新整理聯絡人。任何進一步的編輯都會被丟棄。",
    "Address book" : "通訊錄",
    "Add contact to Birthday Calendar" : "將聯絡人新增至生日行事曆",
    "Exclude contact from Birthday Calendar" : "從生日行事曆排除聯絡人",
    "{title} at {organization}" : "{organization} 的 {title}",
    "Syntax error. Cannot open the contact." : "語法錯誤。無法開啟聯絡人。",
    "The contact does not exist on the server anymore." : "伺服器上不再存在該聯絡人。",
    "Unable to retrieve the contact from the server, please check your network connection." : "無法從伺服器擷取聯絡人，請檢查您的網路連線。",
    "An error occurred while trying to move the contact" : "嘗試移動聯絡人時發生錯誤",
    "An error occurred while trying to copy the contact" : "嘗試複製聯絡人時發生錯誤",
    "Unable to update contact" : "無法更新聯絡人",
    "Search contacts …" : "搜尋聯絡人……",
    "Add to {group}" : "新增至 {group}",
    "Remove {type}" : "移除 {type}",
    "Search {types}" : "搜尋 {types}",
    "Search for people to add" : "搜尋要新增的人",
    "No results" : "沒有結果",
    "Add to group" : "新增至群組",
    "Add {type}" : "新增 {type}",
    "New circle name" : "新的小圈圈名稱",
    "Personal circle" : "個人小圈圈",
    "This circle will only be visible to you. Other members will not be able to see or use it." : "此小圈圈僅有您可見。其他成員將無法看到或使用它。",
    "Local circle" : "本地小圈圈",
    "This circle will not be shared with the other instances of the global scale" : "這個小圈圈不會與全球的其他站台共享",
    "Create circle" : "建立小圈圈",
    "Loading members list …" : "正在載入成員清單……",
    "The list of members is only visible to members of this circle" : "成員清單僅有此小圈圈的成員可見",
    "You currently have no access to the member list" : "您目前無權存取成員清單",
    "Add members" : "新增成員",
    "Show circle details" : "顯示小圈圈詳細資訊",
    "Add to {circle}" : "新增至 {circle}",
    "Unable to get the recommendations list" : "無法取得建議清單",
    "Unable to get the results" : "無法取得結果",
    "Some members could not be added" : "無法新增部份成員",
    "There was an issue adding members to the circle" : "將成員新增至小圈圈時發生錯誤",
    "Accept membership request" : "接受成員資格請求",
    "Reject membership request" : "拒絕成員資格請求",
    "Manage level" : "管理等級",
    "Remove member" : "移除成員",
    "Pending" : "擱置中",
    "Promote as sole owner" : "將其權限升級為唯一擁有者",
    "Promote to {level}" : "將其權限升級為 {level}",
    "Demote to {level}" : "將其權限降級為 {level}",
    "Could not delete the member {displayName}" : "無法刪除成員 {displayName}",
    "Could not change the member level to {level}" : "無法變更成員等級至 {level}",
    "Could not accept membership request" : "無法接受成員請求",
    "Chart" : "圖表",
    "Select chart …" : "選取圖表……",
    "Select type" : "選取類型",
    "Select Date" : "選取日期",
    "Add contact in group" : "新增聯絡人到群組",
    "none" : "無",
    "Select option" : "選取選項",
    "Add property of this type" : "新增此類型的屬性",
    "New contact" : "新聯絡人",
    "Unable to create the contact." : "無法建立聯絡人",
    "Contact not found" : "找不到聯絡人",
    "Group {group} not found" : "找不到群組 {group}",
    "Close" : "關閉",
    "_{success} contact added to {name}_::_{success} contacts added to {name}_" : ["{success} 個聯絡人已新增至 {name}"],
    "_Adding {success} contact to {name}_::_Adding {success} contacts to {name}_" : ["已新增 {success} 個聯絡人至 {name}"],
    "_{count} error_::_{count} errors_" : ["{count} 個錯誤"],
    "_Importing %n contact into {addressbook}_::_Importing %n contacts into {addressbook}_" : ["正在匯入 %n 個聯絡人至 {addressbook}"],
    "_Done importing %n contact into {addressbook}_::_Done importing %n contacts into {addressbook}_" : ["完成匯入 %n 個聯絡人至 {addressbook}"],
    "Import" : "匯入",
    "Could not copy" : "無法複製",
    "Join circle" : "加入小圈圈",
    "You are about to leave {circle}.\nAre you sure?" : "您將要離開 {circle}。\n您確定嗎？",
    "Please confirm circle leave" : "請確認您要離開小圈圈",
    "Could not leave the circle {displayName}" : "無法離開小圈圈 {displayName}",
    "Unable to join the circle" : "無法加入小圈圈",
    "You are about to delete {circle}.\nAre you sure?" : "您將要刪除 {circle}。\n您確定嗎？",
    "Please confirm circle deletion" : "請確認您要刪除小圈圈",
    "Unable to delete the circle" : "無法刪除小圈圈",
    "Link copied to the clipboard" : "連結已複製到剪貼簿",
    "Could not copy link to the clipboard." : "無法複製連結至剪貼簿。",
    "Not grouped" : "未歸類",
    "Recently contacted" : "最近聯絡",
    "Organization chart" : "組織圖表",
    "Circles are groups of people that you can create yourself and with whom you can share data. They can be made up of other accounts or groups of accounts of the Nextcloud instance, but also of contacts from your address book or even external people by simply entering their e-mail addresses." : "小圈圈是您可以自行建立並與他們分享資料的一群人。其可以由 Nextcloud 站台的其他帳號或帳號群組所組成，但也可以由您通訊錄中的聯絡人組成，甚至可以透過輸入電子郵件地址來組成外部人員。",
    "Circle" : "小圈圈",
    "User" : "使用者",
    "Group" : "群組",
    "Email" : "電子郵件",
    "Contact" : "聯絡人",
    "Member" : "成員",
    "Moderator" : "主持人",
    "Admin" : "管理員",
    "Owner" : "擁有者",
    "Invites" : "邀請",
    "Anyone can request membership" : "任何人都可以請求成員資格",
    "Members need to accept invitation" : "成員必須接受邀請",
    "Memberships must be confirmed/accepted by a Moderator (requires Open)" : "成員資格必須由主持人（必須為開放小圈圈）確認／接受",
    "Members can also invite" : "成員也可以邀請",
    "Visibility" : "能見度",
    "Visible to everyone" : "對所有人可見",
    "Circle membership" : "小圈圈成員資格",
    "Prevent circle from being a member of another circle" : "避免小圈圈成為其他小圈圈的成員",
    "Users" : "使用者",
    "Email addresses" : "電子郵件地址",
    "Detailed name" : "詳細名稱",
    "Additional names" : "別名/中間名",
    "Prefix" : "前綴",
    "Suffix" : "後綴",
    "Nickname" : "暱稱",
    "Notes" : "筆記",
    "Website" : "網站",
    "Location" : "地點",
    "Federated Cloud ID" : "雲端聯邦 ID",
    "Home" : "住家",
    "Work" : "工作",
    "Other" : "其他",
    "Address" : "地址",
    "Post office box" : "郵政信箱",
    "Extended address" : "擴展地址",
    "City" : "城市",
    "State or province" : "州或省",
    "Postal code" : "郵遞區號",
    "Country" : "國家",
    "Birthday" : "生日",
    "Anniversary" : "週年",
    "Date of death" : "卒日",
    "Instant messaging" : "即時通訊",
    "Phone" : "電話",
    "Mobile" : "行動電話",
    "Work mobile" : "工作行動電話",
    "Home mobile" : "家用電話",
    "Fax" : "傳真",
    "Fax home" : "傳真（家）",
    "Fax work" : "傳真（公司）",
    "Pager" : "呼叫器",
    "Voice" : "語音",
    "Car" : "車子",
    "Work pager" : "工作呼叫器",
    "Manager" : "經理",
    "Social network" : "社群網路",
    "Relationship to you" : "與您的關係",
    "Spouse" : "配偶",
    "Child" : "小孩",
    "Mother" : "母親",
    "Father" : "父親",
    "Parent" : "父母",
    "Brother" : "兄弟",
    "Sister" : "姊妹",
    "Relative" : "親屬",
    "Friend" : "朋友",
    "Colleague" : "同事",
    "Assistant" : "助理",
    "Related contacts" : "相關聯絡人",
    "Agent" : "代理人",
    "Emergency" : "緊急",
    "Co-worker" : "同事",
    "Gender" : "性別",
    "Female" : "女性",
    "Male" : "男性",
    "None" : "無",
    "Unknown" : "不明",
    "Time zone" : "時區",
    "Spoken languages" : "會說的語言",
    "_{failed} contact failed to be read_::_{failed} contacts failed to be read_" : ["{failed} 個聯絡人讀取失敗"],
    "An error has occurred in circle(s). Check the console for more details." : "小圈圈中出現錯誤。請檢查主控台以取得更多詳細資訊。",
    "Unable to create circle {circleName}" : "無法建立小圈圈 {circleName}",
    "Unable to delete circle {circleId}" : "無法刪除小圈圈 {circleId}",
    "Unable to delete contact" : "無法刪除聯絡人"
},
"nplurals=1; plural=0;");
