OC.L10N.register(
    "contacts",
    {
    "Details" : "Munudoù",
    "Contacts" : "Darempredoù",
    "Add contacts" : "Ouzhpennañ darempredoù",
    "Loading …" : "O Kargañ ...",
    "General settings" : "Stummoù hollek",
    "Send email" : "Kas postel",
    "Circles" : "Kelc'hioù",
    "Download" : "Pellgargañ",
    "Rename" : "Adenvel",
    "Delete" : "Dilemel",
    "Copy link" : "Kopiañ al liamm",
    "Share with users or groups" : "Rannañ gant implijourienn pe strolladoù",
    "No users or groups" : "Implijourienn pe strodadoù ebet",
    "can edit" : "posuple eo embann",
    "Display name" : "Anv ardivink",
    "Password protection" : "Gwareziñ gant ur ger-tremen",
    "Save" : "Enrollañ",
    "Description" : "Deskrivadur",
    "Cancel" : "Arrest",
    "Invalid image" : "N'eo ket aotreet ar skeudenn",
    "Name" : "Anv",
    "Title" : "Titl",
    "Company" : "Embregerez",
    "Search contacts …" : "Klask darempred ...",
    "No results" : "Disoc'h ebet",
    "Pending" : "O c'hortoz",
    "Close" : "Seriñ",
    "Import" : "Emporzhiañ ",
    "User" : "Implijer",
    "Group" : "Stollad",
    "Email" : "Postel",
    "Admin" : "Merour",
    "Owner" : "Perc'henner",
    "Users" : "Implijer",
    "Website" : "Lec'hien web",
    "Location" : "Lec'hiadur",
    "Home" : "Degemer",
    "Work" : "Labour",
    "Other" : "All",
    "Address" : "Chom-lec'h",
    "City" : "Ker",
    "Country" : "Bro",
    "Birthday" : "Deiz-ha-bloaz",
    "None" : "Hini ebet",
    "Unknown" : "Dianv"
},
"nplurals=5; plural=((n%10 == 1) && (n%100 != 11) && (n%100 !=71) && (n%100 !=91) ? 0 :(n%10 == 2) && (n%100 != 12) && (n%100 !=72) && (n%100 !=92) ? 1 :(n%10 ==3 || n%10==4 || n%10==9) && (n%100 < 10 || n% 100 > 19) && (n%100 < 70 || n%100 > 79) && (n%100 < 90 || n%100 > 99) ? 2 :(n != 0 && n % 1000000 == 0) ? 3 : 4);");
