OC.L10N.register(
    "contacts",
    {
    "Details" : "Dettagli",
    "All contacts" : "Tutti i contatti",
    "Contacts" : "Contatti",
    "A contacts app for Nextcloud" : "Un'applicazione di contatti per Nextcloud",
    "The Nextcloud contacts app is a user interface for Nextcloud's CardDAV server. Easily sync contacts from various devices with your Nextcloud and edit them online.\n\n* 🚀 **Integration with other Nextcloud apps!** Currently Mail and Calendar – more to come.\n* 🎉 **Never forget a birthday!** You can sync birthdays and other recurring events with your Nextcloud Calendar.\n* 👥 **Sharing of Adressbooks!** You want to share your contacts with your friends or coworkers? No problem!\n* 🙈 **We’re not reinventing the wheel!** Based on the great and open SabreDAV library." : "L'applicazione Contatti di Nextcloud è un'interfaccia utente per il server CardDAV di Nextcloud. Sincronizza i contatti in modo semplice da diversi dispositivi con il tuo Nextcloud e li modifica in linea.\n\n* 🚀 **Integrazione con altre applicazioni di Nextcloud!** Attualmente Posta e Calendario – altre arriveranno.\n* 🎉 **Non dimenticare mai un compleanno!** Puoi sincronizzare i compleanni e gli altri eventi ricorrenti con il tuo calendario di Nextcloud.\n* 👥 **Condivisione di rubriche!** Desideri condividere i tuoi contatti con i tuoi amici o colleghi? Nessun problema!\n* 🙈 **Non stiamo reinventando la ruota!** Basata sull'ottima libreria open source SabreDAV.",
    "Copy to full name" : "Copia nel nome completo",
    "Omit year" : "Ometti l'anno",
    "Allow updating avatars from social media" : "Consenti l'aggiornamento degli avatar dalle reti sociali",
    "Please select a circle" : "Seleziona una cerchia",
    "Loading circle …" : "Caricamento cerchia …",
    "Your request to join this circle is pending approval" : "La tua richiesta di unirti a questa cerchia è in attesa di approvazione",
    "You are not a member of {circle}" : "Non sei un membro di {circle}",
    "There was an error fetching the member list" : "Si è verificato un errore durante il recupero della lista dei membri",
    "Loading contacts …" : "Caricamento contatti...",
    "There are no contacts yet" : "Non ci sono ancora contatti",
    "Create contact" : "Crea contatto",
    "There are no contacts in this group" : "Non ci sono contatti in questo gruppo",
    "Create contacts" : "Crea contatti",
    "Add contacts" : "Aggiungi contatti",
    "Loading …" : "Caricamento...",
    "Add member" : "Aggiungi membro",
    "Leave circle" : "Abbandona cerchia",
    "Delete circle" : "Elimina cerchia",
    "Contacts settings" : "Impostazioni Contatti",
    "General settings" : "Impostazioni generali",
    "Update avatars from social media" : "Aggiorna gli avatar dalle reti sociali",
    "(refreshed once per week)" : "(aggiornato una volta a settimana)",
    "Address books" : "Rubriche",
    "Export" : "Esporta",
    "Send email" : "Invia email",
    "Send email as BCC" : "Invia email come CCN",
    "Contact groups" : "Gruppo di contatti",
    "Create a new contact group" : "Crea un nuovo gruppo di contatti",
    "Contact group name" : "Nome gruppo contatti",
    "Circles" : "Cerchie",
    "Create a new circle" : "Crea una nuova cerchia",
    "Show all groups" : "Mostra tutti i gruppi",
    "Collapse groups" : "Contrai i gruppi",
    "Show all circles" : "Mostra tutte le cerchie",
    "Collapse circles" : "Contrai cerchie",
    "This group already exists" : "Questo gruppo esiste già",
    "This circle already exists" : "Questa cerchia esiste già",
    "An error happened during the creation of the circle" : "Si è verificato un errore durante la creazione della cerchia",
    "{addressbookname} (Disabled)" : "{addressbookname} (Disattivato)",
    "Download" : "Scarica",
    "Show" : "Mostra",
    "Rename" : "Rinomina",
    "Delete" : "Elimina",
    "Copied" : "Copiato",
    "Cannot copy" : "Impossibile copiare",
    "Copy link" : "Copia collegamento",
    "Toggling of address book was not successful" : "L'abilitazione della rubrica non è riuscita",
    "This will delete the address book and every contacts within it" : "Questo eliminerà la rubrica e ogni contatto in essa contenuto",
    "Delete {addressbook}?" : "Eliminare {addressbook}?",
    "Deletion of address book was not successful." : "L'eliminazione della rubrica non è riuscita.",
    "Renaming of address book was not successful." : "La rinomina della rubrica non è riuscita.",
    "_%n contact_::_%n contacts_" : ["%n contatto","%n contatti","%n contatti"],
    "_%n group_::_%n groups_" : ["%n gruppo","%n gruppi","%n gruppi"],
    "_Shared with {num} entity_::_Shared with {num} entities_" : ["Condiviso con {num} entità","Condiviso con {num} entità","Condiviso con {num} entità"],
    "Share with users or groups" : "Condividi con utenti o gruppi",
    "Share with users" : "Condividi con utenti",
    "No users or groups" : "Nessun utente o gruppo",
    "can edit" : "può modificare",
    "Unable to delete the share" : "Impossibile eliminare la condivisione",
    "Unable to change permissions" : "Impossibile cambiare i permessi",
    "Import contacts" : "Importa contatti",
    "Import into the {addressbookName} address book" : "Importa nella rubrica {addressbookName}",
    "Select local file" : "Seleziona file locale",
    "Import from files" : "Importa da file",
    "Importing is disabled because there are no address books available" : "L'importazione è  disabilitata poiché non ci sono rubriche disponibili",
    "Choose a vCard file to import" : "Scegli un file vCard da importare",
    "Add new address book" : "Aggiungi nuova rubrica",
    "An error occurred, unable to create the address book" : "Si è  verificato un errore, impossibile creare la rubrica",
    "First name" : "Nome",
    "Last name" : "Cognome",
    "Phonetic first name" : "Nome fonetico",
    "Phonetic last name" : "Cognome fonetico",
    "Display name" : "Nome visualizzato",
    "Last modified" : "Ultima modifica",
    "Sort by {sorting}" : "Ordina per {sorting}",
    "Manages" : "Gestisci",
    "Oversees" : "Supervisiona",
    "An error happened during the config change" : "Si è verificato un errore durante il cambio di configurazione",
    "Password protection" : "Protezione password",
    "Enforce password protection on files shared to this circle" : "Applica la protezione con password ai file condivisi in questa cerchia",
    "Use a unique password for all shares to this circle" : "Utilizza un'unica password per tutte le condivisioni in questa cerchia",
    "Unique password …" : "Password unica…",
    "Save" : "Salva",
    "Change unique password" : "Cambia password unica",
    "Failed to save password. Please try again later." : "Impossibile salvare la password. Riprova più tardi.",
    "Circle name" : "Nome cerchia",
    "Circle owned by {owner}" : "Proprietario cerchia: {owner}",
    "Request to join" : "Richiedi di entrare",
    "Description" : "Descrizione",
    "There is no description for this circle" : "Non c'è una descrizione per questa cerchia",
    "Enter a description for the circle" : "Inserisci una descrizione per questa cerchia",
    "An error happened during description sync" : "Si è verificato un errore durante la sincronizzazione della descrizione",
    "An error happened during name sync" : "Si è verificato un errore durante la sincronizzazione del nome",
    "Add more info" : "Aggiungi più informazioni",
    "More fields" : "Altri campi",
    "Crop contact photo" : "Ritaglia foto contatto",
    "Cancel" : "Annulla",
    "Upload a new picture" : "Carica una nuova immagine",
    "Choose from Files" : "Scegli da File",
    "Get from " : "Ottieni da",
    "Download picture" : "Scarica immagine",
    "Delete picture" : "Elimina immagine",
    "Please select a valid format" : "Seleziona un formato valido",
    "Invalid image" : "Immagine non valida",
    "Error cropping picture" : "Errore durante il ritaglio dell'immagine",
    "Pick an avatar" : "Scegli un avatar",
    "Error while processing the picture." : "Errore durante l'elaborazione dell'immagine.",
    "Avatar downloaded from social network" : "Avatar scaricato dalla rete sociale",
    "Avatar already up to date" : "Avatar già aggiornato",
    "Avatar download failed" : "Scaricamento dell'avatar non riuscito",
    "No contact selected" : "Nessun contatto selezionato",
    "Select a contact on the list to begin" : "Seleziona un contatto dall'elenco per iniziare",
    "Name" : "Nome",
    "Title" : "Titolo",
    "Company" : "Azienda",
    "This contact was broken and received a fix. Please review the content and click here to save it." : "Questo contatto era danneggiato e ha ricevuto una correzione. Rivedi il contenuto e fai clic qui per salvarlo.",
    "Edit" : "Modifica",
    "Clone contact" : "Clona contatto",
    "Generate QR Code" : "Genera codice QR",
    "Contact vCard as QR code" : "vCard del contatto come codice QR",
    "Pick an address book" : "Scegli una rubrica",
    "Select address book" : "Seleziona rubrica",
    "Go to talk conversation" : "Vai alla conversazione",
    "View profile" : "Vedi profilo",
    "This contact is in read-only mode. You do not have permission to edit this contact." : "Questo contatto è in modalità di sola lettura. Non hai i permessi per modificare questo contatto.",
    "The contact you were trying to edit has changed. Please manually refresh the contact. Any further edits will be discarded." : "Il contatto che stavi tentando di modificare è cambiato. Aggiorna manualmente il contatto. Qualsiasi modifica ulteriore sarà scartata.",
    "Address book" : "Rubrica",
    "Add contact to Birthday Calendar" : "Aggiungi un contatto al Calendario dei Compleanni",
    "Exclude contact from Birthday Calendar" : "Escludere il contatto dal calendario dei compleanni",
    "{title} at {organization}" : "{title} in {organization}",
    "Syntax error. Cannot open the contact." : "Errore di sintassi. Impossibile aprire il contatto.",
    "The contact does not exist on the server anymore." : "Il contatto non esiste più nel server.",
    "Unable to retrieve the contact from the server, please check your network connection." : "Impossibile recuperare il contatto dal server, controlla la connessione di rete.",
    "An error occurred while trying to move the contact" : "Si è verificato un errore durante il tentativo di spostare il contatto",
    "An error occurred while trying to copy the contact" : "Si è verificato un errore durante il tentativo di copiare il contatto",
    "Unable to update contact" : "Impossibile aggiornare il contatto",
    "Search contacts …" : "Cerca contatti...",
    "Add to {group}" : "Aggiungi a {group}",
    "Remove {type}" : "Rimuovi {type}",
    "Search {types}" : "Cerca {types}",
    "Search for people to add" : "Cerca persone da aggiungere",
    "No results" : "Nessun risultato",
    "Add to group" : "Aggiungi a gruppo",
    "Add {type}" : "Aggiungi {type}",
    "New circle name" : "Nuovo nome della cerchia",
    "Personal circle" : "Cerchia personale",
    "This circle will only be visible to you. Other members will not be able to see or use it." : "Questa cerchia sarà visibile solo a te. Gli altri membri non potranno vederla o usarla.",
    "Local circle" : "Cerchia locale",
    "This circle will not be shared with the other instances of the global scale" : "Questa cerchia non sarà condivisa con altre istanze su scala globale",
    "Create circle" : "Crea cerchia",
    "Loading members list …" : "Caricamento lista membri …",
    "The list of members is only visible to members of this circle" : "La lista dei membri è visibile solo ai membri di questa cerchia",
    "You currently have no access to the member list" : "Al momento non hai accesso all'elenco dei membri",
    "Add members" : "Aggiungi membri",
    "Show circle details" : "Mostra dettagli cerchia",
    "Add to {circle}" : "Aggiungi a {circle}",
    "Unable to get the recommendations list" : "Impossibile recuperare la lista dei consigli",
    "Unable to get the results" : "Impossibile recuperare i risultati",
    "Some members could not be added" : "Alcuni membri non sono stati aggiunti",
    "There was an issue adding members to the circle" : "Si è verificato un errore durante l'aggiunta di membri alla cerchia",
    "Accept membership request" : "Accetta la richiesta di adesione",
    "Reject membership request" : "Rifiuta la richiesta di adesione",
    "Manage level" : "Gestisci livello",
    "Remove member" : "Rimuovi membro",
    "Pending" : "In attesa",
    "Promote as sole owner" : "Promuovi come unico proprietario",
    "Promote to {level}" : "Promuovi a {level}",
    "Demote to {level}" : "Declassa a {level}",
    "Could not delete the member {displayName}" : "Impossibile eliminare il membro {displayName}",
    "Could not change the member level to {level}" : "Impossibile cambiare il livello del membro a {level}",
    "Could not accept membership request" : "Impossibile accettare la richiesta di adesione",
    "Chart" : "Grafico",
    "Select chart …" : "Seleziona grafico...",
    "Select type" : "Seleziona tipo",
    "Select Date" : "Seleziona data",
    "Add contact in group" : "Aggiungi contatto a gruppo",
    "none" : "nessuno",
    "Select option" : "Seleziona opzione",
    "Add property of this type" : "Aggiungi proprietà di questo tipo",
    "New contact" : "Nuovo contatto",
    "Unable to create the contact." : "Impossibile creare il contatto.",
    "Contact not found" : "Contatto non trovato",
    "Group {group} not found" : "Gruppo {group} non trovato",
    "Close" : "Chiudi",
    "_{success} contact added to {name}_::_{success} contacts added to {name}_" : ["{success} contatto aggiunto a {name}","{success} contatti aggiunti a {name}","{success} contatti aggiunti a {name}"],
    "_Adding {success} contact to {name}_::_Adding {success} contacts to {name}_" : ["Aggiunta di {success} contatto a {name}","Aggiunta di {success} contatti a {name}","Aggiunta di {success} contatti a {name}"],
    "_{count} error_::_{count} errors_" : ["{count} errore","{count} errori","{count} errori"],
    "_Importing %n contact into {addressbook}_::_Importing %n contacts into {addressbook}_" : ["Importazione di %n contatto in {addressbook}","Importazione di %n contatti in {addressbook}","Importazione di %n contatti in {addressbook}"],
    "_Done importing %n contact into {addressbook}_::_Done importing %n contacts into {addressbook}_" : ["Importazione completata di %n contatto in {addressbook}","Importazione completata di %n contatti in {addressbook}","Importazione completata di %n contatti in {addressbook}"],
    "Import" : "Importa",
    "Could not copy" : "Impossibile copiare",
    "Join circle" : "Unisciti alla cerchia",
    "You are about to leave {circle}.\nAre you sure?" : "Stai per abbandonare {circle}.\nSei sicuro?",
    "Please confirm circle leave" : "Conferma l'abbandono della cerchia",
    "Could not leave the circle {displayName}" : "Impossibile abbandonare la cerchia {displayName}",
    "Unable to join the circle" : "Impossibile unirsi alla cerchia",
    "You are about to delete {circle}.\nAre you sure?" : "Stai per eliminare {circle}.\nSei sicuro?",
    "Please confirm circle deletion" : "Conferma l'eliminazione della cerchia",
    "Unable to delete the circle" : "Impossibile eliminare la cerchia",
    "Link copied to the clipboard" : "Collegamento copiato negli appunti",
    "Could not copy link to the clipboard." : "Impossibile copiare negli appunti il collegamento.",
    "Not grouped" : "Non raggruppati",
    "Recently contacted" : "Contattati di recente",
    "Organization chart" : "Grafico organizzativo",
    "Circles are groups of people that you can create yourself and with whom you can share data. They can be made up of other accounts or groups of accounts of the Nextcloud instance, but also of contacts from your address book or even external people by simply entering their e-mail addresses." : "Le cerchie sono gruppi di persone che puoi creare con cui condividere dati. Possono essere composte da altri account o gruppi di account dell'istanza di Nextcloud, ma anche da contatti della tua rubrica o anche da persone esterne semplicemente inserendo i loro indirizzi email.",
    "Circle" : "Cerchia",
    "User" : "Utente",
    "Group" : "Gruppo",
    "Email" : "Posta elettronica",
    "Contact" : "Contatto",
    "Member" : "Membro",
    "Moderator" : "Moderatore",
    "Admin" : "Amministratore",
    "Owner" : "Proprietario",
    "Invites" : "Inviti",
    "Anyone can request membership" : "Chiunque può chiedere di entrare",
    "Members need to accept invitation" : "I membri devono accettare un invito",
    "Memberships must be confirmed/accepted by a Moderator (requires Open)" : "Le adesioni devono essere confermate/accettate da un moderatore (richiede \"Aperto\")",
    "Members can also invite" : "I membri possono anche invitare",
    "Visibility" : "Visibilità",
    "Visible to everyone" : "Visibile a tutti",
    "Circle membership" : "Iscrizione alla cerchia",
    "Prevent circle from being a member of another circle" : "Impedisci alla cerchia di essere membro di un'altra cerchia",
    "Users" : "Utenti",
    "Email addresses" : "Indirizzi email",
    "Detailed name" : "Nome dettagliato",
    "Additional names" : "Nomi aggiuntivi",
    "Prefix" : "Prefisso",
    "Suffix" : "Suffisso",
    "Nickname" : "Pseudonimo",
    "Notes" : "Note",
    "Website" : "Sito web",
    "Location" : "Posizione",
    "Federated Cloud ID" : "ID di cloud federata",
    "Home" : "Home",
    "Work" : "Lavoro",
    "Other" : "Altro",
    "Address" : "Indirizzo",
    "Post office box" : "Casella postale",
    "Extended address" : "Indirizzo esteso",
    "City" : "Città",
    "State or province" : "Stato o regione",
    "Postal code" : "CAP",
    "Country" : "Nazione",
    "Birthday" : "Compleanno",
    "Anniversary" : "Anniversario",
    "Date of death" : "Data di morte",
    "Instant messaging" : "Messaggistica istantanea",
    "Phone" : "Telefono",
    "Mobile" : "Cellulare",
    "Work mobile" : "Cellulare lavoro",
    "Home mobile" : "Cellulare personale",
    "Fax" : "Fax",
    "Fax home" : "Fax casa",
    "Fax work" : "Fax lavoro",
    "Pager" : "Cercapersone",
    "Voice" : "Voce",
    "Car" : "Automobile",
    "Work pager" : "Cercapersone lavoro",
    "Manager" : "Responsabile",
    "Social network" : "Rete sociale",
    "Relationship to you" : "Rapporto con te",
    "Spouse" : "Coniuge",
    "Child" : "Figlio",
    "Mother" : "Madre",
    "Father" : "Padre",
    "Parent" : "Genitore",
    "Brother" : "Fratello",
    "Sister" : "Sorella",
    "Relative" : "Parente",
    "Friend" : "Amico",
    "Colleague" : "Collega",
    "Assistant" : "Assistente",
    "Related contacts" : "Contatti correlati",
    "Agent" : "Agente",
    "Emergency" : "Emergenza",
    "Co-worker" : "Collega",
    "Gender" : "Sesso",
    "Female" : "Femmina",
    "Male" : "Maschio",
    "None" : "Nessuno",
    "Unknown" : "Sconosciuto",
    "Time zone" : "Fuso orario",
    "Spoken languages" : "Lingue parlate",
    "_{failed} contact failed to be read_::_{failed} contacts failed to be read_" : ["lettura di {failed} contatto non riuscita","lettura di {failed} contatti non riuscita","lettura di {failed} contatti non riuscita"],
    "An error has occurred in circle(s). Check the console for more details." : "Si è verificato un errore in una o più cerchie. Controlla la console per altri dettagli.",
    "Unable to create circle {circleName}" : "Impossibile creare la cerchia {circleName}",
    "Unable to delete circle {circleId}" : "Impossibile eliminare la cerchia {circleId}",
    "Unable to delete contact" : "Impossibile eliminare il contatto"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
