OC.L10N.register(
    "contacts",
    {
    "Details" : "التفاصيل",
    "All contacts" : "كل جهات الإتصال",
    "Contacts" : "جهات الاتصال",
    "A contacts app for Nextcloud" : "تطبيق \"جهات الاتصال\" Contacts لنكست كلاود",
    "The Nextcloud contacts app is a user interface for Nextcloud's CardDAV server. Easily sync contacts from various devices with your Nextcloud and edit them online.\n\n* 🚀 **Integration with other Nextcloud apps!** Currently Mail and Calendar – more to come.\n* 🎉 **Never forget a birthday!** You can sync birthdays and other recurring events with your Nextcloud Calendar.\n* 👥 **Sharing of Adressbooks!** You want to share your contacts with your friends or coworkers? No problem!\n* 🙈 **We’re not reinventing the wheel!** Based on the great and open SabreDAV library." : "تطبيق \"جهات الاتصال\" Contacts لنكست كلاود هو واجهة مستخدم لخادوم CardDAV الخاص بـنكست كلاود. يمكنك مزامنة جهات الاتصال بسهولة من مختلف الأجهزة مع نكست كلاود وتحريرها عبر الإنترنت. \n\n* 🚀 ** التكامل مع تطبيقات نكست كلاود الأخرى! ** حاليًا البريد والتقويم - المزيد في المستقبل. \n* 🎉 ** يمكنك مزامنة أعياد الميلاد والأحداث المتكررة الأخرى مع تقويم نكست كلاود الخاص بك. \n* 👥 ** مشاركة دفاتر العناوين! ** تريد مشاركة جهات الاتصال الخاصة بك مع أصدقائك أو زملائك في العمل؟ لا مشكلة! \n* 🙈 ** نحن لا نعيد اختراع العجلة! ** استنادًا إلى مكتبة SabreDAV الرائعة والمفتوحة.",
    "Copy to full name" : "إنسخ إلى الإسم الكامل",
    "Omit year" : "تَجَاهَل السَّنَة",
    "Allow updating avatars from social media" : "السماح بتحديث التجسيد الرمزي avatar من وسائل التواصل الاجتماعي.",
    "Please select a circle" : "إختر دائرة Circle، من فضلك",
    "Loading circle …" : "تحميل الدائرة Circle ...",
    "Your request to join this circle is pending approval" : "طلبك الانضمام لهذه الدائرة في انتظار الموافقة",
    "You are not a member of {circle}" : "أنت لست عضواً في {circle}",
    "There was an error fetching the member list" : "حدث خطأٌ في جلب أعضاء القائمة",
    "Loading contacts …" : "تحميل جهات الاتصال ...",
    "There are no contacts yet" : "لا توجد أي جهات اتصال بعدُ",
    "Create contact" : "أنشِيء جهة اتصال",
    "There are no contacts in this group" : "لا توجد أي جهات اتصال في هذه المجموعة",
    "Create contacts" : "أنشِيء جهات اتصال",
    "Add contacts" : "اضافة جهات اتصال",
    "Loading …" : "التحميل جارٍ …",
    "Add member" : "أضِف عُضْواً",
    "Leave circle" : "غادِر الدائرة",
    "Delete circle" : "إحذِف الدائرة",
    "Contacts settings" : "إعدادات جهات الاتصال",
    "General settings" : "الإعدادات العامة",
    "Update avatars from social media" : "تحديث التجسيد الرمزي avatar من وسائط التواصل الاجتماعي",
    "(refreshed once per week)" : "(يتم تحديثه مرةً في الأسبوع)",
    "Address books" : "دفاتر العناوين",
    "Export" : "تصدير",
    "Send email" : "إرسال بريد",
    "Send email as BCC" : "إرسل الإيميل كـنسخة كربونية مخفية BCC",
    "Contact groups" : "مجموعات الاتصال",
    "Create a new contact group" : "إنشاء مجموعة اتصال جديدة",
    "Contact group name" : "اسم مجموعة الاتصال",
    "Circles" : "دائرة Circle",
    "Create a new circle" : "إنشاء دائرة Circle جديدة",
    "Show all groups" : "عرض كل المجموعات",
    "Collapse groups" : "تقويض collapse المجموعات",
    "Show all circles" : "عرض كل المجموعات",
    "Collapse circles" : "تقويض collapse الدوائر",
    "This group already exists" : "المجموعة موجودة مسبقاً",
    "This circle already exists" : "الدائرة موجودة مسبقاً",
    "An error happened during the creation of the circle" : "حدث خطأ أثناء إنشاء الدائرة",
    "{addressbookname} (Disabled)" : "{addressbookname} (معطل)",
    "Download" : "تحميل",
    "Show" : "عرض",
    "Rename" : "تعديل الإسم",
    "Delete" : "حذف",
    "Copied" : "نُسخت ",
    "Cannot copy" : "تعذّر النسخ",
    "Copy link" : "نسخ الرابط",
    "Toggling of address book was not successful" : "تعذّر تبديل دفتر العناوين",
    "This will delete the address book and every contacts within it" : "هذا الإجراء سيؤدي إلى حذف دفتر العناوين و جميع ما فيه من جهات اتصال",
    "Delete {addressbook}?" : "حذف {addressbook}؟",
    "Deletion of address book was not successful." : "تعذّر حذف دفتر العناوين",
    "Renaming of address book was not successful." : "تعذّرت إعادة تسمية دفتر العناوين",
    "_%n contact_::_%n contacts_" : ["%n جهات اتصال","%n جهة اتصال","%n جهات اتصال","%n جهات اتصال","%n جهات اتصال","%n جهات اتصال"],
    "_%n group_::_%n groups_" : ["%n مجموعات","%n مجموعة","%n مجموعات","%n مجموعات","%n مجموعات","%n مجموعات"],
    "_Shared with {num} entity_::_Shared with {num} entities_" : ["تم مشاركته مع {num} كيانات","تم مشاركته مع {num} كيان","تم مشاركته مع {num} كيانات","تم مشاركته مع {num} كيانات","تم مشاركته مع {num} كيانات","تم مشاركته مع {num} كيانات"],
    "Share with users or groups" : "شارِك مع مستخدمين او مجموعات",
    "Share with users" : "مشاركة مع المستخدمين",
    "No users or groups" : "لا يوجد مستخدمون أو مجموعات",
    "can edit" : "يمكن التعديل",
    "Unable to delete the share" : "تعذّر حذف المشاركة",
    "Unable to change permissions" : "تعذّر تغيير الأذونات",
    "Import contacts" : "إستيراد جهات الاتصال",
    "Import into the {addressbookName} address book" : "الإستيراد إلى دفتر العناوين {addressbookName} ",
    "Select local file" : "إختر ملفّاً محليّاً",
    "Import from files" : "إستيراد من تطبيق الملفات ",
    "Importing is disabled because there are no address books available" : "تمّ إيقاف الاستيراد لعدم وجود دفتر عناوين متاح",
    "Choose a vCard file to import" : "إختر ملف vCard لاستيراده",
    "Add new address book" : "أضف دفتر عناوين جديد",
    "An error occurred, unable to create the address book" : "حدث خطأ؛ تعذّر إنشاء دفتر العناوين",
    "First name" : "الإسم",
    "Last name" : "اللقب",
    "Phonetic first name" : "الاسم الأول نُطقاً",
    "Phonetic last name" : "الاسم الأخير نُطقاً",
    "Display name" : "الاسم المعروض",
    "Last modified" : "آخر تعديل",
    "Sort by {sorting}" : "الترتيب بحسب {sorting}",
    "Manages" : "يُدير",
    "Oversees" : "يُشرف على",
    "An error happened during the config change" : "حدث خطأ أثناء تعديل التهيئة",
    "Password protection" : "الحماية بكلمة السر",
    "Enforce password protection on files shared to this circle" : "فرض الحماية بكلمة سر للملفات المُشارَكة مع هذه الدائرة",
    "Use a unique password for all shares to this circle" : "استعمل كلمة سر مُتفرّدة لكل المشاركات مع هذه الدائرة",
    "Unique password …" : "كلمة سر مُتفرّدة ...",
    "Save" : "Save",
    "Change unique password" : "تغيير كلمة السر المُتفرّدة",
    "Failed to save password. Please try again later." : "تعذّر حفظ كلمة السر. رجاءً، حاول مرة أخرى لاحقاً.",
    "Circle name" : "اسم الدائرة",
    "Circle owned by {owner}" : "الدائرة يملكها {owner}",
    "Request to join" : "طلب انضمام",
    "Description" : "الوصف",
    "There is no description for this circle" : "لا يوجد نص يصف هذه الدائرة",
    "Enter a description for the circle" : "أدخل نصاً يصف هذه الدائرة",
    "An error happened during description sync" : "حدث خطأ أثناء مزامنة الوصف",
    "An error happened during name sync" : "حدث خطأ أثناء مزامنة الاسم",
    "Add more info" : "أضِف معلومات أكثر",
    "More fields" : "حقول أكثر",
    "Crop contact photo" : "قصقصة crop صورة صاحب جهة الاتصال",
    "Cancel" : "إلغاء",
    "Upload a new picture" : "تحميل صورة جديدة",
    "Choose from Files" : "اختر من الملفات",
    "Get from " : "خذ من",
    "Download picture" : "تنزيل الصورة",
    "Delete picture" : "حذف الصورة",
    "Please select a valid format" : "رجاءً، إختر نسقاً صحيحاً valid format",
    "Invalid image" : "الصورة غير صالحة",
    "Error cropping picture" : "خطأ أثناء قصقصة الصورة cropping",
    "Pick an avatar" : "إختر تجسيداً رمزيّاً avatar",
    "Error while processing the picture." : "حدث خطأ أثناء معالجة الصورة.",
    "Avatar downloaded from social network" : "تمّ تنزيل التجسيد الرمزي avatar من وسائط التواصل الاجتماعي",
    "Avatar already up to date" : "التجسيد الرمزي avatar على آخر تحديث",
    "Avatar download failed" : "فشل تحميل التجسيد الرمزي avatar",
    "No contact selected" : "لم يتم تحديد جهة اتصال",
    "Select a contact on the list to begin" : "حدّد جهة اتصال في القائمة للبدء",
    "Name" : "الاسم",
    "Title" : "الصفة",
    "Company" : "جهة العمل",
    "This contact was broken and received a fix. Please review the content and click here to save it." : "تمّ قطع جهة الاتصال هذه و تمّ إصلاحها. يرجى مراجعة المحتوى والنقر هنا لحفظه.",
    "Edit" : "تعديل",
    "Clone contact" : "استنساخ الاتصال",
    "Generate QR Code" : "توليد كود QR",
    "Contact vCard as QR code" : "بطاقة اتصال Contact vCard في صورة كود QR",
    "Pick an address book" : "إختر دفتر عناوين",
    "Select address book" : "إختر دفتر العناوين",
    "Go to talk conversation" : "إذهَب إلى محادثة talk",
    "View profile" : "إعرِض الملف الشخصي",
    "Media shares with you" : "وسائط تمّت مُشارَكتها معك",
    "Talk conversations with you" : "مُحادثاتك",
    "Calendar events with you" : "أحداثك على التقويم",
    "Deck cards with you" : "بطاقات لك على الرقعة",
    "No shared items with this contact" : "لا توجد عناصر مُشارَكة مع جهة الاتصال هذه",
    "This contact is in read-only mode. You do not have permission to edit this contact." : "جهة الاتصال هذه في وضع القراءة فقط. ليس لديك إذن لتعديل جهة الاتصال هذه.",
    "The contact you were trying to edit has changed. Please manually refresh the contact. Any further edits will be discarded." : "تم تغيير جهة الاتصال التي كنت تحاول تحريرها. يرجى تحديث جهة الاتصال يدويًا. سيتم تجاهل أي تعديلات أخرى.",
    "Address book" : "دفتر العناوين",
    "Add contact to Birthday Calendar" : "أضف جهات اتصال إلى تقويم أعياد الميلاد",
    "Exclude contact from Birthday Calendar" : "إستبعد جهة اتصال من تقويم أعياد الميلاد",
    "{title} at {organization}" : "{title} في {organization}",
    "Syntax error. Cannot open the contact." : "خطأ في بناء الجملة syntax. لا يمكن فتح جهة الاتصال.",
    "The contact does not exist on the server anymore." : "لم تعد جهة الاتصال هذه موجودة على الخادوم.",
    "Unable to retrieve the contact from the server, please check your network connection." : "تعذر استرداد جهة الاتصال من الخادوم ، يرجى التحقق من اتصال الشبكة.",
    "An error occurred while trying to move the contact" : "حدث خطأ أثناء محاولة نقل جهة الاتصال",
    "An error occurred while trying to copy the contact" : "حدث خطأ أثناء محاولة نسخ جهة الاتصال",
    "Unable to update contact" : "تعذّر تحديث جهة الاتصال",
    "Search contacts …" : "البحث عن جهات الإتصال",
    "Add to {group}" : "أضِف إلى {group}",
    "Remove {type}" : "إحذِف {type}",
    "Search {types}" : "بحث {types}",
    "Search for people to add" : "البحث عن أشخاص لإضافتهم",
    "No results" : "لا توجد نتائج",
    "Add to group" : "إضافة إلى مجموعة",
    "Add {type}" : "أضِف {type}",
    "New circle name" : "اسم دائرة جديدة",
    "Personal circle" : "دائرة شخصية",
    "This circle will only be visible to you. Other members will not be able to see or use it." : "ستكون هذه الدائرة مرئيةً لك أنت فقط. لن يتمكن الأعضاء الآخرون من رؤيتها أو استخدامها.",
    "Local circle" : "دائرة محلية",
    "This circle will not be shared with the other instances of the global scale" : "لن تتم مشاركة هذه الدائرة مع الخوادم الأخرى",
    "Create circle" : "أنشيء دائرة",
    "Loading members list …" : "تحميل قائمة الأعضاء ...",
    "The list of members is only visible to members of this circle" : "قائمة الأعضاء هذه يراها فقط أعضاء هذه الدائرة",
    "You currently have no access to the member list" : "لا يحق لك حاليّاً الوصول إلى قائمة الأعضاء",
    "Add members" : "أضِف أعضاءً",
    "Show circle details" : "أعرُض تفاصيل الدائرة ",
    "Add to {circle}" : "أضِف إلى {circle}",
    "Unable to get the recommendations list" : "تعذّر الحصول على قائمة التوصيات",
    "Unable to get the results" : "تعذّر الحصول على النتائج",
    "Some members could not be added" : "تعذّرت إضافة بعض الأعضاء",
    "There was an issue adding members to the circle" : "حدث خطأ أثناء إضافة أعضاء إلى الدائرة",
    "Accept membership request" : "قبول طلبات العضوية",
    "Reject membership request" : "رفض طلبات العضوية",
    "Manage level" : "إدارة المراتب",
    "Remove member" : "حذف عضو",
    "Pending" : "في انتظار الموافقة",
    "Promote as sole owner" : "ترقية المرتبة كمالكٍ وحيدٍ",
    "Promote to {level}" : "ترقية المرتبة إلى {level}",
    "Demote to {level}" : "خفض المرتبة إلى {level}",
    "Could not delete the member {displayName}" : "تعذّر حذف العضو {displayName}",
    "Could not change the member level to {level}" : "تعذّر تغيير مرتبة العضو إلى  {level}",
    "Could not accept membership request" : "تعذّر قبول طلب العضوية",
    "Chart" : "شكل Chart",
    "Select chart …" : "إختر شكلاً ...",
    "Select type" : "إختر نوعاً",
    "Select Date" : "اختر التاريخ ",
    "Add contact in group" : "أضِف جهة اتصالٍ في المجموعة",
    "none" : "غير محدد",
    "Select option" : "حدّد خياراً",
    "Add property of this type" : "أضِف خاصّيّةً property من هذا النوع ",
    "New contact" : "جهة إتصال جديدة",
    "Unable to create the contact." : "تعذّر إنشاء جهة الاتصال",
    "Contact not found" : "جهة الاتصال غير موجودة",
    "Group {group} not found" : "المجموعة {group} غير موجودة",
    "Close" : "إغلاق",
    "_{success} contact added to {name}_::_{success} contacts added to {name}_" : ["{success} أضيفت جهات الاتصال إلى {name}","{success} أضيفت جهة الاتصال إلى {name}","{success} أضيفت جهات الاتصال إلى {name}","{success} أضيفت جهات الاتصال إلى {name}","{success} أضيفت جهات الاتصال إلى {name}","{success} أضيفت جهات الاتصال إلى {name}"],
    "_Adding {success} contact to {name}_::_Adding {success} contacts to {name}_" : ["جار {success} إضافة جهات اتصال إلى {name}","جار {success} إضافة جهة اتصال إلى {name}","جار {success} إضافة جهات اتصال إلى {name}","جار {success} إضافة جهات اتصال إلى {name}","جار {success} إضافة جهات اتصال إلى {name}","جار {success} إضافة جهات اتصال إلى {name}"],
    "_{count} error_::_{count} errors_" : ["{count} أخطاء","{count} خطأ","{count} أخطاء","{count} أخطاء","{count} أخطاء","{count} أخطاء"],
    "_Importing %n contact into {addressbook}_::_Importing %n contacts into {addressbook}_" : ["جار استيراد %n جهات اتصال إلى {addressbook}","جار استيراد %n جهة اتصال إلى {addressbook}","جار استيراد %n جهات اتصال إلى {addressbook}","جار استيراد %n جهات اتصال إلى {addressbook}","جار استيراد %n جهات اتصال إلى {addressbook}","جار استيراد %n جهات اتصال إلى {addressbook}"],
    "_Done importing %n contact into {addressbook}_::_Done importing %n contacts into {addressbook}_" : ["تم استيراد %nجهات اتصال إلى {addressbook}","تم استيراد %n جهة اتصال إلى {addressbook}","تم استيراد %nجهات اتصال إلى {addressbook}","تم استيراد %nجهات اتصال إلى {addressbook}","تم استيراد  %nجهات اتصال إلى {addressbook}","تم استيراد %n جهات اتصال إلى {addressbook}"],
    "Import" : "استيراد",
    "Could not copy" : "تعذّر النسخ",
    "Join circle" : "إنضم للدائرة",
    "You are about to leave {circle}.\nAre you sure?" : "أنت على وشك مغادرة الدائرة {circle}.\nهل أنت متأكد؟",
    "Please confirm circle leave" : "رجاءً، أكّد رغبتك في مغادرة الدائرة",
    "Could not leave the circle {displayName}" : "تعذّرت مغادرة الدائرة {displayName}",
    "Unable to join the circle" : "تعذّر الانضمام إلى الدائرة",
    "You are about to delete {circle}.\nAre you sure?" : "أنت على وشك حذف الدائرة {circle}.\nهل أنت متأكد؟",
    "Please confirm circle deletion" : "رجاءً، أكّد رغبتك في حذف الدائرة",
    "Unable to delete the circle" : "تعذّر حذف الدائرة",
    "Link copied to the clipboard" : "تمّ نسخ الرابط إلى الحافظة",
    "Could not copy link to the clipboard." : "تعذّر نسخ الرابط إلى الحافظة",
    "Not grouped" : "غير مُجمّعٍ",
    "Recently contacted" : "تمّ التواصل معه مُؤخّراً",
    "Organization chart" : "الهيكل التنظيمي",
    "Circles are groups of people that you can create yourself and with whom you can share data. They can be made up of other accounts or groups of accounts of the Nextcloud instance, but also of contacts from your address book or even external people by simply entering their e-mail addresses." : "الدوائر\"Circles\" هي مجموعات من الأشخاص يمكنك انشاؤها بنفسك ويمكنك مشاركة البيانات معهم. يمكن أن تتكون من حسابات أو مجموعات أخرى على مثيل نكست كلاود. ولكن قد تتكون أيضًا من جهات اتصال من دفتر العناوين الخاص بك أو حتى من أشخاص خارج خادومك عن طريق إدخال عناوين البريد الإلكتروني الخاصة بهم.",
    "Circle" : "دائرة ",
    "User" : "المستخدم",
    "Group" : "المجموعة",
    "Email" : "البريد الإلكترونى",
    "Contact" : "جهة اتصال",
    "Member" : "عضو",
    "Moderator" : "مشرِف",
    "Admin" : "مدير",
    "Owner" : "مالك",
    "Invites" : "يدعو",
    "Anyone can request membership" : "يمكن لأي شخص طلب العضوية",
    "Members need to accept invitation" : "يلزم أن يقبل العضو الدعوة",
    "Memberships must be confirmed/accepted by a Moderator (requires Open)" : "يلزم تأكيد/قبول العضويات من قِبَل المنسق (تستلزم الفتح)",
    "Members can also invite" : "يمكن للأعضاء أيضاً إرسال دعوات العضوية",
    "Visibility" : "الرؤية",
    "Visible to everyone" : "مرئي للجميع",
    "Circle membership" : "عضوية الدائرة",
    "Prevent circle from being a member of another circle" : "إمنع الدائرة من أن تكون عضواً في دائرة أخرى",
    "Users" : "المستخدمين",
    "Email addresses" : "عناوين البريد الالكتروني",
    "Detailed name" : "الاسم بالتفصيل",
    "Additional names" : "الأسماء الإضافية",
    "Prefix" : "بادئة",
    "Suffix" : "لاحقة",
    "Nickname" : "اللقب",
    "Notes" : "ملاحظات",
    "Website" : "موقع إلكتروني",
    "Location" : "المكان",
    "Federated Cloud ID" : "مُعرّف السحابة الاتحاديّة",
    "Home" : "المنزل",
    "Work" : "العمل",
    "Other" : "آخر",
    "Address" : "العنوان",
    "Post office box" : "صندوق البريد",
    "Extended address" : "عنوان مُوسّع Extended address",
    "City" : "المدينة",
    "State or province" : "الولاية أو المقاطعة",
    "Postal code" : "الرمز البريدي",
    "Country" : "البلد",
    "Birthday" : "عيد ميلاد",
    "Anniversary" : "ذكرى سنوية",
    "Date of death" : "تاريخ وفاة",
    "Instant messaging" : "مراسلة فورية",
    "Phone" : "الهاتف",
    "Mobile" : "النقّال",
    "Work mobile" : "نقّال العمل",
    "Home mobile" : "نقّال البيت",
    "Fax" : "الفاكس",
    "Fax home" : "فاكس المنزل",
    "Fax work" : "فاكس العمل",
    "Pager" : "المُنادِي pager",
    "Voice" : "صوت",
    "Car" : "سيارة",
    "Work pager" : "مُنادِي العمل Work pager",
    "Manager" : "مدير",
    "Social network" : "شبكة اجتماعية",
    "Relationship to you" : "العلاقة معك",
    "Spouse" : "زوج/زوجة",
    "Child" : "طفل",
    "Mother" : "أم",
    "Father" : "أب",
    "Parent" : "والدين",
    "Brother" : "أخ",
    "Sister" : "أخت",
    "Relative" : "مرتبط",
    "Friend" : "صديق",
    "Colleague" : "زميل",
    "Assistant" : "مُساعِد",
    "Related contacts" : "جهات الاتصال ذات العلاقة",
    "Agent" : "مندوب",
    "Emergency" : "إسعاف/طوارئ",
    "Co-worker" : "زميل عمل",
    "Gender" : "الجنس",
    "Female" : "أنثى",
    "Male" : "ذكر",
    "None" : "لا شيء",
    "Unknown" : "مجهول",
    "Time zone" : "المنطقة الزمنية",
    "Spoken languages" : "اللغات المحكية",
    "_{failed} contact failed to be read_::_{failed} contacts failed to be read_" : ["{failed} فشل قراءة جهات الاتصال","{failed} فشل قراءة جهة الاتصال","{failed} فشل قراءة جهات الاتصال","{failed} فشل قراءة جهات الاتصال","{failed} فشل قراءة جهات الاتصال","{failed} فشل قراءة جهات الاتصال"],
    "An error has occurred in circle(s). Check the console for more details." : "حدث خطأ في الدائرة (أو الدوائر). تحقق من شاشة التحكم console لمزيد من التفاصيل.",
    "Unable to create circle {circleName}" : "تعذّر إنشاء الدائرة  {circleName}",
    "Unable to delete circle {circleId}" : "تعذّر حذف الدائرة {circleId}",
    "Unable to delete contact" : "تعذّر حذف جهة الاتصال"
},
"nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");
