OC.L10N.register(
    "contacts",
    {
    "Details" : "Mion-fhiosrachadh",
    "Download" : "Luchdaich a-nuas",
    "Rename" : "Thoir ainm ùr air",
    "Delete" : "Sguab às",
    "Copy link" : "Dèan lethbhreac dhen cheangal",
    "Save" : "Sàbhail",
    "Cancel" : "Sguir dheth",
    "Invalid image" : "Dealbh mì-dhligheach",
    "Name" : "Ainm",
    "No results" : "Gun toradh",
    "Pending" : "Ri dhèiligeadh",
    "Close" : "Dùin",
    "User" : "Cleachdaiche",
    "Email" : "Post-d",
    "Notes" : "Nòtaichean",
    "Website" : "Làrach-lìn",
    "Home" : "Dachaigh",
    "Address" : "Seòladh",
    "None" : "Chan eil gin",
    "Unknown" : "Chan eil fhios"
},
"nplurals=4; plural=(n==1 || n==11) ? 0 : (n==2 || n==12) ? 1 : (n > 2 && n < 20) ? 2 : 3;");
