OC.L10N.register(
    "contacts",
    {
    "Details" : "รายละเอียด",
    "All contacts" : "รายชื่อทั้งหมด",
    "Contacts" : "รายชื่อ",
    "A contacts app for Nextcloud" : "แอปรายชื่อสำหรับ Nextcloud",
    "Copy to full name" : "คัดลอกไปยังชื่อเต็ม",
    "Omit year" : "ละเว้นปี",
    "Allow updating avatars from social media" : "อนุญาตให้อัปเดตภาพแทนตัวจากโซเชียลมีเดีย",
    "Loading contacts …" : "กำลังโหลดรายชื่อ …",
    "There are no contacts yet" : "ยังไม่มีรายชื่อผู้ติดต่อ",
    "Create contact" : "สร้างรายชื่อ",
    "There are no contacts in this group" : "ไม่มีรายชื่อในกลุ่มนี้",
    "Create contacts" : "สร้างรายชื่อ",
    "Add contacts" : "เพิ่มรายชื่อ",
    "Loading …" : "กำลังโหลด …",
    "Add member" : "เพิ่มสมาชิก",
    "Contacts settings" : "การตั้งค่ารายชื่อ",
    "General settings" : "การตั้งค่าทั่วไป",
    "Update avatars from social media" : "อัปเดตภาพแทนตัวจากโซเชียลมีเดีย",
    "(refreshed once per week)" : "(รีเฟรชใหม่สัปดาห์ละครั้ง)",
    "Address books" : "สมุดรายชื่อ",
    "Send email" : "ส่งอีเมล",
    "Contact groups" : "กลุ่มรายชื่อ",
    "Create a new contact group" : "สร้างกลุ่มรายชื่อใหม่",
    "Contact group name" : "ชื่อของกลุ่มรายชื่อ",
    "Show all groups" : "แสดงกลุ่มทั้งหมด",
    "Collapse groups" : "ย่อกลุ่ม",
    "Download" : "ดาวน์โหลด",
    "Rename" : "เปลี่ยนชื่อ",
    "Delete" : "ลบ",
    "Copied" : "คัดลอกแล้ว",
    "Cannot copy" : "ไม่สามารถคัดลอก",
    "Copy link" : "คัดลอกลิงก์",
    "Share with users or groups" : "แชร์กับผู้ใช้หรือกลุ่ม",
    "can edit" : "สามารถแก้ไข",
    "First name" : "ชื่อจริง",
    "Last name" : "นามสกุล",
    "Display name" : "ชื่อที่แสดง",
    "Last modified" : "แก้ไขล่าสุด",
    "Sort by {sorting}" : "เรียงตาม {sorting}",
    "Manages" : "จัดการ",
    "Password protection" : "ป้องกันด้วยรหัสผ่าน",
    "Save" : "บันทึก",
    "Request to join" : "ขอเข้าร่วม",
    "Description" : "รายละเอียด",
    "Cancel" : "ยกเลิก",
    "Upload a new picture" : "อัปโหลดรูปภาพใหม่",
    "Choose from Files" : "เลือกจากไฟล์",
    "Get from " : "รับจาก",
    "Download picture" : "ดาวน์โหลดรูปภาพ",
    "Delete picture" : "ลบรูปภาพ",
    "Invalid image" : "รูปภาพไม่ถูกต้อง",
    "Pick an avatar" : "เลือกภาพแทนตัว",
    "Error while processing the picture." : "เกิดข้อผิดพลาดขณะประมวลผลรูปภาพ",
    "Name" : "ชื่อ",
    "Title" : "ชื่อเรื่อง",
    "Company" : "บริษัท",
    "Edit" : "แก้ไข",
    "Search contacts …" : "ค้นหารายชื่อผู้ติดต่อ …",
    "No results" : "ไม่มีผลลัพธ์",
    "Pending" : "รอดำเนินการ",
    "Select option" : "เลือกตัวเลือก",
    "New contact" : "รายชื่อใหม่",
    "Close" : "ปิด",
    "Import" : "นำเข้า",
    "Not grouped" : "ไม่ถูกจัดกลุ่ม",
    "User" : "ผู้ใช้",
    "Group" : "กลุ่ม",
    "Email" : "อีเมล",
    "Admin" : "ผู้ดูแลระบบ",
    "Owner" : "เจ้าของ",
    "Users" : "ผู้ใช้",
    "Detailed name" : "ชื่อโดยละเอียด",
    "Additional names" : "ชื่ออื่น ๆ",
    "Prefix" : "คำนำหน้า",
    "Suffix" : "คำต่อท้าย",
    "Nickname" : "ชื่อเล่น",
    "Notes" : "โน้ต",
    "Website" : "เว็บไซต์",
    "Location" : "ตำแหน่งที่อยู่",
    "Federated Cloud ID" : "ID คลาวด์ที่ติดต่อกับภายนอก",
    "Home" : "บ้าน",
    "Work" : "ที่ทำงาน",
    "Other" : "อื่น ๆ",
    "Address" : "ที่อยู่",
    "Post office box" : "ตู้ไปรษณีย์",
    "City" : "เมือง",
    "State or province" : "รัฐหรือจังหวัด",
    "Postal code" : "รหัสไปรษณีย์",
    "Country" : "ประเทศ",
    "Birthday" : "วันเกิด",
    "Anniversary" : "วันครบรอบ",
    "Date of death" : "วันที่เสียชีวิต",
    "Instant messaging" : "ข้อความโต้ตอบแบบทันที",
    "Phone" : "โทรศัพท์",
    "Mobile" : "มือถือ",
    "Home mobile" : "มือถือที่บ้าน",
    "Fax" : "โทรสาร",
    "Fax home" : "แฟกซ์ที่บ้าน",
    "Fax work" : "แฟกซ์ที่ทำงาน",
    "Pager" : "เพจเจอร์",
    "Voice" : "เสียงพูด",
    "Social network" : "เครือข่ายโซเชียล",
    "Relative" : "สัมพัทธ์",
    "None" : "ไม่มี",
    "Unknown" : "ไม่ทราบ"
},
"nplurals=1; plural=0;");
