OC.L10N.register(
    "contacts",
    {
    "Details" : "معلومات",
    "Download" : "ښکته کول",
    "Rename" : "نوم بدلول",
    "Delete" : "ړنګول",
    "Copy link" : "لېنک کاپي کول",
    "Save" : "ساتل",
    "Cancel" : "پرېښول",
    "Invalid image" : "انځور سم نه دی",
    "Name" : "نوم",
    "Search contacts …" : "اړيکي پلټل ...",
    "Pending" : "د انتظار په حال کې",
    "Close" : "بندول",
    "Circle" : "حلقه",
    "Admin" : "ستر کارن",
    "Users" : "کارنان",
    "Notes" : "شسیب",
    "Home" : "کور",
    "Work" : "دفتر",
    "Other" : "نور"
},
"nplurals=2; plural=(n != 1);");
