OC.L10N.register(
    "contacts",
    {
    "Details" : "Деталі",
    "All contacts" : "Всі контакти",
    "Contacts" : "Контакти",
    "A contacts app for Nextcloud" : "Застосунок для керування контактами у хмарі Nextcloud",
    "The Nextcloud contacts app is a user interface for Nextcloud's CardDAV server. Easily sync contacts from various devices with your Nextcloud and edit them online.\n\n* 🚀 **Integration with other Nextcloud apps!** Currently Mail and Calendar – more to come.\n* 🎉 **Never forget a birthday!** You can sync birthdays and other recurring events with your Nextcloud Calendar.\n* 👥 **Sharing of Adressbooks!** You want to share your contacts with your friends or coworkers? No problem!\n* 🙈 **We’re not reinventing the wheel!** Based on the great and open SabreDAV library." : "Застосунок Nextcloud \"Контакти\" надає зручний користувацький інтерфейс для оперування контактними даними в хмарі Nextcloud за допомогою протоколу CardDAV. Ви зможете легко синхронізувати контакти між різними пристроями з хмарою, редагувати контакти в онлайні.\n* 🚀 **Інтеграція з іншими застосункамиNextcloud! ** Наразі, ви можете синхронізувати контакти із застосунками \"Пошта\" та \"Календар\", інтеграція з рештою застосунків очікується.\n* 🎉 **Завжди пам'ятайте про дати народження! ** Ви зможете синхронізовувати дати народження та інші важливі події, що повторюються, з календарем в хмарі.\n* 👥 **Обмін адресними книгами!** Ви зможете легко поділитися вашими контактами з друзями або колегами.\n* 🙈 **Ми не винаходили колеса! ** Сервіс створено на основі відкритої бібліотеки SabreDAV.",
    "Copy to full name" : "Копіювати до повного імени",
    "Omit year" : "Не включати рік",
    "Allow updating avatars from social media" : "Дозволити оновлення аватарок контактів із соціальних мереж",
    "Please select a circle" : "Будь ласка, виберіть коло",
    "Loading circle …" : "Завантажую коло...",
    "Your request to join this circle is pending approval" : "Ваш запит на додавання до кола очікує на підтвердження",
    "You are not a member of {circle}" : "Ви є учасником кола {circle}",
    "There was an error fetching the member list" : "Помилка під час отримання списку учасників",
    "Loading contacts …" : "Завантаження контактів…",
    "There are no contacts yet" : "Поки що відсутні контакти",
    "Create contact" : "Створити контакт",
    "There are no contacts in this group" : "В цій групі відсутні контакти",
    "Create contacts" : "Створити контакти",
    "Add contacts" : "Додати контакти",
    "Loading …" : "Завантаження...",
    "Add member" : "Додати учасника",
    "Leave circle" : "Залишити коло",
    "Delete circle" : "Вилучити коло",
    "Contacts settings" : "Налаштування",
    "General settings" : "Загальні",
    "Update avatars from social media" : "Оновлювати аватарки з соціальних мереж",
    "(refreshed once per week)" : "(щотижня)",
    "Address books" : "Адресні книги",
    "Export" : "Експортувати",
    "Send email" : "Надіслати лист",
    "Send email as BCC" : "Надіслати лист ел.пошти як приховану копію",
    "Contact groups" : "Групи контактів",
    "Create a new contact group" : "Створити нову групу контактів",
    "Contact group name" : "Назва групи контактів",
    "Circles" : "Кола",
    "Create a new circle" : "Створити нове коло",
    "Show all groups" : "Показувати всі групи",
    "Collapse groups" : "Згорнути групи",
    "Show all circles" : "Показувати всі кола",
    "Collapse circles" : "Згорнути кола",
    "This group already exists" : "Така група вже існує",
    "This circle already exists" : "Таке коло вже існує",
    "An error happened during the creation of the circle" : "Помилка під час створення кола",
    "{addressbookname} (Disabled)" : "{addressbookname} (Вимкнено)",
    "Download" : "Звантажити",
    "Show" : "Показати",
    "Rename" : "Перейменувати",
    "Delete" : "Вилучити",
    "Copied" : "Скопійовано",
    "Cannot copy" : "Не вдалося скопіювати",
    "Copy link" : "Копіювати посилання",
    "Toggling of address book was not successful" : "Не вдалося перемкнути адресну книгу",
    "This will delete the address book and every contacts within it" : "Це призведе до вилучення адресної книги та контактів у ній",
    "Delete {addressbook}?" : "Вилучити {addressbook}?",
    "Deletion of address book was not successful." : "Не вдалося вилучити адресну книгу",
    "Renaming of address book was not successful." : "Не вдалося перейменувати адресну книгу",
    "_%n contact_::_%n contacts_" : ["%n контакт","%n контакти","%n контактів","%n контактів"],
    "_%n group_::_%n groups_" : ["%n група","%n групи","%n груп","%n груп"],
    "_Shared with {num} entity_::_Shared with {num} entities_" : ["Спільний доступ з {num} об'єктом","Спільний доступ з {num} об'єктами","Спільний доступ з {num} об'єктами","Спільний доступ з {num} об'єктами"],
    "Share with users or groups" : "Поділитися з користувачами або групами",
    "Share with users" : "Поділитися",
    "No users or groups" : "Відсутні користувачі або групи",
    "can edit" : "може редагувати",
    "Unable to delete the share" : "Неможливо вилучити спільний ресурс",
    "Unable to change permissions" : "Неможливо змінити права доступу",
    "Import contacts" : "Імпорт контактів",
    "Import into the {addressbookName} address book" : "Імпорт до адресної книги {addressbookName}",
    "Select local file" : "Виберіть файл на вашому комп'ютері",
    "Import from files" : "Імпорт з файлів",
    "Importing is disabled because there are no address books available" : "Імпорт недоступний, оскільки відсутні адресні книги",
    "Choose a vCard file to import" : "Виберіть файл vCard для імпорту",
    "Add new address book" : "Нова адресна книга",
    "An error occurred, unable to create the address book" : "Помилка: неможливо створити адресну книгу",
    "First name" : "Ім'я",
    "Last name" : "Прізвище",
    "Phonetic first name" : "Ім'я за вимовою",
    "Phonetic last name" : "Прізвище за вимовою",
    "Display name" : "Ім'я для показу",
    "Last modified" : "Востаннє змінено",
    "Sort by {sorting}" : "За {sorting}",
    "Manages" : "Керує",
    "Oversees" : "Наглядає",
    "An error happened during the config change" : "Помилка під час внесення змін до конфігурації",
    "Password protection" : "Захист паролем",
    "Enforce password protection on files shared to this circle" : "Налаштувати обов'язкові паролі на файли, до яких було надано доступ в цьому колі",
    "Use a unique password for all shares to this circle" : "Використовувати один пароль для всіх спільних ресурсів у цьому колі",
    "Unique password …" : "Унікальний пароль...",
    "Save" : "Зберегти",
    "Change unique password" : "Змінити унікальний пароль",
    "Failed to save password. Please try again later." : "Не вдалося зберегти пароль. Спробуйте пізніше.",
    "Circle name" : "Назва кола",
    "Circle owned by {owner}" : "Власник кола {owner}",
    "Request to join" : "Запит на приєднання",
    "Description" : "Опис",
    "There is no description for this circle" : "Відсутній опис цього кола",
    "Enter a description for the circle" : "Зазначте опис для цього кола",
    "An error happened during description sync" : "Помилка під час синхронізації опису",
    "An error happened during name sync" : "Помилка під час синхронізації назви",
    "Add more info" : "Додати більше даних",
    "More fields" : "Більше полів",
    "Crop contact photo" : "Обрізати світлину контакту",
    "Cancel" : "Скасувати",
    "Upload a new picture" : "Завантажити нове зображення",
    "Choose from Files" : "Вибрати з Файлів",
    "Get from " : "Отримати з",
    "Download picture" : "Звантажити зображення",
    "Delete picture" : "Вилучити зображення",
    "Please select a valid format" : "Виберіть дійсний формат",
    "Invalid image" : "Недійсне зображення",
    "Error cropping picture" : "Помилка з обрізанням зображення",
    "Pick an avatar" : "Оберіть аватарку",
    "Error while processing the picture." : "Помилка під час обробки зображення.",
    "Avatar downloaded from social network" : "Аватарку вставлено із соціальної мережі",
    "Avatar already up to date" : "Аватарка є актуальною",
    "Avatar download failed" : "Не вдалося звантажити аватарку",
    "No contact selected" : "Контакт не вибрано",
    "Select a contact on the list to begin" : "Для початку оберіть контакт зі списку",
    "Name" : "Ім'я",
    "Title" : "Заголовок",
    "Company" : "Компанія",
    "This contact was broken and received a fix. Please review the content and click here to save it." : "Дані цього контакту було пошкоджено та виправлено. Будь ласка, перегляньте вміст та натисніть тут, щоби зберегти їх.",
    "Edit" : "Редагувати",
    "Clone contact" : "Копіювати контакт",
    "Generate QR Code" : "Створити QR-код",
    "Contact vCard as QR code" : "Контактна vCard у вигляді QR-коду",
    "Pick an address book" : "Виберіть адресну книгу",
    "Select address book" : "Виберіть адресну книгу",
    "Go to talk conversation" : "Перейти до розмви у Talk",
    "View profile" : "Переглянути профіль",
    "Media shares with you" : "Медійні матер'яли, якими поділілися з вами",
    "Talk conversations with you" : "Розмови Talk з вами",
    "Calendar events with you" : "Календарні події з вами",
    "Deck cards with you" : "Картки Deck з вами",
    "No shared items with this contact" : "Відсутні спільні з цим контактом ресурси",
    "This contact is in read-only mode. You do not have permission to edit this contact." : "Доступ до цього контакту лише у режимі читання. У вас відсутні права на редагування.",
    "The contact you were trying to edit has changed. Please manually refresh the contact. Any further edits will be discarded." : "Дані контакту, який ви намагаєтеся відредагувати, змінено. Будь ласка, оновіть сторінку. Усі подальші зміни буде проігноровано.",
    "Address book" : "Адресна книга",
    "Add contact to Birthday Calendar" : "Додати контакт до календаря днів народжень",
    "Exclude contact from Birthday Calendar" : "Не показувати у календарі",
    "{title} at {organization}" : "{title} у {organization}",
    "Syntax error. Cannot open the contact." : "Синтаксична помилка. Неможливо відкрити контакт.",
    "The contact does not exist on the server anymore." : "Цей контакт більше не доступний на цьому сервері.",
    "Unable to retrieve the contact from the server, please check your network connection." : "Неможливо отримати контакт з серверу, будь ласка, перевірте ваше мережеве з'єднання.",
    "An error occurred while trying to move the contact" : "Помилка під час переміщення контакту",
    "An error occurred while trying to copy the contact" : "Помилка під час копіювання контакту",
    "Unable to update contact" : "Не вдалося оновити контакт",
    "Search contacts …" : "Пошук контактів...",
    "Add to {group}" : "Додати до {group}",
    "Remove {type}" : "Вилучити {type}",
    "Search {types}" : "Шукати {types}",
    "Search for people to add" : "Шукати контакти для додавання",
    "No results" : "Немає результатів",
    "Add to group" : "Додати до групи",
    "Add {type}" : "Додати {type}",
    "New circle name" : "Назва нового кола",
    "Personal circle" : "Моє коло",
    "This circle will only be visible to you. Other members will not be able to see or use it." : "Це коло буде видно лише вам. Інші учасники не зможуть його побачити або використовувати.",
    "Local circle" : "Місцеве коло",
    "This circle will not be shared with the other instances of the global scale" : "Це коло не буде у спільному доступу з іншими хмарами на глобальному рівні",
    "Create circle" : "Створити коло",
    "Loading members list …" : "Завантаження списку учасників...",
    "The list of members is only visible to members of this circle" : "Cписок учасників доступний лише учасникам кола",
    "You currently have no access to the member list" : "Зараз у ас відсутній доступ до списку учасників",
    "Add members" : "Додати учасників",
    "Show circle details" : "Показати деталі кола",
    "Add to {circle}" : "Додати до кола {circle}",
    "Unable to get the recommendations list" : "Неможливо отримати список рекомендацій",
    "Unable to get the results" : "Неможливо отримати результати",
    "Some members could not be added" : "Неможливо додати окремих учасників",
    "There was an issue adding members to the circle" : "Проблема з додаванням учасників до кола",
    "Accept membership request" : "Прийняти запит на участь",
    "Reject membership request" : "Відхилити запит на участь",
    "Manage level" : "Рівень керування",
    "Remove member" : "Вилучити учасника",
    "Pending" : "Очікування",
    "Promote as sole owner" : "Зробити єдиним власником",
    "Promote to {level}" : "Підвищити до рівня {level}",
    "Demote to {level}" : "Понизити до рівня {level}",
    "Could not delete the member {displayName}" : "Неможливо вилучити учасника {displayName}",
    "Could not change the member level to {level}" : "Неможливо змінити рівень участи до {level}",
    "Could not accept membership request" : "Неможливо прийняти запит на участь",
    "Chart" : "Діаграма",
    "Select chart …" : "Виберіть діаграму",
    "Select type" : "Виберіть вид",
    "Select Date" : "Вкажіть дату",
    "Add contact in group" : "Додати контакт до групи",
    "none" : "нічого",
    "Select option" : "Виберіть",
    "Add property of this type" : "Додайте властивості такого типу",
    "New contact" : "Новий контакт",
    "Unable to create the contact." : "Неможливо створити контакт.",
    "Contact not found" : "Контакт не знайдено",
    "Group {group} not found" : "Групу {group} не знайдено",
    "Close" : "Закрити",
    "_{success} contact added to {name}_::_{success} contacts added to {name}_" : ["{success} контакт додано до {name}","{success} контакти додано до {name}","{success} контактів додано до {name}","{success} контактів додано до {name}"],
    "_Adding {success} contact to {name}_::_Adding {success} contacts to {name}_" : ["Додавання {success} контакту до {name}","Додавання {success} контактів до {name}","Додавання {success} контактів до {name}","Додавання {success} контактів до {name}"],
    "_{count} error_::_{count} errors_" : ["{count} помилку","{count} помилки","{count} помилок","{count} помилок"],
    "_Importing %n contact into {addressbook}_::_Importing %n contacts into {addressbook}_" : ["Імпорт %n контакту до {addressbook}","Імпорт %n контактів до {addressbook}","Імпорт %n контактів до {addressbook}","Імпорт %n контактів до {addressbook}"],
    "_Done importing %n contact into {addressbook}_::_Done importing %n contacts into {addressbook}_" : ["Виконано імпорт %n контакту до {addressbook}","Виконано імпорт %n контактів до {addressbook}","Виконано імпорт %n контактів до {addressbook}","Виконано імпорт %n контактів до {addressbook}"],
    "Import" : "Імпорт",
    "Could not copy" : "Неможливо скопіювати",
    "Join circle" : "Приєднатися до кола",
    "You are about to leave {circle}.\nAre you sure?" : "Ви збираєтеся залишити коло {circle}.\nПродовжити?",
    "Please confirm circle leave" : "Будь ласка, підтвердіть вихід з кола",
    "Could not leave the circle {displayName}" : "Неможливо залишити коло {displayName}",
    "Unable to join the circle" : "Неможливо приєднатися до кола",
    "You are about to delete {circle}.\nAre you sure?" : "Ви намагаєтеся вилучити коло {circle}.\nПродовжити?",
    "Please confirm circle deletion" : "Будь ласка, підтвердіть вилучення кола",
    "Unable to delete the circle" : "Неможливо вилучити коло",
    "Link copied to the clipboard" : "Посилання скопійовано до буферу обміну",
    "Could not copy link to the clipboard." : "Неможливо скопіювати посилання до буферу обміну",
    "Not grouped" : "Поза групами",
    "Recently contacted" : "Нещодавні контакти",
    "Organization chart" : "Органограма",
    "Circles are groups of people that you can create yourself and with whom you can share data. They can be made up of other accounts or groups of accounts of the Nextcloud instance, but also of contacts from your address book or even external people by simply entering their e-mail addresses." : "Кола - це групи людей, які ви можете самі створювати, щоби подалі ділитися з ними даними. До кіл можна включати інші облікові записи, групи облікових записів у вашій хмарі, а також контакти з вашої адресної книги і навіть інших людей - для цього просто зазначте їхні ел. адреси.",
    "Circle" : "Коло",
    "User" : "Користувач",
    "Group" : "Група",
    "Email" : "Ел.пошта",
    "Contact" : "Контакт",
    "Member" : "Учасник",
    "Moderator" : "Модератор",
    "Admin" : "Адміністратор",
    "Owner" : "Власник",
    "Invites" : "Запрошення",
    "Anyone can request membership" : "Будь-хто може надіслати запит на участь",
    "Members need to accept invitation" : "Учасники мають прийняти запрошення",
    "Memberships must be confirmed/accepted by a Moderator (requires Open)" : "Участь потрібно підтвердити/прийняти модератором (вимагає відкритої)",
    "Members can also invite" : "Учасники також можуть запрошувати",
    "Visibility" : "Видимість",
    "Visible to everyone" : "Видно для всіх",
    "Circle membership" : "Участь у колі",
    "Prevent circle from being a member of another circle" : "Заборонити брати участь в іншому колі",
    "Users" : "Користувачі",
    "Email addresses" : "Адреси ел. пошти",
    "Detailed name" : "Повне ім'я",
    "Additional names" : "Додаткові імена",
    "Prefix" : "Префікс",
    "Suffix" : "Суфікс",
    "Nickname" : "Прізвисько",
    "Notes" : "Примітки",
    "Website" : "Вебсайт",
    "Location" : "Розташування",
    "Federated Cloud ID" : "Ідентифікатор хмари",
    "Home" : "Дім",
    "Work" : "Робочий",
    "Other" : "Інше",
    "Address" : "Адреса",
    "Post office box" : "Аб.скринька",
    "Extended address" : "Розширена адреса",
    "City" : "Місто",
    "State or province" : "Область або регіон",
    "Postal code" : "Поштовий індекс",
    "Country" : "Країна",
    "Birthday" : "Дата народження",
    "Anniversary" : "Річниця",
    "Date of death" : "Дата смерти",
    "Instant messaging" : "Месенджер",
    "Phone" : "Телефон",
    "Mobile" : "Мобільний",
    "Work mobile" : "Роб. мобільний",
    "Home mobile" : "Дом. мобільний",
    "Fax" : "Факс",
    "Fax home" : "Дом. факс",
    "Fax work" : "Роб. факс",
    "Pager" : "Пейджер",
    "Voice" : "Голос",
    "Car" : "В автомобілі",
    "Work pager" : "Роб. пейджер",
    "Manager" : "Менеджер",
    "Social network" : "Сторінка у соціальній мережі",
    "Relationship to you" : "Взаємини з вами",
    "Spouse" : "Чоловік/дружина",
    "Child" : "Дитина",
    "Mother" : "Мати",
    "Father" : "Батько",
    "Parent" : "Батьки",
    "Brother" : "Брат",
    "Sister" : "Сестра",
    "Relative" : "Родина",
    "Friend" : "Друг",
    "Colleague" : "Колега",
    "Assistant" : "Асистент",
    "Related contacts" : "Пов'язані контакти",
    "Agent" : "Агент",
    "Emergency" : "У разі небезпеки",
    "Co-worker" : "Колега",
    "Gender" : "Стать",
    "Female" : "Жінка",
    "Male" : "Чоловік",
    "None" : "Відсутній",
    "Unknown" : "Невідомо",
    "Time zone" : "Часова зона",
    "Spoken languages" : "Мови",
    "_{failed} contact failed to be read_::_{failed} contacts failed to be read_" : ["{failed} контакт не прочитано","{failed} контактів не прочитано","{failed} контактів не прочитано","{failed} контактів не прочитано"],
    "An error has occurred in circle(s). Check the console for more details." : "Помилка в одному з кіл. Перевірте додаткові дані у консолі.",
    "Unable to create circle {circleName}" : "Неможливо створити коло {circleName}",
    "Unable to delete circle {circleId}" : "Неможливо вилучити коло {circleName}",
    "Unable to delete contact" : "Неможливо вилучити контакт"
},
"nplurals=4; plural=(n % 1 == 0 && n % 10 == 1 && n % 100 != 11 ? 0 : n % 1 == 0 && n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14) ? 1 : n % 1 == 0 && (n % 10 ==0 || (n % 10 >=5 && n % 10 <=9) || (n % 100 >=11 && n % 100 <=14 )) ? 2: 3);");
