OC.L10N.register(
    "contacts",
    {
    "Details" : "Manylion",
    "All contacts" : "Pob cyswllt",
    "Contacts" : "Cysylltiadau",
    "A contacts app for Nextcloud" : "Ap cysylltiadau ar gyfer Nextcloud",
    "The Nextcloud contacts app is a user interface for Nextcloud's CardDAV server. Easily sync contacts from various devices with your Nextcloud and edit them online.\n\n* 🚀 **Integration with other Nextcloud apps!** Currently Mail and Calendar – more to come.\n* 🎉 **Never forget a birthday!** You can sync birthdays and other recurring events with your Nextcloud Calendar.\n* 👥 **Sharing of Adressbooks!** You want to share your contacts with your friends or coworkers? No problem!\n* 🙈 **We’re not reinventing the wheel!** Based on the great and open SabreDAV library." : "Mae'r app cysylltiadau Nextcloud yn rhyngwyneb defnyddiwr ar gyfer gweinydd CardDAV Nextcloud. YMae'n hawdd i gydweddu cysylltiadau o wahanol ddyfeisiau â'ch Nextcloud a'u golygu ar-lein.\n\n* 🚀 ** Integreiddio ag apiau Nextcloud eraill! ** Post a Chalendr ar hyn o bryd - mwy i ddod.\n* 🎉 ** Peidiwch byth ag anghofio pen-blwydd! ** Gallwch gysoni penblwyddi a digwyddiadau cylchol eraill gyda'ch Calendr Nextcloud.\n* 👥 ** Rhannu Llyfrau Cyfeiriadau! ** Gallwch rannu'ch cysylltiadau gyda'ch ffrindiau neu gydweithwyr? Dim problem!\n* 🙈 ** Nid ydym yn ailddyfeisio'r olwyn! ** Yn seiliedig ar lyfrgell wych ac agored SabreDAV.",
    "Copy to full name" : "Copi i'r enw llawn",
    "Loading …" : "Yn llwytho …",
    "Download" : "Llwytho i lawr",
    "Rename" : "Ailenwi",
    "Delete" : "Dileu",
    "Copied" : "Copïwyd",
    "Copy link" : "Copïo dolen",
    "_Shared with {num} entity_::_Shared with {num} entities_" : ["Rhannwyd gyda {num} endid","Rhannwyd gyda {num} endid","Rhannwyd gyda {num} endid","Rhannwyd gyda {num} endid"],
    "Share with users or groups" : "Rhannwch gyda defnyddwyr neu grwpiau",
    "No users or groups" : "Dim defnyddwyr na grwpiau",
    "can edit" : "yn gallu golygu",
    "Importing is disabled because there are no address books available" : "Mae mewnforio wedi ei analluogi oherwydd nad oes llyfrau cyfeiriadau ar gael",
    "First name" : "Enw cyntaf",
    "Last name" : "Cyfenw",
    "Display name" : "Enw Dangos",
    "Last modified" : "Newidiwyd diwethaf",
    "Sort by {sorting}" : "Trefnu yn ôl {sorting}",
    "Password protection" : "Password protection",
    "Save" : "Cadw",
    "Description" : "Disgrifiad",
    "Cancel" : "Diddymu",
    "Upload a new picture" : "Llwythwch lun newydd i fyny",
    "Download picture" : "Llwytho llun i lawr",
    "Delete picture" : "Dileu llun",
    "Pick an avatar" : "Dewiswch afatar",
    "Error while processing the picture." : "Gwall wrth brosesu'r llun.",
    "No contact selected" : "Heb ddewis cyswllt",
    "Select a contact on the list to begin" : "Dewiswch gyswllt ar y rhestr i ddechrau",
    "Name" : "Enw",
    "Title" : "Teitl",
    "Company" : "Cwmni",
    "Generate QR Code" : "Cynhyrchu Cod QR",
    "This contact is in read-only mode. You do not have permission to edit this contact." : "Mae'r cyswllt hwn yn y modd darllen yn unig. Nid oes gennych ganiatâd i olygu'r cyswllt hwn.",
    "The contact you were trying to edit has changed. Please manually refresh the contact. Any further edits will be discarded." : "Mae'r cyswllt yr oeddech yn ceisio ei olygu wedi newid. Adnewyddwch y cyswllt â llaw. Bydd unrhyw olygiadau pellach yn cael eu ddileu.",
    "Syntax error. Cannot open the contact." : "Gwall cystrawen. Methu agor y cyswllt.",
    "No results" : "Dim canlyniadau",
    "Pending" : "I ddod",
    "Select type" : "Dewiswch y math",
    "Select Date" : "Dewis Dyddiad",
    "Add contact in group" : "Ychwanegu cyswllt yn y grŵp",
    "Select option" : "Dewiswch opsiwn",
    "New contact" : "Cysylltiad newydd",
    "Unable to create the contact." : "Methu creu'r cyswllt.",
    "Contact not found" : "Heb ganfod cyswllt",
    "Close" : "Cau",
    "Import" : "Mewnforio",
    "Not grouped" : "Heb ei grwpio",
    "User" : "User",
    "Group" : "Grŵp",
    "Email" : "E-bost",
    "Contact" : "Cyswllt",
    "Admin" : "Gweinyddu",
    "Owner" : "Owner",
    "Users" : "Defnyddwyr",
    "Detailed name" : "Enw manwl",
    "Additional names" : "Enwau ychwanegol",
    "Prefix" : "Rhagddodiad",
    "Suffix" : "Ôl-ddodiad",
    "Nickname" : "Llysenw",
    "Notes" : "Nodiadau",
    "Website" : "Gwefan",
    "Location" : "Lleoliad",
    "Federated Cloud ID" : "ID Cwmwl Ffederal",
    "Home" : "Cartref",
    "Work" : "Gwaith",
    "Other" : "Arall",
    "Address" : "Cyfeiriad",
    "Post office box" : "Blwch swyddfa bost",
    "Extended address" : "Cyfeiriad estynedig",
    "City" : "Dinas",
    "State or province" : "Sir neu dalaith",
    "Postal code" : "Cod Post",
    "Country" : "Gwlad",
    "Birthday" : "Pen-blwydd",
    "Anniversary" : "Dathliad",
    "Date of death" : "Dyddiad marwolaeth",
    "Instant messaging" : "Negeseu sydyn",
    "Phone" : "Ffôn",
    "Mobile" : "Symudol",
    "Work mobile" : "Ffôn symudol gwaith",
    "Home mobile" : "Ffôn symudol cartref",
    "Fax" : "Ffacs",
    "Fax home" : "Ffacs cartref",
    "Fax work" : "Ffacs gwaith",
    "Pager" : "Peiriant galw",
    "Voice" : "Llais",
    "Car" : "Car",
    "Work pager" : "Swnyn gwaith",
    "Manager" : "Rheolwr",
    "Social network" : "Rhwydwaith cymdeithasol",
    "Spouse" : "Priod",
    "Child" : "Plentyn",
    "Mother" : "Mam",
    "Father" : "Tad",
    "Parent" : "Rhiant",
    "Brother" : "Brawd",
    "Sister" : "Chwaer",
    "Relative" : "Perthynas",
    "Friend" : "Ffrind",
    "Colleague" : "Cydweithiwr",
    "Assistant" : "Cynorthwywr",
    "Agent" : "Asiant",
    "Emergency" : "Argyfwng",
    "Co-worker" : "Cyd-weithiwr",
    "Gender" : "Rhyw",
    "Female" : "Benyw",
    "Male" : "Gwryw",
    "None" : "Dim",
    "Unknown" : "Anhysbys",
    "_{failed} contact failed to be read_::_{failed} contacts failed to be read_" : ["Methwyd â darllen {failed} cyswllt","Methwyd â darllen {failed} cyswllt","Methwyd â darllen {failed} cyswllt","Methwyd â darllen {failed} cyswllt"]
},
"nplurals=4; plural=(n==1) ? 0 : (n==2) ? 1 : (n != 8 && n != 11) ? 2 : 3;");
