OC.L10N.register(
    "contacts",
    {
    "Details" : "Pojedinosti",
    "All contacts" : "Svi kontakti",
    "Contacts" : "Kontakti",
    "A contacts app for Nextcloud" : "Aplikacija za kontakte za Nextcloud",
    "The Nextcloud contacts app is a user interface for Nextcloud's CardDAV server. Easily sync contacts from various devices with your Nextcloud and edit them online.\n\n* 🚀 **Integration with other Nextcloud apps!** Currently Mail and Calendar – more to come.\n* 🎉 **Never forget a birthday!** You can sync birthdays and other recurring events with your Nextcloud Calendar.\n* 👥 **Sharing of Adressbooks!** You want to share your contacts with your friends or coworkers? No problem!\n* 🙈 **We’re not reinventing the wheel!** Based on the great and open SabreDAV library." : "Nextcloudova aplikacija za kontakte je korisničko sučelje za Nextcloudov CardDAV poslužitelj. Jednostavno sinkronizirajte kontakte s raznih uređaja s Nextcloudom i uređujte ih na mreži.\n\n* 🚀 **Integracija s drugim Nextcloudovim aplikacijama!** Trenutno e-pošta i kalendar – i još puno toga.\n* 🌐 **Nikad više nemojte zaboraviti nečiji rođendan** Sinkronizirajte rođendane i ostale ponavljajuće događaje u svojem Nextcloud kalendaru\n* 🙋 **Dijeljenje adresara!** Želite dijeliti svoje kontakte s prijateljima ili kolegama. Nema problema!\n* 🙈 **Ne izmišljamo toplu vodu!** Na temelju odlične i besplatne SabreDAV biblioteke.",
    "Copy to full name" : "Kopiraj u puno ime",
    "Omit year" : "Izuzmi godinu",
    "Allow updating avatars from social media" : "Omogući ažuriranje avatara s društvenih medija",
    "Please select a circle" : "Odaberite krug",
    "Loading circle …" : "Učitavanje kruga…",
    "Your request to join this circle is pending approval" : "Vaš zahtjev za pridruživanje ovom krugu čeka odobrenje",
    "You are not a member of {circle}" : "Niste član {circle}",
    "There was an error fetching the member list" : "Došlo je do pogreške pri dohvaćanju popisa članova",
    "Loading contacts …" : "Učitavanje kontakata…",
    "There are no contacts yet" : "Još uvijek nema kontakata",
    "Create contact" : "Stvori kontakt",
    "There are no contacts in this group" : "U ovoj grupi nema kontakata",
    "Create contacts" : "Stvori kontakte",
    "Add contacts" : "Dodaj kontakte",
    "Loading …" : "Učitavanje…",
    "Add member" : "Dodaj člana",
    "Leave circle" : "Napusti krug",
    "Delete circle" : "Izbriši krug",
    "General settings" : "Opće postavke",
    "Update avatars from social media" : "Ažuriraj avatare s društvenih mreža",
    "(refreshed once per week)" : "(osvježava se jednom tjedno)",
    "Send email" : "Pošalji poruku e-pošte",
    "Circles" : "Krugovi",
    "Create a new circle" : "Stvori novi krug",
    "Show all groups" : "Prikaži sve grupe",
    "Collapse groups" : "Sakrij grupe",
    "Show all circles" : "Prikaži sve krugove",
    "Collapse circles" : "Sakrij krugove",
    "This group already exists" : "Ova grupa već postoji",
    "This circle already exists" : "Ovaj krug već postoji",
    "An error happened during the creation of the circle" : "Došlo je do pogreške tijekom stvaranja kruga",
    "Download" : "Preuzmi",
    "Rename" : "Preimenuj",
    "Delete" : "Izbriši",
    "Copied" : "Kopirano",
    "Cannot copy" : "Nije moguće kopirati",
    "Copy link" : "Kopiraj poveznicu",
    "Toggling of address book was not successful" : "Promjena adresara nije bila uspješna",
    "This will delete the address book and every contacts within it" : "Brisanjem adresara brišu se i svi kontakti koje sadrži",
    "Delete {addressbook}?" : "Izbrisati {addressbook}?",
    "Deletion of address book was not successful." : "Neuspješno brisanje adresara",
    "Renaming of address book was not successful." : "Neuspješna promjena naziva adresara",
    "_Shared with {num} entity_::_Shared with {num} entities_" : ["Dijeljeno s {num} entitetom","Dijeljeno s {num} entiteta","Dijeljeno s {num} entiteta"],
    "Share with users or groups" : "Dijelite s korisnicima ili grupama",
    "No users or groups" : "Nema korisnika ili grupa",
    "can edit" : "uređivanje moguće",
    "Unable to delete the share" : "Nije moguće izbrisati dijeljenje",
    "Unable to change permissions" : "Nije moguće promijeniti dopuštenja",
    "Import contacts" : "Uvezi kontakte",
    "Import into the {addressbookName} address book" : "Uvezi u adresar {addressbookName}",
    "Select local file" : "Odaberi lokalnu datoteku",
    "Import from files" : "Uvezi iz datoteka",
    "Importing is disabled because there are no address books available" : "Uvoz je onemogućen jer nema dostupnih adresara",
    "Choose a vCard file to import" : "Odaberite datoteku vCard za uvoz",
    "An error occurred, unable to create the address book" : "Došlo je do pogreške, nije moguće stvoriti adresar",
    "First name" : "Ime",
    "Last name" : "Prezime",
    "Phonetic first name" : "Fonetsko ime",
    "Phonetic last name" : "Fonetsko prezime",
    "Display name" : "Ime za prikaz",
    "Last modified" : "Posljednja izmjena",
    "Sort by {sorting}" : "Poredaj po {sorting}",
    "An error happened during the config change" : "Došlo je do pogreške tijekom promjene konfiguracije",
    "Password protection" : "Zaštita zaporkom",
    "Save" : "Spremi",
    "Circle name" : "Naziv kruga",
    "Circle owned by {owner}" : "Krug u vlasništvu {owner}",
    "Request to join" : "Zahtjev za pridruživanje",
    "Description" : "Opis",
    "There is no description for this circle" : "Ne postoji opis za ovaj krug",
    "Enter a description for the circle" : "Unesite opis kruga",
    "An error happened during description sync" : "Došlo je do pogreške tijekom sinkronizacije opisa",
    "An error happened during name sync" : "Došlo je do pogreške tijekom sinkronizacije naziva",
    "Cancel" : "Odustani",
    "Upload a new picture" : "Otpremi novu sliku",
    "Choose from Files" : "Odaberi iz datoteka",
    "Get from " : "Dohvati iz ",
    "Download picture" : "Preuzmi sliku",
    "Delete picture" : "Izbriši sliku",
    "Invalid image" : "Slika neispravna",
    "Pick an avatar" : "Odaberi avatar",
    "Error while processing the picture." : "Pogreška tijekom obrade slike.",
    "Avatar downloaded from social network" : "Avatar je preuzet s društvene mreže",
    "Avatar already up to date" : "Avatar je ažuriran",
    "Avatar download failed" : "Preuzimanje avatara nije uspjelo",
    "No contact selected" : "Nije odabran nijedan kontakt",
    "Select a contact on the list to begin" : "Odaberi kontakt s popisa za početak",
    "Name" : "Naziv",
    "Title" : "Naslov",
    "Company" : "Tvrtka",
    "This contact was broken and received a fix. Please review the content and click here to save it." : "Kontakt je bio pogrešan i ispravljen je. Pregledajte sadržaj i kliknite ovdje kako biste ga spremili.",
    "Clone contact" : "Kloniraj kontakt",
    "Generate QR Code" : "Generiraj QR kod",
    "Contact vCard as QR code" : "VCard kontakta kao QR kod",
    "Pick an address book" : "Odaberi adresar",
    "Select address book" : "Označi adresar",
    "This contact is in read-only mode. You do not have permission to edit this contact." : "Taj je kontakt u načinu rada samo za čitanje. Nemate dopuštenje za uređivanje ovog kontakta.",
    "The contact you were trying to edit has changed. Please manually refresh the contact. Any further edits will be discarded." : "Kontakt koji ste pokušali urediti se promijenio. Ručno osvježite kontakt. Sva daljnja uređivanja bit će odbačena.",
    "Address book" : "Adresar",
    "Syntax error. Cannot open the contact." : "Sintaktička pogreška. Kontakt se ne može otvoriti.",
    "Unable to retrieve the contact from the server, please check your network connection." : "Nije moguće dohvatiti kontakt s poslužitelja, provjerite svoju mrežnu vezu.",
    "An error occurred while trying to move the contact" : "Došlo je do pogreške tijekom prijenosa kontakta",
    "An error occurred while trying to copy the contact" : "Došlo je do pogreške prilikom kopiranja kontakta",
    "Search contacts …" : "Pretraži kontakte...",
    "Add to {group}" : "Dodaj u {group}",
    "Remove {type}" : "Ukloni {type}",
    "Search {types}" : "Traži {types}",
    "Search for people to add" : "Potraži osobe za dodavanje",
    "No results" : "Nema rezultata",
    "Add to group" : "Dodaj u grupu",
    "Add {type}" : "Dodaj {type}",
    "New circle name" : "Naziv novog kruga",
    "Personal circle" : "Osobni krug",
    "This circle will only be visible to you. Other members will not be able to see or use it." : "Ovaj će krug biti vidljiv samo vama. Drugi članovi neće ga moći vidjeti niti upotrebljavati.",
    "Local circle" : "Lokalni krug",
    "This circle will not be shared with the other instances of the global scale" : "Ovaj se krug neće dijeliti s drugim instancama na globalnoj razini",
    "Create circle" : "Stvori krug",
    "Loading members list …" : "Učitavanje popisa članova…",
    "The list of members is only visible to members of this circle" : "Popis članova vidljiv je samo članovima ovog kruga",
    "Add members" : "Dodaj članove",
    "Show circle details" : "Prikaži pojedinosti kruga",
    "Add to {circle}" : "Dodaj u {circle}",
    "Unable to get the recommendations list" : "Nije moguće dohvatiti popis preporuka",
    "Unable to get the results" : "Nije moguće dohvatiti rezultate",
    "Some members could not be added" : "Neki članovi nisu dodani",
    "There was an issue adding members to the circle" : "Došlo je do problema pri dodavanju članova u krug",
    "Accept membership request" : "Prihvati zahtjev za članstvo",
    "Reject membership request" : "Odbij zahtjev za članstvo",
    "Manage level" : "Upravljaj razinom",
    "Remove member" : "Ukloni člana",
    "Pending" : "Na čekanju",
    "Promote as sole owner" : "Unaprijedi kao jedinog vlasnika",
    "Promote to {level}" : "Unaprijedi na {level}",
    "Demote to {level}" : "Vrati na {level}",
    "Could not delete the member {displayName}" : "Brisanje člana {displayName} nije uspjelo",
    "Could not change the member level to {level}" : "Mijenjanje razine člana na {level} nije uspjelo",
    "Could not accept membership request" : "Zahtjev za članstvo nije prihvaćen",
    "Chart" : "Grafikon",
    "Select type" : "Odaberi vrstu",
    "Select Date" : "Odaberi datum",
    "Add contact in group" : "Dodaj kontakt u grupu",
    "Select option" : "Odaberi opciju",
    "New contact" : "Novi kontakt",
    "Unable to create the contact." : "Nije moguće stvoriti kontakt.",
    "Contact not found" : "Kontakt nije pronađen",
    "Group {group} not found" : "Grupa {group} nije pronađena",
    "Close" : "Zatvori",
    "_{success} contact added to {name}_::_{success} contacts added to {name}_" : ["{success} kontakt dodan {name}","{success} kontakta dodana {name}","{success} kontakata dodano {name}"],
    "_Adding {success} contact to {name}_::_Adding {success} contacts to {name}_" : ["Dodavanje {success} kontakta {name}","Dodavanje {success} kontakta {name}","Dodavanje {success} kontakata {name}"],
    "_{count} error_::_{count} errors_" : ["{count} pogreška","{count} pogreške","{count} pogrešaka"],
    "_Importing %n contact into {addressbook}_::_Importing %n contacts into {addressbook}_" : ["Uvoz %n kontakta u {adressbook}","Uvoz %n kontakta u {adressbook}","Uvoz %n kontakta u {adressbook}"],
    "_Done importing %n contact into {addressbook}_::_Done importing %n contacts into {addressbook}_" : ["Završen uvoz %n kontakta u {adressbook}","Završen uvoz %n kontakta u {adressbook}","Završen uvoz %n kontakta u {adressbook}"],
    "Import" : "Uvezi",
    "Could not copy" : "Kopiranje nije uspjelo",
    "Join circle" : "Pridruži se krugu",
    "You are about to leave {circle}.\nAre you sure?" : "Napustit ćete krug {circle}.\nJeste li sigurni?",
    "Please confirm circle leave" : "Potvrdite napuštanje kruga",
    "Could not leave the circle {displayName}" : "Nije moguće napustiti krug {displayName}",
    "Unable to join the circle" : "Nije moguće pridružiti se krugu",
    "You are about to delete {circle}.\nAre you sure?" : "Izbrisat ćete krug {circle}.\nJeste li sigurni?",
    "Please confirm circle deletion" : "Potvrdite brisanje kruga",
    "Unable to delete the circle" : "Nije moguće izbrisati krug",
    "Link copied to the clipboard" : "Poveznica je kopirana u međuspremnik",
    "Could not copy link to the clipboard." : "Kopiranje poveznice u međuspremnik nije uspjelo.",
    "Not grouped" : "Nije grupirano",
    "Recently contacted" : "Nedavno kontaktiran",
    "Circle" : "Krug",
    "User" : "Korisnik",
    "Group" : "Grupa",
    "Email" : "E-pošta",
    "Contact" : "Kontakt",
    "Member" : "Član",
    "Moderator" : "Moderator",
    "Admin" : "Administrator",
    "Owner" : "Vlasnik",
    "Invites" : "Pozivi",
    "Anyone can request membership" : "Svatko može zatražiti članstvo",
    "Members need to accept invitation" : "Članovi moraju prihvatiti poziv",
    "Memberships must be confirmed/accepted by a Moderator (requires Open)" : "Članstvo mora potvrditi/prihvatiti moderator (potrebno je Otvoreno)",
    "Members can also invite" : "Članovi također mogu pozivati",
    "Visibility" : "Vidljivost",
    "Visible to everyone" : "Vidljivo svima",
    "Circle membership" : "Članstvo u krugu",
    "Prevent circle from being a member of another circle" : "Spriječite da krug bude član drugog kruga",
    "Users" : "Korisnici",
    "Detailed name" : "Detaljan naziv",
    "Additional names" : "Dodatna imena",
    "Prefix" : "Prefiks",
    "Suffix" : "Sufiks",
    "Nickname" : "Nadimak",
    "Notes" : "Bilješke",
    "Website" : "Web-mjesto",
    "Location" : "Lokacija",
    "Federated Cloud ID" : "ID udruženog oblaka",
    "Home" : "Početna",
    "Work" : "Posao",
    "Other" : "Ostalo",
    "Address" : "Adresa",
    "Post office box" : "Poštanski sandučić",
    "Extended address" : "Proširena adresa",
    "City" : "Grad",
    "State or province" : "Savezna država ili pokrajina",
    "Postal code" : "Poštanski broj",
    "Country" : "Država",
    "Birthday" : "Rođendan",
    "Anniversary" : "Godišnjica",
    "Date of death" : "Datum smrti",
    "Instant messaging" : "Razmjena izravnih poruka",
    "Phone" : "Telefon",
    "Mobile" : "Mobitel",
    "Work mobile" : "Poslovni mobitel",
    "Home mobile" : "Privatni mobitel",
    "Fax" : "Faks",
    "Fax home" : "Privatni faks",
    "Fax work" : "Poslovni faks",
    "Pager" : "Dojavljivač",
    "Voice" : "Glas",
    "Car" : "Automobil",
    "Work pager" : "Poslovni dojavljivač",
    "Manager" : "Voditelj",
    "Social network" : "Društvena mreža",
    "Relationship to you" : "Odnos s vama",
    "Spouse" : "Supružnik",
    "Child" : "Dijete",
    "Mother" : "Majka",
    "Father" : "Otac",
    "Parent" : "Roditelj",
    "Brother" : "Brat",
    "Sister" : "Sestra",
    "Relative" : "Rođak/rođakinja",
    "Friend" : "Prijatelj/prijateljica",
    "Colleague" : "Kolega",
    "Assistant" : "Pomoćnik",
    "Related contacts" : "Povezani kontakti",
    "Agent" : "Agent",
    "Emergency" : "Hitno",
    "Co-worker" : "Suradnik",
    "Gender" : "Rod",
    "Female" : "Ženski",
    "Male" : "Muški",
    "None" : "Nema",
    "Unknown" : "Nepoznato",
    "Time zone" : "Vremenska zona",
    "Spoken languages" : "Poznati jezici",
    "_{failed} contact failed to be read_::_{failed} contacts failed to be read_" : ["{failed} kontakt nije pročitan","{failed} kontakata nije pročitano","{failed} kontakata nije pročitano"],
    "Unable to create circle {circleName}" : "Nije moguće stvoriti krug {circleName}",
    "Unable to delete circle {circleId}" : "Nije moguće izbrisati krug {circleId}",
    "Unable to delete contact" : "Nije moguće izbrisati kontakt"
},
"nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;");
