OC.L10N.register(
    "contacts",
    {
    "Details" : "Sīkāka informācija",
    "All contacts" : "Visi kontakti",
    "Contacts" : "Kontakti",
    "A contacts app for Nextcloud" : "Kontaktpersonu lietotne priekš Nextcloud",
    "The Nextcloud contacts app is a user interface for Nextcloud's CardDAV server. Easily sync contacts from various devices with your Nextcloud and edit them online.\n\n* 🚀 **Integration with other Nextcloud apps!** Currently Mail and Calendar – more to come.\n* 🎉 **Never forget a birthday!** You can sync birthdays and other recurring events with your Nextcloud Calendar.\n* 👥 **Sharing of Adressbooks!** You want to share your contacts with your friends or coworkers? No problem!\n* 🙈 **We’re not reinventing the wheel!** Based on the great and open SabreDAV library." : "Kontaktpersonu lietotne ir grafiskais interfeiss priekš Nextcloud iebūvētā CardDAV servera. Tas ļauj vienkārši sinhronizēt kontaktpersonu informāciju  no vairākām ierīcēm ar tavu Nextcloud serveri un rediģēt tos tiešsaistē.\n\n* 🚀 **Savienojums ar citām Nextcloud lietotnēm!** Pašlaik ar pastu un kalendāru - drīz vēl vairāk.\n* 🎉  **Nekad neaizmirsti kāda dzimšanas dienu** Sinhronizējat dzimšanas dienu un citas jubilejas ar Nextcloud Kalendāru.\n* 👥 **Adrešu grāmatu kopīgošana!** Velaties nodot kontaktpersonas informāciju draugam vai kolēģīm? Nekādu problēmu!.\n* 🙈 **Mēs nemēģinam atkal izgudrot riteni!** Bazēts uz SabreDAV, lieliskajām atvērtā pirmkoda bibliotēkām.",
    "Copy to full name" : "Kopēt uz pilnu vārdu",
    "Omit year" : "Izlaiduma gads",
    "General settings" : "Vispārīgie iestatījumi",
    "Send email" : "Sūtīt e-pastu",
    "Download" : "Lejupielādēt",
    "Rename" : "Pārsaukt",
    "Delete" : "Dzēst",
    "Copied" : "Nokopēts",
    "Copy link" : "Kopēt saiti",
    "_Shared with {num} entity_::_Shared with {num} entities_" : ["Kopīgots ar {num} entītijām","Kopīgots ar {num} entītiju","Kopīgots ar {num} entītijām"],
    "Share with users or groups" : "Koplietot ar lietotājiem vai grupām",
    "No users or groups" : "Nav lietotāji vai grupas",
    "can edit" : "var rediģēt",
    "Importing is disabled because there are no address books available" : "Importēšana ir atspējota, jo nav pieejamas adrešu grāmatas",
    "First name" : "Vārds",
    "Last name" : "Uzvārds",
    "Display name" : "Ekrāna vārds",
    "Last modified" : "Pēdējoreiz modificēts",
    "Sort by {sorting}" : "Kārtot pēc {sorting}",
    "Password protection" : "Password protection",
    "Save" : "Saglabāt",
    "Description" : "Apraksts",
    "Cancel" : "Atcelt",
    "Upload a new picture" : "Augšupielādēt jaunu attēlu",
    "Download picture" : "Lejupielādēt attēlu",
    "Delete picture" : "Dzēst attēlu",
    "Invalid image" : "Nederīgs attēls",
    "Pick an avatar" : "Izvēlēties avataru",
    "Error while processing the picture." : "Apstrādājot attēlu, radās kļūda.",
    "No contact selected" : "Nav izvēlēta kontaktpersona",
    "Select a contact on the list to begin" : "No saraksta izvēlaties kontaktpersonu lai sāktu darbību.",
    "Name" : "Vārds",
    "Title" : "Amats",
    "Company" : "Uzņēmums",
    "Generate QR Code" : "Ģenerēt QR kodu",
    "This contact is in read-only mode. You do not have permission to edit this contact." : "Šī kontaktpersona ir tikai lasīšanas režīmā. Jums nav atļaujas rediģēt šo kontaktpersonu.",
    "The contact you were trying to edit has changed. Please manually refresh the contact. Any further edits will be discarded." : "Kontaktpersonas informācija kuru rediģējāt ir mainījusies. Lūdzu pašrocīgi atjaunināt kontaktpersonas informāciju. Jebkuras tālākas izmaiņas tiks atmestas.",
    "Syntax error. Cannot open the contact." : "Sintakse kļūda. Nevar atvērt kontaktpersonu.",
    "Search contacts …" : "Meklēt kontaktpersonu",
    "No results" : "Nav rezultātu",
    "Personal circle" : "Personīgais loks",
    "Pending" : "Gaida",
    "Select type" : "Izvēlieties tipu",
    "Select Date" : "Izvēlieties datumu",
    "Add contact in group" : "Pievienot kontaktpersonu grupai",
    "Select option" : "Izvēlieties opciju",
    "New contact" : "Jauns kontakts",
    "Unable to create the contact." : "Nevar izveidot kontaktpersonu.",
    "Contact not found" : "Kontaktpersona nav atrasta!",
    "Close" : "Aizvērt",
    "Import" : "Importēt",
    "Not grouped" : "Negrupēts",
    "Circle" : "Loks",
    "User" : "Lietotājs",
    "Group" : "Grupa",
    "Email" : "E-pasts",
    "Contact" : "Kontakts",
    "Admin" : "Admin",
    "Owner" : "Īpašnieks",
    "Users" : "Lietotāji",
    "Detailed name" : "Izvērsts nosaukums",
    "Additional names" : "Papildu vārdi",
    "Prefix" : "Priedēklis",
    "Suffix" : "Piedēklis",
    "Nickname" : "Iesauka",
    "Notes" : "Piezīmes",
    "Website" : "Mājaslapa",
    "Location" : "Vieta",
    "Federated Cloud ID" : "Federated Cloud ID",
    "Home" : "Mājas",
    "Work" : "Darbs",
    "Other" : "Cits",
    "Address" : "Adrese",
    "Post office box" : "Pasta kastīte",
    "Extended address" : "Paplašinātā adrese",
    "City" : "Pilsēta",
    "State or province" : "Štats vai apgabals",
    "Postal code" : "Pasta kods",
    "Country" : "Valsts",
    "Birthday" : "Dzimšanas diena",
    "Anniversary" : "Gadadiena",
    "Date of death" : "Miršanas datums",
    "Instant messaging" : "Tūlītējā ziņojumapmaiņa",
    "Phone" : "Tālrunis",
    "Mobile" : "Mobilais",
    "Work mobile" : "Darba mobīlais",
    "Home mobile" : "Mājas mobīlais",
    "Fax" : "Fakss",
    "Fax home" : "Fax mājās",
    "Fax work" : "Fax darbā",
    "Pager" : "Peidžeris",
    "Voice" : "Balss",
    "Car" : "Automašīna",
    "Work pager" : "Darba peidžeris",
    "Manager" : "Vadītājs",
    "Social network" : "Sociālais tīkls",
    "Spouse" : "Dzīvesbiedrs",
    "Child" : "Bērns",
    "Mother" : "Māte",
    "Father" : "Tēvs",
    "Parent" : "Vecāki",
    "Brother" : "Brālis",
    "Sister" : "Māsa",
    "Relative" : "Tuvinieks",
    "Friend" : "Draugs",
    "Colleague" : "Kolēģijas",
    "Assistant" : "Asistents",
    "Agent" : "Aģents",
    "Emergency" : "Ārkārtas gadījums",
    "Co-worker" : "Darba biedrs",
    "Gender" : "Dzimums",
    "Female" : "Sieviete",
    "Male" : "Vīrietis",
    "None" : "Nav",
    "Unknown" : "Nezināms",
    "_{failed} contact failed to be read_::_{failed} contacts failed to be read_" : ["{failed} kontaktpersonas neizdevās nolasīt","{failed} kontaktpersonu neizdevās nolasīt","{failed} kontaktpersonas neizdevās nolasīt"]
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");
