OC.L10N.register(
    "contacts",
    {
    "Details" : "Talqayt",
    "Download" : "Sider",
    "Rename" : "Beddel isem",
    "Delete" : "Kkes",
    "Copy link" : "Nɣel aseɣwen",
    "Save" : "Sekles",
    "Cancel" : "Sefsex",
    "Name" : "Nom",
    "Title" : "Azwel",
    "No results" : "Ulac igmad",
    "Pending" : "Yegguni",
    "Close" : "Mdel",
    "User" : "Aseqdac",
    "Email" : "Imayl",
    "Website" : "Asmel web",
    "Home" : "Asnubeg",
    "Address" : "Adresse",
    "None" : "Ula d yiwen",
    "Unknown" : "Arussin"
},
"nplurals=2; plural=(n != 1);");
