OC.L10N.register(
    "contacts",
    {
    "Details" : "Details",
    "All contacts" : "Alle Kontakte",
    "Contacts" : "Kontakte",
    "A contacts app for Nextcloud" : "Eine Adressbuch-App für Nextcloud",
    "The Nextcloud contacts app is a user interface for Nextcloud's CardDAV server. Easily sync contacts from various devices with your Nextcloud and edit them online.\n\n* 🚀 **Integration with other Nextcloud apps!** Currently Mail and Calendar – more to come.\n* 🎉 **Never forget a birthday!** You can sync birthdays and other recurring events with your Nextcloud Calendar.\n* 👥 **Sharing of Adressbooks!** You want to share your contacts with your friends or coworkers? No problem!\n* 🙈 **We’re not reinventing the wheel!** Based on the great and open SabreDAV library." : "Die Nextcloud-Kontakte-App ist eine Benutzeroberfläche für den CardDAV-Server von Nextcloud. Synchronisiere deine Kontakte von unterschiedlichen Geräten mit Nextcloud und bearbeite diese online.\n\n* 🚀 **Integration mit anderen Nextcloud-Apps!** Aktuell Mail und Kalender — weitere sind in Planung.\n* 🎉 **Niemals einen Geburtstag vergessen!** Du kannst Geburtstage und andere wiederkehrende Ereignisse mit deinem Nextcloud-Kalender synchronisieren.\n* 👥 **Teilen von Adressbüchern!** Du möchtest deine Kontakte mit Freunden oder Kollegen teilen? Kein Problem!\n* 🙈 **Wir erfinden das Rad nicht neu!** Basierend auf der großartigen und offenen SabreDAV-Bibliothek.",
    "Copy to full name" : "In vollständigen Namen kopieren",
    "Omit year" : "Jahr weglassen",
    "Allow updating avatars from social media" : "Die Aktualisierung von Avataren aus sozialen Medien erlauben",
    "Please select a circle" : "Bitte wähle einen Kreis aus",
    "Loading circle …" : "Lade Kreis …",
    "Your request to join this circle is pending approval" : "Deine Anfrage, diesem Kreis beizutreten, muss noch genehmigt werden",
    "You are not a member of {circle}" : "Du bist kein Mitglied von {circle}",
    "There was an error fetching the member list" : "Fehler beim Laden der Mitgliederliste",
    "Loading contacts …" : "Lade Kontakte …",
    "There are no contacts yet" : "Es gibt noch keine Kontakte",
    "Create contact" : "Kontakt erstellen",
    "There are no contacts in this group" : "In dieser Gruppe befinden sich keine Kontakte",
    "Create contacts" : "Kontakte erstellen",
    "Add contacts" : "Kontakte hinzufügen",
    "Loading …" : "Lade …",
    "Add member" : "Mitglied hinzufügen",
    "Leave circle" : "Kreis verlassen",
    "Delete circle" : "Kreis löschen",
    "Contacts settings" : "Kontakte-Einstellungen",
    "General settings" : "Allgemeine Einstellungen",
    "Update avatars from social media" : "Aktualisiere Avatare aus sozialen Medien",
    "(refreshed once per week)" : "(Einmal wöchentlich aktualisiert)",
    "Address books" : "Adressbücher",
    "Export" : "Exportieren",
    "Send email" : "E-Mail senden",
    "Send email as BCC" : "E-Mail als Blindkopie senden",
    "Contact groups" : "Kontaktgruppen",
    "Create a new contact group" : "Neue Kontaktgruppe erstellen",
    "Contact group name" : "Name der Kontaktgruppe",
    "Circles" : "Kreise",
    "Create a new circle" : "einen neuen Kreis anlegen",
    "Show all groups" : "Alle Gruppen anzeigen",
    "Collapse groups" : "Gruppen einklappen",
    "Show all circles" : "Alle Kreise anzeigen",
    "Collapse circles" : "Kreise einklappen",
    "This group already exists" : "Diese Gruppe existiert bereits",
    "This circle already exists" : "Dieser Kreis existiert bereits",
    "An error happened during the creation of the circle" : "Es ist ein Fehler beim Erstellen des Kreises aufgetreten",
    "{addressbookname} (Disabled)" : "{addressbookname} (deaktiviert)",
    "Download" : "Herunterladen",
    "Show" : "Anzeigen",
    "Rename" : "Umbenennen",
    "Delete" : "Löschen",
    "Copied" : "Kopiert",
    "Cannot copy" : "Kopieren nicht möglich",
    "Copy link" : "Link kopieren",
    "Toggling of address book was not successful" : "Das Umschalten des Adressbuches war nicht erfolgreich.",
    "This will delete the address book and every contacts within it" : "Hierdurch wird das Adressbuch und alle Kontakte in ihm gelöscht",
    "Delete {addressbook}?" : " {addressbook} löschen?",
    "Deletion of address book was not successful." : "Das Löschen des Adressbuches war nicht erfolgreich.",
    "Renaming of address book was not successful." : "Das Umbenennen des Adressbuches war nicht erfolgreich.",
    "_%n contact_::_%n contacts_" : ["%n Kontakt","%n Kontakte"],
    "_%n group_::_%n groups_" : ["%n Gruppe","%n Gruppen"],
    "_Shared with {num} entity_::_Shared with {num} entities_" : ["Für {num} Entität freigegeben","Für {num} Entitäten freigegeben"],
    "Share with users or groups" : "Mit Benutzern oder Gruppen teilen",
    "Share with users" : "Mit Benutzern teilen",
    "No users or groups" : "Keine Benutzer oder Gruppen",
    "can edit" : "kann bearbeiten",
    "Unable to delete the share" : "Freigabe konnte nicht gelöscht werden",
    "Unable to change permissions" : "Berechtigungen konnten nicht geändert werden.",
    "Import contacts" : "Kontakte importieren",
    "Import into the {addressbookName} address book" : "In das Adressbuch {addressbookName} importieren",
    "Select local file" : "Lokale Datei auswählen",
    "Import from files" : "Aus Dateien importieren",
    "Importing is disabled because there are no address books available" : "Der Import ist deaktiviert, da kein Adressbuch verfügbar ist",
    "Choose a vCard file to import" : "Wähle eine vCard zum Importieren",
    "Add new address book" : "Adressbücher",
    "An error occurred, unable to create the address book" : "Es ist ein Fehler aufgetreten, das Adressbuch konnte nicht erstellt werden.",
    "First name" : "Vorname",
    "Last name" : "Nachname",
    "Phonetic first name" : "Phonetischer Vorname",
    "Phonetic last name" : "Phonetischer Nachname",
    "Display name" : "Anzeigename",
    "Last modified" : "Zuletzt geändert",
    "Sort by {sorting}" : "Sortieren nach {sorting}",
    "Manages" : "Verwaltet",
    "Oversees" : "Überwacht",
    "An error happened during the config change" : "Bei der Konfigurationsänderung ist ein Fehler aufgetreten",
    "Password protection" : "Passwortschutz",
    "Enforce password protection on files shared to this circle" : "Passwortschutz für Dateien erzwingen, die für diesen Kreis freigegeben sind.",
    "Use a unique password for all shares to this circle" : "Ein eindeutiges Passwort für alle Freigaben in diesem Kreis verwenden",
    "Unique password …" : "Eindeutiges Passwort …",
    "Save" : "Speichern",
    "Change unique password" : "Eindeutiges Passwort ändern",
    "Failed to save password. Please try again later." : "Fehler beim Speichern des Passworts. Bitte versuche es später noch einmal.",
    "Circle name" : "Name des Kreises",
    "Circle owned by {owner}" : "Kreis ist im Besitz von {owner}",
    "Request to join" : "Beitritt anfragen",
    "Description" : "Beschreibung",
    "There is no description for this circle" : "Es gibt keine Beschreibung für diesen Kreis",
    "Enter a description for the circle" : "Bitte gib eine Beschreibung für diesen Kreis ein",
    "An error happened during description sync" : "Es ist ein Fehler bei der Synchronisation der Beschreibung aufgetreten",
    "An error happened during name sync" : "Es ist ein Fehler bei der Synchronisation des Namens aufgetreten",
    "Add more info" : "Weitere Informationen hinzufügen",
    "More fields" : "Weitere Felder",
    "Crop contact photo" : "Kontaktfoto beschneiden",
    "Cancel" : "Abbrechen",
    "Upload a new picture" : "Neues Bild hochladen",
    "Choose from Files" : "Aus Dateien wählen",
    "Get from " : "Holen von",
    "Download picture" : "Bild herunterladen",
    "Delete picture" : "Bild löschen",
    "Please select a valid format" : "Bitte wähle ein gültiges Format aus.",
    "Invalid image" : "Ungültiges Bild",
    "Error cropping picture" : "Fehler beim Beschneiden des Bildes",
    "Pick an avatar" : "Avatar auswählen",
    "Error while processing the picture." : "Fehler beim Verarbeiten des Bildes.",
    "Avatar downloaded from social network" : "Avatar vom sozialen Netzwerk heruntergeladen",
    "Avatar already up to date" : "Avatar bereits auf dem neuesten Stand",
    "Avatar download failed" : "Avatar-Download fehlgeschlagen",
    "No contact selected" : "Kein Kontakt ausgewählt",
    "Select a contact on the list to begin" : "Wähle einen Kontakt aus der Liste aus, um zu beginnen.",
    "Name" : "Name",
    "Title" : "Titel",
    "Company" : "Firma",
    "This contact was broken and received a fix. Please review the content and click here to save it." : "Dieser Kontakt war defekt und wurde korrigiert. Bitte überprüfe den Inhalt und klicke hier, um ihn zu speichern.",
    "Edit" : "Bearbeiten",
    "Clone contact" : "Kontakt duplizieren",
    "Generate QR Code" : "QR-Code erzeugen",
    "Contact vCard as QR code" : "vCard des Kontakts als QR-Code",
    "Pick an address book" : "Ein Adressbuch auswählen",
    "Select address book" : "Adressbuch auswählen",
    "Go to talk conversation" : "Zur Talk-Unterhaltung wechseln",
    "View profile" : "Profil ansehen",
    "Media shares with you" : "Mit dir geteilte Medien",
    "Talk conversations with you" : "Talk-Unterhaltungen mit dir",
    "Calendar events with you" : "Kalendereinträge mit dir",
    "Deck cards with you" : "Deck-Karten mit dir",
    "No shared items with this contact" : "Keine geteilten Objekte mit diesem Kontakt",
    "This contact is in read-only mode. You do not have permission to edit this contact." : "Dieser Kontakt ist schreibgeschützt. Du hast keine Berechtigung, diesen Kontakt zu bearbeiten.",
    "The contact you were trying to edit has changed. Please manually refresh the contact. Any further edits will be discarded." : "Der Kontakt, den du versuchst zu bearbeiten, hat sich geändert. Bitte aktualisiere den Kontakt manuell. Alle weiteren Änderungen werden verworfen.",
    "Address book" : "Adressbuch",
    "Add contact to Birthday Calendar" : "Kontakt zum Geburtstagskalender hinzufügen",
    "Exclude contact from Birthday Calendar" : "Kontakt vom Geburtstagskalender ausschließen",
    "{title} at {organization}" : "{title} bei {organization}",
    "Syntax error. Cannot open the contact." : "Syntaxfehler. Der Kontakt kann nicht geöffnet werden.",
    "The contact does not exist on the server anymore." : "Der Kontakt existiert nicht mehr auf dem Server.",
    "Unable to retrieve the contact from the server, please check your network connection." : "Der Kontakt konnte nicht vom Server abgerufen werden, überprüfe bitte deine Netzwerkverbindung.",
    "An error occurred while trying to move the contact" : "Es ist ein Fehler beim Verschieben des Kontakts aufgetreten",
    "An error occurred while trying to copy the contact" : "Es ist ein Fehler beim Kopieren des Kontakts aufgetreten",
    "Unable to update contact" : "Kontakt konnte nicht aktualisiert werden.",
    "Search contacts …" : "Kontakte suchen …",
    "Add to {group}" : "Zur Gruppe {group} hinzufügen",
    "Remove {type}" : "Entferne {type}",
    "Search {types}" : "Suche {types}",
    "Search for people to add" : "Nach Personen zum Hinzufügen suchen",
    "No results" : "Keine Ergebnisse",
    "Add to group" : "Zur Gruppe hinzufügen",
    "Add {type}" : "Hinzufügen von {type}",
    "New circle name" : "Neuer Name des Kreises",
    "Personal circle" : "Persönlicher Kreis",
    "This circle will only be visible to you. Other members will not be able to see or use it." : "Dieser Kreis ist nur für dich sichtbar. Andere Mitglieder können ihn nicht sehen oder verwenden.",
    "Local circle" : "Lokaler Kreis",
    "This circle will not be shared with the other instances of the global scale" : "Dieser Kreis wird nicht mit den anderen Instanzen des \"Global Scales\" geteilt",
    "Create circle" : "Einen Kreis erstellen",
    "Loading members list …" : "Lade Mitgliederliste …",
    "The list of members is only visible to members of this circle" : "Die Mitgliederliste ist nur für Mitglieder dieses Kreises sichtbar",
    "You currently have no access to the member list" : "Du hast derzeit keinen Zugriff auf die Mitgliederliste.",
    "Add members" : "Mitglieder hinzufügen",
    "Show circle details" : "Details des Kreises anzeigen",
    "Add to {circle}" : "Zu {circle} hinzufügen",
    "Unable to get the recommendations list" : "Empfehlungsliste konnte nicht abgerufen werden",
    "Unable to get the results" : "Ergebnisse konnten nicht abgerufen werden",
    "Some members could not be added" : "Einige Mitglieder konnten nicht hinzugefügt werden",
    "There was an issue adding members to the circle" : "Beim Hinzufügen von Mitgliedern zum Kreis ist ein Problem aufgetreten",
    "Accept membership request" : "Mitgliedsanfrage annehmen",
    "Reject membership request" : "Mitgliedsanfrage ablehnen",
    "Manage level" : "Mitgliedsstufe verwalten",
    "Remove member" : "Mitglied entfernen",
    "Pending" : "Mitgliedsanfrage ablehnen",
    "Promote as sole owner" : "Als Alleineigentümer ernennen",
    "Promote to {level}" : "Zum {level} ernennen",
    "Demote to {level}" : "Herabstufen auf {level}",
    "Could not delete the member {displayName}" : "Das Mitglied {displayName} konnte nicht gelöscht werden ",
    "Could not change the member level to {level}" : "Mitgliedsstufe konnte nicht auf {level} geändert werden",
    "Could not accept membership request" : "Mitgliedsanfrage konnte nicht angenommen werden",
    "Chart" : "Diagramm",
    "Select chart …" : "Diagramm auswählen …",
    "Select type" : "Typ auswählen",
    "Select Date" : "Datum auswählen",
    "Add contact in group" : "Kontakt zur Gruppe hinzufügen",
    "none" : "Keine",
    "Select option" : "Option auswählen",
    "Add property of this type" : "Eigenschaft dieses Typs hinzufügen",
    "New contact" : "Neuer Kontakt",
    "Unable to create the contact." : "Kontakt konnte nicht erstellt werden.",
    "Contact not found" : "Kontakt nicht gefunden",
    "Group {group} not found" : "Gruppe {group} wurde nicht gefunden",
    "Close" : "Schließen",
    "_{success} contact added to {name}_::_{success} contacts added to {name}_" : ["{success} Kontakt wurde hinzugefügt zu {name}","{success} Kontakte wurden hinzugefügt zu {name}"],
    "_Adding {success} contact to {name}_::_Adding {success} contacts to {name}_" : ["Füge {success} Kontakt zu {name} hinzu","Füge {success} Kontakte zu {name} hinzu"],
    "_{count} error_::_{count} errors_" : ["{count} Fehler","{count} Fehler"],
    "_Importing %n contact into {addressbook}_::_Importing %n contacts into {addressbook}_" : ["Importiere %n Kontakt nach {addressbook}","Importiere %n Kontakte nach {addressbook}"],
    "_Done importing %n contact into {addressbook}_::_Done importing %n contacts into {addressbook}_" : ["Import von %n Kontakt nach {addressbook} abgeschlossen","Import von %n Kontakten nach {addressbook} abgeschlossen"],
    "Import" : "Importieren",
    "Could not copy" : "Konnte nicht kopiert werden",
    "Join circle" : "Kreis beitreten",
    "You are about to leave {circle}.\nAre you sure?" : "Du bist dabei {circle} zu verlassen.\nBist du dir sicher?",
    "Please confirm circle leave" : "Bitte bestätige das Verlassen  des Kreises",
    "Could not leave the circle {displayName}" : "Kreis {displayName} konnte nicht verlassen werden",
    "Unable to join the circle" : "Beitritt zum Kreis nicht möglich",
    "You are about to delete {circle}.\nAre you sure?" : "Du bist dabei den Kreis {circle} zu löschen.\nBist du dir sicher?",
    "Please confirm circle deletion" : "Bitte bestätige das Löschen des Kreises",
    "Unable to delete the circle" : "Kreis konnte nicht gelöscht werden",
    "Link copied to the clipboard" : "Link wurde in die Zwischenablage kopiert",
    "Could not copy link to the clipboard." : "Link konnte nicht in die Zwischenablage kopiert werden",
    "Not grouped" : "Nicht gruppiert",
    "Recently contacted" : "Zuletzt kontaktiert",
    "Organization chart" : "Organigramm",
    "Circles are groups of people that you can create yourself and with whom you can share data. They can be made up of other accounts or groups of accounts of the Nextcloud instance, but also of contacts from your address book or even external people by simply entering their e-mail addresses." : "Kreise sind Gruppen von Personen, die du selbst erstellen kannst und mit denen du Daten teilen kannst. Sie können aus anderen Konten oder Kontogruppen der Nextcloud-Instanz bestehen, aber auch aus Kontakten aus deinem Adressbuch oder sogar aus externen Personen, indem du einfach deren E-Mail-Adressen eingibst.",
    "Circle" : "Kreis",
    "User" : "Benutzer",
    "Group" : "Gruppe",
    "Email" : "E-Mail-Adresse",
    "Contact" : "Kontakt",
    "Member" : "Mitglied",
    "Moderator" : "Moderator",
    "Admin" : "Administrator",
    "Owner" : "Besitzer",
    "Invites" : "Einladungen",
    "Anyone can request membership" : "Jeder kann eine Mitgliedschaft beantragen ",
    "Members need to accept invitation" : "Mitglieder müssen die Einladung annehmen ",
    "Memberships must be confirmed/accepted by a Moderator (requires Open)" : "Mitgliedschaften müssen von einem Moderator bestätigt / angenommen werden (erfordert Offen)",
    "Members can also invite" : "Mitglieder können auch einladen",
    "Visibility" : "Sichtbarkeit",
    "Visible to everyone" : "Für jeden sichtbar",
    "Circle membership" : "Kreis-Mitgliedschaft",
    "Prevent circle from being a member of another circle" : "Kreis daran hindern, Mitglied eines anderen Kreises zu sein",
    "Users" : "Benutzer",
    "Email addresses" : "E-Mail-Adressen",
    "Detailed name" : "Detaillierter Name",
    "Additional names" : "Zusätzliche Namen",
    "Prefix" : "Präfix",
    "Suffix" : "Suffix",
    "Nickname" : "Spitzname",
    "Notes" : "Notizen",
    "Website" : "Internetseite",
    "Location" : "Ort",
    "Federated Cloud ID" : "Federated-Cloud-ID",
    "Home" : "Privat",
    "Work" : "Arbeit",
    "Other" : "Andere",
    "Address" : "Adresse",
    "Post office box" : "Postfach",
    "Extended address" : "Erweiterte Adresse",
    "City" : "Stadt",
    "State or province" : "Bundesland oder Region",
    "Postal code" : "Postleitzahl",
    "Country" : "Land",
    "Birthday" : "Geburtstag",
    "Anniversary" : "Jahrestag",
    "Date of death" : "Todestag",
    "Instant messaging" : "Instant Messaging",
    "Phone" : "Telefon",
    "Mobile" : "Mobil",
    "Work mobile" : "Arbeit mobil",
    "Home mobile" : "Privat mobil",
    "Fax" : "Fax",
    "Fax home" : "Fax privat",
    "Fax work" : "Fax Arbeit",
    "Pager" : "Pager",
    "Voice" : "Anruf",
    "Car" : "Auto",
    "Work pager" : "Arbeit Pager",
    "Manager" : "Geschäftsführer",
    "Social network" : "Soziales Netzwerk",
    "Relationship to you" : "Verbindung zu dir",
    "Spouse" : "Partner",
    "Child" : "Kind",
    "Mother" : "Mutter",
    "Father" : "Vater",
    "Parent" : "Eltern",
    "Brother" : "Bruder",
    "Sister" : "Schwester",
    "Relative" : "Verwandter",
    "Friend" : "Freund",
    "Colleague" : "Kollege",
    "Assistant" : "Assistent",
    "Related contacts" : "Zugehörige Kontakte",
    "Agent" : "Vertreter",
    "Emergency" : "Notfall",
    "Co-worker" : "Kollege",
    "Gender" : "Geschlecht",
    "Female" : "Weiblich",
    "Male" : "Männlich",
    "None" : "Keine",
    "Unknown" : "Unbekannt",
    "Time zone" : "Zeitzone",
    "Spoken languages" : "Gesprochene Sprachen",
    "_{failed} contact failed to be read_::_{failed} contacts failed to be read_" : ["{failed} Kontakt konnte nicht gelesen werden","{failed} Kontakte konnten nicht gelesen werden"],
    "An error has occurred in circle(s). Check the console for more details." : "Es ist ein Fehler in Kreis(en) ist aufgetreten. Weitere Informationen findest du in der Konsole.",
    "Unable to create circle {circleName}" : "Kreis {circleName} konnte nicht erstellt werden",
    "Unable to delete circle {circleId}" : "Kontakt konnte nicht gelöscht werden",
    "Unable to delete contact" : "Kontakt konnte nicht gelöscht werden"
},
"nplurals=2; plural=(n != 1);");
