OC.L10N.register(
    "contacts",
    {
    "Details" : "詳細",
    "All contacts" : "すべての連絡先",
    "Contacts" : "連絡先",
    "A contacts app for Nextcloud" : "Nextcloud の連絡先アプリ",
    "The Nextcloud contacts app is a user interface for Nextcloud's CardDAV server. Easily sync contacts from various devices with your Nextcloud and edit them online.\n\n* 🚀 **Integration with other Nextcloud apps!** Currently Mail and Calendar – more to come.\n* 🎉 **Never forget a birthday!** You can sync birthdays and other recurring events with your Nextcloud Calendar.\n* 👥 **Sharing of Adressbooks!** You want to share your contacts with your friends or coworkers? No problem!\n* 🙈 **We’re not reinventing the wheel!** Based on the great and open SabreDAV library." : "Nextcloud の連絡先アプリは、 Nextcloud の CardDAV サーバーのユーザーインターフェースです。 さまざまなデバイスの連絡先を Nextcloud で簡単に同期し、オンラインで編集できます。\n\n*🚀**他の Nextcloud アプリケーションとの統合！**現在、メールとカレンダー - 今後の予定です。\n*🎉**誕生日を忘れないでください！**あなたの Nextcloud カレンダーで誕生日やその他の定期的なイベントを同期できます。\n*👥** 連絡先の共有！**あなたの友達や同僚とあなたの連絡先を共有したいですか？ 問題ない！\n*🙈**私たちは車輪を再発明していません！**偉大でオープンな SabreDAV ライブラリをベースにしています。",
    "Copy to full name" : "フルネームをコピー",
    "Omit year" : "年を省略する",
    "Allow updating avatars from social media" : "ソーシャルメディアからのアバターの更新を許可する",
    "Please select a circle" : "サークルを選択",
    "Loading circle …" : "サークルを読み込み中...",
    "Your request to join this circle is pending approval" : "このサークルへの参加リクエストは承認待ちです",
    "You are not a member of {circle}" : "あなたはサークル{circle}のメンバーではありません",
    "There was an error fetching the member list" : "メンバーリストの取得中にエラーが発生しました",
    "Loading contacts …" : "連絡先を読み込み中...",
    "There are no contacts yet" : "連絡先はまだありません",
    "Create contact" : "連絡先を作成",
    "There are no contacts in this group" : "このグループには連絡先がありません",
    "Create contacts" : "連絡先を作成",
    "Add contacts" : "連絡先を追加",
    "Loading …" : "読み込み中…",
    "Add member" : "メンバーの追加",
    "Leave circle" : "サークルを退会する",
    "Delete circle" : "サークルを削除",
    "Contacts settings" : "連絡先の設定",
    "General settings" : "一般設定",
    "Update avatars from social media" : "SNSでアバターをアップデート",
    "(refreshed once per week)" : "(週に1回更新)",
    "Address books" : "アドレス帳",
    "Export" : "エクスポート",
    "Send email" : "メールを送信",
    "Send email as BCC" : "BCCでメール送信",
    "Contact groups" : "連絡先グループ",
    "Create a new contact group" : "新規連絡先グループを作成",
    "Contact group name" : "連絡先グループ名",
    "Circles" : "サークル",
    "Create a new circle" : "新しいサークルを作成する",
    "Show all groups" : "すべてのグループを表示",
    "Collapse groups" : "グループを折りたたむ",
    "Show all circles" : "すべてのサークルを表示",
    "Collapse circles" : "サークルを折りたたむ",
    "This group already exists" : "このグループはすでに存在しています",
    "This circle already exists" : "このサークルはすでに存在します",
    "An error happened during the creation of the circle" : "サークルの作成中にエラーが発生しました",
    "{addressbookname} (Disabled)" : "{addressbookname} (無効)",
    "Download" : "ダウンロード",
    "Show" : "表示",
    "Rename" : "名前を変更",
    "Delete" : "削除",
    "Copied" : "コピーしました",
    "Cannot copy" : "コピーできません",
    "Copy link" : "リンクをコピー",
    "Toggling of address book was not successful" : "アドレス帳の切り替えに失敗",
    "This will delete the address book and every contacts within it" : "これはアドレス帳とその中のすべての連絡先を削除します",
    "Delete {addressbook}?" : "{addressbook} を削除しますか？",
    "Deletion of address book was not successful." : "アドレス帳の削除に失敗しました。",
    "Renaming of address book was not successful." : "アドレス帳の名前変更に失敗しました。",
    "_%n contact_::_%n contacts_" : ["%n 連絡先"],
    "_%n group_::_%n groups_" : ["%n グループ"],
    "_Shared with {num} entity_::_Shared with {num} entities_" : ["{num} 個のエンティティと共有"],
    "Share with users or groups" : "ユーザーまたはグループと共有する",
    "Share with users" : "ユーザーに共有",
    "No users or groups" : "ユーザーまたはグループはありません",
    "can edit" : "編集を許可",
    "Unable to delete the share" : "共有を削除できません",
    "Unable to change permissions" : "権限を変更できません。",
    "Import contacts" : "連絡先のインポート",
    "Import into the {addressbookName} address book" : "アドレス帳 {addressbookName} にインポートします",
    "Select local file" : "ローカルファイルの選択",
    "Import from files" : "ファイルからインポート ",
    "Importing is disabled because there are no address books available" : "使用可能なアドレス帳がないため、インポートは無効です",
    "Choose a vCard file to import" : "インポートするvCardファイルを選択",
    "Add new address book" : "新しいアドレス帳を追加する",
    "An error occurred, unable to create the address book" : "エラーが発生し、アドレス帳を作成できませんでした。",
    "First name" : "名",
    "Last name" : "姓",
    "Phonetic first name" : "めい",
    "Phonetic last name" : "せい",
    "Display name" : "表示名",
    "Last modified" : "最終更新日",
    "Sort by {sorting}" : "{sorting} で整列",
    "Manages" : "管理",
    "Oversees" : "統括",
    "An error happened during the config change" : "構成の変更中にエラーが発生しました",
    "Password protection" : "パスワード保護",
    "Enforce password protection on files shared to this circle" : "このサークルへのファイル共有にはパスワードを強制します",
    "Use a unique password for all shares to this circle" : "このサークルへのすべての共有に一意のパスワードを使用します",
    "Unique password …" : "固有パスワード...",
    "Save" : "保存",
    "Change unique password" : "固有パスワードを変更",
    "Failed to save password. Please try again later." : "パスワードを保存できませんでした。後でもう一度やり直してください",
    "Circle name" : "サークル名",
    "Circle owned by {owner}" : "{owner}が所有しているサークル",
    "Request to join" : "参加リクエスト",
    "Description" : "詳細",
    "There is no description for this circle" : "このサークルについての説明はありません",
    "Enter a description for the circle" : "サークルについて説明を入力してください",
    "An error happened during description sync" : "説明の同期中にエラーが発生しました",
    "An error happened during name sync" : "名前の同期中にエラーが発生しました",
    "Add more info" : "さらに情報を追加",
    "More fields" : "その他のフィールド",
    "Crop contact photo" : "写真を切り抜き",
    "Cancel" : "キャンセル",
    "Upload a new picture" : "新しい写真をアップロードする",
    "Choose from Files" : "ファイルから選択",
    "Get from " : "次から入手:",
    "Download picture" : "画像をダウンロード",
    "Delete picture" : "画像を削除",
    "Please select a valid format" : "有効なフォーマットを選択してください。",
    "Invalid image" : "無効な画像",
    "Error cropping picture" : "画像のトリミング中にエラーが発生しました",
    "Pick an avatar" : "アバターを選択",
    "Error while processing the picture." : "画像の加工中にエラーが発生しました",
    "Avatar downloaded from social network" : "SNSでダウンロード済みのアバター",
    "Avatar already up to date" : "アバターはすでに最新です",
    "Avatar download failed" : "アバターのダウンロードに失敗しました",
    "No contact selected" : "連絡先が選択されていません",
    "Select a contact on the list to begin" : "開始するには、リストの連絡先を選択してください",
    "Name" : "名前",
    "Title" : "タイトル",
    "Company" : "会社",
    "This contact was broken and received a fix. Please review the content and click here to save it." : "この連絡先は変更され、修正を受信しました。内容を確認してクリックで保存してください。",
    "Edit" : "編集",
    "Clone contact" : "連絡先の複製",
    "Generate QR Code" : "QRコードを生成",
    "Contact vCard as QR code" : "QRコードでの連絡先vCard",
    "Pick an address book" : "アドレス帳を選ぶ",
    "Select address book" : "アドレス帳を選ぶ",
    "Go to talk conversation" : "Talkのチャットへ移動",
    "View profile" : "プロフィールを表示",
    "This contact is in read-only mode. You do not have permission to edit this contact." : "この連絡先は読み取り専用モードです。 この連絡先を編集する権限がありません。",
    "The contact you were trying to edit has changed. Please manually refresh the contact. Any further edits will be discarded." : "編集しようとした連絡先が変更されました。 連絡先を手動で更新してください。 それ以上の編集は破棄されます。",
    "Address book" : "アドレス帳",
    "Add contact to Birthday Calendar" : "誕生日カレンダーに連絡先を追加する",
    "Exclude contact from Birthday Calendar" : "誕生日カレンダーから連絡先を除外する",
    "{title} at {organization}" : "{organization}の{title}",
    "Syntax error. Cannot open the contact." : "構文エラー。 連絡先を開けません",
    "The contact does not exist on the server anymore." : "連絡先はサーバー上に存在しません。",
    "Unable to retrieve the contact from the server, please check your network connection." : "サーバーから連絡先を取得できないので、ネットワークの接続をご確認ください。",
    "An error occurred while trying to move the contact" : "連絡先の移動中にエラーが発生しました",
    "An error occurred while trying to copy the contact" : "連絡先のコピー中にエラーが発生しました",
    "Unable to update contact" : "連絡先を更新できません",
    "Search contacts …" : "連絡先を検索...",
    "Add to {group}" : "{group}に追加",
    "Remove {type}" : "{type} を削除",
    "Search {types}" : "{types} を検索",
    "Search for people to add" : "追加するメンバーを検索",
    "No results" : "該当なし",
    "Add to group" : "グループに追加",
    "Add {type}" : "{type}を追加",
    "New circle name" : "新しいサークル名",
    "Personal circle" : "パーソナルサークル",
    "This circle will only be visible to you. Other members will not be able to see or use it." : "このサークルはあなただけに表示されます。他のメンバーはそれを見たり使用したりすることはできません。",
    "Local circle" : "ローカルサークル",
    "This circle will not be shared with the other instances of the global scale" : "このサークルは、グローバルスケールの他のインスタンスと共有されません",
    "Create circle" : "サークルを作成",
    "Loading members list …" : "メンバーリストを読み込んでいます…",
    "The list of members is only visible to members of this circle" : "メンバーのリストは、このサークルのメンバーにのみ表示されます",
    "You currently have no access to the member list" : "メンバーリストへのアクセス権がありません",
    "Add members" : "メンバーの追加",
    "Show circle details" : "サークル詳細を表示",
    "Add to {circle}" : "{circle} に追加",
    "Unable to get the recommendations list" : "おすすめリストを取得できません",
    "Unable to get the results" : "結果を取得できません",
    "Some members could not be added" : "一部のメンバーを追加できませんでした",
    "There was an issue adding members to the circle" : "サークルにメンバーを追加する際に問題が発生しました",
    "Accept membership request" : "メンバーシップリクエストを受け入れる",
    "Reject membership request" : "メンバーシップリクエストを拒否",
    "Manage level" : "レベルを管理",
    "Remove member" : "メンバーを削除",
    "Pending" : "保留中",
    "Promote as sole owner" : "唯一の所有者に昇格",
    "Promote to {level}" : "{level}に昇格",
    "Demote to {level}" : "{level}に降格",
    "Could not delete the member {displayName}" : "メンバー{displayName}を削除できませんでした",
    "Could not change the member level to {level}" : "メンバーレベルを{level}に変更できませんでした",
    "Could not accept membership request" : "メンバーシップリクエストを承諾できませんでした",
    "Chart" : "チャート",
    "Select chart …" : "組織図を選択...",
    "Select type" : "タイプを選択",
    "Select Date" : "日付を選択",
    "Add contact in group" : "グループに連絡先を追加",
    "none" : "なし",
    "Select option" : "オプションを選択",
    "Add property of this type" : "このタイプのプロパティーを追加",
    "New contact" : "新しい連絡先",
    "Unable to create the contact." : "連絡先を追加できません。",
    "Contact not found" : "連絡先がありません",
    "Group {group} not found" : "グループ {group} が見つかりません",
    "Close" : "閉じる",
    "_{success} contact added to {name}_::_{success} contacts added to {name}_" : ["{success} 件の連絡先を {name} に追加しました"],
    "_Adding {success} contact to {name}_::_Adding {success} contacts to {name}_" : ["{success} 件の連絡先を {name} に追加中"],
    "_{count} error_::_{count} errors_" : ["{count} つのエラー"],
    "_Importing %n contact into {addressbook}_::_Importing %n contacts into {addressbook}_" : ["{アドレス帳}に %n の連絡先をインポートしています。"],
    "_Done importing %n contact into {addressbook}_::_Done importing %n contacts into {addressbook}_" : ["{アドレス帳}に %n 連絡先のインポートが完了しました"],
    "Import" : "インポート",
    "Could not copy" : "コピーできませんでした",
    "Join circle" : "サークルに参加",
    "You are about to leave {circle}.\nAre you sure?" : "{circle}を離れようとしています。\nよろしいですか？",
    "Please confirm circle leave" : "サークルから退会しますか",
    "Could not leave the circle {displayName}" : "サークル{displayName}を退会できませんでした",
    "Unable to join the circle" : "サークルに参加できません",
    "You are about to delete {circle}.\nAre you sure?" : "{circle}を削除しようとしています。\nよろしいですか？",
    "Please confirm circle deletion" : "サークルの削除しますか",
    "Unable to delete the circle" : "サークルを削除できません",
    "Link copied to the clipboard" : "クリップボードにリンクをコピーしました",
    "Could not copy link to the clipboard." : "クリップボードにコピーできませんでした",
    "Not grouped" : "グループ化されていません",
    "Recently contacted" : "最近連絡した",
    "Organization chart" : "組織図",
    "Circles are groups of people that you can create yourself and with whom you can share data. They can be made up of other accounts or groups of accounts of the Nextcloud instance, but also of contacts from your address book or even external people by simply entering their e-mail addresses." : "サークルは自分で作成できるグループで、データを共有する先として利用できます。サークルは、Nextcloudインスタンスのアカウントやグループだけでなく、アドレス帳に登録されている連絡先やメールアドレスを入力して外部の人も追加してグループを構成できます。",
    "Circle" : "サークル",
    "User" : "ユーザー",
    "Group" : "グループ",
    "Email" : "メール",
    "Contact" : "連絡先",
    "Member" : "メンバー",
    "Moderator" : "モデレータ",
    "Admin" : "管理者",
    "Owner" : "所有者",
    "Invites" : "招待",
    "Anyone can request membership" : "誰でもメンバーへの参加をリクエストできます",
    "Members need to accept invitation" : "メンバーは招待を承認する必要があります",
    "Memberships must be confirmed/accepted by a Moderator (requires Open)" : "メンバーシップは、モデレーターにより確認/承認が必要です（開く要求）",
    "Members can also invite" : "メンバーによる招待も可能",
    "Visibility" : "公開レベル",
    "Visible to everyone" : "すべての人に公開",
    "Circle membership" : "サークルメンバーシップ",
    "Prevent circle from being a member of another circle" : "サークルが別のサークルのメンバーにならないようにする",
    "Users" : "ユーザー",
    "Email addresses" : "メールアドレス",
    "Detailed name" : "詳細名",
    "Additional names" : "ミドルネーム",
    "Prefix" : "プレフィックス",
    "Suffix" : "サフィックス",
    "Nickname" : "ニックネーム",
    "Notes" : "ノート",
    "Website" : "ウェブサイト",
    "Location" : "場所",
    "Federated Cloud ID" : "クラウド共有ID",
    "Home" : "自宅",
    "Work" : "職場",
    "Other" : "その他",
    "Address" : "住所",
    "Post office box" : "郵便ポスト",
    "Extended address" : "拡張アドレス",
    "City" : "市町村",
    "State or province" : "都道府県",
    "Postal code" : "郵便番号",
    "Country" : "国名",
    "Birthday" : "誕生日",
    "Anniversary" : "記念日",
    "Date of death" : "命日",
    "Instant messaging" : "インスタントメッセージ",
    "Phone" : "電話番号",
    "Mobile" : "携帯",
    "Work mobile" : "職場携帯",
    "Home mobile" : "個人携帯",
    "Fax" : "FAX",
    "Fax home" : "自宅FAX",
    "Fax work" : "職場FAX",
    "Pager" : "ポケベル",
    "Voice" : "音声番号",
    "Car" : "自動車",
    "Work pager" : "ワークページャー",
    "Manager" : "マネージャー",
    "Social network" : "ソーシャルネットワーク",
    "Relationship to you" : "あなたとの関係",
    "Spouse" : "配偶者",
    "Child" : "子供",
    "Mother" : "母親",
    "Father" : "父親",
    "Parent" : "両親",
    "Brother" : "兄弟",
    "Sister" : "姉妹",
    "Relative" : "親族",
    "Friend" : "友人",
    "Colleague" : "同僚",
    "Assistant" : "アシスタント",
    "Related contacts" : "関連した連絡先",
    "Agent" : "エージェント",
    "Emergency" : "緊急",
    "Co-worker" : "同僚",
    "Gender" : "性別",
    "Female" : "女性",
    "Male" : "男性",
    "None" : "なし",
    "Unknown" : "不明",
    "Time zone" : "時間帯",
    "Spoken languages" : "話せる言語",
    "_{failed} contact failed to be read_::_{failed} contacts failed to be read_" : ["{failed}連絡先の読み込みができませんでした。"],
    "An error has occurred in circle(s). Check the console for more details." : "サークルでエラーが発生しました。コンソールで詳細を確認してください。",
    "Unable to create circle {circleName}" : "サークル {circleName} を作成できません",
    "Unable to delete circle {circleId}" : "サークル{circleId}を削除できません",
    "Unable to delete contact" : "連絡先を削除できません。"
},
"nplurals=1; plural=0;");
