OC.L10N.register(
    "contacts",
    {
    "Details" : "Detalles",
    "All contacts" : "Todos los contactos",
    "Contacts" : "Contactos",
    "A contacts app for Nextcloud" : "Una app de contactos para Nextcloud.",
    "The Nextcloud contacts app is a user interface for Nextcloud's CardDAV server. Easily sync contacts from various devices with your Nextcloud and edit them online.\n\n* 🚀 **Integration with other Nextcloud apps!** Currently Mail and Calendar – more to come.\n* 🎉 **Never forget a birthday!** You can sync birthdays and other recurring events with your Nextcloud Calendar.\n* 👥 **Sharing of Adressbooks!** You want to share your contacts with your friends or coworkers? No problem!\n* 🙈 **We’re not reinventing the wheel!** Based on the great and open SabreDAV library." : "La app de Contactos de Nextcloud es una interfaz de usuario para el servidor CardDAV de Nextcloud. Sincroniza fácilmente los contactos de varios dispositivos con tu Nextcloud y edítalos en línea\n\n* 🚀 **Integración con otras apps de Nextcloud.** Actualmente Correo y Calendario; más por llegar.\n* 🎉 **No olvides nunca un calendario.** Puedes sincronizar los calendarios y otros eventos recurrentes con tu calendario de Nextcloud.\n* 👥 **Compartir libretas de dirección.** ¿Quieres compartir tus contactos con tus amigos y colegas? ¡No hay problema!\n* 🙈 **No reinventamos la rueda.l** Basada en la gran biblioteca de código abierto SabreDAV.",
    "Copy to full name" : "Copiar al nombre completo",
    "Omit year" : "Omitir el año",
    "Allow updating avatars from social media" : "Permitir la actualización de avatares desde medios sociales",
    "Please select a circle" : "Por favor, selecciona un círculo",
    "Loading circle …" : "Cargando círculo…",
    "Your request to join this circle is pending approval" : "Tu solicitud de unión a este círculo está pendiente de aprobación",
    "You are not a member of {circle}" : "No eres miembro de {circle}",
    "There was an error fetching the member list" : "Ha habido un error al recuperar la lista de miembros",
    "Loading contacts …" : "Cargando contactos …",
    "There are no contacts yet" : "Aún no hay contactos",
    "Create contact" : "Crear contacto",
    "There are no contacts in this group" : "No hay contactos en este grupo",
    "Create contacts" : "Crear contactos",
    "Add contacts" : "Añadir contactos",
    "Loading …" : "Cargando …",
    "Add member" : "Añadir miembro",
    "Leave circle" : "Abandonar círculo",
    "Delete circle" : "Eliminar círculo",
    "Contacts settings" : "Configuración de contactos",
    "General settings" : "Ajustes generales",
    "Update avatars from social media" : "Actualizar avatares desde redes sociales",
    "(refreshed once per week)" : "(actualizado una vez a la semana)",
    "Address books" : "Libretas de direcciones",
    "Export" : "Exportar",
    "Send email" : "Enviar correo electrónico",
    "Send email as BCC" : "Enviar correo como BCC",
    "Contact groups" : "Grupos de contactos",
    "Create a new contact group" : "Crear un nuevo grupo de contactos",
    "Contact group name" : "Nombre del grupo de contactos",
    "Circles" : "Círculos",
    "Create a new circle" : "Crear un círculo nuevo",
    "Show all groups" : "Mostrar todos los grupos",
    "Collapse groups" : "Colapsar grupos",
    "Show all circles" : "Mostrar todos los círculos",
    "Collapse circles" : "Colapsar círculos",
    "This group already exists" : "Este grupo ya existe",
    "This circle already exists" : "Este círculo ya existe",
    "An error happened during the creation of the circle" : "Ha ocurrido un error durante la creación del círculo",
    "{addressbookname} (Disabled)" : "{addressbookname} (Deshabilitado)",
    "Download" : "Descargar",
    "Show" : "Mostrar",
    "Rename" : "Cambiar nombre",
    "Delete" : "Eliminar",
    "Copied" : "Copiado",
    "Cannot copy" : "No se pudo copiar",
    "Copy link" : "Copiar enlace",
    "Toggling of address book was not successful" : "El cambio de la libreta de direcciones falló",
    "This will delete the address book and every contacts within it" : "Esto eliminará la libreta de direcciones y todos los contactos que hay en ella",
    "Delete {addressbook}?" : "¿Eliminar {addressbook}?",
    "Deletion of address book was not successful." : "El borrado de la libreta de direcciones falló.",
    "Renaming of address book was not successful." : "El renombrado de la libreta de direcciones falló.",
    "_%n contact_::_%n contacts_" : ["%n contacto","%n contactos","%n contactos"],
    "_%n group_::_%n groups_" : ["%n grupo","%n grupos","%n grupos"],
    "_Shared with {num} entity_::_Shared with {num} entities_" : ["Compartido con {num} entidad","Compartido con {num} entidades","Compartido con {num} entidades"],
    "Share with users or groups" : "Compartir con otros usuarios o grupos",
    "Share with users" : "Compartir con los usuarios",
    "No users or groups" : "No hay usuarios ni grupos.",
    "can edit" : "puede editar",
    "Unable to delete the share" : "No se ha podido eliminar el recurso compartido",
    "Unable to change permissions" : "No se han podido cambiar los permisos",
    "Import contacts" : "Importar contactos",
    "Import into the {addressbookName} address book" : "Importar en la libreta de direcciones {addressbookName}",
    "Select local file" : "Selecciona archivo local",
    "Import from files" : "Importar desde archivos",
    "Importing is disabled because there are no address books available" : "Importar está desactivado porque no hay libretas de direcciones disponibles",
    "Choose a vCard file to import" : "Elige un archivo vCard para importar",
    "Add new address book" : "Agregar nueva libreta de direcciones",
    "An error occurred, unable to create the address book" : "Ha ocurrido un error, no se ha podido crear la libreta de direcciones",
    "First name" : "Nombre",
    "Last name" : "Apellido",
    "Phonetic first name" : "Nombre fonético",
    "Phonetic last name" : "Apellido fonético",
    "Display name" : "Nombre mostrado",
    "Last modified" : "Última modificación",
    "Sort by {sorting}" : "Ordenar por {sorting}",
    "Manages" : "Gestiona",
    "Oversees" : "Vigila",
    "An error happened during the config change" : "Ha ocurrido un error durante el cambio de la configuración",
    "Password protection" : "Protección con contraseña",
    "Enforce password protection on files shared to this circle" : "Exigir la protección por contraseña de los archivos compartidos en este círculo",
    "Use a unique password for all shares to this circle" : "Utilizar una contraseña única para todos los recursos compartidos en este círculo",
    "Unique password …" : "Contraseña única ...",
    "Save" : "Guardar",
    "Change unique password" : "Cambiar la contraseña única",
    "Failed to save password. Please try again later." : "No se ha podido guardar la contraseña. Por favor, inténtelo de nuevo más tarde.",
    "Circle name" : "Nombre del círculo",
    "Circle owned by {owner}" : "Círculo propiedad de {owner}",
    "Request to join" : "Solicitar unirse",
    "Description" : "Descripción",
    "There is no description for this circle" : "No hay descripción para este círculo",
    "Enter a description for the circle" : "Introduzca una descripción para el círculo",
    "An error happened during description sync" : "Ha ocurrido un error al sincronizar la descripción",
    "An error happened during name sync" : "Ha ocurrido un error al sincronizar el nombre",
    "Add more info" : "Añadir más información",
    "More fields" : "Mas campos",
    "Crop contact photo" : "Recortar foto del contacto",
    "Cancel" : "Cancelar",
    "Upload a new picture" : "Subir una imagen nueva",
    "Choose from Files" : "Escoger desde Archivos",
    "Get from " : "Obtener de",
    "Download picture" : "Descargar imagen",
    "Delete picture" : "Eliminar imagen",
    "Please select a valid format" : "Por favor, seleccione un formato válido",
    "Invalid image" : "La imagen no es válida",
    "Error cropping picture" : "Error al recortar la foto",
    "Pick an avatar" : "Escoger un avatar",
    "Error while processing the picture." : "Error al procesar la imagen",
    "Avatar downloaded from social network" : "Avatar descargado desde red social",
    "Avatar already up to date" : "Avatar ya actualizado",
    "Avatar download failed" : "Descarga del avatar fallido",
    "No contact selected" : "No hay contactos seleccionados",
    "Select a contact on the list to begin" : "Seleccione un contacto de la lista para comenzar",
    "Name" : "Nombre",
    "Title" : "Título",
    "Company" : "Compañía",
    "This contact was broken and received a fix. Please review the content and click here to save it." : "Este contacto estaba dañado y se ha reparado. Por favor, revise el contenido y haga clic aquí para guardarlo.",
    "Edit" : "Editar",
    "Clone contact" : "Clonar contacto",
    "Generate QR Code" : "Generar código QR",
    "Contact vCard as QR code" : "Contacto vCard como código QR",
    "Pick an address book" : "Escoge una libreta de direcciones",
    "Select address book" : "Selecciona una libreta de direcciones",
    "Go to talk conversation" : "Ir a la conversación de talk",
    "View profile" : "Ver perfil",
    "Media shares with you" : "Multimedia compartido contigo",
    "Talk conversations with you" : "Conversaciones Talk contigo",
    "Calendar events with you" : "Eventos de calendario contigo",
    "Deck cards with you" : "Tarjetas de Deck contigo",
    "No shared items with this contact" : "No hay artículos compartidos con este contacto",
    "This contact is in read-only mode. You do not have permission to edit this contact." : "El contacto está en modo de solo lectura. No tienes permiso para editar este contacto.",
    "The contact you were trying to edit has changed. Please manually refresh the contact. Any further edits will be discarded." : "El contacto que estaba intentando editar ha cambiado, Por favor, actualice el contacto manualmente. Cualquier otra edición será descartada.",
    "Address book" : "Libreta de direcciones",
    "Add contact to Birthday Calendar" : "Añadir contacto al calendario de Cumpleaños",
    "Exclude contact from Birthday Calendar" : "Excluir contacto del calendario de Cumpleaños",
    "{title} at {organization}" : "{title} en {organization}",
    "Syntax error. Cannot open the contact." : "Error de sintaxis. No se puede abrir el contacto",
    "The contact does not exist on the server anymore." : "El contacto ya no existe en el servidor.",
    "Unable to retrieve the contact from the server, please check your network connection." : "Imposible recibir el contacto del servidor, por favor comprueba tu conexión de red.",
    "An error occurred while trying to move the contact" : "Ocurrió un error intentando mover el contacto",
    "An error occurred while trying to copy the contact" : "Ocurrió un error intentando copiar el contacto",
    "Unable to update contact" : "No fue posible actualizar el contacto",
    "Search contacts …" : "Buscar contactos...",
    "Add to {group}" : "Añadir a {group}",
    "Remove {type}" : "Eliminar {type}",
    "Search {types}" : "Buscar en {types}",
    "Search for people to add" : "Buscar personas a añadir",
    "No results" : "Sin resultados",
    "Add to group" : "Añadir a grupo",
    "Add {type}" : "Añadir {type}",
    "New circle name" : "Nuevo nombre de círculo",
    "Personal circle" : "Círculo personal",
    "This circle will only be visible to you. Other members will not be able to see or use it." : "Este círculo solo será visible para usted. No podrá verlo ni utilizarlo el resto de miembros.",
    "Local circle" : "Círculo local",
    "This circle will not be shared with the other instances of the global scale" : "Este círculo no se compartirá con las demás instancias de escala global",
    "Create circle" : "Crear círculo",
    "Loading members list …" : "Cargando la lista de miembros ...",
    "The list of members is only visible to members of this circle" : "La lista de miembros solo es visible para los miembros de este círculo",
    "You currently have no access to the member list" : "Actualmente no tiene acceso a la lista de miembros",
    "Add members" : "Añadir miembros",
    "Show circle details" : "Mostrar detalles del círculo",
    "Add to {circle}" : "Añadir a {circle}",
    "Unable to get the recommendations list" : "No se puede obtener la lista de recomendaciones",
    "Unable to get the results" : "No se puede obtener los resultados",
    "Some members could not be added" : "Algunos miembros no se han podido añadir",
    "There was an issue adding members to the circle" : "Hubo un problema al añadir miembros al círculo",
    "Accept membership request" : "Aceptar solicitud de unión",
    "Reject membership request" : "Rechazar solicitud de unión",
    "Manage level" : "Administrar el nivel",
    "Remove member" : "Eliminar miembro",
    "Pending" : "Pendiente",
    "Promote as sole owner" : "Promover como único propietario",
    "Promote to {level}" : "Promover a {level}",
    "Demote to {level}" : "Descender a {level}",
    "Could not delete the member {displayName}" : "No se ha podido eliminar el miembro {displayName}",
    "Could not change the member level to {level}" : "No se ha podido modificar el nivel del miembro a {level}",
    "Could not accept membership request" : "No se ha podido aceptar la solicitud de unión",
    "Chart" : "Gráfico",
    "Select chart …" : "Seleccionar cuadro ...",
    "Select type" : "Selecciona tipo",
    "Select Date" : "Seleccione la fecha",
    "Add contact in group" : "Añadir contacto en grupo",
    "none" : "ninguno",
    "Select option" : "Selecciona opción",
    "Add property of this type" : "Añadir una propiedad de este tipo",
    "New contact" : "Nuevo contacto",
    "Unable to create the contact." : "No se ha podido crear el contacto.",
    "Contact not found" : "Contacto no encontrado",
    "Group {group} not found" : "Grupo {group} no encontrado",
    "Close" : "Cerrar",
    "_{success} contact added to {name}_::_{success} contacts added to {name}_" : ["{success} contacto añadido a {name}","{success} contactos añadidos a {name}","{success} contactos añadidos a {name}"],
    "_Adding {success} contact to {name}_::_Adding {success} contacts to {name}_" : ["Añadiendo {success} contacto a {name}","Añadiendo {success} contactos a {name}","Añadiendo {success} contactos a {name}"],
    "_{count} error_::_{count} errors_" : ["{count} error","{count} errores","{count} errores"],
    "_Importing %n contact into {addressbook}_::_Importing %n contacts into {addressbook}_" : ["Importando %n contacto en {addressbook}","Importando %n contactos en {addressbook}","Importando %n contactos en {addressbook}"],
    "_Done importing %n contact into {addressbook}_::_Done importing %n contacts into {addressbook}_" : ["Completado importando %n contacto en {addressbook}","Completado importando %n contactos en {addressbook}","Completado importando %n contactos en {addressbook}"],
    "Import" : "Importar",
    "Could not copy" : "No se ha podido copiar",
    "Join circle" : "Unirse al círculo",
    "You are about to leave {circle}.\nAre you sure?" : "Está a punto de salir de {circle}.\n¿Está seguro?",
    "Please confirm circle leave" : "Por favor, confirme que desea salir del círculo",
    "Could not leave the circle {displayName}" : "No se pudo salir del círculo {displayName}",
    "Unable to join the circle" : "No se ha podido unirse al círculo",
    "You are about to delete {circle}.\nAre you sure?" : "Estás a punto de eliminar {circle}.\n¿Desea continuar?",
    "Please confirm circle deletion" : "Por favor, confirme que desea eliminar el círculo",
    "Unable to delete the circle" : "No se pudo eliminar el círculo",
    "Link copied to the clipboard" : "Enlace copiado al portapapeles",
    "Could not copy link to the clipboard." : "No se pudo copiar el enlace al portapapeles.",
    "Not grouped" : "No agrupado",
    "Recently contacted" : "Contactados recientemente",
    "Organization chart" : "Cuadro organizacional",
    "Circles are groups of people that you can create yourself and with whom you can share data. They can be made up of other accounts or groups of accounts of the Nextcloud instance, but also of contacts from your address book or even external people by simply entering their e-mail addresses." : "Los Círculos son grupos de personas que puede crear Ud. mismo y con los que puede compartir datos. Pueden estar compuestos de otras cuentas o grupos de cuentas de la instancia de Nextcloud, pero también de contactos de su libreta de direcciones o inclusive personas externas simplemente ingresando sus direcciones de correo electrónico.",
    "Circle" : "Círculo",
    "User" : "Usuario",
    "Group" : "Grupo",
    "Email" : "Correo electrónico",
    "Contact" : "Contacto",
    "Member" : "Participante",
    "Moderator" : "Moderador",
    "Admin" : "Administrador",
    "Owner" : "Propietario",
    "Invites" : "Invitaciones",
    "Anyone can request membership" : "Cualquiera puede solicitar membresía",
    "Members need to accept invitation" : "Los miembros deben aceptar la invitación",
    "Memberships must be confirmed/accepted by a Moderator (requires Open)" : "Las membresías deben ser confirmadas/aceptadas por un moderador (requiere Open)",
    "Members can also invite" : "Los miembros también pueden invitar",
    "Visibility" : "Visibilidad",
    "Visible to everyone" : "Visible para todo el mundo",
    "Circle membership" : "Membresía del círculo",
    "Prevent circle from being a member of another circle" : "Evitar que el círculo sea miembro de otro círculo",
    "Users" : "Usuarios",
    "Email addresses" : "Direcciones de correo",
    "Detailed name" : "Nombre",
    "Additional names" : "Nombres adicionales",
    "Prefix" : "Prefijo",
    "Suffix" : "Sufijo",
    "Nickname" : "Apodo",
    "Notes" : "Notas",
    "Website" : "Sitio web",
    "Location" : "Ubicación",
    "Federated Cloud ID" : "ID Nube Federada",
    "Home" : "Casa",
    "Work" : "Trabajo",
    "Other" : "Otro",
    "Address" : "Dirección",
    "Post office box" : "Apartado de correos",
    "Extended address" : "Dirección extendida",
    "City" : "Ciudad",
    "State or province" : "Estado o provincia",
    "Postal code" : "Código postal",
    "Country" : "País",
    "Birthday" : "Fecha de nacimiento",
    "Anniversary" : "Aniversario",
    "Date of death" : "Fecha de fallecimiento",
    "Instant messaging" : "Mensajería instantánea",
    "Phone" : "Teléfono",
    "Mobile" : "Móvil",
    "Work mobile" : "Móvil del trabajo",
    "Home mobile" : "Casa móvil",
    "Fax" : "Fax",
    "Fax home" : "Fax de casa",
    "Fax work" : "Fax del trabajo",
    "Pager" : "Localizador",
    "Voice" : "Voz",
    "Car" : "Coche",
    "Work pager" : "Busca del trabajo",
    "Manager" : "Mánager",
    "Social network" : "Redes sociales",
    "Relationship to you" : "Relación contigo",
    "Spouse" : "Cónyuge",
    "Child" : "Hijo",
    "Mother" : "Madre",
    "Father" : "Padre",
    "Parent" : "Progenitor",
    "Brother" : "Hermano",
    "Sister" : "Hermana",
    "Relative" : "Pariente",
    "Friend" : "Amigo",
    "Colleague" : "Colega",
    "Assistant" : "Asistente",
    "Related contacts" : "Contactos relacionados",
    "Agent" : "Agente",
    "Emergency" : "Emergencia",
    "Co-worker" : "Compañero de trabajo",
    "Gender" : "Género",
    "Female" : "Mujer",
    "Male" : "Hombre",
    "None" : "Ninguno",
    "Unknown" : "Desconocido",
    "Time zone" : "Zona horaria",
    "Spoken languages" : "Idiomas hablados",
    "_{failed} contact failed to be read_::_{failed} contacts failed to be read_" : ["{failed} contacto no se ha podido leer","{failed} contactos no se han podido leer","{failed} contactos no se han podido leer"],
    "An error has occurred in circle(s). Check the console for more details." : "Ha ocurrido un error en uno o varios circles. Chequee la consola para más detalles.",
    "Unable to create circle {circleName}" : "No se pudo crear el círculo {circleName}",
    "Unable to delete circle {circleId}" : "No se pudo eliminar el círculo {circleId}",
    "Unable to delete contact" : "No se ha podido eliminar el contacto"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
