OC.L10N.register(
    "contacts",
    {
    "Details" : "Podrobnosti",
    "All contacts" : "Všechny kontakty",
    "Contacts" : "Kontakty",
    "A contacts app for Nextcloud" : "Aplikace pro správu kontaktů pro Nextcloud",
    "The Nextcloud contacts app is a user interface for Nextcloud's CardDAV server. Easily sync contacts from various devices with your Nextcloud and edit them online.\n\n* 🚀 **Integration with other Nextcloud apps!** Currently Mail and Calendar – more to come.\n* 🎉 **Never forget a birthday!** You can sync birthdays and other recurring events with your Nextcloud Calendar.\n* 👥 **Sharing of Adressbooks!** You want to share your contacts with your friends or coworkers? No problem!\n* 🙈 **We’re not reinventing the wheel!** Based on the great and open SabreDAV library." : "Nextcloud aplikace Kontakty je uživatelské rozhraní k CardDAV serveru, vestavěnému v Nextcloud. Jednoduše synchronizujte kontakty z různých zařízení se svým Nextcloud a upravujte je online.\n\n* 🚀 **Napojení na ostatní Nextcloud aplikace!** Nyní E-mailový klient a Kalendář – další jsou na cestě.\n* 🎉 **Nikdy nezapomeňte na něčí narozeniny!** Je možné synchronizovat narozeniny a ostatní opakující se události s vaším Nextcloud Kalendářem.\n* 👥 **Sdílení adresářů kontaktů!** Chcete sdílet své kontakty s přáteli nebo spolupracovníky? Žádný problém!\n* 🙈 **Nevymýšlíme znovu kolo!** Založeno na skvělé a otevřené softwarové knihovně SabreDAV.",
    "Copy to full name" : "Zkopírovat do celého jména",
    "Omit year" : "Vynechat rok",
    "Allow updating avatars from social media" : "Povolit aktualizaci zástupných obrázků ze sociálních sítí",
    "Please select a circle" : "Vyberte okruh",
    "Loading circle …" : "Načítání okruhu…",
    "Your request to join this circle is pending approval" : "Vaše žádost o přidání do tohoto okruhu čeká na schválení",
    "You are not a member of {circle}" : "Nejste členy {circle}",
    "There was an error fetching the member list" : "Při získávání seznamu členů došlo k chybě",
    "Loading contacts …" : "Načítání kontaktů…",
    "There are no contacts yet" : "Zatím zde nejsou žádné kontakty",
    "Create contact" : "Vytvořit kontakt",
    "There are no contacts in this group" : "V této skupině nejsou žádné kontakty",
    "Create contacts" : "Vytvořit kontakty",
    "Add contacts" : "Přidat kontakty",
    "Loading …" : "Načítání…",
    "Add member" : "Přidat člena",
    "Leave circle" : "Opustit okruh",
    "Delete circle" : "Smazat okruh",
    "Contacts settings" : "Nastavení pro Kontakty",
    "General settings" : "Obecná nastavení",
    "Update avatars from social media" : "Aktualizovat zástupné obrázky ze sociálních médií",
    "(refreshed once per week)" : "(znovu načteno každý týden)",
    "Address books" : "Adresáře kontaktů",
    "Export" : "Exportovat",
    "Send email" : "Odeslat e-mail",
    "Send email as BCC" : "Odeslat e-mail jako skrytou kopii (bcc)",
    "Contact groups" : "Skupiny kontaktů",
    "Create a new contact group" : "Vytvořit novou skupinu kontaktů",
    "Contact group name" : "Název skupiny kontaktů",
    "Circles" : "Okruhy",
    "Create a new circle" : "Vytvořit nový okruh",
    "Show all groups" : "Zobrazit všechny skupiny",
    "Collapse groups" : "Sbalit skupiny",
    "Show all circles" : "Zobrazit všechny okruhy",
    "Collapse circles" : "Sbalit okruhy",
    "This group already exists" : "Tato skupina už existuje",
    "This circle already exists" : "Takto nazvaný okruh už existuje",
    "An error happened during the creation of the circle" : "V průběhu vytváření okruhu došlo k chybě",
    "{addressbookname} (Disabled)" : "{addressbookname} (vypnuto)",
    "Download" : "Stáhnout",
    "Show" : "Zobrazit",
    "Rename" : "Přejmenovat",
    "Delete" : "Smazat",
    "Copied" : "Zkopírováno",
    "Cannot copy" : "Nelze kopírovat",
    "Copy link" : "Zkopírovat odkaz",
    "Toggling of address book was not successful" : "Vyp/zap. adresáře kontaktů nebylo úspěšné",
    "This will delete the address book and every contacts within it" : "Toto smaže adresář kontaktů a všechny obsažené kontakty",
    "Delete {addressbook}?" : "Smazat {addressbook}?",
    "Deletion of address book was not successful." : "Smazání adresáře kontaktů nebylo úspěšné.",
    "Renaming of address book was not successful." : "Přejmenování adresáře kontaktů nebylo úspěšné.",
    "_%n contact_::_%n contacts_" : ["%n kontakt","%n kontakty","%n kontaktů","%n kontakty"],
    "_%n group_::_%n groups_" : ["%n skupina","%n skupiny","%n skupin","%n skupiny"],
    "_Shared with {num} entity_::_Shared with {num} entities_" : ["Sdíleno s {num} entitou","Sdíleno se {num} entitami","Sdíleno s {num} entitami","Sdíleno se {num} entitami"],
    "Share with users or groups" : "Sdílet s uživateli nebo skupinami",
    "Share with users" : "Nasdílet uživatelům",
    "No users or groups" : "Žádní uživatelé nebo skupiny",
    "can edit" : "může upravovat",
    "Unable to delete the share" : "Sdílení se nedaří smazat",
    "Unable to change permissions" : "Oprávnění se nedaří změnit",
    "Import contacts" : "Importovat kontakty",
    "Import into the {addressbookName} address book" : "Importovat do adresáře kontaktů {addressbookName}",
    "Select local file" : "Vybrat místní soubor",
    "Import from files" : "Importovat ze souborů",
    "Importing is disabled because there are no address books available" : "Import je vypnutý, protože nejsou k dispozici žádné adresáře kontaktů",
    "Choose a vCard file to import" : "Vyberte vCard soubor, který chcete importovat",
    "Add new address book" : "Přidat nový adresář kontaktů",
    "An error occurred, unable to create the address book" : "Vyskytla se chyba, adresář kontaktů se nepodařilo vytvořit",
    "First name" : "Jméno",
    "Last name" : "Příjmení",
    "Phonetic first name" : "Jméno foneticky",
    "Phonetic last name" : "Příjmení foneticky",
    "Display name" : "Zobrazované jméno",
    "Last modified" : "Naposledy upraveno",
    "Sort by {sorting}" : "Řadit podle {sorting}",
    "Manages" : "Spravuje",
    "Oversees" : "Dohlíží",
    "An error happened during the config change" : "V průběhu měnění nastavení došlo k chybě",
    "Password protection" : "Ochrana heslem",
    "Enforce password protection on files shared to this circle" : "Vynutit ochranu heslem pro soubory nasdílené tomuto okruhu",
    "Use a unique password for all shares to this circle" : "Použít neopakující se heslo pro veškerá sdílení tomuto okruhu",
    "Unique password …" : "Neopakující se heslo…",
    "Save" : "Uložit",
    "Change unique password" : "Změnit neopakující se heslo",
    "Failed to save password. Please try again later." : "Heslo se nepodařilo uložit. Zkuste to prosím znovu později.",
    "Circle name" : "Název okruhu",
    "Circle owned by {owner}" : "Okruh vlastněný {owner}",
    "Request to join" : "Požádat o přidání",
    "Description" : "Popis",
    "There is no description for this circle" : "K tomuto okruhu neexistuje popis",
    "Enter a description for the circle" : "Zadejte popis k okruhu",
    "An error happened during description sync" : "V průběhu synchronizace popisu došlo k chybě",
    "An error happened during name sync" : "V průběhu synchronizace jména došlo k chybě",
    "Add more info" : "Přidat další informace",
    "More fields" : "Další kolonky",
    "Crop contact photo" : "Oříznout fotku kontaktu",
    "Cancel" : "Storno",
    "Upload a new picture" : "Nahrát nový obrázek",
    "Choose from Files" : "Zvolit ze Souborů",
    "Get from " : "Získat z",
    "Download picture" : "Stáhnout si obrázek",
    "Delete picture" : "Smazat obrázek",
    "Please select a valid format" : "Vyberte platný formát",
    "Invalid image" : "Neplatný obrázek",
    "Error cropping picture" : "Chyba při ořezávání obrázku",
    "Pick an avatar" : "Zvolte avatara",
    "Error while processing the picture." : "Chyba při zpracovávání obrázku.",
    "Avatar downloaded from social network" : "Zástupný obrázek získán ze sociální sítě",
    "Avatar already up to date" : "Zástupný obrázek už je aktuální",
    "Avatar download failed" : "Stažení zástupného obrázku se nezdařilo",
    "No contact selected" : "Nevybrán žádný kontakt",
    "Select a contact on the list to begin" : "Začněte výběrem kontaktu ze seznamu",
    "Name" : "Zobrazované jméno",
    "Title" : "Funkce",
    "Company" : "Společnost/organizace",
    "This contact was broken and received a fix. Please review the content and click here to save it." : "Tento kontakt byl poškozený a proto automaticky opraven. Zkontrolujte prosím správnost obsahu a kliknutím sem ho uložte.",
    "Edit" : "Upravit",
    "Clone contact" : "Klonovat kontakt",
    "Generate QR Code" : "Vytvořit QR kód",
    "Contact vCard as QR code" : "Vizitka (ve formátu vCard) kontaktu jako QR kód",
    "Pick an address book" : "Zvolit adresář kontaktů",
    "Select address book" : "Vybrat adresář kontaktů",
    "Go to talk conversation" : "Přejít do konverzace v Talk",
    "View profile" : "Zobrazit profil ",
    "Media shares with you" : "Média vám nasdílená",
    "Talk conversations with you" : "Konverzace v Talk s vámi",
    "Calendar events with you" : "Události v kalendáři s vámi",
    "Deck cards with you" : "Deck karty s vámi",
    "No shared items with this contact" : "S tímto kontaktem nemáte žádné sdílené položky",
    "This contact is in read-only mode. You do not have permission to edit this contact." : "Tento kontakt je v režimu pouze pro čtení. Nemáte oprávnění k úpravě tohoto kontaktu.",
    "The contact you were trying to edit has changed. Please manually refresh the contact. Any further edits will be discarded." : "Kontakt který jste se pokoušeli upravit se mezitím změnil. Ručně ho znovu načtěte. Mezitím provedené úpravy budou zahozeny.",
    "Address book" : "Adresář kontaktů",
    "Add contact to Birthday Calendar" : "Přidat kontakt do kalendáře s narozeninami",
    "Exclude contact from Birthday Calendar" : "Vynechat kontakt z kalendáře s narozeninami",
    "{title} at {organization}" : "{title} v {organization}",
    "Syntax error. Cannot open the contact." : "Chyba syntaxe. Kontakt nelze otevřít.",
    "The contact does not exist on the server anymore." : "Kontakt už na serveru neexistuje.",
    "Unable to retrieve the contact from the server, please check your network connection." : "Kontakt se nedaří získat ze serveru – prosím zkontrolujte své připojení k síti.",
    "An error occurred while trying to move the contact" : "Při pokusu o přesunutí kontaktu došlo k chybě",
    "An error occurred while trying to copy the contact" : "Při pokusu o zkopírování kontaktu došlo k chybě",
    "Unable to update contact" : "Nedaří se zaktualizovat kontakt",
    "Search contacts …" : "Hledat v kontaktech…",
    "Add to {group}" : "Přidat do {group}",
    "Remove {type}" : "Odebrat {type}",
    "Search {types}" : "Hledat {types}",
    "Search for people to add" : "Vyhledat lidi které přidat",
    "No results" : "Žádné výsledky",
    "Add to group" : "Přidat do skupiny",
    "Add {type}" : "Přidat {type}",
    "New circle name" : "Název pro nový okruh",
    "Personal circle" : "Osobní okruh",
    "This circle will only be visible to you. Other members will not be able to see or use it." : "Tento okruh bude viditelný pouze vám. Ostatní členové ho neuvidí a nebudou ho moci používat.",
    "Local circle" : "Místní okruh",
    "This circle will not be shared with the other instances of the global scale" : "Tento okruh nebude sdílen s ostatními instancemi globálního rozsahu",
    "Create circle" : "Vytvořit okruh",
    "Loading members list …" : "Načítání seznamu členů…",
    "The list of members is only visible to members of this circle" : "Seznam členů je viditelný pouze členům tohoto okruhu",
    "You currently have no access to the member list" : "V tuto chvíli nemáte přístup k seznamu členů",
    "Add members" : "Přidat členy",
    "Show circle details" : "Zobrazit podrobnosti o okruhu",
    "Add to {circle}" : "Přidat do {circle}",
    "Unable to get the recommendations list" : "Nedaří se načíst seznam doporučení",
    "Unable to get the results" : "Nedaří se získat výsledky",
    "Some members could not be added" : "Některé členy nebylo možné přidat",
    "There was an issue adding members to the circle" : "Došlo k potížím při přidávání členů do okruhu",
    "Accept membership request" : "Přijmout žádost o členství",
    "Reject membership request" : "Odmítnout žádost o členství",
    "Manage level" : "Spravovat stupeň",
    "Remove member" : "Odebrat člena",
    "Pending" : "Čekající",
    "Promote as sole owner" : "Povýšit na jediného vlastníka",
    "Promote to {level}" : "Povýšit na {level}",
    "Demote to {level}" : "Degradovat na {level}",
    "Could not delete the member {displayName}" : "Nedaří se smazat člena {displayName}",
    "Could not change the member level to {level}" : "Nedaří se změnit oprávnění člena na stupeň {level}",
    "Could not accept membership request" : "Žádost o členství nemohla být přijata",
    "Chart" : "Graf",
    "Select chart …" : "Vybrat graf…",
    "Select type" : "Vybrat typ",
    "Select Date" : "Vybrat datum",
    "Add contact in group" : "Přidat kontakt do skupiny",
    "none" : "žádné",
    "Select option" : "Vybrat volbu",
    "Add property of this type" : "Přidat vlastnost tohoto typu",
    "New contact" : "Nový kontakt",
    "Unable to create the contact." : "Nedaří se vytvořit kontakt.",
    "Contact not found" : "Kontakt nenalezen",
    "Group {group} not found" : "Skupina {group} nenalezena",
    "Close" : "Zavřít",
    "_{success} contact added to {name}_::_{success} contacts added to {name}_" : ["{success} kontakt přidán do {name}","{success} kontakty přidány do {name}","{success} kontaktů přidáno do {name}","{success} kontakty přidány do {name}"],
    "_Adding {success} contact to {name}_::_Adding {success} contacts to {name}_" : ["Přidává se {success} kontakt do {name}","Přidávají se {success} kontakty do {name}","Přidává se {success} kontaktů do {name}","Přidávají se {success} kontakty do {name}"],
    "_{count} error_::_{count} errors_" : ["{count} chyba","{count} chyby","{count} chyb","{count} chyby"],
    "_Importing %n contact into {addressbook}_::_Importing %n contacts into {addressbook}_" : ["Importuje se %n kontakt do {addressbook}","Importují se %n kontakty do {addressbook}","Importuje se %n kontaktů do {addressbook}","Importují se %n kontakty do {addressbook}"],
    "_Done importing %n contact into {addressbook}_::_Done importing %n contacts into {addressbook}_" : ["Dokončen import %n kontaktu do {addressbook}","Dokončen import %n kontaktů do {addressbook}","Dokončen import %n kontaktů do {addressbook}","Dokončen import %n kontaktů do {addressbook}"],
    "Import" : "Importovat",
    "Could not copy" : "Nedaří se zkopírovat",
    "Join circle" : "Přidat se do okruhu",
    "You are about to leave {circle}.\nAre you sure?" : "Chystáte se opustit  {circle}.\nOpravdu to chcete?",
    "Please confirm circle leave" : "Potvrďte úmysl opustit okruh",
    "Could not leave the circle {displayName}" : "Nedaří se opustit okruh {displayName}",
    "Unable to join the circle" : "K okruhu se nedaří připojit",
    "You are about to delete {circle}.\nAre you sure?" : "Chystáte se smazat {circle}.\nOpravdu to chcete?",
    "Please confirm circle deletion" : "Potvrďte úmysl smazat okruh",
    "Unable to delete the circle" : "Okruh se nedaří smazat",
    "Link copied to the clipboard" : "Odkaz zkopírován do schránky",
    "Could not copy link to the clipboard." : "Odkaz se nedaří zkopírovat do schránky.",
    "Not grouped" : "Neseskupené",
    "Recently contacted" : "Nedávno kontaktovaní",
    "Organization chart" : "Organizační graf",
    "Circles are groups of people that you can create yourself and with whom you can share data. They can be made up of other accounts or groups of accounts of the Nextcloud instance, but also of contacts from your address book or even external people by simply entering their e-mail addresses." : "Okruhy jsou skupiny (lidí), které jste si sami vytvořili a se kterými sdílíte data. Mohou být tvořeny jinými účty či jejich skupinami z instance Nextcloud, ale také kontakty z vašeho adresáře kontaktů nebo i externí lidé – stačí jen zadat jejich e-mailové adresy.",
    "Circle" : "Okruh",
    "User" : "Uživatel",
    "Group" : "Skupina",
    "Email" : "E-mail",
    "Contact" : "Kontakt",
    "Member" : "Člen",
    "Moderator" : "Moderátor",
    "Admin" : "Správce",
    "Owner" : "Vlastník",
    "Invites" : "Pozvání",
    "Anyone can request membership" : "O členství si může požádat kdokoli",
    "Members need to accept invitation" : "Je třeba, aby členové pozvání přijali",
    "Memberships must be confirmed/accepted by a Moderator (requires Open)" : "Členství bude muset být potvrzeno/přijato moderátorem (vyžaduje Otevřené)",
    "Members can also invite" : "Členové také mohou zvát",
    "Visibility" : "Viditelnost",
    "Visible to everyone" : "Viditelné všem",
    "Circle membership" : "Členství v okruzích",
    "Prevent circle from being a member of another circle" : "Zabránit okruhu aby byl členem jiného okruhu",
    "Users" : "Uživatelé",
    "Email addresses" : "E-mailové adresy",
    "Detailed name" : "Jméno podrobně",
    "Additional names" : "Další jména",
    "Prefix" : "Předpona",
    "Suffix" : "Přípona",
    "Nickname" : "Přezdívka",
    "Notes" : "Poznámky",
    "Website" : "Webová stránka",
    "Location" : "Umístění",
    "Federated Cloud ID" : "Identifikátor v rámci federovaného cloudu",
    "Home" : "Domů",
    "Work" : "Práce",
    "Other" : "Jiný",
    "Address" : "Adresa",
    "Post office box" : "P.O. box",
    "Extended address" : "Rozšířená adresa",
    "City" : "Město",
    "State or province" : "Stát nebo provincie",
    "Postal code" : "Směrovací číslo",
    "Country" : "Země",
    "Birthday" : "Narozeniny",
    "Anniversary" : "Výročí",
    "Date of death" : "Datum úmrtí",
    "Instant messaging" : "Komunikátor",
    "Phone" : "Telefon",
    "Mobile" : "Mobil",
    "Work mobile" : "Pracovní mobil",
    "Home mobile" : "Osobní mobil",
    "Fax" : "Fax",
    "Fax home" : "Fax domů",
    "Fax work" : "Fax do práce",
    "Pager" : "Pager",
    "Voice" : "Hlas",
    "Car" : "Auto",
    "Work pager" : "Pracovní pager",
    "Manager" : "Nadřízený",
    "Social network" : "Sociální síť",
    "Relationship to you" : "Souvislost s vámi",
    "Spouse" : "Partner(ka)",
    "Child" : "Dítě",
    "Mother" : "Matka",
    "Father" : "Otec",
    "Parent" : "Rodič",
    "Brother" : "Bratr",
    "Sister" : "Sestra",
    "Relative" : "Příbuzný",
    "Friend" : "Kamarád(ka)",
    "Colleague" : "Kolega",
    "Assistant" : "Asistent",
    "Related contacts" : "Související kontakty",
    "Agent" : "Agent",
    "Emergency" : "Nouze",
    "Co-worker" : "Spolupracovník",
    "Gender" : "Pohlaví",
    "Female" : "Žena",
    "Male" : "Muž",
    "None" : "Žádné",
    "Unknown" : "Neznámé",
    "Time zone" : "Časové pásmo",
    "Spoken languages" : "Jazyky, kterými hovoří",
    "_{failed} contact failed to be read_::_{failed} contacts failed to be read_" : ["{failed} kontakt se nepodařilo načíst","{failed} kontakty se nepodařilo načíst","{failed} kontaktů se nepodařilo načíst","{failed} kontakty se nepodařilo načíst"],
    "An error has occurred in circle(s). Check the console for more details." : "V okruzích došlo k chybě. Další podrobnosti naleznete v konzoli.",
    "Unable to create circle {circleName}" : "Nedaří se vytvořit okruh {circleName}",
    "Unable to delete circle {circleId}" : "Nedaří se smazat okruh {circleId}",
    "Unable to delete contact" : "Nedaří se smazat kontakt"
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n >= 2 && n <= 4 && n % 1 == 0) ? 1: (n % 1 != 0 ) ? 2 : 3;");
