OC.L10N.register(
    "contacts",
    {
    "Contacts" : "Hubungi ",
    "Download" : "Muat turun",
    "Rename" : "Namakan",
    "Delete" : "Padam",
    "can edit" : "boleh mengubah",
    "Password protection" : "Password protection",
    "Save" : "Simpan",
    "Description" : "Keterangan",
    "Cancel" : "Batal",
    "Name" : "Nama",
    "Title" : "Judul",
    "Pending" : "Dalam proses",
    "Close" : "Tutup",
    "Import" : "Import",
    "User" : "User",
    "Group" : "Group",
    "Email" : "Email",
    "Admin" : "Admin",
    "Owner" : "Owner",
    "Users" : "Pengguna",
    "Additional names" : "Nama tambahan",
    "Nickname" : "Nama Samaran",
    "Notes" : "Nota",
    "Location" : "Lokasi",
    "Home" : "Rumah",
    "Work" : "Kerja",
    "Other" : "Lain",
    "Address" : "Alamat",
    "City" : "bandar",
    "Country" : "Negara",
    "Birthday" : "Hari lahir",
    "Phone" : "Telefon",
    "Mobile" : "Mudah alih",
    "Fax" : "Fax",
    "Pager" : "Alat Kelui",
    "Voice" : "Suara"
},
"nplurals=1; plural=0;");
