OC.L10N.register(
    "contacts",
    {
    "Details" : "Détails",
    "All contacts" : "Tous les contacts",
    "Contacts" : "Contacts",
    "A contacts app for Nextcloud" : "Application contacts pour Nextcloud",
    "The Nextcloud contacts app is a user interface for Nextcloud's CardDAV server. Easily sync contacts from various devices with your Nextcloud and edit them online.\n\n* 🚀 **Integration with other Nextcloud apps!** Currently Mail and Calendar – more to come.\n* 🎉 **Never forget a birthday!** You can sync birthdays and other recurring events with your Nextcloud Calendar.\n* 👥 **Sharing of Adressbooks!** You want to share your contacts with your friends or coworkers? No problem!\n* 🙈 **We’re not reinventing the wheel!** Based on the great and open SabreDAV library." : "L'application de contacts Nextcloud est une interface utilisateur pour le serveur CardDAV de Nextcloud. Synchronisez facilement les contacts de divers appareils avec votre Nextcloud et modifiez-les en ligne.\n\n* 🚀 ** Intégration avec d'autres applications Nextcloud! ** Actuellement Mail et  agenda - plus à venir.\n* 🎉 ** N'oubliez jamais plus d'anniversaire! ** Vous pouvez synchroniser les anniversaires et autres événements récurrents avec votre agenda Nextcloud.\n* 👥 ** Partage de carnet d’adresses !  ** Vous souhaitez partager vos contacts avec vos amis ou vos collègues? Aucun problème!\n* 🙈 ** Nous ne réinventons pas la roue! ** Basé sur la superbe bibliothèque ouverte SabreDAV.",
    "Copy to full name" : "Copier dans le nom complet",
    "Omit year" : "Ignorer l'année",
    "Allow updating avatars from social media" : "Autoriser la mise à jour des avatars à partir des réseaux sociaux",
    "Please select a circle" : "Veuillez sélectionner un cercle",
    "Loading circle …" : "Chargement du cercle...",
    "Your request to join this circle is pending approval" : "Votre demande d'adhésion au cercle est en attente d'approbation",
    "You are not a member of {circle}" : "Vous n'êtes pas un membre de {circle}",
    "There was an error fetching the member list" : "Erreur lors de la récupération de la liste des membres",
    "Loading contacts …" : "Chargement des contacts...",
    "There are no contacts yet" : "Il n'y a aucun contact pour l’instant",
    "Create contact" : "Créer un contact",
    "There are no contacts in this group" : "Il n'y a aucun contact dans ce groupe",
    "Create contacts" : "Créer des contacts",
    "Add contacts" : "Ajouter des contacts",
    "Loading …" : "Chargement …",
    "Add member" : "Ajouter des membres",
    "Leave circle" : "Quitter le cercle",
    "Delete circle" : "Supprimer le cercle",
    "Contacts settings" : "Paramètres de Contacts",
    "General settings" : "Paramètres généraux",
    "Update avatars from social media" : "Mettre à jour les avatars à partir des réseaux sociaux",
    "(refreshed once per week)" : "(rafraîchi une fois par semaine)",
    "Address books" : "Carnets d'adresses",
    "Export" : "Exporter",
    "Send email" : "Envoyer un e-mail",
    "Send email as BCC" : "Envoyer l'e-mail comme CCI",
    "Contact groups" : "Groupes de contacts",
    "Create a new contact group" : "Créer un nouveau groupe de contacts",
    "Contact group name" : "Nom du groupe de contacts",
    "Circles" : "Cercles",
    "Create a new circle" : "Créer un nouveau cercle",
    "Show all groups" : "Afficher tous les groupes",
    "Collapse groups" : "Replier les groupes",
    "Show all circles" : "Afficher tous les cercles",
    "Collapse circles" : "Replier les cercles",
    "This group already exists" : "Ce groupe existe déjà",
    "This circle already exists" : "Ce cercle existe déjà",
    "An error happened during the creation of the circle" : "Erreur lors de la création du cercle",
    "{addressbookname} (Disabled)" : "{addressbookname} (Disabled)",
    "Download" : "Télécharger",
    "Show" : "Montrer",
    "Rename" : "Renommer",
    "Delete" : "Supprimer",
    "Copied" : "Copié",
    "Cannot copy" : "Impossible de copier",
    "Copy link" : "Copier le lien",
    "Toggling of address book was not successful" : "L'activation ou désactivation du carnet d'adresses a échoué",
    "This will delete the address book and every contacts within it" : "Le carnet d'adresses ainsi que tous les contacts qu'il contient va être supprimé",
    "Delete {addressbook}?" : "Supprimer {addressbook} ?",
    "Deletion of address book was not successful." : "La suppression du carnet d'adresses a échoué.",
    "Renaming of address book was not successful." : "Le renommage du carnet d'adresses à échoué.",
    "_%n contact_::_%n contacts_" : ["%n contact","%n contacts","%n contacts"],
    "_%n group_::_%n groups_" : ["%n groupe","%n groupes","%n groupes"],
    "_Shared with {num} entity_::_Shared with {num} entities_" : ["Partagé avec {num} entité","Partagé avec {num} entités","Partagé avec {num} entités"],
    "Share with users or groups" : "Partager avec des utilisateurs ou des groupes",
    "Share with users" : "Share with users",
    "No users or groups" : "Aucun utilisateur ou groupe",
    "can edit" : "peut modifier",
    "Unable to delete the share" : "Impossible de supprimer le partage",
    "Unable to change permissions" : "Impossible de modifier les autorisations",
    "Import contacts" : "Importer des contacts",
    "Import into the {addressbookName} address book" : "Importer dans le carnet d'adresses {addressbookName}",
    "Select local file" : "Sélectionnez un fichier local",
    "Import from files" : "Importer depuis Fichiers",
    "Importing is disabled because there are no address books available" : "L'import n'est pas disponible car il n'existe aucun carnet d'adresses",
    "Choose a vCard file to import" : "Sélectionnez un fichier vCard à importer",
    "Add new address book" : "Ajouter un nouveau carnet d'adresses",
    "An error occurred, unable to create the address book" : "Une erreur est survenue, impossible de créer le carnet d'adresses",
    "First name" : "Prénom",
    "Last name" : "Nom",
    "Phonetic first name" : "Prénom phonétique",
    "Phonetic last name" : "Nom de famille phonétique",
    "Display name" : "Nom affiché",
    "Last modified" : "Dernière modification",
    "Sort by {sorting}" : "Trier par {sorting}",
    "Manages" : "Gère",
    "Oversees" : "Supervise",
    "An error happened during the config change" : "Erreur lors du changement de configuration",
    "Password protection" : "Protection par mot de passe",
    "Enforce password protection on files shared to this circle" : "Renforcer la sécurité des partages de fichiers effectués vers ce cercle avec des mots de passe",
    "Use a unique password for all shares to this circle" : "Utilisez un mot de passe unique pour tous les partages vers ce cercle",
    "Unique password …" : "Mot de passe unique ...",
    "Save" : "Enregistrer",
    "Change unique password" : "Modifier le mot de passe unique",
    "Failed to save password. Please try again later." : "Impossible d'enregistrer le mot de passe. Veuillez réessayer plus tard.",
    "Circle name" : "Nom du cercle",
    "Circle owned by {owner}" : "Cercle appartenant à {owner}",
    "Request to join" : "Demander à rejoindre",
    "Description" : "Description",
    "There is no description for this circle" : "Il n'y a pas de description pour ce cercle",
    "Enter a description for the circle" : "Entrez une description pour ce cercle",
    "An error happened during description sync" : "Erreur lors de la synchronisation de la description",
    "An error happened during name sync" : "Erreur lors de la synchronisation du nom",
    "Add more info" : "Ajouter plus d'informations",
    "More fields" : "Plus de champs",
    "Crop contact photo" : "Recadrer la photo du contact",
    "Cancel" : "Annuler",
    "Upload a new picture" : "Téléverser une nouvelle image",
    "Choose from Files" : "Sélectionner depuis les fichiers",
    "Get from " : "Obtenir de",
    "Download picture" : "Télécharger l'image",
    "Delete picture" : "Supprimer l'image",
    "Please select a valid format" : "Veuillez sélectionner un format valide",
    "Invalid image" : "Image invalide",
    "Error cropping picture" : "Erreur de recadrage de l'image",
    "Pick an avatar" : "Sélectionnez un avatar",
    "Error while processing the picture." : "Erreur lors du traitement de  l'image.",
    "Avatar downloaded from social network" : "Avatar téléchargé à partir des réseaux sociaux",
    "Avatar already up to date" : "Avatar déjà à jour",
    "Avatar download failed" : "Téléchargement de l'avatar échoué",
    "No contact selected" : "Aucun contact sélectionné",
    "Select a contact on the list to begin" : "Sélectionnez un contact dans la liste pour commencer",
    "Name" : "Nom",
    "Title" : "Fonction",
    "Company" : "Société",
    "This contact was broken and received a fix. Please review the content and click here to save it." : "Ce contact a été tronqué et a été corrigé. Veuillez en examiner le contenu, puis cliquez ici pour l’enregistrer.",
    "Edit" : "Éditer",
    "Clone contact" : "Dupliquer le contact",
    "Generate QR Code" : "Générer un QR code",
    "Contact vCard as QR code" : "Contact vCard comme QR code",
    "Pick an address book" : "Sélectionner un carnet d'adresses",
    "Select address book" : "Sélectionner un carnet d'adresses",
    "Go to talk conversation" : "Aller à la conversation Talk",
    "View profile" : "Voir le profile",
    "Media shares with you" : "Média partagés avec vous",
    "Talk conversations with you" : "Conversations orales avec vous",
    "Calendar events with you" : "Agendas avec vous",
    "No shared items with this contact" : "Aucun éléments partagés avec ce contact",
    "This contact is in read-only mode. You do not have permission to edit this contact." : "Ce contact est en lecture seule. Vous n'avez pas les autorisations pour modifier ce contact.",
    "The contact you were trying to edit has changed. Please manually refresh the contact. Any further edits will be discarded." : "Le contact que vous essayiez de modifier a changé. Merci de rafraîchir manuellement le contact. Vos modifications seront abandonnées. ",
    "Address book" : "Carnet d'adresses",
    "Add contact to Birthday Calendar" : "Ajouter le contact à l'agenda d’anniversaire",
    "Exclude contact from Birthday Calendar" : "Exclure le contact de l'agenda d'anniversaire",
    "{title} at {organization}" : "{title} chez {organization}",
    "Syntax error. Cannot open the contact." : "Erreur de syntaxe. Impossible de lire le contact.",
    "The contact does not exist on the server anymore." : "Le contact n'existe plus sur le serveur.",
    "Unable to retrieve the contact from the server, please check your network connection." : "Impossible de récupérer le contact à partir du serveur, s'il vous plait vérifiez votre connexion internet.",
    "An error occurred while trying to move the contact" : "Une erreur s'est produite lors du déplacement du contact",
    "An error occurred while trying to copy the contact" : "Une erreur s'est produite lors de la copie du contact",
    "Unable to update contact" : "Impossible de mettre à jour le contact",
    "Search contacts …" : "Rechercher un contact...",
    "Add to {group}" : "Ajouter à {group}",
    "Remove {type}" : "Retirer {type}",
    "Search {types}" : "Rechercher {types}",
    "Search for people to add" : "Chercher des personnes à ajouter",
    "No results" : "Aucun résultat",
    "Add to group" : "Ajouter au groupe",
    "Add {type}" : "Ajouter des {type}",
    "New circle name" : "Nom du nouveau cercle",
    "Personal circle" : "Cercle personnel",
    "This circle will only be visible to you. Other members will not be able to see or use it." : "Ce cercle sera uniquement visible par vous. Les autres membres ne pourront ni le voir, ni l'utiliser.",
    "Local circle" : "Cercle local",
    "This circle will not be shared with the other instances of the global scale" : "Ce cercle ne sera pas partagé avec les autres instances à l'échelle globale",
    "Create circle" : "Créer un cercle",
    "Loading members list …" : "Chargement de la liste des membres...",
    "The list of members is only visible to members of this circle" : "La liste des membres est uniquement visible par les membres de ce cercle",
    "You currently have no access to the member list" : "Vous n'avez actuellement pas accès à la liste des membres",
    "Add members" : "Ajouter des membres",
    "Show circle details" : "Afficher les détails du cercle",
    "Add to {circle}" : "Ajouter à {circle}",
    "Unable to get the recommendations list" : "Impossible de récupérer la liste des recommandations.",
    "Unable to get the results" : "Impossible de récupérer les résultats",
    "Some members could not be added" : "Certains membres n'ont pas pu être ajoutés",
    "There was an issue adding members to the circle" : "Erreur lors de l'ajout de membres au cercle",
    "Accept membership request" : "Accepter la demande d'adhésion",
    "Reject membership request" : "Rejeter la demande d'adhésion",
    "Manage level" : "Définir le rôle",
    "Remove member" : "Retirer le membre",
    "Pending" : "En attente",
    "Promote as sole owner" : "Promouvoir seul propriétaire",
    "Promote to {level}" : "Promouvoir {level}",
    "Demote to {level}" : "Rétrograder {level}",
    "Could not delete the member {displayName}" : "Impossible de supprimer le membre {displayName}",
    "Could not change the member level to {level}" : "Impossible de changer le niveau du membre vers {level}",
    "Could not accept membership request" : "Impossible d'accepter la demande d'adhésion",
    "Chart" : "Organigramme",
    "Select chart …" : "Sélectionnez un organigramme...",
    "Select type" : "Sélectionnez le type",
    "Select Date" : "Sélectionnez une date",
    "Add contact in group" : "Ajouter le contact dans un groupe",
    "none" : "aucun",
    "Select option" : "Sélectionnez une option",
    "Add property of this type" : "Ajouter une propriété de ce type",
    "New contact" : "Nouveau contact",
    "Unable to create the contact." : "Impossible de créer le contact.",
    "Contact not found" : "Contact introuvable",
    "Group {group} not found" : "Groupe {group} introuvable",
    "Close" : "Fermer",
    "_{success} contact added to {name}_::_{success} contacts added to {name}_" : ["{success} contact ajouté à {name}","{success} contacts ajoutés à {name}","{success} contacts ajoutés à {name}"],
    "_Adding {success} contact to {name}_::_Adding {success} contacts to {name}_" : ["Ajouter {success} contact à {name}","Ajouter {success} contacts à {name}","Ajouter {success} contacts à {name}"],
    "_{count} error_::_{count} errors_" : ["{count} erreur","{count} erreurs","{count} erreurs"],
    "_Importing %n contact into {addressbook}_::_Importing %n contacts into {addressbook}_" : ["Import de %n contact dans {addressbook}","Import de %n contacts dans {addressbook}","Import de %n contacts dans {addressbook}"],
    "_Done importing %n contact into {addressbook}_::_Done importing %n contacts into {addressbook}_" : ["Import de %n contact dans {addressbook} terminé","Import de %n contacts dans {addressbook} terminé","Import de %n contacts dans {addressbook} terminé"],
    "Import" : "Importer",
    "Could not copy" : "Impossible de copier",
    "Join circle" : "Rejoindre le cercle",
    "You are about to leave {circle}.\nAre you sure?" : "Vous êtes sur le point de quitter le cercle {circle}.\nÊtes-vous sûr ?",
    "Please confirm circle leave" : "Confirmer votre départ du cercle",
    "Could not leave the circle {displayName}" : "Impossible de quitter le cercle {displayName}",
    "Unable to join the circle" : "Impossible de rejoindre le cercle",
    "You are about to delete {circle}.\nAre you sure?" : "Vous êtes sur le point de supprimer {circle}.\nÊtes-vous sûr ?",
    "Please confirm circle deletion" : "Confirmez la suppression du cercle",
    "Unable to delete the circle" : "Impossible de supprimer le cercle",
    "Link copied to the clipboard" : "Lien copié dans le presse-papier",
    "Could not copy link to the clipboard." : "Impossible de copier le lien dans le presse-papier",
    "Not grouped" : "Non groupé",
    "Recently contacted" : "Contacté récemment",
    "Organization chart" : "Organigramme",
    "Circles are groups of people that you can create yourself and with whom you can share data. They can be made up of other accounts or groups of accounts of the Nextcloud instance, but also of contacts from your address book or even external people by simply entering their e-mail addresses." : "Les cercles sont des groupes de personnes que vous pouvez créer vous-même et avec lesquels vous pouvez partager des données. Ils peuvent être constitués d'autres comptes ou groupes de comptes de l'instance Nextcloud, mais aussi de contacts de votre carnet d'adresses ou même de personnes externes en entrant simplement leur adresse e-mail.",
    "Circle" : "Cercle",
    "User" : "Utilisateur",
    "Group" : "Groupe",
    "Email" : "E-mail",
    "Contact" : "Contact",
    "Member" : "Membre",
    "Moderator" : "Modérateur",
    "Admin" : "Administrateur",
    "Owner" : "Propriétaire",
    "Invites" : "Invitations et adhésions",
    "Anyone can request membership" : "Tout le monde peut demander à adhérer",
    "Members need to accept invitation" : "Les membres doivent accepter l'invitation",
    "Memberships must be confirmed/accepted by a Moderator (requires Open)" : "Les adhésions doivent être confirmées/acceptées par un Modérateur (nécessite Open)",
    "Members can also invite" : "Les membres peuvent aussi inviter",
    "Visibility" : "Visibilité",
    "Visible to everyone" : "Visible pour tous",
    "Circle membership" : "Adhésion d'un cercle à un autre",
    "Prevent circle from being a member of another circle" : "Empêche le cercle d'être membre d'un autre cercle",
    "Users" : "Utilisateurs",
    "Email addresses" : "Adresses e-mail",
    "Detailed name" : "Nom détaillé",
    "Additional names" : "Noms supplémentaires",
    "Prefix" : "Civilité",
    "Suffix" : "Suffixe",
    "Nickname" : "Surnom",
    "Notes" : "Notes",
    "Website" : "Site web",
    "Location" : "Position",
    "Federated Cloud ID" : "ID de Cloud Fédéré",
    "Home" : "Personnel",
    "Work" : "Professionnel",
    "Other" : "Autre",
    "Address" : "Adresse",
    "Post office box" : "Boîte postale",
    "Extended address" : "Adresse étendue",
    "City" : "Ville",
    "State or province" : "État ou région",
    "Postal code" : "Code postal",
    "Country" : "Pays",
    "Birthday" : "Anniversaire",
    "Anniversary" : "Autre date",
    "Date of death" : "Date de décès",
    "Instant messaging" : "Messagerie instantanée",
    "Phone" : "Téléphone",
    "Mobile" : "Mobile",
    "Work mobile" : "Téléphone portable professionnel",
    "Home mobile" : "Téléphone portable personnel",
    "Fax" : "Fax",
    "Fax home" : "Fax personnel",
    "Fax work" : "Fax professionnel",
    "Pager" : "Bipeur",
    "Voice" : "Voix",
    "Car" : "Voiture",
    "Work pager" : "Bipper professionnel",
    "Manager" : "Supérieur",
    "Social network" : "Réseau social",
    "Relationship to you" : "Relation avec vous",
    "Spouse" : "Conjoint",
    "Child" : "Enfant",
    "Mother" : "Mère",
    "Father" : "Père",
    "Parent" : "Parent",
    "Brother" : "Frère",
    "Sister" : "Sœur",
    "Relative" : "Membre de la famille",
    "Friend" : "Ami",
    "Colleague" : "Collègue",
    "Assistant" : "Assistant",
    "Related contacts" : "Contacts liés",
    "Agent" : "Agent",
    "Emergency" : "Urgence",
    "Co-worker" : "Collaborateur",
    "Gender" : "Sexe",
    "Female" : "Femme",
    "Male" : "Homme",
    "None" : "Aucun",
    "Unknown" : "Inconnu",
    "Time zone" : "Fuseau horaire",
    "Spoken languages" : "Langues parlées",
    "_{failed} contact failed to be read_::_{failed} contacts failed to be read_" : ["Erreur de lecture pour {failed} contact","Erreur de lecture pour {failed} contacts","Erreur de lecture pour {failed} contacts"],
    "An error has occurred in circle(s). Check the console for more details." : "Une erreur est survenue dans le·s cercle·s. Vérifiez la console pour plus de détails.",
    "Unable to create circle {circleName}" : "Impossible de créer le cercle {circleName}",
    "Unable to delete circle {circleId}" : "Impossible de supprimer le cercle {circleId}",
    "Unable to delete contact" : "Impossible de supprimer le contact."
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
