OC.L10N.register(
    "contacts",
    {
    "Details" : "Detaljer",
    "All contacts" : "Alle kontakter",
    "Contacts" : "Kontakter",
    "A contacts app for Nextcloud" : "En kontaktapp for Nextcloud",
    "Copy to full name" : "Kopier til fullt navn",
    "Omit year" : "Utelat år",
    "Allow updating avatars from social media" : "Tillat oppdatering av avatarer fra sosiale medier",
    "Please select a circle" : "Vennligst velg en sirkel",
    "Loading circle …" : "Laster sirkel...",
    "Your request to join this circle is pending approval" : "Forespørselen din om å bli med i denne sirkelen venter på godkjenning",
    "You are not a member of {circle}" : "Du er ikke medlem av {circle}",
    "Loading contacts …" : "Laster inn kontakter…",
    "There are no contacts yet" : "Det finnes ingen kontakter enda",
    "Create contact" : "Opprett kontakt",
    "There are no contacts in this group" : "Det finnes ingen kontaker i denne gruppen",
    "Create contacts" : "Opprett kontakter",
    "Add contacts" : "Legg til kontaker",
    "Loading …" : "Laster...",
    "Add member" : "Legg til et medlem",
    "Leave circle" : "Forlat sirkelen",
    "Delete circle" : "Slett sirkel",
    "Contacts settings" : "Kontaktinnstillinger",
    "General settings" : "Generelle innstillinger",
    "Address books" : "Adressebøker",
    "Send email" : "Send e-post",
    "Contact groups" : "Kontaktgrupper",
    "Create a new contact group" : "Opprett en ny kontaktgruppe",
    "Contact group name" : "Kontaktgruppenavn",
    "Circles" : "Sirkler",
    "Create a new circle" : "Opprett en ny sirkel",
    "Show all groups" : "Vis alle grupper",
    "Collapse groups" : "Kollapse grupper",
    "Show all circles" : "Vis alle sirkler",
    "Collapse circles" : "Kollapse sirkler",
    "This group already exists" : "Denne gruppen finnes allerede",
    "This circle already exists" : "Denne sirkelen finnes allerede",
    "An error happened during the creation of the circle" : "En feil oppsto under opprettelse av sirkelen",
    "Download" : "Last ned",
    "Rename" : "Gi nytt navn",
    "Delete" : "Slett",
    "Copied" : "Kopiert",
    "Cannot copy" : "Kan ikke kopiere",
    "Copy link" : "Kopier lenke",
    "Toggling of address book was not successful" : "Veksling av adressebok var ikke vellykket",
    "Delete {addressbook}?" : "Slette {addressbook}?",
    "_Shared with {num} entity_::_Shared with {num} entities_" : ["Delt med {num} entitet","Delt med {num} entiteter"],
    "Share with users or groups" : "Del med brukere eller grupper",
    "No users or groups" : "Ingen brukere eller grupper",
    "can edit" : "kan redigere",
    "Unable to delete the share" : "Kan ikke slette delingen",
    "Unable to change permissions" : "Kan ikke endre tillatelser",
    "Import contacts" : "Importer kontakter",
    "Import into the {addressbookName} address book" : "Importer til {addressbookName}-adresseboken",
    "Select local file" : "Velg lokal fil",
    "Choose a vCard file to import" : "Velg en vCard-fil å importere",
    "Add new address book" : "Legg til ny adressebok",
    "First name" : "Fornavn",
    "Last name" : "Etternavn",
    "Phonetic first name" : "Fonetisk fornavn",
    "Phonetic last name" : "Fonetisk etternavn",
    "Display name" : "Visningsnavn",
    "Last modified" : "Sist endret",
    "Sort by {sorting}" : "Sorter etter {sorting}",
    "Oversees" : "Overvåker",
    "Password protection" : "Passordbeskyttelse",
    "Enforce password protection on files shared to this circle" : "Håndhev passordbeskyttelse på filer som deles med denne sirkelen",
    "Unique password …" : "Unikt passord...",
    "Save" : "Lagre",
    "Change unique password" : "Endre unikt passord",
    "Circle name" : "Sirkelnavn",
    "Circle owned by {owner}" : "Sirkel eid av {owner}",
    "Request to join" : "Spør om å bli med",
    "Description" : "Beskrivelse",
    "There is no description for this circle" : "Det er ingen beskrivelse av denne sirkelen",
    "Enter a description for the circle" : "Gi en beskrivelse av denne sirkelen",
    "Cancel" : "Avbryt",
    "Upload a new picture" : "Last opp et nytt bilde",
    "Choose from Files" : "Velg fra Filer",
    "Download picture" : "Last ned bilde",
    "Delete picture" : "Slett bilde",
    "Invalid image" : "Ugyldig bilde",
    "Pick an avatar" : "Velg en avatar",
    "No contact selected" : "Ingen kontakt valgt",
    "Select a contact on the list to begin" : "Velg en kontakt fra listen for å begynne",
    "Name" : "Navn",
    "Title" : "Tittel",
    "Company" : "Bedrift",
    "Edit" : "Redigere",
    "Clone contact" : "Dupliser kontakt",
    "Generate QR Code" : "Generer QR-kode",
    "Pick an address book" : "Velg en adressebok",
    "Select address book" : "Velg adressebok",
    "This contact is in read-only mode. You do not have permission to edit this contact." : "Kontakten er skrivebeskyttet. Du har ikke tillatelse til å redigere denne kontakten.",
    "The contact you were trying to edit has changed. Please manually refresh the contact. Any further edits will be discarded." : "Kontakten du prøvde å redigere, har blitt endret. Vennligst oppdater manuelt. Ytterligere endringer vil ikke kunne lagres.",
    "Address book" : "Adressebok",
    "Syntax error. Cannot open the contact." : "Syntaksfeil. Kan ikke åpne kontakten.",
    "Search contacts …" : "Søk etter kontakter…",
    "Add to {group}" : "Legg til i {group}",
    "No results" : "Ingen resultater",
    "Add to group" : "Legg til gruppe",
    "New circle name" : "Nytt sirkelnavn",
    "Personal circle" : "Personlig sirkel",
    "This circle will only be visible to you. Other members will not be able to see or use it." : "Denne sirkelen vil bare være synlig for deg. Andre medlemmer vil ikke kunne se eller bruke den.",
    "Local circle" : "Lokal sirkel",
    "Create circle" : "Opprett sirkel",
    "Loading members list …" : "Laster liste over medlemmer...",
    "The list of members is only visible to members of this circle" : "Listen over medlemmer er kun synlig for medlemmer av denne sirkelen",
    "Add members" : "Legg til medlemmer",
    "Show circle details" : "Vis sirkeldetaljer",
    "Add to {circle}" : "Legg til i {circle}",
    "There was an issue adding members to the circle" : "Det oppsto et problem med å legge til medlemmer til denne sirkelen",
    "Manage level" : "Håndtere nivå",
    "Remove member" : "Fjern medlem",
    "Pending" : "Venter",
    "Promote as sole owner" : "Fremme som eneeier",
    "Promote to {level}" : "Fremme til {level}",
    "Demote to {level}" : "Nedgradere til {level}",
    "Select type" : "Velg type",
    "Select Date" : "Velg dato",
    "Add contact in group" : "Legg kontakt til gruppe",
    "Select option" : "Velg innstilling",
    "New contact" : "Ny kontakt",
    "Unable to create the contact." : "Kontakten kunne ikke opprettes.",
    "Contact not found" : "Kontakten ble ikke funnet",
    "Group {group} not found" : "Fant ikke gruppen {group}",
    "Close" : "Lukk",
    "_{success} contact added to {name}_::_{success} contacts added to {name}_" : ["{success} kontakt lagt til {name}","{success} kontakter lagt til {name}"],
    "_Adding {success} contact to {name}_::_Adding {success} contacts to {name}_" : ["Legger til {success} kontakt til {name}","Legger til {success} kontakter til {name}"],
    "_{count} error_::_{count} errors_" : ["{count} feil","{count} feil"],
    "_Importing %n contact into {addressbook}_::_Importing %n contacts into {addressbook}_" : ["Importerer %n kontakt til {addressbook}","Importerer %n kontakter til {addressbook}"],
    "Import" : "Importer",
    "Could not copy" : "Kunne ikke kopiere",
    "Join circle" : "Bli med i sirkelen",
    "You are about to leave {circle}.\nAre you sure?" : "Du er i ferd med å forlate {circle}.\nEr du sikker?",
    "Please confirm circle leave" : "Vennligst bekreft å forlate sirkelen",
    "Could not leave the circle {displayName}" : "Kunne ikke forlate sirkelen {displayName}",
    "Unable to join the circle" : "Kunne ikke bli med i sirkelen",
    "You are about to delete {circle}.\nAre you sure?" : "Du er i ferd med å slette {circle}.\nEr du sikker?",
    "Please confirm circle deletion" : "Vennligst bekreft sletting av sirkelen",
    "Unable to delete the circle" : "Kunne ikke slette sirkelen",
    "Link copied to the clipboard" : "Lenke kopiert til utklippstavlen",
    "Could not copy link to the clipboard." : "Kunne ikke kopiere lenke til utklippstavlen",
    "Not grouped" : "Ikke gruppert",
    "Recently contacted" : "Nylig kontaktet",
    "Organization chart" : "Organisasjonskart",
    "Circle" : "Sirkel",
    "User" : "Bruker",
    "Group" : "Gruppe",
    "Email" : "E-post",
    "Contact" : "Kontakt",
    "Member" : "Medlem",
    "Moderator" : "Moderator",
    "Admin" : "Administrator",
    "Owner" : "Eier",
    "Invites" : "Invitasjoner",
    "Anyone can request membership" : "Alle kan be om medlemskap",
    "Members need to accept invitation" : "Medlemmer må godta invitasjonen",
    "Members can also invite" : "Medlemmer kan også invitere",
    "Visibility" : "Synlighet",
    "Visible to everyone" : "Synlig for alle",
    "Circle membership" : "Sirkelmedlemskap",
    "Prevent circle from being a member of another circle" : "Hindre sirkel fra å kunne bli medlem av en annen sirkel",
    "Users" : "Brukere",
    "Email addresses" : "E-postadresser",
    "Detailed name" : "Detaljert navn",
    "Additional names" : "Ev. mellomnavn",
    "Prefix" : "Prefiks",
    "Suffix" : "Suffiks",
    "Nickname" : "Kallenavn",
    "Notes" : "Notater",
    "Website" : "Nettsted",
    "Location" : "Sted",
    "Federated Cloud ID" : "ID for sammenknyttet sky",
    "Home" : "Hjem",
    "Work" : "Jobb",
    "Other" : "Annet",
    "Address" : "Adresse",
    "Post office box" : "Postboks",
    "Extended address" : "Utvidet adresse",
    "City" : "By",
    "State or province" : "Stat eller fylke",
    "Postal code" : "Postnummer",
    "Country" : "Land",
    "Birthday" : "Bursdag",
    "Anniversary" : "Jubileum",
    "Date of death" : "Dødsdato",
    "Instant messaging" : "Direktemeldinger",
    "Phone" : "Telefon",
    "Mobile" : "Mobil",
    "Work mobile" : "Arbeidstelefon",
    "Home mobile" : "Hjemmemobil",
    "Fax" : "Faks",
    "Fax home" : "Faks hjemme",
    "Fax work" : "Faks jobb",
    "Pager" : "Pager",
    "Voice" : "Svarer",
    "Car" : "Bil",
    "Work pager" : "Arbeidspersonsøker",
    "Manager" : "Sjef",
    "Social network" : "Sosialt nettverk",
    "Relationship to you" : "Relasjon til deg",
    "Spouse" : "Ektefelle",
    "Child" : "Barn",
    "Mother" : "Mor",
    "Father" : "Far",
    "Parent" : "Forelder",
    "Brother" : "Bror",
    "Sister" : "Søster",
    "Relative" : "Slektning",
    "Friend" : "Venn",
    "Colleague" : "Kollega",
    "Assistant" : "Assistent",
    "Emergency" : "Nødstilfelle",
    "Co-worker" : "Kollega",
    "Gender" : "Kjønn",
    "Female" : "Mann",
    "Male" : "Dame",
    "None" : "Ingen",
    "Unknown" : "Ukjent",
    "Time zone" : "Tidssone",
    "Spoken languages" : "Talte språk",
    "_{failed} contact failed to be read_::_{failed} contacts failed to be read_" : ["{failed} kontakt kunne ikke bli lest inn","{failed} kontakter kunne ikke bli lest inn"],
    "Unable to create circle {circleName}" : "Kunne ikke opprette sirkelen {displayName}",
    "Unable to delete circle {circleId}" : "Kunne ikke slette sirkelen {circleId}"
},
"nplurals=2; plural=(n != 1);");
