/**
 * @copyright Copyright (c) 2018 John Molakvoæ <skjnldsv@protonmail.com>
 *
 * @author John Molakvoæ <skjnldsv@protonmail.com>
 * @author Team Popcorn <teampopcornberlin@gmail.com>
 *
 * @license GNU AGPL version 3 or any later version
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 *
 */

.addressbook-sharee {
	padding: 0 5px;
	display: inline-flex;
	align-items: center;
	width: 100%;
	
	.icon {
		margin-right: 5px;
		opacity: 0.2;
		width: 16px;
		height: 16px;
		display: inline-block;
		margin-bottom: 2px;
		&.icon-loading-small {
			opacity: 1;
		}
	}

	&__identifier {
		width: 100%;
		overflow: hidden;
		white-space: nowrap;
		text-overflow: ellipsis;
		display: inline-block;
		vertical-align: top;
		opacity: 0.7;
	}

	&__utils {
		padding: 0 !important;
		float: right;
		position: relative !important;
		display: inline-flex;
		align-items: center;
		flex-shrink: 0;
		height: 20px;
		
		.icon-delete {
			display: inline-block;
			width: 20px;
			height: 20px;
			opacity: 0.4;
			margin-bottom: 2px;
			margin-left: 4px;
		}
		
		// loading state
		&--disabled {
			opacity: .2 !important;
		}
		.checkbox + label {
			padding: 0 !important;
		}
		label {
			opacity: 0.7;
		}
	}
}