OC.L10N.register(
    "contacts",
    {
    "Details" : "Details",
    "All contacts" : "Alle contactpersonen",
    "Contacts" : "Contactpersonen",
    "A contacts app for Nextcloud" : "Een contactpersonen app voor Nextcloud",
    "The Nextcloud contacts app is a user interface for Nextcloud's CardDAV server. Easily sync contacts from various devices with your Nextcloud and edit them online.\n\n* 🚀 **Integration with other Nextcloud apps!** Currently Mail and Calendar – more to come.\n* 🎉 **Never forget a birthday!** You can sync birthdays and other recurring events with your Nextcloud Calendar.\n* 👥 **Sharing of Adressbooks!** You want to share your contacts with your friends or coworkers? No problem!\n* 🙈 **We’re not reinventing the wheel!** Based on the great and open SabreDAV library." : "De contactpersonen app is een gebruikersinterface voor de Nextcloud's CardDAV server. Eenvoudig synchroniseren van contacten vanuit verschillende apparaten met jouw Nextcloud en online bewerken ervan.\n\n* 🚀 **Integratie met andere Nextcloud apps!** Momenteel Mail en Agenda - meer volgt later.\n* 🎉 **vergeet geen enkele verjaardag!** Je kunt verjaardagen en andere herhalende afspraken synchroniseren met je Nextcloud Agenda.\n* 👥 **Delen van adresboeken!** Wil je jouw contactpersonen delen met vrienden of collega's? Geen probleem!\n* 🙈 **We vinden het wiel niet opnieuw uit!** Gebaseerd op de fraaie SabreDAV library.",
    "Copy to full name" : "Kopiëren naar volledige naam",
    "Omit year" : "Jaar weglaten",
    "Allow updating avatars from social media" : "Sta het bijwerken van avatars van sociale media toe",
    "Please select a circle" : "Selecteer een kring aub",
    "Loading circle …" : "Kring laden ...",
    "Your request to join this circle is pending approval" : "Uw verzoek om toe te treden tot deze kring is nog niet goedgekeurd",
    "You are not a member of {circle}" : "U bent geen lid van [circle]",
    "There was an error fetching the member list" : "Er trad fout op bij het ophalen van de ledenlijst",
    "Loading contacts …" : "Contacten laden ...",
    "There are no contacts yet" : "Er zijn nog geen contactpersonen",
    "Create contact" : "Contactpersoon aanmaken",
    "There are no contacts in this group" : "Er zijn geen contactpersonen in deze groep",
    "Create contacts" : "Contactpersonen aanmaken",
    "Add contacts" : "Toevoegen contactpersonen",
    "Loading …" : "Laden ...",
    "Add member" : "Toevoegen lid",
    "Leave circle" : "Verlaat kring",
    "Delete circle" : "Verwijderen kring",
    "Contacts settings" : "Contacten instellingen",
    "General settings" : "Algemene instellingen",
    "Update avatars from social media" : "Werk de avatars van sociale media bij",
    "(refreshed once per week)" : "(wordt eens per week bijgewerkt)",
    "Address books" : "Adresboeken",
    "Send email" : "Stuur e-mail",
    "Circles" : "Kringen",
    "Create a new circle" : "Maak een nieuwe kring",
    "Show all groups" : "Toon alle groepen",
    "Collapse groups" : "Inklappen groepen",
    "Show all circles" : "Toon alle kringen",
    "Collapse circles" : "Kringen inklappen",
    "This group already exists" : "Deze groep bestaat al",
    "This circle already exists" : "Deze kring bestaat al",
    "An error happened during the creation of the circle" : "Er trad een fout op bij aanmaken van de kring",
    "Download" : "Downloaden",
    "Rename" : "Hernoemen",
    "Delete" : "Verwijderen",
    "Copied" : "Gekopieerd",
    "Cannot copy" : "Kan niet kopiëren",
    "Copy link" : "Link kopiëren",
    "Toggling of address book was not successful" : "Omwisseling van adresboek is niet gelukt",
    "This will delete the address book and every contacts within it" : "Dit verwijdert het adresboek en alle contactpersonen daarbinnen",
    "Delete {addressbook}?" : "Verwijderen {addressbook}?",
    "Deletion of address book was not successful." : "Verwijderen adresboek is niet gelukt.",
    "Renaming of address book was not successful." : "Hernoemen adresboek is niet gelukt.",
    "_Shared with {num} entity_::_Shared with {num} entities_" : ["Gedeeld met {num} andere","Gedeeld met {num} anderen"],
    "Share with users or groups" : "Delen met gebruikers of groepen",
    "No users or groups" : "Geen gebruikers of groepen",
    "can edit" : "kan bewerken",
    "Unable to delete the share" : "Kan de share niet verwijderen",
    "Unable to change permissions" : "Kan de machtigingen niet wijzigen",
    "Import contacts" : "Importeer contactpersonen",
    "Import into the {addressbookName} address book" : "Importeren in het {addressbookName} adresboek",
    "Select local file" : "Selecteer lokaal bestand",
    "Import from files" : "Importeren uit bestanden",
    "Importing is disabled because there are no address books available" : "Import is uitgeschakeld omdat er geen adresboek beschikbaar is",
    "Choose a vCard file to import" : "Kies een vCard bestand om te importeren",
    "Add new address book" : "Nieuw adresboek toevoegen",
    "An error occurred, unable to create the address book" : "Er trad een fout op, kon het adresboek niet creëren",
    "First name" : "Voornaam",
    "Last name" : "Achternaam",
    "Phonetic first name" : "Fonetische voornaam",
    "Phonetic last name" : "Fonetische achternaam",
    "Display name" : "Weergavenaam",
    "Last modified" : "Laatst gewijzigd",
    "Sort by {sorting}" : "Sorteren op {sorting}",
    "Manages" : "Leid",
    "Oversees" : "Ziet toe op",
    "An error happened during the config change" : "Er trad een fout op bij de config-wijziging",
    "Password protection" : "Wachtwoordbeveiliging",
    "Enforce password protection on files shared to this circle" : "Dwing wachtwoordbeveiliging af voor bestanden gedeeld in deze kring",
    "Use a unique password for all shares to this circle" : "Gebruik een uniek wachtwoord voor alle shares in deze kring",
    "Unique password …" : "Uniek wachtwoord ...",
    "Save" : "Opslaan",
    "Change unique password" : "Wijzig uniek wachtwoord",
    "Failed to save password. Please try again later." : "Niet gelukt om het wachtwoord op te slaan. Probeer aub later nogmaals.",
    "Circle name" : "Naam kring",
    "Circle owned by {owner}" : "Kring is van {owner}",
    "Request to join" : "Aanvraag voor deelname",
    "Description" : "Beschrijving",
    "There is no description for this circle" : "Er is geen beschrijving van deze kring",
    "Enter a description for the circle" : "Geef een beschrijving op voor deze kring",
    "An error happened during description sync" : "Er trad een fout op bij synch beschrijvingen",
    "An error happened during name sync" : "Er trad een fout op bij sync naam",
    "Cancel" : "Annuleren",
    "Upload a new picture" : "Uploaden nieuwe afbeelding",
    "Choose from Files" : "Kies uit Bestanden",
    "Get from " : "Krijgen van ",
    "Download picture" : "Download afbeelding",
    "Delete picture" : "Verwijder afbeelding",
    "Invalid image" : "Afbeelding ongeldig",
    "Pick an avatar" : "Kies een avatar",
    "Error while processing the picture." : "Fout bij het verwerken van de afbeelding.",
    "Avatar downloaded from social network" : "Avatar gedownload van sociaal netwerk",
    "Avatar already up to date" : "Avatar is al up-to-date",
    "Avatar download failed" : "Avatar downloaden is mislukt",
    "No contact selected" : "Geen contactpersoon geselecteerd",
    "Select a contact on the list to begin" : "Selecteer een contactpersoon in de lijst om te beginnen",
    "Name" : "Naam",
    "Title" : "Titel",
    "Company" : "Organisatie",
    "This contact was broken and received a fix. Please review the content and click here to save it." : "Dit contactpersoon was beschadigd en is hersteld. Controleer alstublieft of de contactpersoon correct hersteld is en klik hier om het te bewaren.",
    "Clone contact" : "Klonen contactpersoon",
    "Generate QR Code" : "Genereer QR code",
    "Contact vCard as QR code" : "Contactpersoon vCard als QR code",
    "Pick an address book" : "Kies een adresboek",
    "Select address book" : "Selecteer adresboek",
    "This contact is in read-only mode. You do not have permission to edit this contact." : "Deze contactpersoon is alleen-leesbaar. Je hebt niet de machtiging om deze contactpersoon te bewerken.",
    "The contact you were trying to edit has changed. Please manually refresh the contact. Any further edits will be discarded." : "De contactpersoon die je wilde bewerken is gewijzigd. Ververs de contactgegevens handmatig. Verdere wijzigingen worden genegeerd.",
    "Address book" : "Adresboek",
    "Add contact to Birthday Calendar" : "Contact toevoegen aan verjaardagskalender",
    "Exclude contact from Birthday Calendar" : "Contact uitsluiten van verjaardagskalender",
    "Syntax error. Cannot open the contact." : "Syntaxfout. Kan de contactpersoon niet openen.",
    "Unable to retrieve the contact from the server, please check your network connection." : "Kan contactpersoon niet ophalen van de server. Controleer je netwerkverbinding.",
    "An error occurred while trying to move the contact" : "Er trad een fout op bij het verplaatsen van de contactpersoon",
    "An error occurred while trying to copy the contact" : "Er trad een fout op bij het kopiëren van de contactpersoon",
    "Search contacts …" : "Zoek contacten ...",
    "Add to {group}" : "Toevoegen aan {groep}",
    "Remove {type}" : "Verwijder {type}",
    "Search {types}" : "Zoeken naar {types}",
    "Search for people to add" : "Zoek naar toe te voegen personen",
    "No results" : "Geen resultaten",
    "Add to group" : "Toevoegen aan een groep",
    "Add {type}" : "{type} toevoegen",
    "New circle name" : "Naam nieuwe kring",
    "Personal circle" : "Persoonlijke kring",
    "This circle will only be visible to you. Other members will not be able to see or use it." : "Deze kring is alleen voor jou zichtbaar. Andere leden kunnen die niet zien of gebruiken.",
    "Local circle" : "Lokale kring",
    "This circle will not be shared with the other instances of the global scale" : "Deze kring wordt niet gedeeld met de andere instanties",
    "Create circle" : "Maak een kring",
    "Loading members list …" : "Laden ledenlijst ...",
    "The list of members is only visible to members of this circle" : "De lijst met leden is alleen zichtbaar voor leden van deze kring",
    "Add members" : "Toevoegen leden",
    "Show circle details" : "Toon kringdetails",
    "Add to {circle}" : "Toevoegen aan {circle}",
    "Unable to get the recommendations list" : "Kan lijst met aanbevelingen niet laden",
    "Unable to get the results" : "Kan de resultaten niet ophalen",
    "Some members could not be added" : "Sommige leden konden niet worden toegevoegd",
    "There was an issue adding members to the circle" : "Er trad een probleem op bij het toevoegen van leden aan de kring",
    "Accept membership request" : "Accepteer het lidmaatschapsverzoek",
    "Reject membership request" : "Weiger lidmaatschapsverzoek",
    "Manage level" : "Beheren niveau",
    "Remove member" : "Verwijder lid",
    "Pending" : "In behandeling",
    "Promote as sole owner" : "Promoveer tot enige eigenaar",
    "Promote to {level}" : "Promoveer naar {level}",
    "Demote to {level}" : "Terugzetten naar {level}",
    "Could not delete the member {displayName}" : "Kon lid {displayName} niet verwijderen",
    "Could not change the member level to {level}" : "Kon lidmaatschapsniveau niet wijzigen naar {level}",
    "Could not accept membership request" : "Kon lidmaatschapsverzoek niet accepteren",
    "Chart" : "Grafiek",
    "Select chart …" : "Selecteer grafiek ...",
    "Select type" : "Selecteer type",
    "Select Date" : "Selecteer datum",
    "Add contact in group" : "Voeg contactpersoon aan groep toe",
    "Select option" : "Selecteer optie",
    "New contact" : "Nieuwe contactpersoon",
    "Unable to create the contact." : "Kan contactpersoon niet aanmaken.",
    "Contact not found" : "Contactpersoon niet gevonden",
    "Group {group} not found" : "Groep {group} niet gevonden",
    "Close" : "Sluit",
    "_{success} contact added to {name}_::_{success} contacts added to {name}_" : ["{success} contactpersoon toegevoegd aan {name}","{success} contactpersonen toegevoegd aan {name}"],
    "_Adding {success} contact to {name}_::_Adding {success} contacts to {name}_" : ["{success} contactpersonen aan het toevoegen aan {name}","{success} contactpersonen aan het toevoegen aan {name}"],
    "_{count} error_::_{count} errors_" : ["{count} fout","{count} fouten"],
    "_Importing %n contact into {addressbook}_::_Importing %n contacts into {addressbook}_" : ["Importeren %n contactpersoon in {addressbook}","Importeren %n contactpersonen in {addressbook}"],
    "_Done importing %n contact into {addressbook}_::_Done importing %n contacts into {addressbook}_" : ["Klaar met het importeren van %n contactpersoon in {addressbook}","Klaar met het importeren van %n contactpersonen in {addressbook}"],
    "Import" : "Importeren",
    "Could not copy" : "Kon niet kopiëren",
    "Join circle" : "Deelnemen aan kring",
    "You are about to leave {circle}.\nAre you sure?" : "Je gaat kring {circle} verlaten.\nWeet je het zeker?",
    "Please confirm circle leave" : "Bevestig verlaten kring",
    "Could not leave the circle {displayName}" : "Kon kring {displayName} niet verlaten",
    "Unable to join the circle" : "Kon niet deelnemen aan de kring",
    "You are about to delete {circle}.\nAre you sure?" : "Je gaat kring {circle} verwijderen.\nWeet je het zeker?",
    "Please confirm circle deletion" : "Bevestig verwijderen kring",
    "Unable to delete the circle" : "Kan de kring niet verwijderen",
    "Link copied to the clipboard" : "Link gekopieerd naar het klembord",
    "Could not copy link to the clipboard." : "Kon link niet kopiëren naar het klembord.",
    "Not grouped" : "Niet gegroepeerd",
    "Recently contacted" : "Recentelijk gecontacteerd",
    "Organization chart" : "Organisatiestructuur",
    "Circle" : "Kring",
    "User" : "Gebruiker",
    "Group" : "Groep",
    "Email" : "Email",
    "Contact" : "Contactpersoon",
    "Member" : "Lid",
    "Moderator" : "Moderator",
    "Admin" : "Beheerder",
    "Owner" : "Eigenaar",
    "Invites" : "Uitnodigingen",
    "Anyone can request membership" : "Iedereen kan lid worden",
    "Members need to accept invitation" : "Leden moeten de uitnodiging accepteren",
    "Memberships must be confirmed/accepted by a Moderator (requires Open)" : "Lidmaatschap moet worden bevestigd/geaccepteerd door een Moderator (vereist Open)",
    "Members can also invite" : "Leden kunnen anderen uitnodigen",
    "Visibility" : "Zichtbaarheid",
    "Visible to everyone" : "Zichtbaar voor iedereen",
    "Circle membership" : "Lidmaatschap kring",
    "Prevent circle from being a member of another circle" : "Voorkom dat een kring lid wordt van een andere kring",
    "Users" : "Gebruikers",
    "Email addresses" : "E-mailadressen",
    "Detailed name" : "Gedetailleerde naam",
    "Additional names" : "Extra namen",
    "Prefix" : "Voorvoegsel",
    "Suffix" : "Achtervoegsel",
    "Nickname" : "Roepnaam",
    "Notes" : "Notities",
    "Website" : "Website",
    "Location" : "Locatie",
    "Federated Cloud ID" : "Gefedereerde Cloud ID",
    "Home" : "Thuis",
    "Work" : "Werk",
    "Other" : "Overig",
    "Address" : "Adres",
    "Post office box" : "Postbus",
    "Extended address" : "Uitgebreid adres",
    "City" : "Stad",
    "State or province" : "Staat of provincie",
    "Postal code" : "Postcode",
    "Country" : "Land",
    "Birthday" : "Verjaardag",
    "Anniversary" : "Jubileum",
    "Date of death" : "Sterfdatum",
    "Instant messaging" : "Instant messaging",
    "Phone" : "Telefoon",
    "Mobile" : "Mobiel",
    "Work mobile" : "Werk mobiel",
    "Home mobile" : "Thuis mobiel",
    "Fax" : "Fax",
    "Fax home" : "Fax thuis",
    "Fax work" : "Fax werk",
    "Pager" : "Pieper",
    "Voice" : "Stem",
    "Car" : "Auto",
    "Work pager" : "Werk pieper",
    "Manager" : "Manager",
    "Social network" : "Sociaal netwerk",
    "Relationship to you" : "Relatie met jou",
    "Spouse" : "Echtgenoot",
    "Child" : "Kind",
    "Mother" : "Moeder",
    "Father" : "Vader",
    "Parent" : "Ouder",
    "Brother" : "Broer",
    "Sister" : "Zus",
    "Relative" : "Familielid",
    "Friend" : "Vriend",
    "Colleague" : "Collega",
    "Assistant" : "Assistent",
    "Related contacts" : "Gerelateerde contactpersonen",
    "Agent" : "Agent",
    "Emergency" : "Nood",
    "Co-worker" : "Medewerker",
    "Gender" : "Geslacht",
    "Female" : "Vrouw",
    "Male" : "Man",
    "None" : "Geen",
    "Unknown" : "Onbekend",
    "Time zone" : "Tijdzone",
    "Spoken languages" : "Gesproken talen",
    "_{failed} contact failed to be read_::_{failed} contacts failed to be read_" : ["{failed} contactpersoon werd niet ingelezen","{failed} contactpersonen werden niet ingelezen"],
    "Unable to create circle {circleName}" : "Kon kring {circleName} niet aanmaken",
    "Unable to delete circle {circleId}" : "Kon kring {circleId} niet verwijderen",
    "Unable to delete contact" : "Kan contactpersoon niet verwijderen"
},
"nplurals=2; plural=(n != 1);");
