OC.L10N.register(
    "contacts",
    {
    "Details" : "Подробности",
    "All contacts" : "Всички контакти",
    "Contacts" : "Контакти",
    "A contacts app for Nextcloud" : "Контакти за Nextcloud",
    "The Nextcloud contacts app is a user interface for Nextcloud's CardDAV server. Easily sync contacts from various devices with your Nextcloud and edit them online.\n\n* 🚀 **Integration with other Nextcloud apps!** Currently Mail and Calendar – more to come.\n* 🎉 **Never forget a birthday!** You can sync birthdays and other recurring events with your Nextcloud Calendar.\n* 👥 **Sharing of Adressbooks!** You want to share your contacts with your friends or coworkers? No problem!\n* 🙈 **We’re not reinventing the wheel!** Based on the great and open SabreDAV library." : "Приложението Contacts е интерфейс в Nextcloud към CardDAV сървър. Чрез него можете да синхронизирате контакти към Nextcloud и да ги редактирате онлайн.\n\n* 🚀 **Интеграция с други приложения!** В момента Mail и Calendar – ще бъдат добавени и други.\n* 🎉 **Не забравяйте рожден ден!** Можете да синхронизирате рождени дати и и други повтарящи се събития.\n* 👥 **Споделяйте адресни книги!** Желаете да споделите контактите си с приятел или колега? Няма проблем!\n* 🙈 **Ние не преоткриваме колелото!** Ползваме библиотеката SabreDAV.",
    "Copy to full name" : "Копиране до пълното име",
    "Omit year" : "Пропусни една година",
    "Allow updating avatars from social media" : "Разрешаване на актуализирането на аватари от социалните медии",
    "Please select a circle" : "Моля, изберете кръг",
    "Loading circle …" : "Зареждане на кръг ...",
    "Your request to join this circle is pending approval" : "Заявката ви за присъединяване към този кръг изчаква одобрение",
    "You are not a member of {circle}" : "Вие не сте член на {circle}",
    "There was an error fetching the member list" : "Възникна грешка при извличането на списъка с членове",
    "Loading contacts …" : "Зареждане на контактите ...",
    "There are no contacts yet" : "Все още няма контакти",
    "Create contact" : "Създаване на контакт",
    "There are no contacts in this group" : "Няма контакти в тази група",
    "Create contacts" : "Създаване на контакти",
    "Add contacts" : "Добавяне на контакти",
    "Loading …" : "Зарежда …",
    "Add member" : "Добавяне на член",
    "Leave circle" : "Напускане на кръг",
    "Delete circle" : "Изтриване на кръга",
    "Contacts settings" : "Настрройки на контакти",
    "General settings" : "Общи настройки",
    "Update avatars from social media" : "Актуализиране на аватари от социалните медии",
    "(refreshed once per week)" : "(опреснява се веднъж седмично)",
    "Address books" : "Адресни книги",
    "Export" : "Експорт /изнасям/",
    "Send email" : "Изпращане на имейл",
    "Send email as BCC" : "Изпращане на имейл, като BCC",
    "Contact groups" : "Групи за контакт",
    "Create a new contact group" : "Създаване на нова група за контакти",
    "Contact group name" : "Име на групата за контакти",
    "Circles" : "Кръгове",
    "Create a new circle" : "Създаване на нов кръг",
    "Show all groups" : "Показване на всички групи",
    "Collapse groups" : "Свиване на групи",
    "Show all circles" : "Показване на всички кръгове",
    "Collapse circles" : "Свиване на кръгове",
    "This group already exists" : "Тази група вече съществува",
    "This circle already exists" : "Този кръг вече съществува",
    "An error happened during the creation of the circle" : "Възникна грешка при създаването на кръга",
    "Download" : "Свали",
    "Rename" : "Преименувай",
    "Delete" : "Изтрий",
    "Copied" : "Копирано",
    "Cannot copy" : "Не може да се копира",
    "Copy link" : "Копирай връзката",
    "Toggling of address book was not successful" : "Превключването на адресната книга беше неуспешно",
    "This will delete the address book and every contacts within it" : "Това ще изтрие адресната книга и всички контакти в нея",
    "Delete {addressbook}?" : "Изтриване на {addressbook}?",
    "Deletion of address book was not successful." : "Изтриването на адресната книга беше неуспешно.",
    "Renaming of address book was not successful." : "Преименуването на адресната книга беше неуспешно.",
    "_Shared with {num} entity_::_Shared with {num} entities_" : ["Споделено с {num} обекта","Споделено с {num} обекта"],
    "Share with users or groups" : "Сподели с потребители или групи",
    "No users or groups" : "Няма потребители или групи",
    "can edit" : "може да редактира",
    "Unable to delete the share" : "Неуспешно изтриване на споделяне",
    "Unable to change permissions" : "Неуспешна промяна на права.",
    "Import contacts" : "Внасяне на контакти",
    "Import into the {addressbookName} address book" : "Внасяне в адресната книга {addressbookName}",
    "Select local file" : "Избор на локален файл",
    "Importing is disabled because there are no address books available" : "Внасянето е деактивирано, защото няма налични адресни книги ",
    "Choose a vCard file to import" : "Избор на vCard файл за импортиране",
    "Add new address book" : "Добавяне на нова адресна книга",
    "An error occurred, unable to create the address book" : "Възникна грешка, адресната книга не може да бъде създадена",
    "First name" : "Име",
    "Last name" : "Фамилия",
    "Phonetic first name" : "Собствено име, фонетично ",
    "Phonetic last name" : "Фамилия, фонетична",
    "Display name" : "Вписване като",
    "Last modified" : "Променена",
    "Sort by {sorting}" : "Сортиране по {sorting}",
    "Manages" : "Управление на",
    "Oversees" : "Наблюдава се",
    "An error happened during the config change" : "Възникна грешка по време на промяна на конфигурацията",
    "Password protection" : "Защита с парола",
    "Enforce password protection on files shared to this circle" : "Прилагане на защита с парола на файлове споделени в този кръг",
    "Use a unique password for all shares to this circle" : "Използване на уникална парола за всички споделяния в този кръг",
    "Unique password …" : "Уникална парола …",
    "Save" : "Запиши",
    "Change unique password" : "Промяна на уникална парола",
    "Failed to save password. Please try again later." : "Неуспешно запазване на паролата. Моля, опитайте отново по-късно.",
    "Circle name" : "Име на кръг",
    "Circle owned by {owner}" : "Кръг, притежаван от {owner}",
    "Request to join" : "Заявка за присъединяване",
    "Description" : "Описание",
    "There is no description for this circle" : "Няма описание за този кръг",
    "Enter a description for the circle" : "Въвеждане на описание за кръга",
    "An error happened during description sync" : "Възникна грешка по време на синхронизиране на описанието",
    "An error happened during name sync" : "Възникна грешка по време на синхронизиране на името",
    "Add more info" : "Добавяне на още информация",
    "More fields" : "Още полета",
    "Cancel" : "Отказ",
    "Upload a new picture" : "Качи нова снимка",
    "Choose from Files" : "Избор от Файлове",
    "Get from " : "Вземете от",
    "Download picture" : "Изтегляне на снимка",
    "Delete picture" : "Изтриване на снимка",
    "Invalid image" : "Невалидно изображение.",
    "Pick an avatar" : "Избор на аватар",
    "Error while processing the picture." : "Грешка при обработка на снимката.",
    "Avatar downloaded from social network" : "Аватар, изтеглен от социалната мрежа",
    "Avatar already up to date" : "Аватарът вече е актуален",
    "Avatar download failed" : "Изтеглянето на аватар беше неуспешно",
    "No contact selected" : "Няма избран контакт",
    "Select a contact on the list to begin" : "Избор на контакт от списъка, за започване",
    "Name" : "Име",
    "Title" : "Длъжност",
    "Company" : "Фирма",
    "This contact was broken and received a fix. Please review the content and click here to save it." : "Този контакт се повреди и беше поправен. Моля, прегледайте съдържанието и кликнете тук, за да го запишете.",
    "Edit" : "Редактирай",
    "Clone contact" : "Клонирай контакта",
    "Generate QR Code" : "Генериране на QR код",
    "Contact vCard as QR code" : "Свързване с vCard, като QR код",
    "Pick an address book" : "Избор на адресна книга",
    "Select address book" : "Изберете адресна книга",
    "This contact is in read-only mode. You do not have permission to edit this contact." : "Този контакт е в режим само за четене. Нямате право да редактирате този контакт.",
    "The contact you were trying to edit has changed. Please manually refresh the contact. Any further edits will be discarded." : "Контактът, който се опитвахте да редактирате, е променен. Моля, опреснете контакта ръчно. Всякакви допълнителни редакции ще бъдат отхвърлени.",
    "Address book" : "Адресна книга",
    "Add contact to Birthday Calendar" : "Добавяне на контакт към Календар за рожден ден",
    "Exclude contact from Birthday Calendar" : "Изключване на контакт от Календар за рожден ден",
    "{title} at {organization}" : "{title} в {organization}",
    "Syntax error. Cannot open the contact." : "Синтактична грешка. Контактът не може да се отвори.",
    "The contact does not exist on the server anymore." : "Контактът вече не съществува на сървъра.",
    "Unable to retrieve the contact from the server, please check your network connection." : "Невъзможно е да се извлече контакта от сървъра, моля, проверете мрежовата си връзка.",
    "An error occurred while trying to move the contact" : "Възникна грешка при опит за преместване на контакта",
    "An error occurred while trying to copy the contact" : "Възникна грешка при опит за копиране на контакта",
    "Search contacts …" : "Търсене в контактите ...",
    "Add to {group}" : "Добавяне към {group}",
    "Remove {type}" : "Премахване на {type}",
    "Search {types}" : "Търсене на  {types}",
    "Search for people to add" : "Търсене на хора за добавяне ",
    "No results" : "Няма резултати",
    "Add to group" : "Добавяне към група",
    "Add {type}" : "Добавяне на {type}",
    "New circle name" : "Име на нов кръг",
    "Personal circle" : "Личен кръг",
    "This circle will only be visible to you. Other members will not be able to see or use it." : "Този кръг ще се вижда само от вас. Други членове няма да могат да го видят или използват.",
    "Local circle" : "Локален кръг",
    "This circle will not be shared with the other instances of the global scale" : "Този кръг няма да бъде споделен с другите екземпляри в глобален мащаб",
    "Create circle" : "Създаване на кръг",
    "Loading members list …" : "Зарежда се списък с членове …",
    "The list of members is only visible to members of this circle" : "Списъкът с членове се вижда само от членовете на този кръг",
    "You currently have no access to the member list" : "В момента нямате достъп до списъка с членове",
    "Add members" : "Добавяне на членове",
    "Show circle details" : "Показване на подробности за кръг",
    "Add to {circle}" : "Добавяне към {circle}",
    "Unable to get the recommendations list" : "Списъкът с препоръки не може да се получи",
    "Unable to get the results" : "Резултатите не може да се получат",
    "Some members could not be added" : "Някои членове не могат да бъдат добавени",
    "There was an issue adding members to the circle" : "Възникна проблем при добавянето на членове в кръга",
    "Accept membership request" : "Приемане на заявка за членство",
    "Reject membership request" : "Отхвърляне на заявка за членство ",
    "Manage level" : "Управление на нивото",
    "Remove member" : "Премахване на член",
    "Pending" : "Чакащ",
    "Promote as sole owner" : "Повишаване като едноличен собственик",
    "Promote to {level}" : "Повишаване до {level}",
    "Demote to {level}" : "Понижаване до {level}",
    "Could not delete the member {displayName}" : "Членът {displayName} не можа да бъде изтрит",
    "Could not change the member level to {level}" : "Нивото на члена не можа да се промени на {level}",
    "Could not accept membership request" : "Не можа да се приеме заявка за членство",
    "Chart" : "Диаграма",
    "Select chart …" : "Избор на диаграма ...",
    "Select type" : "Изберете тип",
    "Select Date" : "Изберете дата",
    "Add contact in group" : "Добавяне на контакта в група",
    "Select option" : "Избор на опция",
    "Add property of this type" : "Добавяне на свойство от този тип",
    "New contact" : "Нов контакт",
    "Unable to create the contact." : "Контактът не може да се създаде.",
    "Contact not found" : "Контактът не е намерен",
    "Group {group} not found" : "Групата {group} не е намерена",
    "Close" : "Затваряне",
    "_{success} contact added to {name}_::_{success} contacts added to {name}_" : [" {success} контакти добави към {name} "," {success} контакти добави към {name} "],
    "_Adding {success} contact to {name}_::_Adding {success} contacts to {name}_" : ["Добавяне на {success} контакти към {name}","Добавяне на {success} контакти към {name}"],
    "_{count} error_::_{count} errors_" : ["{count} грешки","{count} грешки"],
    "_Importing %n contact into {addressbook}_::_Importing %n contacts into {addressbook}_" : ["Импортиране на %n контакта в {addressbook}","Импортиране на %n контакта в {addressbook}"],
    "_Done importing %n contact into {addressbook}_::_Done importing %n contacts into {addressbook}_" : ["Импортирането на%n контакта в {addressbook} приключи","Импортирането на %n контакта в {addressbook} приключи"],
    "Import" : "Внасяне",
    "Could not copy" : "Не можа да се копира",
    "Join circle" : "Присъединяване към кръг",
    "You are about to leave {circle}.\nAre you sure?" : "На път сте да напуснете {circle}.\nСигурни ли сте?",
    "Please confirm circle leave" : "Моля, потвърдете напускането на кръга",
    "Could not leave the circle {displayName}" : "{displayName} не можа да напусне кръга",
    "Unable to join the circle" : "Не може да се присъедини към кръга",
    "You are about to delete {circle}.\nAre you sure?" : "Предстои ви да изтриете {circle}.\nСигурни ли сте?",
    "Please confirm circle deletion" : "Моля, потвърдете изтриването на кръга",
    "Unable to delete the circle" : "Неуспешно изтриване на кръга",
    "Link copied to the clipboard" : "Връзката е копирана в клипборда",
    "Could not copy link to the clipboard." : "Неуспешно копиране на връзката в клипборда.",
    "Not grouped" : "Негрупирани",
    "Recently contacted" : "Наскоро влезли в контакт",
    "Organization chart" : "Диаграма на организация",
    "Circle" : "Кръг",
    "User" : "Потребител",
    "Group" : "Група",
    "Email" : "Имейл",
    "Contact" : "Контакт",
    "Member" : "Член",
    "Moderator" : "Модератор",
    "Admin" : "Администратор",
    "Owner" : "Собственик",
    "Invites" : "Покани",
    "Anyone can request membership" : "Всеки може да поиска членство",
    "Members need to accept invitation" : "Членовете трябва да приемат покана",
    "Memberships must be confirmed/accepted by a Moderator (requires Open)" : "Членствата трябва да бъдат потвърдени/приети от модератор (изисква Отваряне)",
    "Members can also invite" : "Членовете също могат да канят",
    "Visibility" : "Видимост",
    "Visible to everyone" : "Видим за всеки",
    "Circle membership" : "Членство в кръга",
    "Prevent circle from being a member of another circle" : "Предотвратяване на членството на един кръг в друг кръг",
    "Users" : "Потребители",
    "Email addresses" : "Имейл адреси",
    "Detailed name" : "Детайлно име",
    "Additional names" : "Други имена",
    "Prefix" : "Обръщение",
    "Suffix" : "Добавка",
    "Nickname" : "Псевдоним",
    "Notes" : "Бележки",
    "Website" : "Уеб страница",
    "Location" : "Местоположение",
    "Federated Cloud ID" : "Federated Cloud ID",
    "Home" : "Домашен",
    "Work" : "Служебен",
    "Other" : "Друг",
    "Address" : "Адрес",
    "Post office box" : "Пощенска кутия",
    "Extended address" : "Детайлен адрес",
    "City" : "Град",
    "State or province" : "Област",
    "Postal code" : "Пощенски код",
    "Country" : "Държава",
    "Birthday" : "Рожден ден",
    "Anniversary" : "Годишнина",
    "Date of death" : "Починал на",
    "Instant messaging" : "Чат",
    "Phone" : "Телефон",
    "Mobile" : "Мобилен",
    "Work mobile" : "Служебен мобилен",
    "Home mobile" : "Домашен мобилен",
    "Fax" : "Факс",
    "Fax home" : "Домашен факс",
    "Fax work" : "Служебен факс",
    "Pager" : "Пейджър",
    "Voice" : "Гласов",
    "Car" : "Кола",
    "Work pager" : "Служебен пейджър",
    "Manager" : "Управител",
    "Social network" : "Социална мрежа",
    "Relationship to you" : "Връзка с теб",
    "Spouse" : "Съпруг(а)",
    "Child" : "Дете",
    "Mother" : "Майка",
    "Father" : "Баща",
    "Parent" : "Родител",
    "Brother" : "Брат",
    "Sister" : "Сестра",
    "Relative" : "Роднина",
    "Friend" : "Приятел",
    "Colleague" : "Колега",
    "Assistant" : "Асистент",
    "Related contacts" : "Свързани контакти",
    "Agent" : "Агент",
    "Emergency" : "Спешно",
    "Co-worker" : "Колега",
    "Gender" : "Пол",
    "Female" : "Жена",
    "Male" : "Мъж",
    "None" : "Без",
    "Unknown" : "Непознат",
    "Time zone" : "Часова зона",
    "Spoken languages" : "Говорими езици",
    "_{failed} contact failed to be read_::_{failed} contacts failed to be read_" : ["{failed} контактите не бяха прочетени","{failed} контактите не бяха прочетени"],
    "An error has occurred in circle(s). Check the console for more details." : "В приложението кръг(ове) възникна грешка. Проверете конзолата за повече подробности.",
    "Unable to create circle {circleName}" : "Кръгът {circleName}, не може да се създаде",
    "Unable to delete circle {circleId}" : "Не може да се изтрие кръг {circleId}",
    "Unable to delete contact" : "Контактът не може да се изтрие"
},
"nplurals=2; plural=(n != 1);");
