OC.L10N.register(
    "contacts",
    {
    "Details" : "Podrobnosti",
    "All contacts" : "Všetky kontakty",
    "Contacts" : "Kontakty",
    "A contacts app for Nextcloud" : "Apka kontaktov pre Nextcloud",
    "The Nextcloud contacts app is a user interface for Nextcloud's CardDAV server. Easily sync contacts from various devices with your Nextcloud and edit them online.\n\n* 🚀 **Integration with other Nextcloud apps!** Currently Mail and Calendar – more to come.\n* 🎉 **Never forget a birthday!** You can sync birthdays and other recurring events with your Nextcloud Calendar.\n* 👥 **Sharing of Adressbooks!** You want to share your contacts with your friends or coworkers? No problem!\n* 🙈 **We’re not reinventing the wheel!** Based on the great and open SabreDAV library." : "Aplikácia Nextcloud kontakty je používateľské rozhranie pre Nextcloud CardDAV server.  Jednoducho synchronizujte kontakty z rôznych zariadení s Vaším Nextcloud a upravujte ich online.\n\n* 🚀 **Integrácia s ostatnými Nextcloud aplikáciami!** V súčasnosti Mail a Calendar - ďalšie pribudnú neskôr.\n* 🎉 **Nikdy nezabudnite na narodeniny!** Môžete synchronizovať narodeniny a iné opakujúce sa udalosti s Vašim Nextcloud Calendar.\n* 👥 **Sprístupnenie adresárov!** Chcete sprístupniť Vaše kontakty priateľom alebo spolupracovníkom? Bez problémov!\n* 🙈 **Nevynachádzame koleso!** Založené na vynikajúcej a otvorenej knižnici SabreDAV.",
    "Copy to full name" : "Kopírovať na celé meno",
    "Omit year" : "Vynechať rok",
    "Allow updating avatars from social media" : "Povoliť aktualizáciu avatarov zo sociálnych médií",
    "Please select a circle" : "Prosím vyberte kruh",
    "Loading circle …" : "Načítavam kruh ...",
    "Your request to join this circle is pending approval" : "Vaša požiadavka na pripojenie k tomuto kruhu čaká na schválenie",
    "You are not a member of {circle}" : "Nie ste členom {circle}",
    "There was an error fetching the member list" : "Pri načítavaní zoznamu členov sa vyskytla chyba",
    "Loading contacts …" : "Načítavajú sa kontakty ...",
    "There are no contacts yet" : "Zatiaľ tu nie sú žiadne kontakty.",
    "Create contact" : "Vytvoriť kontakt",
    "There are no contacts in this group" : "V tejto skupine nie sú žiadne kontakty",
    "Create contacts" : "Vytvoriť kontakty",
    "Add contacts" : "Pridať kontakty",
    "Loading …" : "Načítava sa...",
    "Add member" : "Pridať člena",
    "Leave circle" : "Opustiť kruh",
    "Delete circle" : "Zmazať kruh",
    "Contacts settings" : "Nastavenia kontaktov",
    "General settings" : "Všeobecné nastavenia",
    "Update avatars from social media" : "Aktualizovať avatarov zo sociálneho média",
    "(refreshed once per week)" : "(aktualizovať raz za týždeň)",
    "Address books" : "Adresáre",
    "Export" : "Export",
    "Send email" : "Odoslať email",
    "Circles" : "Kruhy",
    "Create a new circle" : "Vytvoriť nový kruh",
    "Show all groups" : "Zobraziť všetky skupiny",
    "Collapse groups" : "Zbaliť skupiny",
    "Show all circles" : "Zobraziť všetky kruhy",
    "Collapse circles" : "Zbaliť kruhy",
    "This group already exists" : "Táto skupina už existuje",
    "This circle already exists" : "Tento kruh už existuje",
    "An error happened during the creation of the circle" : "Pri vytváraní kruhu sa stala chyba",
    "Download" : "Stiahnuť",
    "Rename" : "Premenovať",
    "Delete" : "Zmazať",
    "Copied" : "Skopírované",
    "Cannot copy" : "Nemôžem kopírovať",
    "Copy link" : "Kopírovať odkaz",
    "Toggling of address book was not successful" : "Zapnutie/vypnutie adresára nebolo úspešné",
    "This will delete the address book and every contacts within it" : "Týmto sa odstráni adresár a všetky kontakty v ňom",
    "Delete {addressbook}?" : "Zmazať {addressbook}?",
    "Deletion of address book was not successful." : "Odstránenie adresára nebolo úspešné.",
    "Renaming of address book was not successful." : "Premenovanie adresára nebolo úspešné.",
    "_Shared with {num} entity_::_Shared with {num} entities_" : ["Zdieľané s {num} entitou","Zdieľané s {num} entitami","Zdieľané s {num} entitami","Zdieľané s {num} entitami"],
    "Share with users or groups" : "Sprístupniť používateľom alebo skupinám",
    "Share with users" : "Zdieľať s používateľmi",
    "No users or groups" : "Žiadny používatelia alebo skupiny",
    "can edit" : "môže upravovať",
    "Unable to delete the share" : "Nemožno zmazať zdieľanie.",
    "Unable to change permissions" : "Nepodarilo sa zmeniť oprávnenia",
    "Import contacts" : "Importovať kontakty",
    "Import into the {addressbookName} address book" : "Importovať do {addressbookName} adresára",
    "Select local file" : "Vybrať miestny súbor",
    "Import from files" : "Importovať zo súborov",
    "Importing is disabled because there are no address books available" : "Nie je možné importovať, pretože neexistuje ani jeden adresár kontaktov",
    "Choose a vCard file to import" : "Vyberte súbor vCard, ktorý chcete importovať",
    "Add new address book" : "Pridať nový adresár",
    "An error occurred, unable to create the address book" : "Vyskytla sa chyba, nepodarilo sa vytvoriť adresár",
    "First name" : "Krstné meno",
    "Last name" : "Priezvisko",
    "Phonetic first name" : "Meno foneticky",
    "Phonetic last name" : "Priezvisko foneticky",
    "Display name" : "Zobrazované meno",
    "Last modified" : "Naposledy zmenené",
    "Sort by {sorting}" : "Zoradiť podľa {sorting}",
    "Manages" : "Spravuje",
    "Oversees" : "Dohliada",
    "An error happened during the config change" : "Pri zmene konfigurácie sa stala chyba",
    "Password protection" : "Ochrana heslom",
    "Enforce password protection on files shared to this circle" : "Vyžadovať ochranu heslom pre súbory zdieľané v tomto kruhu",
    "Use a unique password for all shares to this circle" : "Použiť unikátne heslo pre každé zdieľanie v tomto kruhu",
    "Unique password …" : "Unikátne heslo ...",
    "Save" : "Uložiť",
    "Change unique password" : "Zmeniť unikátne heslo",
    "Failed to save password. Please try again later." : "Uloženie hesla zlyhalo. Prosím skúste to znova neskôr.",
    "Circle name" : "Meno kruhu",
    "Circle owned by {owner}" : "Vlastníctvo kruhu {owner}",
    "Request to join" : "Požiadať o pripojenie",
    "Description" : "Popis",
    "There is no description for this circle" : "Kruh nemá žiadny popis",
    "Enter a description for the circle" : "Vložte popis kruhu",
    "An error happened during description sync" : "Pri synchronizovaní popisu sa stala chyba",
    "An error happened during name sync" : "Pri synchronizovaní názvu sa stala chyba",
    "Add more info" : "Pridať viac informácií",
    "Cancel" : "Zrušiť",
    "Upload a new picture" : "Nahrať nový obrázok",
    "Choose from Files" : "Vybrať zo Súborov",
    "Get from " : "Získať z",
    "Download picture" : "Stiahnuť obrázok",
    "Delete picture" : "Zmazať obrázok",
    "Invalid image" : "Chybný obrázok",
    "Error cropping picture" : "Chyba počas orezávania obrázku",
    "Pick an avatar" : "Zvoľte si avatar",
    "Error while processing the picture." : "Chyba pri spracovaní obrázka.",
    "Avatar downloaded from social network" : "Avatar stiahnutý zo sociálnej siete",
    "Avatar already up to date" : "Avatar už je aktuálny",
    "Avatar download failed" : "Stiahnutie avataru zlyhalo",
    "No contact selected" : "Vyberte aspoň jeden kontakt",
    "Select a contact on the list to begin" : "Pre začatie vyberte kontakt zo zoznamu",
    "Name" : "Meno",
    "Title" : "Funkcia",
    "Company" : "Spoločnosť",
    "This contact was broken and received a fix. Please review the content and click here to save it." : "Tento kontakt bol opravený. Overte prosím obsah a kliknite pre uloženie.",
    "Clone contact" : "Duplikovať kontakt",
    "Generate QR Code" : "Vygenerovať QR kód",
    "Contact vCard as QR code" : "Zobraziť QR kód vCard kontaktu",
    "Pick an address book" : "Vybrať adresár",
    "Select address book" : "Označiť adresár",
    "This contact is in read-only mode. You do not have permission to edit this contact." : "Tento kontakt je iba na čítanie. Nemáte oprávnenie na úpravu tohto kontaktu.",
    "The contact you were trying to edit has changed. Please manually refresh the contact. Any further edits will be discarded." : "Kontakt ktorý sa snažíte modifikovať sa zmenil.  Prosím manuálne obnovte kontakt.  Akékoľvek ďalšie zmeny nebudú brané do úvahy.",
    "Address book" : "Adresár",
    "Add contact to Birthday Calendar" : "Pridať kontakt do Kalendára narodenín",
    "Exclude contact from Birthday Calendar" : "Odobrať kontakt z Kalendára Narodenín",
    "Syntax error. Cannot open the contact." : "Chyba zápisu. Nepodarilo sa otvoriť kontakt.",
    "Unable to retrieve the contact from the server, please check your network connection." : "Nepodarilo sa načítať kontakt zo servera, skontrolujte sieťové pripojenie.",
    "An error occurred while trying to move the contact" : "Pri pokuse o presun kontaktu sa vyskytla chyba",
    "An error occurred while trying to copy the contact" : "Pri pokuse o skopírovanie kontaktu sa vyskytla chyba",
    "Unable to update contact" : "Nepodarilo sa aktualizovať kontakt",
    "Search contacts …" : "Prehľadať kontakty...",
    "Add to {group}" : "Pridať do {group}",
    "Remove {type}" : "Odstrániť {type}",
    "Search {types}" : "Vyhľadať {types}",
    "Search for people to add" : "Vyhľadať ľudí pre pridanie",
    "No results" : "Žiadne výsledky",
    "Add to group" : "Pridať do skupiny",
    "Add {type}" : "Pridať {type}",
    "New circle name" : "Nový názov kruhu",
    "Personal circle" : "Osobný kruh",
    "This circle will only be visible to you. Other members will not be able to see or use it." : "Tento kruh bude viditeľný iba pre vás. Ostatní členovia ho nebudú vidieť ani ho používať.",
    "Local circle" : "Lokálny kruh",
    "This circle will not be shared with the other instances of the global scale" : "Tento kruh nebude zdieľaný z inými inštanciami globálneho rozsahu",
    "Create circle" : "Vytvoriť kruh",
    "Loading members list …" : "Načítavam zoznam členov ...",
    "The list of members is only visible to members of this circle" : "Zoznam členov je viditeľný iba pre členov tohto kruhu",
    "Add members" : "Pridať členov",
    "Show circle details" : "Zobraziť podrobnosti o kruhu",
    "Add to {circle}" : "Pridať do {circle}",
    "Unable to get the recommendations list" : "Nie je možné načítať zoznam odporúčaní",
    "Unable to get the results" : "Nemôžem získať výsledky",
    "Some members could not be added" : "Niektorých členov nie je možné pridať",
    "There was an issue adding members to the circle" : "Nastala chyba pri pridávaní členov do kruhu",
    "Accept membership request" : "Prijať žiadosť o členstvo",
    "Reject membership request" : "Odmietnuť žiadosť o členstvo",
    "Manage level" : "Spravovať úroveň",
    "Remove member" : "Odstrániť člena",
    "Pending" : "Čakajúce",
    "Promote as sole owner" : "Povýšiť ako jediný vlastník",
    "Promote to {level}" : "Povýšiť na {level}",
    "Demote to {level}" : "Degradovať na {level}",
    "Could not delete the member {displayName}" : "Nemôžem vymazať člena {displayName}",
    "Could not change the member level to {level}" : "Nemôžem zmeniť úroveň člena na {level}",
    "Could not accept membership request" : "Nie je možné prijať žiadosť o členstvo",
    "Chart" : "Graf",
    "Select chart …" : "Vybrať graf ...",
    "Select type" : "Vyberte typ",
    "Select Date" : "Vybrať dátum",
    "Add contact in group" : "Pridať kontakt do skupiny",
    "Select option" : "Vyberte možnosť",
    "New contact" : "Nový kontakt",
    "Unable to create the contact." : "Nepodarilo sa vytvoriť kontakt.",
    "Contact not found" : "Kontakt sa nenašiel",
    "Group {group} not found" : "Skupina {group} nebola nájdená",
    "Close" : "Zavrieť",
    "_{success} contact added to {name}_::_{success} contacts added to {name}_" : ["{success} kontakt pridaný pre {name}","{success} kontakty pridané pre {name}","{success} kontakty pridané pre {name}","{success} kontakty pridané pre {name}"],
    "_Adding {success} contact to {name}_::_Adding {success} contacts to {name}_" : ["Pridanie kontaktu k {name} bolo {success}","Pridanie kontaktov k {name} bolo {success}","Pridanie kontaktov k {name} bolo {success}","Pridanie kontaktov k {name} bolo {success}"],
    "_{count} error_::_{count} errors_" : ["{count} chyba","{count} chýb","{count} chýb","{count} chýb"],
    "_Importing %n contact into {addressbook}_::_Importing %n contacts into {addressbook}_" : ["Importuje sa %n kontakt do {addressbook}","Importujú sa %n kontakty do {addressbook}","Importujú sa %n kontakty do {addressbook}","Importuje sa %n kontaktov do {addressbook}"],
    "_Done importing %n contact into {addressbook}_::_Done importing %n contacts into {addressbook}_" : ["Do {addressbook} bol dokončený import %n kontaktu","Do {addressbook} bol dokončený import %n kontaktov","Do {addressbook} bol dokončený import %n kontaktov","Do {addressbook} bol dokončený import %n kontaktov"],
    "Import" : "Import",
    "Could not copy" : "Nie je možné skopírovať",
    "Join circle" : "Pripojiť sa ku kruhu",
    "You are about to leave {circle}.\nAre you sure?" : "Ste na odchode z {circle}.\nSte si istý?",
    "Please confirm circle leave" : "Prosím potvrďte opustenie kruhu",
    "Could not leave the circle {displayName}" : "Nemôžem opustiť kruh {displayName}",
    "Unable to join the circle" : "Nedarí sa pripojiť ku kruhu",
    "You are about to delete {circle}.\nAre you sure?" : "Odstraňujete {circle}.\nSte si istý?",
    "Please confirm circle deletion" : "Prosím potvrďte zmazanie kruhu",
    "Unable to delete the circle" : "Nie je možné zmazať kruh",
    "Link copied to the clipboard" : "Odkaz bol skopírovaný do schránky",
    "Could not copy link to the clipboard." : "Nepodarilo sa skopírovať do schránky.",
    "Not grouped" : "Bez skupiny",
    "Recently contacted" : "Nedávno kontaktovaní",
    "Organization chart" : "Organizačný diagram",
    "Circle" : "Kruh",
    "User" : "Užívateľ",
    "Group" : "Skupina",
    "Email" : "Email",
    "Contact" : "Kontakt",
    "Member" : "Člen",
    "Moderator" : "Moderátor",
    "Admin" : "Administrátor",
    "Owner" : "Vlastník",
    "Invites" : "Pozvánky",
    "Anyone can request membership" : "Ktokoľvek môže žiadať o členstvo",
    "Members need to accept invitation" : "Členovia musia potvrdiť pozvánku",
    "Memberships must be confirmed/accepted by a Moderator (requires Open)" : "Členstvo musí byť potvrdené/prijaté moderátorom (vyžaduje sa Otvorené)",
    "Members can also invite" : "Členovia môžu tiež pozývať",
    "Visibility" : "Viditeľnosť",
    "Visible to everyone" : "Viditeľné pre všetkých",
    "Circle membership" : "Členstvo v kruhu",
    "Prevent circle from being a member of another circle" : "Odoprieť kruhu byť členom iného kruhu",
    "Users" : "Používatelia",
    "Email addresses" : "E-mailové adresy",
    "Detailed name" : "Podrobné meno",
    "Additional names" : "Ďalšie mená",
    "Prefix" : "Titul pred menom",
    "Suffix" : "Titul po mene",
    "Nickname" : "Prezývka",
    "Notes" : "Poznámky",
    "Website" : "Webstránka",
    "Location" : "Umiestnenie",
    "Federated Cloud ID" : "Identifikátor združeného cloudu",
    "Home" : "Domov",
    "Work" : "Práca",
    "Other" : "Iné",
    "Address" : "Adresa",
    "Post office box" : "Poštová adresa",
    "Extended address" : "Rozšírené adresy",
    "City" : "Mesto",
    "State or province" : "Kraj alebo oblasť",
    "Postal code" : "PSČ",
    "Country" : "Krajina",
    "Birthday" : "Narodeniny",
    "Anniversary" : "Výročie",
    "Date of death" : "Dátum smrti",
    "Instant messaging" : "Instant messaging",
    "Phone" : "Telefón",
    "Mobile" : "Mobil",
    "Work mobile" : "Pracovný mobil",
    "Home mobile" : "Domáci mobil",
    "Fax" : "Fax",
    "Fax home" : "Fax doma",
    "Fax work" : "Fax v práci",
    "Pager" : "Pager",
    "Voice" : "Odkazová schránka",
    "Car" : "Auto",
    "Work pager" : "Pracovný pager",
    "Manager" : "Manažér",
    "Social network" : "Sociálna sieť",
    "Relationship to you" : "Vzťah s vami",
    "Spouse" : "Partner/ka",
    "Child" : "Dieťa",
    "Mother" : "Matka",
    "Father" : "Otec",
    "Parent" : "Rodič",
    "Brother" : "Brat",
    "Sister" : "Sestra",
    "Relative" : "Príbuzný",
    "Friend" : "Kamarát/ka",
    "Colleague" : "Kolega",
    "Assistant" : "Asistent",
    "Related contacts" : "Súvisiace kontakty",
    "Agent" : "Agent",
    "Emergency" : "Núdzový kontakt",
    "Co-worker" : "Spolupracovník",
    "Gender" : "Pohlavie",
    "Female" : "Žena",
    "Male" : "Muž",
    "None" : "Žiadne",
    "Unknown" : "Neznámy",
    "Time zone" : "Časová zóna",
    "Spoken languages" : "Hovorené jazyky",
    "_{failed} contact failed to be read_::_{failed} contacts failed to be read_" : ["{failed} kontakt nebolo možné prečítať","{failed} kontakty nebolo možné prečítať","{failed} kontaktov nebolo možné prečítať","{failed} kontaktov nebolo možné prečítať"],
    "Unable to create circle {circleName}" : "Nie je možné vytvoriť kruh {circleName}",
    "Unable to delete circle {circleId}" : "Nie je možné zmazať kruh {circleId}",
    "Unable to delete contact" : "Nepodarilo sa zmazať kontakt."
},
"nplurals=4; plural=(n % 1 == 0 && n == 1 ? 0 : n % 1 == 0 && n >= 2 && n <= 4 ? 1 : n % 1 != 0 ? 2: 3);");
