OC.L10N.register(
    "contacts",
    {
    "Details" : "Մանրամասներ",
    "Download" : "Ներբեռնել",
    "Rename" : "Վերանվանել",
    "Delete" : "հեռացնել",
    "Copy link" : "Պատճենել հղումը",
    "Share with users or groups" : "Կիսվել օգտատերերի կամ խմբերի հետ",
    "can edit" : "կարող է խմբագրել",
    "First name" : "Անուն",
    "Last name" : "Ազգանուն",
    "Password protection" : "Password protection",
    "Save" : "Պահպանել",
    "Description" : "Նկարագրություն",
    "Cancel" : "ընդհատել",
    "Name" : "Անուն",
    "Title" : "Վերնագիր",
    "Close" : "Փակել",
    "Import" : "Ներմուծում",
    "User" : "User",
    "Group" : "Խումբ",
    "Email" : "Էլ. հասցե",
    "Owner" : "Owner",
    "Nickname" : "Մականուն",
    "Notes" : "Նոթեր",
    "Location" : "Տեղակայություն",
    "Other" : "Այլ",
    "Address" : "Հասցե",
    "City" : "Քաղաք",
    "Country" : "Երկիր",
    "Birthday" : "Ծննդյան օր",
    "Relative" : "Հարաբերական",
    "Unknown" : "Անհայտ"
},
"nplurals=2; plural=(n != 1);");
