OC.L10N.register(
    "contacts",
    {
    "Details" : "დეტალები",
    "All contacts" : "ყველა კონტაქტი",
    "Contacts" : "კონტაქტები",
    "Loading contacts …" : "კონტაქტების ჩატვირთვა ...",
    "Delete circle" : "წრის გაუქმება",
    "General settings" : "მთავარი პარამეტრები",
    "Send email" : "ელ-წერილის გაგზავნა",
    "Circles" : "წრეები",
    "Create a new circle" : "შექმენით წრე",
    "Download" : "ჩამოტვირთვა",
    "Rename" : "სახელის შეცვლა",
    "Delete" : "გაუქმება",
    "Copy link" : "ბმულის კოპირება",
    "Share with users or groups" : "გაზიარება მოხმარებლებთან ან ჯგუფებთან",
    "can edit" : "შეუძლია შეცვლა",
    "First name" : "სახელი",
    "Last name" : "გვარი",
    "Display name" : "დისპლეი სახელი",
    "Last modified" : "ბოლო ცვლილება",
    "Password protection" : "პაროლით თავდაცვა",
    "Save" : "შენახვა",
    "Description" : "აღწერილობა",
    "Cancel" : "უარყოფა",
    "Invalid image" : "არასწორი სურათი",
    "Name" : "სახელი",
    "Title" : "სათაური",
    "Address book" : "მისამართების წიგნი",
    "Search contacts …" : "მოძებნეთ კონტაქტები ...",
    "No results" : "შედეგები არაა",
    "Personal circle" : "პირადი წრე",
    "Pending" : "მოლოდინში",
    "New contact" : "ახალი კონტაქტი",
    "Close" : "დახურვა",
    "Import" : "იმპორტი",
    "Not grouped" : "არაა დაჯგუფებული",
    "Circle" : "წრე",
    "User" : "მომხმარებელი",
    "Group" : "ჯგუფი",
    "Email" : "ელ-ფოსტა",
    "Contact" : "კონტაქტი",
    "Member" : "წევრი",
    "Moderator" : "მოდერატორი",
    "Admin" : "ადმინისტრატორი",
    "Owner" : "მფლობელი",
    "Users" : "მომხმარებლები",
    "Detailed name" : "დეტალური სახელი",
    "Additional names" : "დამატებითი სახელები",
    "Prefix" : "პრეფიქსი",
    "Suffix" : "სუფიქსი",
    "Nickname" : "ნიკნეიმი",
    "Notes" : "შენიშვნები",
    "Website" : "ვებ-საიტი",
    "Location" : "ადგილმდებარეობა",
    "Federated Cloud ID" : "ფედერალური ქლაუდ ID",
    "Home" : "სახლი",
    "Work" : "სამსახური",
    "Other" : "სხვა",
    "Address" : "მისამართი",
    "Post office box" : "საფოსტო ყუთი",
    "City" : "ქალაქი",
    "State or province" : "შტატი ან პროვინცია",
    "Postal code" : "საფოსტო კოდი",
    "Country" : "ქვეყანა",
    "Birthday" : "დაბადების დრე",
    "Anniversary" : "დაბადების დღე",
    "Date of death" : "გადრდაცვალების დღე",
    "Instant messaging" : "მესინჯერი",
    "Phone" : "ტელეფონი",
    "Mobile" : "მობილური",
    "Work mobile" : "სამუშაო ტელეფონი",
    "Fax" : "ფაქსი",
    "Fax home" : "სახლის ფაქსი",
    "Fax work" : "სამსახურის ფაქსი",
    "Pager" : "პეიჯერი",
    "Voice" : "ხმა",
    "Car" : "მაქნანა",
    "Work pager" : "სამუშაო პეიჯერი",
    "Manager" : "მენეჯერი",
    "Social network" : "სოციალური ქსელი",
    "Spouse" : "მეუღლე",
    "Child" : "შვილი",
    "Mother" : "დედა",
    "Father" : "მამა",
    "Parent" : "მშობელი",
    "Brother" : "ძმა",
    "Sister" : "და",
    "Relative" : "ნათესავი",
    "Friend" : "მეგობარი",
    "Colleague" : "კოლეგა",
    "Assistant" : "ასისტენტი",
    "Gender" : "სქესი",
    "Female" : "მდედორობითი",
    "Male" : "მამრობითი",
    "None" : "არც ერთი",
    "Unknown" : "ამოუცნობი"
},
"nplurals=2; plural=(n!=1);");
