OC.L10N.register(
    "contacts",
    {
    "Details" : "Λεπτομέριες",
    "All contacts" : "Όλες οι επαφές",
    "Contacts" : "Επαφές",
    "A contacts app for Nextcloud" : "Εφαρμογή επαφών για το Nextcloud",
    "The Nextcloud contacts app is a user interface for Nextcloud's CardDAV server. Easily sync contacts from various devices with your Nextcloud and edit them online.\n\n* 🚀 **Integration with other Nextcloud apps!** Currently Mail and Calendar – more to come.\n* 🎉 **Never forget a birthday!** You can sync birthdays and other recurring events with your Nextcloud Calendar.\n* 👥 **Sharing of Adressbooks!** You want to share your contacts with your friends or coworkers? No problem!\n* 🙈 **We’re not reinventing the wheel!** Based on the great and open SabreDAV library." : "Η εφαρμογή επαφών του Nextcloud είναι η διεπαφή χρήστη για το χειρισμό του διακομιστή Nextcloud CardDAV. Εύκολος συγχρονισμός και επεξεργασία επαφών από διάφορες συσκευές με το Nextcloud\n\n* 🚀 **Συνεργασία με άλλες εφαρμογές Nextcloud!** Ήδη με Ηλεκτρονικό Ταχυδρομείο και Ημερολόγιο - προσεχώς και άλλα.\n* 🎉 **Δεν ξεχνάτε ποτέ γενέθλια!** Συγχρονισμός γενεθλίων και άλλων επετείων με το ημερολόγιο Nextclound\n* 👥 **Κοινή χρήση Βιβλίου διευθύνσεων!** Θέλεις να μοιραστείς τις επαφές σου με φίλους ή συνεργάτες? Κανένα πρόβλημα!\n* 🙈 ** Δεν ανακαλύψαμε τον τροχό!** Βασίζεται στο ανοικτό λογισμικό SabreDAV.",
    "Copy to full name" : "Αντιγραφή στο πλήρες όνομα",
    "Omit year" : "Παράλειψη έτους",
    "Allow updating avatars from social media" : "Να επιτρέπεται η ενημέρωση του άβαταρ από τα μέσα κοινωνικής δικτύωσης.",
    "Please select a circle" : "Παρακαλούμε επιλέξτε έναν κύκλο",
    "Loading circle …" : "Φόρτωση κύκλου ...",
    "Your request to join this circle is pending approval" : "Το αίτημά σας για συμμετοχή σε αυτόν τον κύκλο βρίσκεται σε αναμονή έγκρισης",
    "You are not a member of {circle}" : "Δεν είστε μέλος του κύκλου {circle}",
    "There was an error fetching the member list" : "Παρουσιάστηκε σφάλμα κατά την ανάκτηση της λίστας μελών",
    "Loading contacts …" : "Φόρτωση επαφών ...",
    "There are no contacts yet" : "Δεν υπάρχουν ακόμη επαφές",
    "Create contact" : "Δημιουργία επαφής",
    "There are no contacts in this group" : "Δεν υπάρχουν επαφές σε αυτήν την ομάδα ",
    "Create contacts" : "Δημιουργία επαφών",
    "Add contacts" : "Προσθήκη επαφών",
    "Loading …" : "Φόρτωση…",
    "Add member" : "Προσθήκη μέλους",
    "Leave circle" : "Αποχώρηση από τον κύκλο",
    "Delete circle" : "Διαγραφή κύκλου",
    "Contacts settings" : "Ρυθμίσεις επαφών",
    "General settings" : "Γενικές ρυθμίσεις",
    "Update avatars from social media" : "Ενημέρωση των άβαταρ από τα κοινωνικά δίκτυα",
    "(refreshed once per week)" : "(ανανεώνεται μία φορά την εβδομάδα)",
    "Address books" : "Βιβλία διευθύνσεων",
    "Export" : "Εξαγωγή",
    "Send email" : "Αποστολή email",
    "Send email as BCC" : "Αποστολή email ως BCC",
    "Contact groups" : "Ομάδες επαφών",
    "Create a new contact group" : "Δημιουργία νέας ομάδας επαφών",
    "Contact group name" : "Όνομα ομάδας επαφών",
    "Circles" : "Κύκλοι",
    "Create a new circle" : "Δημιουργήστε έναν νέο κύκλο",
    "Show all groups" : "Εμφάνιση όλων των ομάδων",
    "Collapse groups" : "Σύμπτυξη ομάδων",
    "Show all circles" : "Εμφάνιση όλων των κύκλων",
    "Collapse circles" : "Σύμπτυξη κύκλων",
    "This group already exists" : "Αυτή η ομάδα υπάρχει ήδη",
    "This circle already exists" : "Αυτός ο κύκλος υπάρχει ήδη",
    "An error happened during the creation of the circle" : "Παρουσιάστηκε σφάλμα κατά τη δημιουργία του κύκλου",
    "Download" : "Λήψη",
    "Show" : "Εμφάνιση",
    "Rename" : "Μετονομασία",
    "Delete" : "Διαγραφή",
    "Copied" : "Αντιγράφτηκε",
    "Cannot copy" : "Αδυναμία αντιγραφής",
    "Copy link" : "Αντιγραφή συνδέσμου",
    "Toggling of address book was not successful" : "Η εναλλαγή του βιβλίου διευθύνσεων απέτυχε",
    "This will delete the address book and every contacts within it" : "Θα διαγραφεί το βιβλίο διευθύνσεων και όλες τις επαφές",
    "Delete {addressbook}?" : "Διαγραφή του {addressbook}?",
    "Deletion of address book was not successful." : "Απέτυχε η διαγραφή του βιβλίου διευθύνσεων.",
    "Renaming of address book was not successful." : "Η μετονομασία του βιβλίου διευθύνσεων απέτυχε.",
    "_%n contact_::_%n contacts_" : ["%n επαφή","%n επαφές"],
    "_%n group_::_%n groups_" : ["%n ομάδα","%n ομάδες"],
    "_Shared with {num} entity_::_Shared with {num} entities_" : ["Κοινη χρήση με {num} οντότητα","Κοινή χρήση με {num} οντότητες"],
    "Share with users or groups" : "Διαμοιρασμός με χρήστες ή ομάδες",
    "Share with users" : "Μοιραστείτε με χρήστες",
    "No users or groups" : "Χωρίς χρήστες ή ομάδες",
    "can edit" : "με δυνατότητα επεξεργασίας",
    "Unable to delete the share" : "Δεν είναι δυνατή η διαγραφή του κοινόχρηστου",
    "Unable to change permissions" : "Δεν είναι δυνατή η αλλαγή δικαιωμάτων",
    "Import contacts" : "Εισαγωγή επαφών",
    "Import into the {addressbookName} address book" : "Εισαγωγή στο {addressbookName} βιβλίο διευθύνσεων",
    "Select local file" : "Επιλογή τοπικού αρχείου",
    "Import from files" : "Εισαγωγή απο αρχεία",
    "Importing is disabled because there are no address books available" : "Η λειτουργία εισαγωγής απενεργοποιήθηκε, καθώς δεν βρέθηκε κάποιο βιβλίο διευθύνσεων διαθέσιμο",
    "Choose a vCard file to import" : "Επιλογή αρχείου vCard για εισαγωγή",
    "Add new address book" : "Προσθήκη νέου βιβλίο διευθύνσεων",
    "An error occurred, unable to create the address book" : "Παρουσιάστηκε σφάλμα, δεν ήταν δυνατή η δημιουργία του βιβλίου διευθύνσεων",
    "First name" : "Όνομα",
    "Last name" : "Επώνυμο",
    "Phonetic first name" : "Φωνητικό πρώτο όνομα",
    "Phonetic last name" : "Φωνητικό επίθετο",
    "Display name" : "Εμφανιζόμενο όνομα",
    "Last modified" : "Τελευταία τροποίηση",
    "Sort by {sorting}" : "Ταξινόμηση κατά {sorting}",
    "Manages" : "Διαχειρίζεται",
    "Oversees" : "Επιβλέπει",
    "An error happened during the config change" : "Παρουσιάστηκε σφάλμα κατά την αλλαγή της ρύθμισης",
    "Password protection" : "Προστασία συνθηματικού",
    "Enforce password protection on files shared to this circle" : "Επιβολή προστασίας με κωδικό πρόσβασης σε κοινόχρηστα αρχεία αυτού του κύκλου",
    "Use a unique password for all shares to this circle" : "Χρησιμοποιήστε έναν μοναδικό κωδικό πρόσβασης για όλα τα κοινόχρηστα στοιχεία σε αυτόν τον κύκλο",
    "Unique password …" : "Μοναδικός κωδικός πρόσβασης…",
    "Save" : "Αποθήκευση",
    "Change unique password" : "Αλλαγή μοναδικού κωδικού πρόσβασης",
    "Failed to save password. Please try again later." : "Αποτυχία αποθήκευσης κωδικού πρόσβασης. Παρακαλώ προσπαθήστε ξανά αργότερα.",
    "Circle name" : "Όνομα κύκλου",
    "Circle owned by {owner}" : "Κύκλος που ανήκει στον/στην {owner}",
    "Request to join" : "Αίτημα συμμετοχής",
    "Description" : "Περιγραφή",
    "There is no description for this circle" : "Δεν υπάρχει περιγραφή για αυτόν τον κύκλο",
    "Enter a description for the circle" : "Εισαγάγετε μια περιγραφή για τον κύκλο",
    "An error happened during description sync" : "Παρουσιάστηκε σφάλμα κατά τον συγχρονισμό της περιγραφής",
    "An error happened during name sync" : "Παρουσιάστηκε σφάλμα κατά τον συγχρονισμό του ονόματος",
    "Add more info" : "Προσθέστε περισσότερες πληροφορίες",
    "More fields" : "Περισσότερα πεδία",
    "Crop contact photo" : "Περικοπή φωτογραφίας της επαφής",
    "Cancel" : "Ακύρωση",
    "Upload a new picture" : "Μεταφόρτωση νέας φωτογραφίας",
    "Choose from Files" : "Επιλέξτε από τα Αρχεία",
    "Get from " : "Λήψη από",
    "Download picture" : "Λήψη εικόνας",
    "Delete picture" : "Διαγραφή εικόνας",
    "Please select a valid format" : "Παρακαλούμε επιλέξτε μια έγκυρη μορφή",
    "Invalid image" : "Μη έγκυρη εικόνα",
    "Error cropping picture" : "Σφάλμα περικοπής εικόνας",
    "Pick an avatar" : "Επιλογή άβαταρ",
    "Error while processing the picture." : "Σφάλμα κατά την επεξεργασία εικόνας.",
    "Avatar downloaded from social network" : "Το άβαταρ λήφθηκε από κοινωνικό δίκτυο",
    "Avatar already up to date" : "Το άβαταρ είναι ήδη ενημερωμένο",
    "Avatar download failed" : "Η λήψη του άβαταρ επέτυχε",
    "No contact selected" : "Καμιά επαφή δεν επιλέχθηκε",
    "Select a contact on the list to begin" : "Επέλεξε μια επαφή απο την λίστα για έναρξη",
    "Name" : "Όνομα",
    "Title" : "Τίτλος",
    "Company" : "Εταιρία",
    "This contact was broken and received a fix. Please review the content and click here to save it." : "Η επαφή παρουσίασε σφάλμα και διορθώθηκε. Παρακαλώ ελέγξτε την καταχώρηση και αποθηκεύστε εδώ.",
    "Edit" : "Επεξεργασία",
    "Clone contact" : "Κλωνοποίηση επαφής",
    "Generate QR Code" : "Δημιουργία Κώδικα QR",
    "Contact vCard as QR code" : "Κάρτα επαφής vCard ως κώδικας QR",
    "Pick an address book" : "Επιλέξτε ένα βιβλίο διευθύνσεων",
    "Select address book" : "Επιλογή βιβλίου διευθύνσεων",
    "This contact is in read-only mode. You do not have permission to edit this contact." : "Η επαφή είναι μόνο για εμφάνιση. Δεν έχετε δικαιώματα για την επεξεργασία της.",
    "The contact you were trying to edit has changed. Please manually refresh the contact. Any further edits will be discarded." : "Η επαφή που προσπαθείτε να επεξεργαστείτε άλλαξε. Παρακαλώ ανανεώστε. Όποια άλλη επεξεργασία θα απορριφθεί.",
    "Address book" : "Βιβλίο διευθύνσεων",
    "Add contact to Birthday Calendar" : "Προσθήκη επαφής στο Ημερολόγιο γενεθλίων",
    "Exclude contact from Birthday Calendar" : "Εξαίρεση επαφής από το Ημερολόγιο γενεθλίων",
    "{title} at {organization}" : "{title} σε {organization}",
    "Syntax error. Cannot open the contact." : "Σφάλμα σύνταξης. Η επαφή δεν ανοίγει.",
    "The contact does not exist on the server anymore." : "Η επαφή δεν υπάρχει πλέον στον διακομιστή.",
    "Unable to retrieve the contact from the server, please check your network connection." : "Δεν είναι δυνατή η λήψη της επαφής από τον διακομιστή, παρακαλούμε ελέγξτε την σύνδεσή του δικτύου σας.",
    "An error occurred while trying to move the contact" : "Παρουσιάστηκε σφάλμα κατά την μετακίνηση της επαφής",
    "An error occurred while trying to copy the contact" : "Παρουσιάστηκε σφάλμα κατά την αντιγραφή επαφής",
    "Unable to update contact" : "Αδυναμία ενημέρωσης επαφής",
    "Search contacts …" : "Αναζήτηση επαφών …",
    "Add to {group}" : "Προσθήκη σε {group}",
    "Remove {type}" : "Κατάργηση {type}",
    "Search {types}" : "Αναζήτηση για {types}",
    "Search for people to add" : "Αναζητήστε άτομα για προσθήκη",
    "No results" : "Κανένα αποτέλεσμα",
    "Add to group" : "Προσθήκη στην ομάδα",
    "Add {type}" : "Προσθήκη {type}",
    "New circle name" : "Νέο όνομα κύκλου",
    "Personal circle" : "Προσωπικός κύκλος",
    "This circle will only be visible to you. Other members will not be able to see or use it." : "Αυτός ο κύκλος θα είναι ορατός μόνο σε εσάς. Τα άλλα μέλη δε θα μπορούν να τον δουν ή να το χρησιμοποιήσουν.",
    "Local circle" : "Τοπικός κύκλος",
    "This circle will not be shared with the other instances of the global scale" : "Αυτός ο κύκλος δε θα είναι κοινόχρηστος με τις άλλες  εγκαταστάσεις παγκόσμιας κλίμακας",
    "Create circle" : "Δημιουργία κύκλου",
    "Loading members list …" : "Φόρτωση λίστας μελών …",
    "The list of members is only visible to members of this circle" : "Η λίστα των μελών είναι ορατή μόνο σε μέλη αυτού του κύκλου",
    "You currently have no access to the member list" : "Αυτήν τη στιγμή δεν έχετε πρόσβαση στη λίστα μελών",
    "Add members" : "Προσθήκη μελών",
    "Show circle details" : "Εμφάνιση λεπτομερειών κύκλου",
    "Add to {circle}" : "Προσθήκη σε {circle}",
    "Unable to get the recommendations list" : "Δεν είναι δυνατή η λήψη της λίστας προτάσεων",
    "Unable to get the results" : "Δεν είναι δυνατή η λήψη των αποτελεσμάτων",
    "Some members could not be added" : "Δεν ήταν δυνατή η προσθήκη ορισμένων μελών",
    "There was an issue adding members to the circle" : "Παρουσιάστηκε πρόβλημα με την προσθήκη μελών στον κύκλο",
    "Accept membership request" : "Αποδοχή αιτήματος μέλους",
    "Reject membership request" : "Απόρριψη αιτήματος μέλους",
    "Manage level" : "Διαχείριση ρόλου",
    "Remove member" : "Κατάργηση μέλους",
    "Pending" : "Εκκρεμεί",
    "Promote as sole owner" : "Προαγωγή σε μοναδικό κάτοχο",
    "Promote to {level}" : "Προαγωγή σε {level}",
    "Demote to {level}" : "Υποβίβαση σε {level}",
    "Could not delete the member {displayName}" : "Αδυναμία διαγραφής του μέλους {displayName}",
    "Could not change the member level to {level}" : "Δεν ήταν δυνατή η αλλαγή του ρόλου του μέλους σε {level}",
    "Could not accept membership request" : "Δεν ήταν δυνατή η αποδοχή του αιτήματος μέλους",
    "Chart" : "Διάγραμμα",
    "Select chart …" : "Επιλέξτε διάγραμμα …",
    "Select type" : "Επιλέξτε τύπο",
    "Select Date" : "Επιλέξτε Ημέρα",
    "Add contact in group" : "Προσθήκη στην ομάδα",
    "none" : "κανένα",
    "Select option" : "Επιλέξτε μια επιλογή",
    "Add property of this type" : "Προσθήκη ιδιότητας αυτού του τύπου",
    "New contact" : "Νέα επαφή",
    "Unable to create the contact." : "Αδυναμία δημιουργίας επαφής.",
    "Contact not found" : "Δεν βρέθηκε η επαφή.",
    "Group {group} not found" : "Η ομάδα {group} δε βρέθηκε",
    "Close" : "Κλείσιμο",
    "_{success} contact added to {name}_::_{success} contacts added to {name}_" : ["Προστέθηκε {success} επαφή σε {name}","Προστέθηκαν {success} επαφές σε {name}"],
    "_Adding {success} contact to {name}_::_Adding {success} contacts to {name}_" : ["Προσθήκη {success} επαφής σε {name}","Προσθήκη {success} επαφών σε {name}"],
    "_{count} error_::_{count} errors_" : ["{count} σφάλμα","{count} σφάλματα"],
    "_Importing %n contact into {addressbook}_::_Importing %n contacts into {addressbook}_" : ["Εισαγωγή %n επαφής σε {addressbook}","Εισαγωγή %n επαφών σε {addressbook}"],
    "_Done importing %n contact into {addressbook}_::_Done importing %n contacts into {addressbook}_" : ["Ολοκληρώθηκε η εισαγωγή %n επαφής σε {addressbook}","Ολοκληρώθηκε η εισαγωγή %n επαφών σε {addressbook}"],
    "Import" : "Εισαγωγή",
    "Could not copy" : "Δεν ήταν δυνατή η αντιγραφή",
    "Join circle" : "Συμμετοχή στον κύκλο",
    "You are about to leave {circle}.\nAre you sure?" : "Πρόκειται να αποχωρήσετε από τον κύκλο {circle}.\nΕίστε σίγουρος;",
    "Please confirm circle leave" : "Παρακαλώ επιβεβαιώστε την αποχώρηση από τον κύκλο",
    "Could not leave the circle {displayName}" : "Δεν ήταν δυνατή η αποχώρηση από τον κύκλο {displayName}",
    "Unable to join the circle" : "Δεν είναι δυνατή η συμμετοχή στον κύκλο",
    "You are about to delete {circle}.\nAre you sure?" : "Πρόκειται να διαγράψετε τον κύκλο {circle}.\nΕίστε σίγουροι?",
    "Please confirm circle deletion" : "Παρακαλώ επιβεβαιώστε την αποχώρηση από τον κύκλο",
    "Unable to delete the circle" : "Δεν είναι δυνατή η διαγραφή του κύκλου",
    "Link copied to the clipboard" : "Ο σύνδεσμος αντιγράφηκε στο πρόχειρο",
    "Could not copy link to the clipboard." : "Δεν ήταν δυνατή η αντιγραφή του συνδέσμου στο πρόχειρο.",
    "Not grouped" : "Χωρίς ομάδα",
    "Recently contacted" : "Πρόσφατη επικοινωνία",
    "Organization chart" : "Οργανόγραμμα",
    "Circles are groups of people that you can create yourself and with whom you can share data. They can be made up of other accounts or groups of accounts of the Nextcloud instance, but also of contacts from your address book or even external people by simply entering their e-mail addresses." : "Οι Κύκλοι είναι ομάδες ατόμων που μπορείτε να δημιουργήσετε μόνοι σας και με τα οποία θα μπορείτε να μοιράζεστε δεδομένα. Μπορούν να αποτελούνται από άλλους χρήστες ή ομάδες χρηστών του Nextcloud, αλλά και από επαφές από το βιβλίο διευθύνσεών σας ή ακόμη και από εξωτερικούς συνεργάτες, εισάγοντας απλώς τις διευθύνσεις ηλεκτρονικού ταχυδρομείου τους.",
    "Circle" : "Κύκλος",
    "User" : "Χρήστης",
    "Group" : "Ομάδα",
    "Email" : "Ηλ. ταχυδρομείο",
    "Contact" : "Επαφή",
    "Member" : "Μέλος",
    "Moderator" : "Συντονιστής",
    "Admin" : "Διαχειριστής",
    "Owner" : "Κάτοχος",
    "Invites" : "Προσκλήσεις",
    "Anyone can request membership" : "Οποιοσδήποτε μπορεί να αιτηθεί συμμετοχή",
    "Members need to accept invitation" : "Τα μέλη πρέπει να αποδεχτούν την πρόσκληση",
    "Memberships must be confirmed/accepted by a Moderator (requires Open)" : "Τα αιτήματα μελών πρέπει να επιβεβαιωθούν/αποδεχθούν από έναν συντονιστή (απαιτείται Ανοιχτός κύκλος)",
    "Members can also invite" : "Τα μέλη μπορούν επίσης να προσκαλέσουν",
    "Visibility" : "Ορατότητα",
    "Visible to everyone" : "Ορατός σε όλους",
    "Circle membership" : "Κύκλος ως μέλος",
    "Prevent circle from being a member of another circle" : "Αποτρέψτε τον κύκλο να είναι μέλος άλλου κύκλου",
    "Users" : "Χρήστες",
    "Email addresses" : "Διευθύνσεις ηλεκτρονικού ταχυδρομείου",
    "Detailed name" : "Λεπτομερές όνομα",
    "Additional names" : "Επιπλέον ονόματα",
    "Prefix" : "Πρόθεμα",
    "Suffix" : "Κατάληξη",
    "Nickname" : "Παρατσούκλι",
    "Notes" : "Σημειώσεις",
    "Website" : "Ιστοσελίδα",
    "Location" : "Τοποθεσία",
    "Federated Cloud ID" : "Federated Cloud ID",
    "Home" : "Σπίτι",
    "Work" : "Εργασία",
    "Other" : "Άλλο",
    "Address" : "Διεύθυνση",
    "Post office box" : "Ταχυδρομική θυρίδα",
    "Extended address" : "Εκτεταμένη διεύθυνση",
    "City" : "Πόλη",
    "State or province" : "Νομός ή περιφέρεια",
    "Postal code" : "Ταχυδρομικός Κώδικας",
    "Country" : "Χώρα",
    "Birthday" : "Γενέθλια",
    "Anniversary" : "Επέτειος",
    "Date of death" : "Ημερομηνία θανάτου",
    "Instant messaging" : "Άμεσα μηνύματα",
    "Phone" : "Τηλέφωνο",
    "Mobile" : "Κινητό",
    "Work mobile" : "Κινητό εργασίας",
    "Home mobile" : "Κινητό οικίας",
    "Fax" : "Φαξ",
    "Fax home" : "Φαξ σπίτι",
    "Fax work" : "Φαξ εργασία",
    "Pager" : "Βομβητής",
    "Voice" : "Ομιλία",
    "Car" : "Αμάξι",
    "Work pager" : "Βομβητής δουλειάς",
    "Manager" : "Διευθυντής",
    "Social network" : "Κοινωνικό δίκτυο",
    "Relationship to you" : "Σχέση με εσάς",
    "Spouse" : "Σύζυγος",
    "Child" : "Παιδί",
    "Mother" : "Μητέρα",
    "Father" : "Πατέρας",
    "Parent" : "Γονέας",
    "Brother" : "Αδελφός",
    "Sister" : "Αδελφή",
    "Relative" : "Συγγενής",
    "Friend" : "Φίλος",
    "Colleague" : "Συνάδελφος",
    "Assistant" : "Βοηθός",
    "Related contacts" : "Συναφείς επαφές",
    "Agent" : "Agent",
    "Emergency" : "Επείγον",
    "Co-worker" : "Συνάδελφος",
    "Gender" : "Φύλο",
    "Female" : "Γυναίκα",
    "Male" : "Άνδρας",
    "None" : "Κανένα",
    "Unknown" : "Άγνωστο",
    "Time zone" : "Ζώνη ώρας",
    "Spoken languages" : "Ομιλούσες γλώσσες",
    "_{failed} contact failed to be read_::_{failed} contacts failed to be read_" : ["Αποτυχία ανάγνωσης {failed} επαφής","Αποτυχία ανάγνωσης {failed} επαφών"],
    "An error has occurred in circle(s). Check the console for more details." : "Παρουσιάστηκε ένα σφάλμα στον κύκλο(ους). Ελέγξτε την κονσόλα για περισσότερες λεπτομέρειες.",
    "Unable to create circle {circleName}" : "Δεν είναι δυνατή η δημιουργία του κύκλου {circleName}",
    "Unable to delete circle {circleId}" : "Δεν είναι δυνατή η διαγραφή του κύκλου {circleId}",
    "Unable to delete contact" : "Δεν είναι δυνατή η διαγραφή της επαφής"
},
"nplurals=2; plural=(n != 1);");
