OC.L10N.register(
    "contacts",
    {
    "Details" : "詳細資料",
    "All contacts" : "所有聯絡人",
    "Contacts" : "通訊錄",
    "A contacts app for Nextcloud" : "Nextcloud 的通訊錄應用程式",
    "The Nextcloud contacts app is a user interface for Nextcloud's CardDAV server. Easily sync contacts from various devices with your Nextcloud and edit them online.\n\n* 🚀 **Integration with other Nextcloud apps!** Currently Mail and Calendar – more to come.\n* 🎉 **Never forget a birthday!** You can sync birthdays and other recurring events with your Nextcloud Calendar.\n* 👥 **Sharing of Adressbooks!** You want to share your contacts with your friends or coworkers? No problem!\n* 🙈 **We’re not reinventing the wheel!** Based on the great and open SabreDAV library." : "Nextcloud 通訊錄應用程式是 Nextcloud 的 CardDAV 伺服器的用戶界面。可輕鬆使用您的 Nextcloud 同步各個裝置上的聯絡人，並在線上編輯。\n\n* 🚀 **與其他 Nextcloud 應用程式整合！** 目前有電子郵件與日曆，還會有更多。\n* 🎉 **不會忘記生日！** 您可以將生日與其他重複的活動與您的 Nextcloud 日曆同步。\n* 👥 **分享通訊錄！** 您想與您的朋友或同事分享您的聯絡人嗎？沒問題！\n* 🙈 **我們沒有無謂地重複開發！** 以超棒且開放的 SabreDAV 函式庫為基礎。",
    "Copy to full name" : "複製到全名",
    "Omit year" : "省略年份",
    "Allow updating avatars from social media" : "允許從社群媒體更新虛擬化身大頭照",
    "Please select a circle" : "請選擇社交圈子",
    "Loading circle …" : "社交圈子加載中 ...",
    "Your request to join this circle is pending approval" : "您加入此圈子的請求正在等待批准",
    "You are not a member of {circle}" : "您不是 {circle} 的成員",
    "There was an error fetching the member list" : "擷取成員清單出錯",
    "Loading contacts …" : "正在載入通訊錄 …",
    "There are no contacts yet" : "目前沒有聯絡人",
    "Create contact" : "建立聯絡人",
    "There are no contacts in this group" : "群組中沒有聯絡人",
    "Create contacts" : "建立聯絡人",
    "Add contacts" : "新增聯絡人",
    "Loading …" : "正在載入 …",
    "Add member" : "添加成員",
    "Leave circle" : "離開社交圈子",
    "Delete circle" : "刪除社交圈子",
    "Contacts settings" : " 通訊錄設定",
    "General settings" : "一般設定",
    "Update avatars from social media" : "從社群媒體更新虛擬化身大頭照",
    "(refreshed once per week)" : "（每週重新整理一次）",
    "Address books" : "通訊錄",
    "Export" : "導出",
    "Send email" : "傳送電郵",
    "Send email as BCC" : "以 BCC 方式發送電郵",
    "Contact groups" : "聯絡群組",
    "Create a new contact group" : "創建新聯絡人群組",
    "Contact group name" : "聯絡人群組名稱",
    "Circles" : "社交圈子",
    "Create a new circle" : "創建新社交圈子",
    "Show all groups" : "顯示所有群組",
    "Collapse groups" : "收合群組",
    "Show all circles" : "顯示所有社交圈子",
    "Collapse circles" : "收合社交圈子",
    "This group already exists" : "該群組已存在",
    "This circle already exists" : "此社交圈子已存在",
    "An error happened during the creation of the circle" : "創建社交圈子的過程中發生錯誤",
    "{addressbookname} (Disabled)" : "{addressbookname}（已停用）",
    "Download" : "下載",
    "Show" : "顯示",
    "Rename" : "重新命名",
    "Delete" : "刪除",
    "Copied" : "已複製",
    "Cannot copy" : "無法複製",
    "Copy link" : "複製連結",
    "Toggling of address book was not successful" : "通訊錄切換失敗",
    "This will delete the address book and every contacts within it" : "這將刪除通訊錄及其所有的聯絡人",
    "Delete {addressbook}?" : "刪除 {addressbook}？",
    "Deletion of address book was not successful." : "刪除通訊錄失敗。",
    "Renaming of address book was not successful." : "重新命名通訊錄失敗。",
    "_%n contact_::_%n contacts_" : ["%n 位聯絡人"],
    "_%n group_::_%n groups_" : ["%n 個群組"],
    "_Shared with {num} entity_::_Shared with {num} entities_" : ["與 {num} 個實體分享"],
    "Share with users or groups" : "與用戶或群組分享",
    "Share with users" : "與用戶分享",
    "No users or groups" : "沒有用戶或群組",
    "can edit" : "允許編輯",
    "Unable to delete the share" : "無法刪除這個分享",
    "Unable to change permissions" : "無法變更權限",
    "Import contacts" : "導入聯絡人",
    "Import into the {addressbookName} address book" : "導入至 {addressbookName} 通訊錄",
    "Select local file" : "選擇本機檔案",
    "Import from files" : "從檔案導入",
    "Importing is disabled because there are no address books available" : "已停用導入，因為沒有可用的通訊錄",
    "Choose a vCard file to import" : "選取要導入的 vCard 檔案",
    "Add new address book" : "添加新通訊錄",
    "An error occurred, unable to create the address book" : "發生錯誤，無法建立通訊錄",
    "First name" : "名",
    "Last name" : "姓",
    "Phonetic first name" : "語音名",
    "Phonetic last name" : "語音姓",
    "Display name" : "顯示名稱",
    "Last modified" : "上次修改",
    "Sort by {sorting}" : "按 {sorting} 排序",
    "Manages" : "管理",
    "Oversees" : "監督",
    "An error happened during the config change" : "配置更改期間發生錯誤",
    "Password protection" : "密碼保護",
    "Enforce password protection on files shared to this circle" : "對分享到此圈子的檔案實施密碼保護",
    "Use a unique password for all shares to this circle" : "對此圈子的所有分享使用獨一無二的密碼",
    "Unique password …" : "獨一無二的密碼 ...",
    "Save" : "保存",
    "Change unique password" : "更改獨一無二的密碼",
    "Failed to save password. Please try again later." : "保存密碼失敗。請稍後再試。",
    "Circle name" : "社交圈子名稱",
    "Circle owned by {owner}" : "{owner} 擁有的社交圈子",
    "Request to join" : "請求加入",
    "Description" : "描述",
    "There is no description for this circle" : "此社交圈子沒有任何描述",
    "Enter a description for the circle" : "輸入社交圈子的描述",
    "An error happened during description sync" : "描述同步期間發生錯誤",
    "An error happened during name sync" : "名稱同步期間發生錯誤",
    "Add more info" : "添加更多資料",
    "More fields" : "更多欄位",
    "Crop contact photo" : "裁剪聯絡人照片",
    "Cancel" : "取消",
    "Upload a new picture" : "上傳一張新的圖片",
    "Choose from Files" : "從檔案選取",
    "Get from " : "取自",
    "Download picture" : "下載圖片",
    "Delete picture" : "刪除圖片",
    "Please select a valid format" : "請選擇有效的格式",
    "Invalid image" : "圖像無效",
    "Error cropping picture" : "裁剪圖片時出錯",
    "Pick an avatar" : "選擇一個虛擬化身大頭照",
    "Error while processing the picture." : "處理相片時錯誤。",
    "Avatar downloaded from social network" : "從社群網路下載虛擬化身大頭照",
    "Avatar already up to date" : "虛擬化身大頭照已是最新",
    "Avatar download failed" : "虛擬化身大頭照下載失敗",
    "No contact selected" : "未選擇聯絡人",
    "Select a contact on the list to begin" : "在列表中選擇一個聯絡人以開始",
    "Name" : "姓名",
    "Title" : "職銜",
    "Company" : "公司名稱",
    "This contact was broken and received a fix. Please review the content and click here to save it." : "此聯絡人的資料有問題，已修復。請審閱內容並點擊此處以儲存。",
    "Edit" : "編輯",
    "Clone contact" : "複製聯絡人",
    "Generate QR Code" : "生成 QR Code",
    "Contact vCard as QR code" : "QR Code 形式的聯絡人 vCard",
    "Pick an address book" : "選取一個通訊錄",
    "Select address book" : "選擇通訊錄",
    "Go to talk conversation" : "前往對話",
    "View profile" : "檢視個人檔案",
    "This contact is in read-only mode. You do not have permission to edit this contact." : "此聯絡人處於唯讀模式。您無權編輯此聯絡人。",
    "The contact you were trying to edit has changed. Please manually refresh the contact. Any further edits will be discarded." : "您嘗試編輯的聯絡人已變更。請手動重新整理聯絡人。任何進一步的編輯都會被丟棄。",
    "Address book" : "通訊錄",
    "Add contact to Birthday Calendar" : "將聯絡人添加至生日日曆",
    "Exclude contact from Birthday Calendar" : "從生日日曆中排除聯絡人",
    "{title} at {organization}" : "{organization} {title}",
    "Syntax error. Cannot open the contact." : "語法錯誤。無法開啟聯絡人。",
    "The contact does not exist on the server anymore." : "伺服器上不再存在該聯絡人。",
    "Unable to retrieve the contact from the server, please check your network connection." : "無法從伺服器擷取聯絡人，請檢查您的網路連線。",
    "An error occurred while trying to move the contact" : "嘗試移動聯絡人時發生錯誤",
    "An error occurred while trying to copy the contact" : "嘗試複製聯絡人時發生錯誤",
    "Unable to update contact" : "無法更新聯絡人",
    "Search contacts …" : "搜尋聯絡人…",
    "Add to {group}" : "新增至 {group]",
    "Remove {type}" : "移除 {type}",
    "Search {types}" : "搜尋 {types}",
    "Search for people to add" : "搜索要添加的人",
    "No results" : "沒有結果",
    "Add to group" : "新增至群組",
    "Add {type}" : "新增 {type}",
    "New circle name" : "新社交圈子名稱",
    "Personal circle" : "個人社交圈子",
    "This circle will only be visible to you. Other members will not be able to see or use it." : "這個圈子只有你能看到。其他成員將無法看到或使用它。",
    "Local circle" : "近端社交圈子",
    "This circle will not be shared with the other instances of the global scale" : "此社交圈子不會與全球範圍內的其他實例共享",
    "Create circle" : "創建社交圈子",
    "Loading members list …" : "正在加載成員清單 …",
    "The list of members is only visible to members of this circle" : "成員列表僅此圈子的成員可見",
    "You currently have no access to the member list" : "您目前無權存取會員清單",
    "Add members" : "添加成員",
    "Show circle details" : "顯示社交圈子細節",
    "Add to {circle}" : "添加到 {circle}",
    "Unable to get the recommendations list" : "無法獲取推薦列表",
    "Unable to get the results" : "無法得到結果",
    "Some members could not be added" : "部分成員無法添加",
    "There was an issue adding members to the circle" : "將成員添加到社交圈子時出現問題",
    "Accept membership request" : "接受會員申請",
    "Reject membership request" : "拒絕會員申請",
    "Manage level" : "管理程度",
    "Remove member" : "移除成員",
    "Pending" : "待定的",
    "Promote as sole owner" : "晉升作為唯一所有者",
    "Promote to {level}" : "晉升到 {level}",
    "Demote to {level}" : "降級到 {level}",
    "Could not delete the member {displayName}" : "不能刪除成員 {displayName}",
    "Could not change the member level to {level}" : "無法將成員級別更改為 {level}",
    "Could not accept membership request" : "無法接受成為成員的申請",
    "Chart" : "圖表",
    "Select chart …" : "選擇圖表 ...",
    "Select type" : "選擇類型",
    "Select Date" : "選擇日期",
    "Add contact in group" : "新增聯絡人到群組",
    "none" : "無",
    "Select option" : "選擇選項",
    "Add property of this type" : "添加此類型的屬性",
    "New contact" : "新聯絡人",
    "Unable to create the contact." : "無法建立聯絡人",
    "Contact not found" : "找不到聯絡人",
    "Group {group} not found" : "找不到群組 {group}",
    "Close" : "關閉",
    "_{success} contact added to {name}_::_{success} contacts added to {name}_" : ["{success} 個聯絡人已新增至 {name}"],
    "_Adding {success} contact to {name}_::_Adding {success} contacts to {name}_" : ["已新增 {success} 個聯絡人至 {name}"],
    "_{count} error_::_{count} errors_" : ["{count} 個錯誤"],
    "_Importing %n contact into {addressbook}_::_Importing %n contacts into {addressbook}_" : ["正在導入 %n 個聯絡人至 {addressbook}"],
    "_Done importing %n contact into {addressbook}_::_Done importing %n contacts into {addressbook}_" : ["完成導入 %n 個聯絡人至 {addressbook}"],
    "Import" : "導入",
    "Could not copy" : "無法複製",
    "Join circle" : "加入社交圈子",
    "You are about to leave {circle}.\nAre you sure?" : "您即將離開 {circle}。\n你確定嗎？",
    "Please confirm circle leave" : "請確認您要離開此社交圈子",
    "Could not leave the circle {displayName}" : "不能退出社交圈子 {displayName}",
    "Unable to join the circle" : "無法加入社交圈子",
    "You are about to delete {circle}.\nAre you sure?" : "您即將刪除 {circle}。\n你確定嗎？",
    "Please confirm circle deletion" : "請確認社交圈子刪除",
    "Unable to delete the circle" : "無法刪除社交圈子",
    "Link copied to the clipboard" : "已複製連結至剪貼板",
    "Could not copy link to the clipboard." : "無法複製連結至剪貼板",
    "Not grouped" : "未歸類",
    "Recently contacted" : "最近聯絡",
    "Organization chart" : "機構圖表",
    "Circles are groups of people that you can create yourself and with whom you can share data. They can be made up of other accounts or groups of accounts of the Nextcloud instance, but also of contacts from your address book or even external people by simply entering their e-mail addresses." : "小圈圈是您可以自行建立並與他們分享資料的一群人。其可以由 Nextcloud 站台的其他帳號或帳號群組所組成，但也可以由您通訊錄中的聯絡人組成，甚至可以透過輸入電子郵件地址來組成外部人員。",
    "Circle" : "社交圈子",
    "User" : "用戶",
    "Group" : "群組",
    "Email" : "電郵地址",
    "Contact" : "聯絡人",
    "Member" : "成員",
    "Moderator" : "主持人",
    "Admin" : "管理員",
    "Owner" : "擁有者",
    "Invites" : "邀請",
    "Anyone can request membership" : "任何人都可以申請加入",
    "Members need to accept invitation" : "會員需要接受邀請",
    "Memberships must be confirmed/accepted by a Moderator (requires Open)" : "會員資格必須由版主確認/接受（需要開放）",
    "Members can also invite" : "會員也可以邀請",
    "Visibility" : "可見性",
    "Visible to everyone" : "所有人都看得到",
    "Circle membership" : "社交圈子會員",
    "Prevent circle from being a member of another circle" : "防止社交圈子成為另一個圈子的成員",
    "Users" : "用戶",
    "Email addresses" : "電郵地址",
    "Detailed name" : "詳細名稱",
    "Additional names" : "別名/中間名",
    "Prefix" : "前綴",
    "Suffix" : "後綴",
    "Nickname" : "暱稱",
    "Notes" : "備忘",
    "Website" : "網站",
    "Location" : "地點",
    "Federated Cloud ID" : "雲端聯邦 ID",
    "Home" : "家",
    "Work" : "業務",
    "Other" : "其他",
    "Address" : "地址",
    "Post office box" : "郵政信箱",
    "Extended address" : "擴展地址",
    "City" : "城市",
    "State or province" : "州或省",
    "Postal code" : "郵遞區號",
    "Country" : "國家",
    "Birthday" : "生日",
    "Anniversary" : "週年",
    "Date of death" : "卒日",
    "Instant messaging" : "即時通訊",
    "Phone" : "電話",
    "Mobile" : "手提電話",
    "Work mobile" : "手提電話（業務）",
    "Home mobile" : "手提電話（家）",
    "Fax" : "傳真",
    "Fax home" : "傳真（家）",
    "Fax work" : "傳真（業務）",
    "Pager" : "傳呼機",
    "Voice" : "語音",
    "Car" : "車子",
    "Work pager" : "傳呼機（業務）",
    "Manager" : "上司",
    "Social network" : "社交網絡",
    "Relationship to you" : "與您的關係",
    "Spouse" : "配偶",
    "Child" : "孩子 ",
    "Mother" : "母親",
    "Father" : "父親",
    "Parent" : "父母",
    "Brother" : "兄弟",
    "Sister" : "姊妹",
    "Relative" : "親屬",
    "Friend" : "朋友",
    "Colleague" : "同事",
    "Assistant" : "助理",
    "Related contacts" : "相關聯絡人",
    "Agent" : "代理人",
    "Emergency" : "緊急",
    "Co-worker" : "同事",
    "Gender" : "性別",
    "Female" : "女性",
    "Male" : "男性",
    "None" : "無",
    "Unknown" : "不詳",
    "Time zone" : "時區",
    "Spoken languages" : "會說的語言",
    "_{failed} contact failed to be read_::_{failed} contacts failed to be read_" : ["{failed} 個聯絡人讀取失敗"],
    "An error has occurred in circle(s). Check the console for more details." : "圈子中出現錯誤。 請查看控制台以獲取更多詳細資訊。",
    "Unable to create circle {circleName}" : "無法創建社交圈子 {circleName}",
    "Unable to delete circle {circleId}" : "無法刪除社交圈子 {circleId}",
    "Unable to delete contact" : "無法刪除聯絡人"
},
"nplurals=1; plural=0;");
