OC.L10N.register(
    "contacts",
    {
    "Details" : "Detaljer",
    "All contacts" : "Alle kontakter",
    "Contacts" : "Kontakter",
    "A contacts app for Nextcloud" : "En kontakt-app til Nextcloud",
    "The Nextcloud contacts app is a user interface for Nextcloud's CardDAV server. Easily sync contacts from various devices with your Nextcloud and edit them online.\n\n* 🚀 **Integration with other Nextcloud apps!** Currently Mail and Calendar – more to come.\n* 🎉 **Never forget a birthday!** You can sync birthdays and other recurring events with your Nextcloud Calendar.\n* 👥 **Sharing of Adressbooks!** You want to share your contacts with your friends or coworkers? No problem!\n* 🙈 **We’re not reinventing the wheel!** Based on the great and open SabreDAV library." : "Nextcloud kontakt app-en er en brugerflade til Nextclouds CardDAV server. Synkroniser let kontakter fra forskellige enheder med din Nextcloud og rediger dem online.\n\n* 🚀 **Integreret med andre Nextcloud apps!** For nuværende Mail og kalender - og flere på vej.\n* 🎉 **Glem aldrig en fødselsdag!** Du kan synkornisere fødselsdage og andre tilbagevendende begivenheder med din Nextcloud kalender.\n* 👥 **Deling af adressebøger!** Vil du dele dine kontakter med dine venner og kolleger? Ikke noget problem!\n* 🙈 **Vi er ikke i gang med at genopfinde hjulet!** Baseret på det alle tiders bibliotek SabreDAV.",
    "Copy to full name" : "Kopier til fuldt navn",
    "Omit year" : "Udelad år",
    "Allow updating avatars from social media" : "Tillad opdatering af avatarer fra sociale medier",
    "Please select a circle" : "Vælg venligst en cirkel",
    "Loading circle …" : "Indlæser cirkel...",
    "Your request to join this circle is pending approval" : "Din anmodning om at deltage i denne cirkel afventer godkendelse",
    "You are not a member of {circle}" : "Du er ikke medlem af {circle}",
    "There was an error fetching the member list" : "Der opstod en fejl under hentning af medlemslisten",
    "Loading contacts …" : "Henter kontakter …",
    "There are no contacts yet" : "Der er ingen kontakter endnu",
    "Create contact" : "Opret kontakt",
    "There are no contacts in this group" : "Der er ingen kontakter i denne gruppe",
    "Create contacts" : "Opret kontakter",
    "Add contacts" : "Tilføj kontakter",
    "Loading …" : "Indlæser…",
    "Add member" : "Tilføj medlem",
    "Leave circle" : "Forlad cirkel",
    "Delete circle" : "Slet cirkel",
    "Contacts settings" : "Kontaktindstillinger",
    "General settings" : "Generelle indstillinger",
    "Update avatars from social media" : "Opdater avatarer fra sociale medier",
    "(refreshed once per week)" : "(opfriskes en gang om ugen)",
    "Address books" : "Adressebøger",
    "Export" : "Eksportér",
    "Send email" : "Send e-mail",
    "Send email as BCC" : "Send e-mail som BCC",
    "Contact groups" : "Kontaktgrupper",
    "Create a new contact group" : "Opret en ny kontaktgruppe",
    "Contact group name" : "Navn på kontaktgruppe",
    "Circles" : "Cirkler",
    "Create a new circle" : "Opret en ny cirkel",
    "Show all groups" : "Vis alle grupper",
    "Collapse groups" : "Skjul grupper",
    "Show all circles" : "Vis alle cirkler",
    "Collapse circles" : "Skjul cirkler",
    "This group already exists" : "Denne gruppe eksisterer allerede",
    "This circle already exists" : "Denne cirkel eksisterer allerede",
    "An error happened during the creation of the circle" : "Der opstod en fejl under oprettelsen af cirklen",
    "{addressbookname} (Disabled)" : "{addressbookname} (Deaktiveret)",
    "Download" : "Download",
    "Show" : "Vis",
    "Rename" : "Omdøb",
    "Delete" : "Slet",
    "Copied" : "opieret",
    "Cannot copy" : "Kan ikke kopiere",
    "Copy link" : "Kopier link",
    "Toggling of address book was not successful" : "Skift af adressebog lykkedes ikke",
    "This will delete the address book and every contacts within it" : "Dette vil slette adressebogen og alle kontakter i den",
    "Delete {addressbook}?" : "Vil du slette {adressebog}?",
    "Deletion of address book was not successful." : "Sletning af adressebog lykkedes ikke.",
    "Renaming of address book was not successful." : "Omdøbning af adressebog lykkedes ikke.",
    "_%n contact_::_%n contacts_" : ["%n kontaktperson","%n kontaktpersoner"],
    "_%n group_::_%n groups_" : ["%n gruppe","%n grupper"],
    "_Shared with {num} entity_::_Shared with {num} entities_" : ["Delt med {num} element","Delt med {num} elementer"],
    "Share with users or groups" : "Del med brugere eller grupper",
    "Share with users" : "Del med brugere",
    "No users or groups" : "Ingen brugere eller grupper",
    "can edit" : "kan redigere",
    "Unable to delete the share" : "Delingen kunne ikke slettes",
    "Unable to change permissions" : "Kan ikke ændre tilladelser",
    "Import contacts" : "Importer kontakter",
    "Import into the {addressbookName} address book" : "Importer til adressebogen {addressbookName}",
    "Select local file" : "Vælg lokal fil",
    "Import from files" : "Importer fra filer",
    "Importing is disabled because there are no address books available" : "Indlæsning er deaktiveret da der ikke er nogen adressebog tilgængelig",
    "Choose a vCard file to import" : "Vælg en vCard fil at importere",
    "Add new address book" : "Tilføj ny adressebog",
    "An error occurred, unable to create the address book" : "Der opstod en fejl, og adressebogen kunne ikke oprettes",
    "First name" : "Fornavn",
    "Last name" : "Efternavn",
    "Phonetic first name" : "Fonetisk fornavn",
    "Phonetic last name" : "Fonetisk efternavn",
    "Display name" : "Vist navn",
    "Last modified" : "Sidst ændret",
    "Sort by {sorting}" : "Sorter efter {sorting}",
    "Manages" : "Leder",
    "Oversees" : "Fører tilsyn",
    "An error happened during the config change" : "Der opstod en fejl under konfigurationsændringen",
    "Password protection" : "Adgangskodebeskyttelse",
    "Enforce password protection on files shared to this circle" : "Håndhæv adgangskodebeskyttelse på filer, der deles med denne cirkel",
    "Use a unique password for all shares to this circle" : "Brug en unik adgangskode til alle delinger til denne cirkel",
    "Unique password …" : "Unik adgangskode …",
    "Save" : "Gem",
    "Change unique password" : "Skift unik adgangskode",
    "Failed to save password. Please try again later." : "Adgangskoden kunne ikke gemmes. Prøv igen senere.",
    "Circle name" : "Cirkelnavn",
    "Circle owned by {owner}" : "Cirkel ejet af {owner}",
    "Request to join" : "Anmod om at deltage",
    "Description" : "Beskrivelse",
    "There is no description for this circle" : "Der er ingen beskrivelse for denne cirkel",
    "Enter a description for the circle" : "Indtast en beskrivelse af cirklen",
    "An error happened during description sync" : "Der opstod en fejl under beskrivelsessynkronisering",
    "An error happened during name sync" : "Der opstod en fejl under navnesynkronisering",
    "Add more info" : "Tilføj flere informationer",
    "More fields" : "Flere felter",
    "Crop contact photo" : "Beskær billede",
    "Cancel" : "Annullér",
    "Upload a new picture" : "Upload et nyt billede",
    "Choose from Files" : "Vælg fra Filer",
    "Get from " : "Få fra",
    "Download picture" : "Hent billede",
    "Delete picture" : "Slet billede",
    "Please select a valid format" : "Vælg venligst et gyldigt format",
    "Invalid image" : "Ugyldigt billede",
    "Error cropping picture" : "Fejl ved beskæring af billede",
    "Pick an avatar" : "Vælg en avatar",
    "Error while processing the picture." : "Fejl under behandling af billedet.",
    "Avatar downloaded from social network" : "Avatar downloadet fra sociale netværk",
    "Avatar already up to date" : "Avatar er allerede opdateret",
    "Avatar download failed" : "Avatar-download mislykkedes",
    "No contact selected" : "Ingen kontakt valgt",
    "Select a contact on the list to begin" : "Vælg en kontakt fra listen for at begynde",
    "Name" : "Navn",
    "Title" : "Titel",
    "Company" : "Firma",
    "This contact was broken and received a fix. Please review the content and click here to save it." : "Der var en fejl i denne kontakt, som er blevet rettet . Gennemgå indholdet, og klik her for at gemme det.",
    "Edit" : "Redigér",
    "Clone contact" : "Klon kontakt",
    "Generate QR Code" : "Generer QR-kode",
    "Contact vCard as QR code" : "Kontakt vCard som QR-kode",
    "Pick an address book" : "Vælg en adressebog",
    "Select address book" : "Vælg adressebog",
    "Go to talk conversation" : "Gå til Snak-samtale",
    "View profile" : "Vis profil",
    "This contact is in read-only mode. You do not have permission to edit this contact." : "Kontakten er skrivebeskyttet. Du har ikke tilladelse til at redigere denne kontakt.",
    "The contact you were trying to edit has changed. Please manually refresh the contact. Any further edits will be discarded." : "Kontakten du er i gang med at redigere er ændret. Venligst genopfrisk kontaktvisningen manuelt. Alle videre modifikationer vil blive tabt.",
    "Address book" : "Adressebog",
    "Add contact to Birthday Calendar" : "Tilføj kontakt til fødselsdagskalender",
    "Exclude contact from Birthday Calendar" : "Udelad kontakt fra fødselsdagskalender",
    "{title} at {organization}" : "{title} hos {organization}",
    "Syntax error. Cannot open the contact." : "Syntaks fejl. Kan ikke åbne kontakt.",
    "The contact does not exist on the server anymore." : "Kontakten findes ikke længere på serveren.",
    "Unable to retrieve the contact from the server, please check your network connection." : "Kan ikke hente kontakten fra serveren. Tjek venligst din netværksforbindelse.",
    "An error occurred while trying to move the contact" : "Der opstod en fejl under forsøget på at flytte kontakten",
    "An error occurred while trying to copy the contact" : "Der opstod en fejl under forsøget på at kopiere kontakten",
    "Unable to update contact" : "Kan ikke opdaterer kontakten",
    "Search contacts …" : "Søg efter brugere ...",
    "Add to {group}" : "Føj til {gruppe}",
    "Remove {type}" : "Fjern {type}",
    "Search {types}" : "Søg efter {typer}",
    "Search for people to add" : "Søg efter personer at tilføje",
    "No results" : "Ingen resultater",
    "Add to group" : "Tilføj til gruppe",
    "Add {type}" : "Tilføj {type}",
    "New circle name" : "Nyt cirkelnavn",
    "Personal circle" : "Personlig cirkel",
    "This circle will only be visible to you. Other members will not be able to see or use it." : "Denne cirkel vil kun være synlig for dig. Andre medlemmer vil ikke kunne se eller bruge det.",
    "Local circle" : "Lokal cirkel",
    "This circle will not be shared with the other instances of the global scale" : "Denne cirkel vil ikke blive delt med de andre forekomster af den globale skala",
    "Create circle" : "Opret cirkel",
    "Loading members list …" : "Indlæser medlemsliste...",
    "The list of members is only visible to members of this circle" : "Listen over medlemmer er kun synlig for medlemmer af denne cirkel",
    "You currently have no access to the member list" : "Du har i øjeblikket ingen adgang til medlemslisten",
    "Add members" : "Tilføj medlemmer",
    "Show circle details" : "Vis cirkeldetaljer",
    "Add to {circle}" : "Føj til {cirkel}",
    "Unable to get the recommendations list" : "Kan ikke hente listen med anbefalinger",
    "Unable to get the results" : "Ude af stand til at få resultaterne",
    "Some members could not be added" : "Nogle medlemmer kunne ikke tilføjes",
    "There was an issue adding members to the circle" : "Der var et problem med at tilføje medlemmer til cirklen",
    "Accept membership request" : "Accepter anmodning om medlemskab",
    "Reject membership request" : "Afvis anmodning om medlemskab",
    "Manage level" : "Administrer niveau",
    "Remove member" : "Fjern medlem",
    "Pending" : "Afventer",
    "Promote as sole owner" : "Fremhæv som eneejer",
    "Promote to {level}" : "Forfrem til {level}",
    "Demote to {level}" : "Nedryk til {level}",
    "Could not delete the member {displayName}" : "Kunne ikke slette medlemmet {displayName}",
    "Could not change the member level to {level}" : "Kunne ikke ændre medlemsniveauet til {level}",
    "Could not accept membership request" : "Kunne ikke acceptere medlemsanmodning",
    "Chart" : "Diagram",
    "Select chart …" : "Vælg diagram ...",
    "Select type" : "Vælg type",
    "Select Date" : "Vælg dato",
    "Add contact in group" : "Føj kontakt til gruppe",
    "none" : "ingen",
    "Select option" : "Vælg indstilling",
    "Add property of this type" : "Tilføj element af denne type",
    "New contact" : "Ny kontakt",
    "Unable to create the contact." : "Kontakten kunne ikke oprettes.",
    "Contact not found" : "Kontakten kunne ikke findes",
    "Group {group} not found" : "Gruppen {gruppe} blev ikke fundet",
    "Close" : "Luk",
    "_{success} contact added to {name}_::_{success} contacts added to {name}_" : ["{success} kontakt føjet til {name}","{success} kontakter føjet til {name}"],
    "_Adding {success} contact to {name}_::_Adding {success} contacts to {name}_" : ["Føjer {success} kontakt til {name}","Tilføjer {success} kontakter til {name}"],
    "_{count} error_::_{count} errors_" : ["{count} fejl","{count} fejl"],
    "_Importing %n contact into {addressbook}_::_Importing %n contacts into {addressbook}_" : ["Importer %n kontakt til {adressebog}","Importerer %n kontakter til {adressebog}"],
    "_Done importing %n contact into {addressbook}_::_Done importing %n contacts into {addressbook}_" : ["Færdig med at importere %n kontakt til {adressebog}","Færdig med at importere %n kontakter til {adressebog}"],
    "Import" : "Importér",
    "Could not copy" : "Kunne ikke kopiere",
    "Join circle" : "Deltag i cirkel",
    "You are about to leave {circle}.\nAre you sure?" : "Du er ved at forlade {circle}.\nEr du sikker?",
    "Please confirm circle leave" : "Bekræft venligst cirkelforlad",
    "Could not leave the circle {displayName}" : "Kunne ikke forlade cirklen {displayName}",
    "Unable to join the circle" : "Kan ikke deltage i cirklen",
    "You are about to delete {circle}.\nAre you sure?" : "Du er ved at slette {circle}.\nEr du sikker?",
    "Please confirm circle deletion" : "Bekræft sletning af cirkel",
    "Unable to delete the circle" : "Cirklen kunne ikke slettes",
    "Link copied to the clipboard" : "Linket er kopieret til udklipsholderen",
    "Could not copy link to the clipboard." : "Kunne ikke kopiere linket til udklipsholderen.",
    "Not grouped" : "Ikke i gruppe",
    "Recently contacted" : "For nylig kontaktet",
    "Organization chart" : "Organisationsdiagram",
    "Circle" : "Cirkel",
    "User" : "Bruger",
    "Group" : "Gruppe",
    "Email" : "E-mail",
    "Contact" : "takt",
    "Member" : "Medlem",
    "Moderator" : "Moderator",
    "Admin" : "Admin",
    "Owner" : "Ejer",
    "Invites" : "Inviterede",
    "Anyone can request membership" : "Alle kan anmode om medlemskab",
    "Members need to accept invitation" : "Medlemmer skal acceptere invitationen",
    "Memberships must be confirmed/accepted by a Moderator (requires Open)" : "Medlemskaber skal bekræftes/accepteres af en moderator (kræver åbent)",
    "Members can also invite" : "Medlemmer kan også invitere",
    "Visibility" : "Synlighed",
    "Visible to everyone" : "Synlig for alle",
    "Circle membership" : "Cirkelmedlemskab",
    "Prevent circle from being a member of another circle" : "Forhindre cirkel i at være medlem af en anden cirkel",
    "Users" : "Brugere",
    "Email addresses" : "Email adresse",
    "Detailed name" : "Detaljeret navn",
    "Additional names" : "Mellemnavne",
    "Prefix" : "Præfiks",
    "Suffix" : "Suffiks",
    "Nickname" : "Kaldenavn",
    "Notes" : "Noter",
    "Website" : "Hjemmeside",
    "Location" : "Sted",
    "Federated Cloud ID" : "Federated Cloud ID",
    "Home" : "Hjemme",
    "Work" : "Arbejde",
    "Other" : "Andet",
    "Address" : "Adresse",
    "Post office box" : "Postboks",
    "Extended address" : "Udvidet adresse",
    "City" : "By",
    "State or province" : "Stat eller provins",
    "Postal code" : "Postnummer",
    "Country" : "Land",
    "Birthday" : "Fødselsdag",
    "Anniversary" : "Årsdag",
    "Date of death" : "Dødsdato",
    "Instant messaging" : "Instant Messaging",
    "Phone" : "Telefon",
    "Mobile" : "Mobil",
    "Work mobile" : "Arbdejsmobil",
    "Home mobile" : "Hjemmemobil",
    "Fax" : "Fax",
    "Fax home" : "Fax hjemme",
    "Fax work" : "Fax arbejde",
    "Pager" : "Personsøger",
    "Voice" : "Telefonsvarer",
    "Car" : "Bil",
    "Work pager" : "Arbejdespager ",
    "Manager" : "Leder",
    "Social network" : "Socialt netværk",
    "Relationship to you" : "Forhold til dig",
    "Spouse" : "Ægtefælle",
    "Child" : "Barn",
    "Mother" : "Mor",
    "Father" : "Far",
    "Parent" : "Forælder",
    "Brother" : "Bror",
    "Sister" : "Søster",
    "Relative" : "Slægtning",
    "Friend" : "Ven",
    "Colleague" : "Kollega",
    "Assistant" : "Assistent",
    "Related contacts" : "Relaterede kontakter",
    "Agent" : "Agent",
    "Emergency" : "Nødstilfælde",
    "Co-worker" : "Kollega",
    "Gender" : "Køn",
    "Female" : "Kvinde",
    "Male" : "Mand",
    "None" : "Ingen",
    "Unknown" : "Ukendt",
    "Time zone" : "Tidszone",
    "Spoken languages" : "Talte sprog",
    "_{failed} contact failed to be read_::_{failed} contacts failed to be read_" : ["{failed} kontakt kunne ikke indlæses","{failed} kontakter kunne ikke indlæses"],
    "Unable to create circle {circleName}" : "Kunne ikke oprette kredsen {circleName}",
    "Unable to delete circle {circleId}" : "Cirklen {circleId} kunne ikke slettes",
    "Unable to delete contact" : "Kan ikke slette kontakten"
},
"nplurals=2; plural=(n != 1);");
